%auto-ignore
(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[         0,          0]
NotebookDataLength[  25319552,     637731]
NotebookOptionsPosition[  25200508,     634247]
NotebookOutlinePosition[  25200867,     634263]
CellTagsIndexPosition[  25200824,     634260]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"<<", "HighEnergyPhysics`FeynCalc`"}]], "Input"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"if", " ", "FeynCalc", " ", "is", " ", "not", " ", "installed"}], 
   ",", " ", 
   RowBox[{
   "the", " ", "following", " ", "command", " ", "will", " ", "try", " ", 
    "to", " ", "install", " ", "it", " ", 
    RowBox[{"automatically", ":", " ", "\[IndentingNewLine]", 
     RowBox[{
     "Import", "[", "\"\<http://www.feyncalc.org/install.m\>\"", "]"}]}]}]}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.658725033420209*^9, 3.658725069109188*^9}}],

Cell["\<\
OUTLINE:

Based on Olaf Hohm\[CloseCurlyQuote]s factorization paper in DFT, this \
notebook is to compute scattering amplitudes at tree-level with up to 5 legs. 

The sections are as follows:
- Conventions & abbreviations
- Expanding DFT/Siegel\[CloseCurlyQuote]s Lagrangian
- DFT Vertices
- \[OpenCurlyDoubleQuote]amplitudes\[CloseCurlyDoubleQuote] with \[CurlyPhi]\
\[LineSeparator]- 3 e scattering amplitude
- 4 e scattering amplitude\[LineSeparator]- 5 e scattering amplitude
- Agreement with KLT
- BCFW
- Investigating the \[CurlyPhi] structure
- Playground (q-light-cone gauge etc.)\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QLSH6+KrINpgReJ1EP3gmFSEMJC+fiA2AUTnMhrkbAbSSSrba0C02oQjzGL3
Xzkem7yIFUTXPbwoC6KLPrLLgeg782fli7575SgbvqkERAtFcV4G0WFXPcD0
otepjOJAWk16KROI9km8HiUFpLW268SC6DvWTd7uQNqDz8oHRNsmKqinfnzl
yGTqAqYjPvTa6PwAutNB3RFE/3Db96DM6bWjScGyRyAaANr9mf4=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell["Conventions & abbreviations", "Section",
 CellChangeTimes->{{3.5916907485189943`*^9, 3.591690811930585*^9}, {
  3.604648748150077*^9, 3.604648752012698*^9}, {3.6144881339050913`*^9, 
  3.6144881371517344`*^9}}],

Cell[TextData[{
 "Unlike in previous computations the metric has to be \
\[OpenCurlyDoubleQuote]mostly plus\[CloseCurlyDoubleQuote] (-+...+) because \
the Einstein-Hilbert action is given in this convention (and the Ricci scalar \
is not inert under metrtric sign flips).\n\nMandelstam variables:\ns = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["k", "1"]}], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "2"], ")"}], "2"], TraditionalForm]]],
 " =  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["k", "3"]}], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "4"], ")"}], "2"], TraditionalForm]]],
 "\nt = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["k", "1"]}], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "3"], ")"}], "2"], TraditionalForm]]],
 " =  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["k", "2"]}], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "4"], ")"}], "2"], TraditionalForm]]],
 "\nu = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["k", "1"]}], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "4"], ")"}], "2"], TraditionalForm]]],
 " =  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    SubscriptBox["k", "2"]}], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{
     SubscriptBox["k", "3"], ")"}], "2"], TraditionalForm]]],
 " \n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "ij"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["k", "i"], "+", 
      SubscriptBox["k", "j"]}], ")"}], "2"], TraditionalForm]]],
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "ijk"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["k", "i"], "+", 
      SubscriptBox["k", "j"], "+", 
      SubscriptBox["k", "k"]}], ")"}], "2"], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.6044041482973137`*^9, 3.604404157841824*^9}, {3.604648554310869*^9, 
   3.6046486678278627`*^9}, {3.604648710643353*^9, 3.60464871601261*^9}, {
   3.6101731816627207`*^9, 3.610173232803544*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell["Some useful abbreviations", "Subsection",
 CellChangeTimes->{{3.5916907485189943`*^9, 3.591690811930585*^9}, {
  3.604652969836174*^9, 3.6046529700744467`*^9}}],

Cell["Define external momenta labeled by i", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k", "[", 
   RowBox[{"i_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"FVD", "[", 
   RowBox[{
    SubscriptBox["k", "i"], ",", "m"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.586681430982521*^9, 3.586681442243847*^9}, {
  3.5866814800175457`*^9, 3.586681576268126*^9}, {3.586681742197968*^9, 
  3.586681756711389*^9}, {3.5882996240254*^9, 3.5882996283993196`*^9}}],

Cell["The metric:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
   3.588395627459991*^9, 3.588395637607997*^9}, {3.591690880276667*^9, 
   3.591690903386566*^9}, {3.591690945467572*^9, 3.591690952227316*^9}, {
   3.6018824857962017`*^9, 3.6018824867679996`*^9}, 3.6018911211603527`*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"d", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"MTD", "[", 
   RowBox[{"m", ",", "n"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5882997130589533`*^9, 3.588299720433675*^9}}],

Cell["Define external polarizations labeled by i for later use.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601875113482526*^9, 
  3.601875115048492*^9}, {3.601875989495708*^9, 3.601875992596834*^9}, {
  3.601882456620056*^9, 3.6018824604123287`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi", "[", 
   RowBox[{"i_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"FVD", "[", 
   RowBox[{
    SubscriptBox["\[Xi]", "i"], ",", "m"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.601875119135034*^9, 3.601875143310013*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xibar", "[", 
   RowBox[{"i_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"FVD", "[", 
   RowBox[{
    SubscriptBox["\[Eta]", "i"], ",", "m"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6018751497113743`*^9, 3.601875157351359*^9}, {
  3.60187527277535*^9, 3.601875276986508*^9}}],

Cell["A filter function:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601875113482526*^9, 
  3.601875115048492*^9}, {3.601875989495708*^9, 3.601875992596834*^9}, {
  3.601882456620056*^9, 3.6018824604123287`*^9}, {3.604652979789229*^9, 
  3.604652988154709*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Filter", "[", 
   RowBox[{"haystack_", ",", "needle_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"haystack", "-", 
    RowBox[{"(", 
     RowBox[{"haystack", "/.", 
      RowBox[{"{", 
       RowBox[{"needle", " ", "\[Rule]", " ", 
        RowBox[{"AAAAAAAA", " ", "needle"}]}], "}"}]}], ")"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{"AAAAAAAA", "\[Rule]", "0"}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.601977660152355*^9, 3.6019778314917717`*^9}, {
  3.60224554611765*^9, 3.6022455513556843`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{
   RowBox[{"Filter", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", "b"}], "+", 
      RowBox[{"c", " ", "d"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", " ", "b"}], ")"}], "e"}]}], ",", 
     RowBox[{"a", " ", "b"}]}], "]"}], ",", "e"}], "]"}]], "Input",
 CellChangeTimes->{{3.601977904006403*^9, 3.601977960582699*^9}, {
  3.602245536727963*^9, 3.6022455400319633`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"a", " ", "b", " ", "e"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6022258590902987`*^9, 3.602227129722578*^9, 3.602227271646722*^9, 
   3.602227480757914*^9, 3.602235712148098*^9, 3.602240491574588*^9, {
   3.6022455376357813`*^9, 3.602245554595317*^9}, 3.6024998520588503`*^9, 
   3.602832033451561*^9, 3.602832432982106*^9, 3.603088212154607*^9, 
   3.603094350060532*^9, 3.6040371260776987`*^9, 3.604045008894672*^9, 
   3.6040527265997763`*^9, 3.60405593276659*^9, 3.604056086028367*^9, 
   3.604397680628937*^9, 3.604397904111685*^9, 3.604398291364402*^9, 
   3.604398539804432*^9, 3.604398630072649*^9, 3.6044010301012383`*^9, 
   3.604402016850575*^9, 3.604402155378385*^9, 3.6044033632261553`*^9, 
   3.604405766299317*^9, 3.6046493021766253`*^9, 3.604653203181828*^9, 
   3.604821173744508*^9, 3.604821356517527*^9, 3.6048270552860622`*^9, 
   3.604901611514881*^9, 3.604997491065146*^9, 3.604997820794518*^9, 
   3.604997980436447*^9, 3.6049982435028553`*^9, 3.604998661746059*^9, 
   3.604999006732142*^9, 3.604999549710313*^9, 3.605322199247711*^9, 
   3.60532923213171*^9, 3.605344863001315*^9, 3.605499345050621*^9, 
   3.6054997440650806`*^9, 3.605500253906273*^9, 3.605500963724526*^9, 
   3.6055175101600657`*^9, 3.605518571349205*^9, 3.6060196918006287`*^9, 
   3.6066244908086767`*^9, 3.60725478619541*^9, 3.6077468179098873`*^9, 
   3.6084586507720213`*^9, 3.6084610266441593`*^9, 3.608611336967705*^9, 
   3.608972227752638*^9, 3.609039042211458*^9, 3.609065493898321*^9, 
   3.609130510204907*^9, 3.6100787656766233`*^9, 3.610182993564169*^9, 
   3.610768718209736*^9, 3.61432119743351*^9, 3.614486279818879*^9, 
   3.614488575912429*^9, 3.614495166971508*^9, 3.6145005346901913`*^9, 
   3.614500756661106*^9, 3.614500898756456*^9, 3.614505624669511*^9, 
   3.614577105359508*^9, 3.614937116431259*^9, 3.615633699245777*^9, 
   3.616214552264863*^9, 3.617336061636772*^9, 3.617338181259941*^9, 
   3.617970288961788*^9, 3.618217328256578*^9, 3.619333555277143*^9, 
   3.619513093847756*^9, 3.619519211599513*^9, 3.619774923289331*^9}]
}, Open  ]],

Cell["Define external winding momenta labeled by i", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.6102602095188704`*^9, 
  3.6102602100324783`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", 
   RowBox[{"i_", ",", "m_"}], "]"}], ":=", 
  RowBox[{"FVD", "[", 
   RowBox[{
    SubscriptBox["w", "i"], ",", "m"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.610260216128437*^9, 3.61026021781726*^9}}],

Cell["\<\
For substitution rules involving momenta and metrics the following functions \
are convenient:\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.614485545788596*^9, 
  3.614485588076529*^9}, {3.614485640935101*^9, 3.614485642028902*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kc", "[", 
   RowBox[{"i_", ",", "m_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"k", "[", 
    RowBox[{"i", ",", "m"}], "]"}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.614485592718337*^9, 3.6144856295845613`*^9}, 
   3.614485659599683*^9}],

Cell[BoxData[
 FormBox[
  SubsuperscriptBox["k", "i", 
   FormBox[
    FormBox["m",
     TraditionalForm],
    TraditionalForm]], TraditionalForm]], "Output",
 CellChangeTimes->{3.614485660404788*^9, 3.614486279852158*^9, 
  3.61448857593342*^9, 3.614495166998081*^9, 3.614500534717141*^9, 
  3.61450075669597*^9, 3.614500898775886*^9, 3.6145056246815367`*^9, 
  3.614577105394433*^9, 3.614937116449082*^9, 3.615633699271083*^9, 
  3.616214552286437*^9, 3.617336061667185*^9, 3.617338181312319*^9, 
  3.6179702890061817`*^9, 3.618217328296934*^9, 3.619333555329525*^9, 
  3.619513093876494*^9, 3.6195192116300793`*^9, 3.619774923336961*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dc", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"d", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.61448565003998*^9, 3.614485691798175*^9}}],

Cell[BoxData[
 FormBox[
  SuperscriptBox["g", 
   RowBox[{"m", "n"}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.614485497286716*^9, 3.614485520556302*^9}, 
   3.614485692196684*^9, 3.614486279879141*^9, 3.6144885759515257`*^9, 
   3.614495167016694*^9, 3.6145005347422647`*^9, 3.614500756727867*^9, 
   3.614500898793385*^9, 3.614505624687708*^9, 3.614577105422842*^9, 
   3.614937116463421*^9, 3.615633699294017*^9, 3.616214552310903*^9, 
   3.617336061694879*^9, 3.6173381813493223`*^9, 3.61797028903378*^9, 
   3.618217328325088*^9, 3.6193335553693237`*^9, 3.619513093902925*^9, 
   3.619519211653613*^9, 3.6197749233774357`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kdotk", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], "=", 
  RowBox[{"Pair", "[", 
   RowBox[{
    RowBox[{"Momentum", "[", 
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "m"}], "]"}], ",", "D"}], "]"}], ",", 
    RowBox[{"Momentum", "[", 
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "n"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.614488821084836*^9, 3.614488864383553*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FormBox[
    SubscriptBox["k", "m"],
    TraditionalForm], "\[CenterDot]", 
   FormBox[
    SubscriptBox["k", "n"],
    TraditionalForm]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.614488853202311*^9, 3.61448886525661*^9}, 
   3.614495167023116*^9, 3.614500534747859*^9, 3.614500756756024*^9, 
   3.6145008988004513`*^9, 3.614505624718746*^9, 3.614577105454467*^9, 
   3.614937116477373*^9, 3.6156336993166027`*^9, 3.61621455233385*^9, 
   3.6173360617240763`*^9, 3.617338181385983*^9, 3.61797028905118*^9, 
   3.618217328356207*^9, 3.619333555408258*^9, 3.619513093930114*^9, 
   3.6195192116794367`*^9, 3.619774923409148*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Expanding Siegel's Lagrangian up to 7 fields", "Section",
 CellChangeTimes->{{3.610941495634375*^9, 3.610941522156375*^9}, 
   3.614486162653803*^9, {3.6144952367113237`*^9, 3.6144952433980627`*^9}}],

Cell[CellGroupData[{

Cell["Lagrangian", "Subsection",
 CellChangeTimes->{{3.610941644913225*^9, 3.6109416511781597`*^9}}],

Cell["\<\
Expanding the DFT Lagrangian to 7-point interactions or lower (for 8-points \
one would have to include terms to the power of 6 in the metrics!)\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
   3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
   3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
   3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
   3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, 
   3.610861943174123*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "\[Phi]"}], ")"}], "^", "2"}], 
      RowBox[{"G", "[", 
       RowBox[{"a", ",", "b"}], "]"}], 
      RowBox[{"GG", "[", 
       RowBox[{"cc", ",", "dd"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"G", "[", 
          RowBox[{"c", ",", "d"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dh", "[", 
            RowBox[{"c", ",", "a", ",", "cc"}], "]"}], "-", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"c", ",", "ee"}], "]"}], 
            RowBox[{"DDh", "[", 
             RowBox[{"ee", ",", "a", ",", "cc"}], "]"}]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Dh", "[", 
            RowBox[{"d", ",", "b", ",", "dd"}], "]"}], "-", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"d", ",", "ff"}], "]"}], 
            RowBox[{"DDh", "[", 
             RowBox[{"ff", ",", "b", ",", "dd"}], "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"G", "[", 
          RowBox[{"c", ",", "d"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Dh", "[", 
             RowBox[{"a", ",", "c", ",", "cc"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"a", ",", "ee"}], "]"}], 
            RowBox[{"DDh", "[", 
             RowBox[{"ee", ",", "c", ",", "cc"}], "]"}]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Dh", "[", 
             RowBox[{"d", ",", "b", ",", "dd"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"d", ",", "ff"}], "]"}], 
            RowBox[{"DDh", "[", 
             RowBox[{"ff", ",", "b", ",", "dd"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"GG", "[", 
          RowBox[{"aa", ",", "bb"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"DDh", "[", 
            RowBox[{"aa", ",", "a", ",", "cc"}], "]"}], "+", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"e", ",", "aa"}], "]"}], 
            RowBox[{"Dh", "[", 
             RowBox[{"e", ",", "a", ",", "cc"}], "]"}]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"DDh", "[", 
            RowBox[{"dd", ",", "b", ",", "bb"}], "]"}], "+", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"f", ",", "dd"}], "]"}], 
            RowBox[{"Dh", "[", 
             RowBox[{"f", ",", "b", ",", "bb"}], "]"}]}]}], ")"}]}]}], 
       ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Phi]"}], ")"}], 
      RowBox[{"G", "[", 
       RowBox[{"a", ",", "b"}], "]"}], 
      RowBox[{"GG", "[", 
       RowBox[{"cc", ",", "dd"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"DDh", "[", 
            RowBox[{"cc", ",", "a", ",", "dd"}], "]"}], "+", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"e", ",", "cc"}], "]"}], 
            RowBox[{"Dh", "[", 
             RowBox[{"e", ",", "a", ",", "dd"}], "]"}]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"D\[Phi]", "[", "b", "]"}], "-", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"b", ",", "ee"}], "]"}], 
            RowBox[{"DD\[Phi]", "[", "ee", "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Dh", "[", 
             RowBox[{"a", ",", "b", ",", "cc"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"a", ",", "ee"}], "]"}], 
            RowBox[{"DDh", "[", 
             RowBox[{"ee", ",", "b", ",", "cc"}], "]"}]}]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"DD\[Phi]", "[", "dd", "]"}], "+", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"e", ",", "dd"}], "]"}], 
            RowBox[{"D\[Phi]", "[", "e", "]"}]}]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"2", 
      RowBox[{"G", "[", 
       RowBox[{"a", ",", "b"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D\[Phi]", "[", "a", "]"}], "-", 
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{"a", ",", "bb"}], "]"}], 
         RowBox[{"DD\[Phi]", "[", "bb", "]"}]}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"D\[Phi]", "[", "b", "]"}], "-", 
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{"b", ",", "ee"}], "]"}], 
         RowBox[{"DD\[Phi]", "[", "ee", "]"}]}]}], ")"}]}]}], "//", 
    "Expand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.610859761832953*^9, 3.6108598541475487`*^9}, {
  3.610859885697571*^9, 3.610859943732875*^9}, {3.61086004410189*^9, 
  3.610860083365057*^9}, {3.610860310738394*^9, 3.610861142050407*^9}, {
  3.610948069102645*^9, 3.610948096374997*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "L", "]"}]], "Input",
 CellChangeTimes->{{3.6108609944148827`*^9, 3.6108609959391336`*^9}}],

Cell[BoxData[
 FormBox["56", TraditionalForm]], "Output",
 CellChangeTimes->{3.6108609962374897`*^9, 3.610861145024929*^9, 
  3.6109481748021603`*^9, 3.614415460625787*^9, 3.614486279943779*^9, 
  3.614488575979876*^9, 3.614495167058312*^9, 3.6145005347834187`*^9, 
  3.614500756807415*^9, 3.614500898839199*^9, 3.614505624761252*^9, 
  3.614577105499064*^9, 3.61493711651311*^9, 3.6156336993596373`*^9, 
  3.616214552378747*^9, 3.6173360617821903`*^9, 3.617338181440219*^9, 
  3.618217328409481*^9, 3.6193335554701777`*^9, 3.6197749234612713`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rule$metrics", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "[", 
      RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"BG", "[", 
       RowBox[{"a", ",", "b"}], "]"}], "-", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"a", ",", "ll"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"b", ",", "ll"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"a", ",", "ll"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"l", ",", "ll"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"l", ",", "gg"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"b", ",", "gg"}], "]"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"GG", "[", 
      RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"BGG", "[", 
       RowBox[{"aa", ",", "bb"}], "]"}], "-", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"i", ",", "aa"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"i", ",", "bb"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"h", "[", 
        RowBox[{"i", ",", "aa"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"i", ",", "ii"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"j", ",", "ii"}], "]"}], 
       RowBox[{"h", "[", 
        RowBox[{"j", ",", "bb"}], "]"}]}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6108615489091053`*^9, 3.610861562419289*^9}, {
  3.610948141582983*^9, 3.610948158715108*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "(", 
      RowBox[{"a_", ",", "b_"}], ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"BG", "(", 
       RowBox[{"a", ",", "b"}], ")"}], "+", 
      RowBox[{
       RowBox[{"h", "(", 
        RowBox[{"a", ",", "ll"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"b", ",", "gg"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"l", ",", "gg"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"l", ",", "ll"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"h", "(", 
        RowBox[{"a", ",", "ll"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"b", ",", "ll"}], ")"}]}]}]}], ",", 
    RowBox[{
     RowBox[{"GG", "(", 
      RowBox[{"aa_", ",", "bb_"}], ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"BGG", "(", 
       RowBox[{"aa", ",", "bb"}], ")"}], "+", 
      RowBox[{
       RowBox[{"h", "(", 
        RowBox[{"i", ",", "aa"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"j", ",", "bb"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"i", ",", "ii"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"j", ",", "ii"}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"h", "(", 
        RowBox[{"i", ",", "aa"}], ")"}], " ", 
       RowBox[{"h", "(", 
        RowBox[{"i", ",", "bb"}], ")"}]}]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.610861563351015*^9, 3.610948176689375*^9, 
  3.614415460670951*^9, 3.61448627998733*^9, 3.614488576000743*^9, 
  3.6144951670799303`*^9, 3.614500534811314*^9, 3.61450075683416*^9, 
  3.614500898860096*^9, 3.614505624793786*^9, 3.614577105533684*^9, 
  3.614937116534307*^9, 3.615633699382112*^9, 3.616214552401514*^9, 
  3.61733606181391*^9, 3.617338181478074*^9, 3.618217328444783*^9, 
  3.619333555511763*^9, 3.619774923491775*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lexpanded", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"L", "/.", "rule$metrics"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61086157265407*^9, 3.610861595890437*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "2"]}], " ", 
            RowBox[{"BG", "(", 
             RowBox[{"a", ",", "b"}], ")"}], " ", 
            RowBox[{"DDh", "(", 
             RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
            RowBox[{"DDh", "(", 
             RowBox[{"dd", ",", "b", ",", "bb"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"i", ",", "aa"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"i", ",", "cc"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"h", "(", 
              RowBox[{"i", ",", "ii"}], ")"}], "2"], " ", 
            RowBox[{"h", "(", 
             RowBox[{"j", ",", "bb"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"j", ",", "dd"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"h", "(", 
              RowBox[{"j", ",", "ii"}], ")"}], "2"], " ", 
            SuperscriptBox["\[Phi]", "2"]}], "+", 
           RowBox[{"\[LeftSkeleton]", "1695", "\[RightSkeleton]"}], "+", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"Dh", "(", 
             RowBox[{"e", ",", "a", ",", "cc"}], ")"}], " ", 
            RowBox[{"Dh", "(", 
             RowBox[{"f", ",", "b", ",", "bb"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"a", ",", "ll"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"b", ",", "gg"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"e", ",", "aa"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"f", ",", "dd"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"i", ",", "aa"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"i", ",", "bb"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"i", ",", "cc"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"i", ",", "ii"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"j", ",", "dd"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"j", ",", "ii"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"l", ",", "gg"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"l", ",", "ll"}], ")"}]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 15, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 15, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 15, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[15]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6108615753449373`*^9, 3.61086159665833*^9}, 
   3.610948179126134*^9, 3.614415461045743*^9, 3.61448628042139*^9, 
   3.6144885763423243`*^9, 3.6144951674712963`*^9, 3.614500535167451*^9, 
   3.6145007572147303`*^9, 3.6145008992375317`*^9, 3.614505625202923*^9, 
   3.6145771058960953`*^9, 3.6149371169674463`*^9, 3.615633699755673*^9, 
   3.616214552788619*^9, 3.617336062307022*^9, 3.61733818183179*^9, 
   3.6182173287978983`*^9, 3.619333555921494*^9, 3.619774923902787*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lexpanded", "]"}]], "Input",
 CellChangeTimes->{{3.610861599969425*^9, 3.610861601215085*^9}}],

Cell[BoxData[
 FormBox["1128", TraditionalForm]], "Output",
 CellChangeTimes->{3.610861601504643*^9, 3.6109481809537773`*^9, 
  3.6144154610903873`*^9, 3.614486280767261*^9, 3.6144885763643227`*^9, 
  3.6144951674899673`*^9, 3.614500535194581*^9, 3.614500757559215*^9, 
  3.614500899256487*^9, 3.614505625544952*^9, 3.6145771059376087`*^9, 
  3.6149371170028887`*^9, 3.615633699772314*^9, 3.616214552815638*^9, 
  3.617336062326662*^9, 3.6173381818710327`*^9, 3.618217328829401*^9, 
  3.6193335559963818`*^9, 3.619774923985469*^9}]
}, Open  ]],

Cell["\<\
Now project out n-point interactions for n smaller 8. 
To this end, scale all fields by \[Lambda] and expand as power series in \
\[Lambda].\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{"\[Lambda]", "=."}]], "Input",
 CellChangeTimes->{{3.61086214617585*^9, 3.610862174422414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lexpanded$scaled", "=", 
  RowBox[{"Lexpanded", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Phi]", "\[Rule]", 
      RowBox[{"\[Lambda]", " ", "\[Phi]"}]}], ",", 
     RowBox[{
      RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"D\[Phi]", "[", "a", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"DD\[Phi]", "[", "aa", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"a", ",", "aa"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Dh", "[", 
       RowBox[{"b_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"Dh", "[", 
        RowBox[{"b", ",", "a", ",", "aa"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"DDh", "[", 
       RowBox[{"bb_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
      RowBox[{"\[Lambda]", " ", 
       RowBox[{"DDh", "[", 
        RowBox[{"bb", ",", "a", ",", "aa"}], "]"}]}]}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.6108619614947233`*^9, 3.610862041242485*^9}, {
   3.6108620758195047`*^9, 3.610862118807506*^9}, 3.610862209263546*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"\[LeftSkeleton]", "1695", "\[RightSkeleton]"}], "+", 
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"BG", "(", 
             RowBox[{"a", ",", "b"}], ")"}], " ", 
            RowBox[{"D\[Phi]", "(", "a", ")"}], " ", 
            RowBox[{"D\[Phi]", "(", "b", ")"}], " ", 
            SuperscriptBox["\[Lambda]", "2"]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 18, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 18, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 18, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[18]], TraditionalForm]], "Output",
 CellChangeTimes->{3.61086212260299*^9, 3.610862210241531*^9, 
  3.6109481849856586`*^9, 3.614415461513028*^9, 3.614486281192316*^9, 
  3.614488576760393*^9, 3.614495167913138*^9, 3.6145005357018642`*^9, 
  3.61450075795055*^9, 3.614500899671327*^9, 3.614505625976653*^9, 
  3.614577106429634*^9, 3.614937117423443*^9, 3.6156337001677017`*^9, 
  3.616214553461012*^9, 3.6173360627356987`*^9, 3.617338182314631*^9, 
  3.618217329246633*^9, 3.619333556528097*^9, 3.619774924409367*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lexpanded$scaled$strip", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Normal", "[", 
    RowBox[{"Series", "[", 
     RowBox[{"Lexpanded$scaled", ",", 
      RowBox[{"{", 
       RowBox[{"\[Lambda]", ",", "0", ",", "7"}], "}"}]}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.610862293422134*^9, 3.610862346618205*^9}, {
  3.610862524175817*^9, 3.610862527002442*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox["\[Phi]", "2"], " ", 
            RowBox[{"BG", "(", 
             RowBox[{"c", ",", "d"}], ")"}], " ", 
            RowBox[{"BGG", "(", 
             RowBox[{"cc", ",", "dd"}], ")"}], " ", 
            RowBox[{"DDh", "(", 
             RowBox[{"ee", ",", "c", ",", "cc"}], ")"}], " ", 
            RowBox[{"Dh", "(", 
             RowBox[{"d", ",", "b", ",", "dd"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"a", ",", "ee"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"a", ",", "ll"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"b", ",", "ll"}], ")"}], " ", 
            SuperscriptBox["\[Lambda]", "7"]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            SuperscriptBox["\[Phi]", "2"], " ", 
            RowBox[{"BG", "(", 
             RowBox[{"c", ",", "d"}], ")"}], " ", 
            RowBox[{"BGG", "(", 
             RowBox[{"cc", ",", "dd"}], ")"}], " ", 
            RowBox[{"DDh", "(", 
             RowBox[{"ee", ",", "a", ",", "cc"}], ")"}], " ", 
            RowBox[{"Dh", "(", 
             RowBox[{"d", ",", "b", ",", "dd"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"a", ",", "ll"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"b", ",", "ll"}], ")"}], " ", 
            RowBox[{"h", "(", 
             RowBox[{"c", ",", "ee"}], ")"}], " ", 
            SuperscriptBox["\[Lambda]", "7"]}], "+", 
           RowBox[{"\[LeftSkeleton]", "424", "\[RightSkeleton]"}], "+", 
           RowBox[{
            RowBox[{"BG", "(", 
             RowBox[{"a", ",", "b"}], ")"}], " ", 
            RowBox[{"BGG", "(", 
             RowBox[{"cc", ",", "dd"}], ")"}], " ", 
            RowBox[{"DDh", "(", 
             RowBox[{"cc", ",", "a", ",", "dd"}], ")"}], " ", 
            RowBox[{"D\[Phi]", "(", "b", ")"}], " ", 
            SuperscriptBox["\[Lambda]", "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"BG", "(", 
             RowBox[{"a", ",", "b"}], ")"}], " ", 
            RowBox[{"D\[Phi]", "(", "a", ")"}], " ", 
            RowBox[{"D\[Phi]", "(", "b", ")"}], " ", 
            SuperscriptBox["\[Lambda]", "2"]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 19, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 19, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 19, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[19]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.610862318739451*^9, 3.610862347239306*^9}, 
   3.6108624318258963`*^9, 3.610862528003016*^9, 3.61094819146516*^9, 
   3.614415462119348*^9, 3.614486281930952*^9, 3.614488577269713*^9, 
   3.614495168783476*^9, 3.614500536220275*^9, 3.614500758490467*^9, 
   3.614500900531766*^9, 3.614505626554097*^9, 3.614577106959124*^9, 
   3.614937118188192*^9, 3.615633700793516*^9, 3.616214554694087*^9, 
   3.617336063447254*^9, 3.61733818289779*^9, 3.618217329955817*^9, 
   3.619333557142899*^9, 3.6197749249661922`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lexpanded$scaled$strip", "]"}]], "Input",
 CellChangeTimes->{{3.610862531973942*^9, 3.610862533478406*^9}}],

Cell[BoxData[
 FormBox["290", TraditionalForm]], "Output",
 CellChangeTimes->{3.610862533828886*^9, 3.610948195272369*^9, 
  3.614415462441675*^9, 3.614486282509706*^9, 3.614488577275517*^9, 
  3.6144951687916517`*^9, 3.614500536228228*^9, 3.614500758838867*^9, 
  3.614500900539844*^9, 3.614505626887053*^9, 3.614577106968742*^9, 
  3.614937118196507*^9, 3.615633700798501*^9, 3.616214554813534*^9, 
  3.617336063455814*^9, 3.6173381829071913`*^9, 3.6182173299654427`*^9, 
  3.619333557305862*^9, 3.619774925058036*^9}]
}, Open  ]],

Cell[TextData[{
 "No \[Lambda] and by construction no ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Lambda]", "8"], TraditionalForm]]],
 " terms:"
}], "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610865050068767*^9, 3.610865056359763*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"Lexpanded$scaled$strip", ",", 
   RowBox[{"\[Lambda]", "^", "8"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.610862440350113*^9, 3.610862468462*^9}, {
  3.610862544808393*^9, 3.610862571759953*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6108624560796757`*^9, 3.610862468867448*^9}, {
   3.6108625451861553`*^9, 3.610862572357731*^9}, 3.610948196970029*^9, 
   3.614415462476733*^9, 3.614486282555937*^9, 3.614488577292831*^9, 
   3.6144951688169403`*^9, 3.614500536252389*^9, 3.614500758858807*^9, 
   3.614500900555367*^9, 3.614505626912685*^9, 3.6145771070041018`*^9, 
   3.614937118216415*^9, 3.615633700815427*^9, 3.616214554838499*^9, 
   3.6173360634775743`*^9, 3.617338182949582*^9, 3.618217329998416*^9, 
   3.61933355735835*^9, 3.619774925086915*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{"Lexpanded$scaled$strip", "/", "\[Lambda]"}], "]"}], ",", 
   RowBox[{"1", "/", "\[Lambda]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.610862621066362*^9, 3.610862625664171*^9}, {
  3.610862665792336*^9, 3.6108626768895407`*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6108626680100393`*^9, 3.610862677146038*^9}, 
   3.610948198939754*^9, 3.6144154625151854`*^9, 3.61448628265184*^9, 
   3.614488577321334*^9, 3.614495168845108*^9, 3.614500536287794*^9, 
   3.6145007588851223`*^9, 3.614500900584371*^9, 3.614505626943746*^9, 
   3.614577107046378*^9, 3.614937118239283*^9, 3.615633700903273*^9, 
   3.616214554968224*^9, 3.617336063570455*^9, 3.617338182992937*^9, 
   3.618217330099256*^9, 3.6193335575185738`*^9, 3.6197749251884413`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Order", " ", 
  SuperscriptBox["\[Lambda]", "2"]}]], "Subsection",
 CellChangeTimes->{{3.6109416717633953`*^9, 3.6109417062806883`*^9}, 
   3.614486284360527*^9, {3.614495252626313*^9, 3.614495274771304*^9}}],

Cell[TextData[{
 "Here we just compute the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]]],
 " terms:"
}], "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.6109417292629337`*^9, 
  3.6109417370609694`*^9}, {3.614488208114849*^9, 3.6144882086972446`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag2e", "=", 
  RowBox[{
   RowBox[{"Filter", "[", 
    RowBox[{"Lexpanded$scaled$strip", ",", 
     RowBox[{"\[Lambda]", "^", "2"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Phi]", "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.610869558116445*^9, {3.61087882144272*^9, 3.610878845404212*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"BG", "(", 
      RowBox[{"a", ",", "b"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"aa", ",", "bb"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"cc", ",", "dd"}], ")"}], " ", 
     RowBox[{"DDh", "(", 
      RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
     RowBox[{"DDh", "(", 
      RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610869558328738*^9, {3.610878836651787*^9, 3.6108788480759287`*^9}, 
   3.610948200742261*^9, 3.614415462561657*^9, 3.61448628267142*^9, 
   3.6144885773545523`*^9, 3.6144951688832607`*^9, 3.614500536334752*^9, 
   3.614500758920114*^9, 3.614500900623863*^9, 3.614505626984743*^9, 
   3.614577107089285*^9, 3.614937118278058*^9, 3.615633700942499*^9, 
   3.616214555049715*^9, 3.617336063603009*^9, 3.617338183049383*^9, 
   3.618217330138176*^9, 3.619333557579987*^9, 3.619774925228292*^9}]
}, Open  ]],

Cell["\<\
Note that the order of replacement rules in the next expression is important!\
\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610878382829616*^9, 
  3.6108783852723837`*^9}, {3.610941741677971*^9, 3.610941774780137*^9}, {
  3.6144882262572927`*^9, 3.6144882298089743`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag2e$nicer", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Lag2e", "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"DDh", "[", 
                RowBox[{"aa_", ",", "b_", ",", "cc_"}], "]"}], 
               RowBox[{"DDh", "[", 
                RowBox[{"bb_", ",", "a_", ",", "dd_"}], "]"}]}], "\[Rule]", 
              RowBox[{
               RowBox[{"BGG", "[", 
                RowBox[{"aa", ",", "xx"}], "]"}], 
               RowBox[{"BG", "[", 
                RowBox[{"b", ",", "m"}], "]"}], 
               RowBox[{"BGG", "[", 
                RowBox[{"cc", ",", "mm"}], "]"}], 
               RowBox[{"BGG", "[", 
                RowBox[{"bb", ",", "yy"}], "]"}], 
               RowBox[{"BG", "[", 
                RowBox[{"a", ",", "n"}], "]"}], 
               RowBox[{"BGG", "[", 
                RowBox[{"dd", ",", "nn"}], "]"}], 
               RowBox[{"DDh", "[", 
                RowBox[{"xx", ",", "m", ",", "mm"}], "]"}], 
               RowBox[{"DDh", "[", 
                RowBox[{"yy", ",", "n", ",", "nn"}], "]"}]}]}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"Dh", "[", 
                RowBox[{"e_", ",", "b_", ",", "cc_"}], "]"}], 
               RowBox[{"Dh", "[", 
                RowBox[{"f_", ",", "a_", ",", "dd_"}], "]"}]}], "\[Rule]", 
              RowBox[{
               RowBox[{"BG", "[", 
                RowBox[{"e", ",", "x"}], "]"}], 
               RowBox[{"BG", "[", 
                RowBox[{"b", ",", "m"}], "]"}], 
               RowBox[{"BGG", "[", 
                RowBox[{"cc", ",", "mm"}], "]"}], 
               RowBox[{"BG", "[", 
                RowBox[{"f", ",", "y"}], "]"}], 
               RowBox[{"BG", "[", 
                RowBox[{"a", ",", "n"}], "]"}], 
               RowBox[{"BGG", "[", 
                RowBox[{"dd", ",", "nn"}], "]"}], 
               RowBox[{"Dh", "[", 
                RowBox[{"x", ",", "m", ",", "mm"}], "]"}], 
               RowBox[{"Dh", "[", 
                RowBox[{"y", ",", "n", ",", "nn"}], "]"}]}]}]}], "}"}]}], 
          ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"BG", "[", 
            RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
           RowBox[{"d", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{"d", "[", 
           RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
         RowBox[{"BG", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"BGG", "[", 
        RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
       RowBox[{"d", "[", 
        RowBox[{"aa", ",", "bb"}], "]"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{"d", "[", 
       RowBox[{"aa_", ",", "bb_"}], "]"}], "]"}], "\[Rule]", 
     RowBox[{"BGG", "[", 
      RowBox[{"aa", ",", "bb"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6109402878308573`*^9, 3.6109404765570393`*^9}, {
   3.6109406044236298`*^9, 3.6109406251164103`*^9}, 3.610940769550816*^9, {
   3.610940805781087*^9, 3.610940839401932*^9}, {3.61094086954537*^9, 
   3.610940883971314*^9}, {3.6109409169647703`*^9, 3.610941140856151*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"BG", "(", 
      RowBox[{"m", ",", "n"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"mm", ",", "yy"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"nn", ",", "xx"}], ")"}], " ", 
     RowBox[{"DDh", "(", 
      RowBox[{"xx", ",", "m", ",", "mm"}], ")"}], " ", 
     RowBox[{"DDh", "(", 
      RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "y"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "x"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"x", ",", "y"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610940416096775*^9, 3.610940477336957*^9, {3.610940618628463*^9, 
   3.610940625395817*^9}, 3.610940769992733*^9, {3.610940815493471*^9, 
   3.6109408401843033`*^9}, {3.6109408703670473`*^9, 3.6109408844876823`*^9}, 
   3.6109409660719557`*^9, {3.610941007881611*^9, 3.610941085024829*^9}, {
   3.610941122536213*^9, 3.610941141720385*^9}, 3.610948204160266*^9, 
   3.614415462638794*^9, 3.614486283372682*^9, 3.614488577430121*^9, 
   3.6144951689595413`*^9, 3.61450053641444*^9, 3.61450075898015*^9, 
   3.61450090068302*^9, 3.6145056270538397`*^9, 3.614577107159176*^9, 
   3.614937118337162*^9, 3.615633701002782*^9, 3.616214555123927*^9, 
   3.6173360636616497`*^9, 3.617338183131145*^9, 3.618217330204686*^9, 
   3.619333557676631*^9, 3.619774925275597*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag2e$nicer$world", "=", 
  RowBox[{"Lag2e$nicer", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"BG", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "b"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"BGG", "[", 
       RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"1", "/", "2"}], 
       RowBox[{"d", "[", 
        RowBox[{"aa", ",", "bb"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"h", "[", 
       RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
      RowBox[{"e", "[", 
       RowBox[{"a", ",", "aa"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Dh", "[", 
       RowBox[{"e_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
      RowBox[{"de", "[", 
       RowBox[{"e", ",", "a", ",", "aa"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"DDh", "[", 
       RowBox[{"ee_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
      RowBox[{"de", "[", 
       RowBox[{"ee", ",", "a", ",", "aa"}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.610941190127479*^9, 3.610941209979866*^9}, {
  3.61094126082806*^9, 3.6109412612420673`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"mm", "nn"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"mm", "nn"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"mm", "yy"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"nn", "xx"}]], " ", 
    RowBox[{"de", "(", 
     RowBox[{"xx", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.610941203232748*^9, 3.610941210456004*^9}, 
   3.610941261819582*^9, 3.610948206622068*^9, 3.6144154626877527`*^9, 
   3.6144862836961823`*^9, 3.614488577459399*^9, 3.614495169302376*^9, 
   3.614500536448188*^9, 3.6145007590133753`*^9, 3.614500901024047*^9, 
   3.6145056270932007`*^9, 3.61457710720068*^9, 3.614937118370565*^9, 
   3.615633701032639*^9, 3.616214555196065*^9, 3.617336063696424*^9, 
   3.617338183178925*^9, 3.618217330241296*^9, 3.619333557731002*^9, 
   3.619774925314294*^9}]
}, Open  ]],

Cell["This is indeed what we found in the manual computation.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610878382829616*^9, 
  3.6108783852723837`*^9}, {3.610941741677971*^9, 3.610941751733459*^9}, {
  3.614488238971239*^9, 3.6144882400248938`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Order", " ", 
  SuperscriptBox["\[Lambda]", "3"]}]], "Subsection",
 CellChangeTimes->{{3.610941781870956*^9, 3.610941793017185*^9}, 
   3.610941843745512*^9, 3.6109508297771387`*^9, 3.6144862903648*^9, {
   3.6144952554501123`*^9, 3.614495256123776*^9}}],

Cell[TextData[{
 "Do ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "3"], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QPSEuIyvIJrHpwhMb9vl/3Dh7VeOWxaVPwHRYdeNeHSev3Ls2aXDC6I3ffGW
AtG/VtUrgehm1fk6IPpBapcBiI55ohUI5kcYh4JoBbaWehD9Znd+I5gfy94D
oj9wOoFp855bpiZAOm67hhmI/rBxq2owkK6v+K4GoptfXdIB0S4Fe3VBtEnf
ASMQzepfaQyinfvsp4UD6R1TIDQA9kOfXg==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3e", "=", 
  RowBox[{
   RowBox[{"Filter", "[", 
    RowBox[{"Lexpanded$scaled$strip", ",", 
     RowBox[{"\[Lambda]", "^", "3"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Phi]", "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.610862697072743*^9, {3.61086301200909*^9, 3.610863013753297*^9}, {
   3.6108633360176363`*^9, 3.610863372875196*^9}, {3.610869509199832*^9, 
   3.610869517459168*^9}, {3.610869564542656*^9, 3.610869588213954*^9}, {
   3.61087170251621*^9, 3.610871704828367*^9}, {3.610941856927662*^9, 
   3.610941858863269*^9}, {3.6109508379783373`*^9, 3.610950841520466*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"BG", "(", 
      RowBox[{"a", ",", "b"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"aa", ",", "bb"}], ")"}], " ", 
     RowBox[{"h", "(", 
      RowBox[{"e", ",", "aa"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"cc", ",", "dd"}], ")"}], " ", 
     RowBox[{"Dh", "(", 
      RowBox[{"e", ",", "a", ",", "cc"}], ")"}], " ", 
     RowBox[{"DDh", "(", 
      RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"f", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"f", ",", "b", ",", "bb"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ee"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "c", ",", "cc"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ee"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610862697723528*^9, 3.610863014019474*^9, {3.610863336204615*^9, 
   3.6108633731110277`*^9}, {3.610869509930108*^9, 3.6108695181669188`*^9}, {
   3.610869573919915*^9, 3.610869588982315*^9}, 3.61087170595199*^9, 
   3.610941862996011*^9, 3.610948228093824*^9, 3.610950842065675*^9, 
   3.614415462770463*^9, 3.614486283964464*^9, 3.614488577502722*^9, 
   3.614495169335436*^9, 3.614500536501748*^9, 3.614500759060278*^9, 
   3.614500901067437*^9, 3.6145056271483593`*^9, 3.6145771073277473`*^9, 
   3.614937118412614*^9, 3.615633701078025*^9, 3.616214555256288*^9, 
   3.6173360637414207`*^9, 3.617338183213168*^9, 3.6182173302764797`*^9, 
   3.619333557805711*^9, 3.619774925369933*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lag3e", "]"}]], "Input",
 CellChangeTimes->{{3.610869528473722*^9, 3.6108695332416697`*^9}, 
   3.6108717121083107`*^9, 3.610941866403091*^9, 3.6109508443854*^9}],

Cell[BoxData[
 FormBox["6", TraditionalForm]], "Output",
 CellChangeTimes->{3.6108695335010767`*^9, 3.610869593595397*^9, 
  3.61087171255167*^9, 3.610941866506708*^9, 3.61094823895366*^9, 
  3.610950844933628*^9, 3.614415462807528*^9, 3.614486283977165*^9, 
  3.614488577518928*^9, 3.6144951693502817`*^9, 3.614500536506072*^9, 
  3.614500759081408*^9, 3.614500901079939*^9, 3.614505627153632*^9, 
  3.614577107356868*^9, 3.614937118427082*^9, 3.6156337010826807`*^9, 
  3.6162145552609987`*^9, 3.617336063825631*^9, 3.617338183247967*^9, 
  3.618217330400545*^9, 3.619333557850965*^9, 3.619774925397148*^9}]
}, Open  ]],

Cell["\<\
In what follows it is important to maintain the order of replacement rules.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3e$nicer", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Lag3e", "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"Dh", "[", 
                 RowBox[{"e_", ",", "a_", ",", "cc_"}], "]"}], "\[Rule]", 
                RowBox[{
                 RowBox[{"BG", "[", 
                  RowBox[{"e", ",", "x"}], "]"}], 
                 RowBox[{"BG", "[", 
                  RowBox[{"a", ",", "m"}], "]"}], 
                 RowBox[{"BGG", "[", 
                  RowBox[{"cc", ",", "mm"}], "]"}], 
                 RowBox[{"Dh", "[", 
                  RowBox[{"x", ",", "m", ",", "mm"}], "]"}]}]}], ",", 
               RowBox[{
                RowBox[{"DDh", "[", 
                 RowBox[{"dd_", ",", "b_", ",", "bb_"}], "]"}], "\[Rule]", 
                RowBox[{
                 RowBox[{"BGG", "[", 
                  RowBox[{"dd", ",", "yy"}], "]"}], 
                 RowBox[{"BG", "[", 
                  RowBox[{"b", ",", "n"}], "]"}], 
                 RowBox[{"BGG", "[", 
                  RowBox[{"bb", ",", "nn"}], "]"}], 
                 RowBox[{"Dh", "[", 
                  RowBox[{"yy", ",", "n", ",", "nn"}], "]"}]}]}]}], "}"}]}], 
            ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"h", "[", 
              RowBox[{"a_", ",", "ee_"}], "]"}], "\[Rule]", 
             RowBox[{
              RowBox[{"BG", "[", 
               RowBox[{"a", ",", "u"}], "]"}], 
              RowBox[{"BGG", "[", 
               RowBox[{"ee", ",", "uu"}], "]"}], 
              RowBox[{"h", "[", 
               RowBox[{"u", ",", "uu"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"BG", "[", 
            RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
           RowBox[{"d", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{"d", "[", 
           RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
         RowBox[{"BG", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"BGG", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{"d", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
     RowBox[{"BGG", "[", 
      RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.610871714854949*^9, 3.6108717524276943`*^9}, {
   3.610871792868222*^9, 3.610871828546763*^9}, {3.610871860064332*^9, 
   3.610871988648801*^9}, {3.610872141630171*^9, 3.610872278032997*^9}, {
   3.61087236730477*^9, 3.6108726820248947`*^9}, {3.6108727130845327`*^9, 
   3.610872770672801*^9}, 3.610872926054221*^9, {3.61095091567548*^9, 
   3.6109509784008007`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"BG", "(", 
      RowBox[{"m", ",", "n"}], ")"}], " ", 
     RowBox[{"BG", "(", 
      RowBox[{"u", ",", "x"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"mm", ",", "yy"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"nn", ",", "uu"}], ")"}], " ", 
     RowBox[{"h", "(", 
      RowBox[{"u", ",", "uu"}], ")"}], " ", 
     RowBox[{"Dh", "(", 
      RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
     RowBox[{"Dh", "(", 
      RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}]}], "-", 
   RowBox[{
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "u"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "x"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "yy"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "x"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "yy"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6109509825963573`*^9, 3.6144154628898067`*^9, 
  3.6144862842539663`*^9, 3.61448857759435*^9, 3.614495169428236*^9, 
  3.614500536585623*^9, 3.6145007591575747`*^9, 3.6145009011676702`*^9, 
  3.614505627231719*^9, 3.614577107457407*^9, 3.6149371185090113`*^9, 
  3.615633701158718*^9, 3.616214555339159*^9, 3.6173360639024343`*^9, 
  3.6173381833267517`*^9, 3.618217330479464*^9, 3.619333557932301*^9, 
  3.619774925476695*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Lag3e$nicer", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.610872657627907*^9, 3.610872659044886*^9}, {
   3.610872939019191*^9, 3.610872942388152*^9}, 3.610944594933577*^9, 
   3.610950987854107*^9}],

Cell[BoxData[
 FormBox["3", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610872659376094*^9, {3.61087293522755*^9, 3.610872942628978*^9}, {
   3.610944595208178*^9, 3.6109446066038237`*^9}, 3.610945261103282*^9, 
   3.610945429262931*^9, 3.610948244895814*^9, 3.610950987977785*^9, 
   3.6144154629267282`*^9, 3.614486284265295*^9, 3.614488577598899*^9, 
   3.6144951694432907`*^9, 3.614500536612377*^9, 3.614500759162689*^9, 
   3.614500901182476*^9, 3.614505627255423*^9, 3.614577107491768*^9, 
   3.6149371185958023`*^9, 3.6156337011775303`*^9, 3.616214555371049*^9, 
   3.617336063919606*^9, 3.617338183365996*^9, 3.6182173305033417`*^9, 
   3.6193335579374523`*^9, 3.619774925503611*^9}]
}, Open  ]],

Cell["\<\
Take indices at h, Dh, DDh all downstairs and all indices at BG, BGG \
upstairs.
Then transition to world indices is easy:
h -> e
Dh -> partial e
DDh -> partial e
BG -> -1/2 G
BGG -> 1/2 G\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3e$nicer$world", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"(", 
        RowBox[{"Lag3e$nicer", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"BG", "[", 
             RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1"}], "/", "2"}], 
             RowBox[{"d", "[", 
              RowBox[{"a", ",", "b"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"BGG", "[", 
             RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
            RowBox[{
             RowBox[{"1", "/", "2"}], 
             RowBox[{"d", "[", 
              RowBox[{"aa", ",", "bb"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"h", "[", 
             RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
            RowBox[{"e", "[", 
             RowBox[{"a", ",", "aa"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"Dh", "[", 
             RowBox[{"e_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
            RowBox[{"de", "[", 
             RowBox[{"e", ",", "a", ",", "aa"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"DDh", "[", 
             RowBox[{"ee_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
            RowBox[{"de", "[", 
             RowBox[{"ee", ",", "a", ",", "aa"}], "]"}]}]}], "}"}]}], ")"}], 
       ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"u", "\[Rule]", "a"}], ",", 
        RowBox[{"uu", "\[Rule]", "b"}], ",", 
        RowBox[{"v", "\[Rule]", "g"}], ",", 
        RowBox[{"vv", "\[Rule]", "h"}], ",", 
        RowBox[{"m", "\[Rule]", "c"}], ",", 
        RowBox[{"mm", "\[Rule]", "d"}], ",", 
        RowBox[{"n", "\[Rule]", "e"}], ",", 
        RowBox[{"nn", "\[Rule]", "f"}], ",", 
        RowBox[{"xx", "\[Rule]", "x"}], ",", 
        RowBox[{"yy", "\[Rule]", "y"}]}], "}"}]}], "//", "Simplify"}], ")"}], 
   "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "\[Rule]", "i"}], ",", 
     RowBox[{"b", "\[Rule]", "j"}], ",", 
     RowBox[{"c", "\[Rule]", "a"}], ",", 
     RowBox[{"d", "\[Rule]", "b"}], ",", 
     RowBox[{"e", "\[Rule]", "c"}], ",", 
     RowBox[{"f", "\[Rule]", "d"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.610945740400408*^9, 3.6109457999168787`*^9}, 
   3.6109461128323193`*^9, {3.610948254574554*^9, 3.610948274648202*^9}, {
   3.610951053481941*^9, 3.610951108571004*^9}, {3.610951151849098*^9, 
   3.610951157657091*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "16"], " ", 
   RowBox[{"c", "(", 
    RowBox[{"i", ",", "j"}], ")"}], " ", 
   RowBox[{"de", "(", 
    RowBox[{"x", ",", "a", ",", "b"}], ")"}], " ", 
   RowBox[{"de", "(", 
    RowBox[{"y", ",", "c", ",", "d"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "x"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"b", "d"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"j", "y"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"b", "y"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "j"}]]}]}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "y"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610945561611257*^9, 3.6109458009021883`*^9, 3.6109461139799232`*^9, {
   3.61094824844833*^9, 3.61094827522922*^9}, {3.610951057758946*^9, 
   3.610951074957073*^9}, 3.61095115851975*^9, 3.614415462986565*^9, 
   3.6144862844654016`*^9, 3.6144885776267347`*^9, 3.614495169473627*^9, 
   3.6145005366577177`*^9, 3.614500759191884*^9, 3.614500901214538*^9, 
   3.614505627289938*^9, 3.614577107528777*^9, 3.614937118629756*^9, 
   3.6156337012066402`*^9, 3.616214555410508*^9, 3.617336063954789*^9, 
   3.61733818340777*^9, 3.6182173305366287`*^9, 3.619333557989106*^9, 
   3.61977492553613*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lag3e$nicer$world", "]"}]], "Input",
 CellChangeTimes->{{3.610948277344809*^9, 3.610948278461933*^9}, 
   3.610951064620008*^9}],

Cell[BoxData[
 FormBox["5", TraditionalForm]], "Output",
 CellChangeTimes->{3.610948278833323*^9, 3.610951064813229*^9, 
  3.614415463025865*^9, 3.614486284728257*^9, 3.6144885776434727`*^9, 
  3.614495169491558*^9, 3.614500536682604*^9, 3.614500759211144*^9, 
  3.614500901228302*^9, 3.614505627313574*^9, 3.614577107535153*^9, 
  3.614937118643971*^9, 3.6156337013109818`*^9, 3.616214555443191*^9, 
  3.617336063972395*^9, 3.617338183442439*^9, 3.6182173305588083`*^9, 
  3.6193335580386133`*^9, 3.619774925564026*^9}]
}, Open  ]],

Cell["This coincides with the result from the manual computation.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}, {
  3.610949486610433*^9, 3.610949505151391*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Order", " ", 
  SuperscriptBox["\[Lambda]", "4"]}]], "Subsection",
 CellChangeTimes->{{3.610941781870956*^9, 3.610941793017185*^9}, 
   3.610941843745512*^9, 3.614486297196616*^9, {3.614495276714285*^9, 
   3.614495277266567*^9}}],

Cell[TextData[{
 "Do ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "4"], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610878382829616*^9, 
  3.6108783852723837`*^9}, {3.610941741677971*^9, 3.610941751733459*^9}, {
  3.610941798591127*^9, 3.6109418059199543`*^9}, {3.610941846017359*^9, 
  3.610941851790896*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag4e", "=", 
  RowBox[{
   RowBox[{"Filter", "[", 
    RowBox[{"Lexpanded$scaled$strip", ",", 
     RowBox[{"\[Lambda]", "^", "4"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Phi]", "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.610862697072743*^9, {3.61086301200909*^9, 3.610863013753297*^9}, {
   3.6108633360176363`*^9, 3.610863372875196*^9}, {3.610869509199832*^9, 
   3.610869517459168*^9}, {3.610869564542656*^9, 3.610869588213954*^9}, {
   3.61087170251621*^9, 3.610871704828367*^9}, {3.610941856927662*^9, 
   3.610941858863269*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "aa"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "bb"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"e", ",", "aa"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"f", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"e", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"f", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ee"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "c", ",", "cc"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ee"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ll"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ll"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610862697723528*^9, 3.610863014019474*^9, {3.610863336204615*^9, 
   3.6108633731110277`*^9}, {3.610869509930108*^9, 3.6108695181669188`*^9}, {
   3.610869573919915*^9, 3.610869588982315*^9}, 3.61087170595199*^9, 
   3.610941862996011*^9, 3.610948228093824*^9, 3.614415463111462*^9, 
   3.614486284812029*^9, 3.614488577697297*^9, 3.614495169555485*^9, 
   3.6145005367620707`*^9, 3.614500759268187*^9, 3.614500901288477*^9, 
   3.6145056273718357`*^9, 3.6145771076001377`*^9, 3.61493711870348*^9, 
   3.61563370136829*^9, 3.616214555500452*^9, 3.61733606402988*^9, 
   3.617338183502274*^9, 3.618217330616888*^9, 3.61933355813626*^9, 
   3.6197749256243258`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lag4e", "]"}]], "Input",
 CellChangeTimes->{{3.610869528473722*^9, 3.6108695332416697`*^9}, 
   3.6108717121083107`*^9, 3.610941866403091*^9}],

Cell[BoxData[
 FormBox["12", TraditionalForm]], "Output",
 CellChangeTimes->{3.6108695335010767`*^9, 3.610869593595397*^9, 
  3.61087171255167*^9, 3.610941866506708*^9, 3.61094823895366*^9, 
  3.6144154631479273`*^9, 3.6144862848470373`*^9, 3.6144885777142773`*^9, 
  3.6144951695889683`*^9, 3.614500536793625*^9, 3.614500759287805*^9, 
  3.614500901293407*^9, 3.614505627396461*^9, 3.614577107679256*^9, 
  3.614937118716325*^9, 3.6156337013729343`*^9, 3.6162145555329123`*^9, 
  3.617336064034624*^9, 3.6173381835362988`*^9, 3.618217330641406*^9, 
  3.619333558183392*^9, 3.619774925652192*^9}]
}, Open  ]],

Cell["\<\
In what follows it is important to maintain the order of replacement rules.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag4e$nicer", "=", 
  RowBox[{"First", "[", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"PolynomialForm", "[", 
              RowBox[{
               RowBox[{"Lag4e", "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"DDh", "[", 
                    RowBox[{"aa_", ",", "b_", ",", "cc_"}], "]"}], 
                    RowBox[{"DDh", "[", 
                    RowBox[{"bb_", ",", "a_", ",", "dd_"}], "]"}]}], 
                   "\[Rule]", 
                   RowBox[{
                    RowBox[{"BGG", "[", 
                    RowBox[{"aa", ",", "xx"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"b", ",", "m"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"cc", ",", "mm"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"bb", ",", "yy"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"a", ",", "n"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"dd", ",", "nn"}], "]"}], 
                    RowBox[{"DDh", "[", 
                    RowBox[{"xx", ",", "m", ",", "mm"}], "]"}], 
                    RowBox[{"DDh", "[", 
                    RowBox[{"yy", ",", "n", ",", "nn"}], "]"}]}]}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Dh", "[", 
                    RowBox[{"e_", ",", "b_", ",", "cc_"}], "]"}], 
                    RowBox[{"Dh", "[", 
                    RowBox[{"f_", ",", "a_", ",", "dd_"}], "]"}]}], "\[Rule]", 
                   RowBox[{
                    RowBox[{"BG", "[", 
                    RowBox[{"e", ",", "x"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"b", ",", "m"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"cc", ",", "mm"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"f", ",", "y"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"a", ",", "n"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"dd", ",", "nn"}], "]"}], 
                    RowBox[{"Dh", "[", 
                    RowBox[{"x", ",", "m", ",", "mm"}], "]"}], 
                    RowBox[{"Dh", "[", 
                    RowBox[{"y", ",", "n", ",", "nn"}], "]"}]}]}]}], "}"}]}], 
               ",", 
               RowBox[{"TraditionalOrder", "\[Rule]", "True"}]}], "]"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"h", "[", 
                 RowBox[{"a_", ",", "aa_"}], "]"}], 
                RowBox[{"h", "[", 
                 RowBox[{"b_", ",", "bb_"}], "]"}]}], "\[Rule]", 
               RowBox[{
                RowBox[{"BG", "[", 
                 RowBox[{"a", ",", "u"}], "]"}], 
                RowBox[{"BGG", "[", 
                 RowBox[{"aa", ",", "uu"}], "]"}], 
                RowBox[{"BG", "[", 
                 RowBox[{"b", ",", "v"}], "]"}], 
                RowBox[{"BGG", "[", 
                 RowBox[{"bb", ",", "vv"}], "]"}], 
                RowBox[{"h", "[", 
                 RowBox[{"u", ",", "uu"}], "]"}], 
                RowBox[{"h", "[", 
                 RowBox[{"v", ",", "vv"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"BG", "[", 
              RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
             RowBox[{"d", "[", 
              RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{"d", "[", 
             RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
           RowBox[{"BG", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"BGG", "[", 
          RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
         RowBox[{"d", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{"d", "[", 
         RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
       RowBox[{"BGG", "[", 
        RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.610871714854949*^9, 3.6108717524276943`*^9}, {
   3.610871792868222*^9, 3.610871828546763*^9}, {3.610871860064332*^9, 
   3.610871988648801*^9}, {3.610872141630171*^9, 3.610872278032997*^9}, {
   3.61087236730477*^9, 3.6108726820248947`*^9}, {3.6108727130845327`*^9, 
   3.610872770672801*^9}, 3.610872926054221*^9, 3.610941871586946*^9, {
   3.610942059902787*^9, 3.610942069642877*^9}, 3.610942122531764*^9, {
   3.610942170671884*^9, 3.610942183715197*^9}, {3.610942234791154*^9, 
   3.61094223833834*^9}, {3.610942723884069*^9, 3.610942754087391*^9}, {
   3.610942874287359*^9, 3.610942918797304*^9}, {3.610942959141005*^9, 
   3.610942970499049*^9}, {3.610943009533876*^9, 3.6109430339017878`*^9}, {
   3.610943323215108*^9, 3.6109433860731792`*^9}, 3.61094345443511*^9, {
   3.610943498335054*^9, 3.610943551117934*^9}, {3.610943823545167*^9, 
   3.610943828297076*^9}, {3.610944038118657*^9, 3.610944109510005*^9}, {
   3.610944181787184*^9, 3.610944220709124*^9}, 3.6109443078743067`*^9, {
   3.610944360670504*^9, 3.6109444906916437`*^9}, {3.6109445311212683`*^9, 
   3.610944573215452*^9}, {3.610945251602112*^9, 3.610945254163925*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "u"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "v"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "yy"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"nn", ",", "xx"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "vv"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"xx", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "v"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "yy"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"nn", ",", "vv"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "xx"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"xx", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "v"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "uu"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"nn", ",", "xx"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"vv", ",", "yy"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"xx", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "v"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "u"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "xx"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"vv", ",", "yy"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"xx", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "v"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "xx"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"vv", ",", "yy"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"xx", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"yy", ",", "n", ",", "nn"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "x"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"v", ",", "y"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "vv"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"nn", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "y"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "x"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "v"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "uu"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"nn", ",", "vv"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "v"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"x", ",", "y"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "uu"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"nn", ",", "vv"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "y"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "v"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "x"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "vv"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "u"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "x"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"v", ",", "y"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "vv"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "n"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"u", ",", "x"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"v", ",", "y"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "vv"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"m", ",", "u"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"n", ",", "v"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"x", ",", "y"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"mm", ",", "nn"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"uu", ",", "vv"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"u", ",", "uu"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"v", ",", "vv"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"y", ",", "n", ",", "nn"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.6109435305434628`*^9, 3.610943551554125*^9}, 
   3.610944112259531*^9, {3.610944201479868*^9, 3.6109442170814857`*^9}, {
   3.6109442950115767`*^9, 3.6109443094319897`*^9}, {3.61094436484625*^9, 
   3.6109443721110086`*^9}, {3.610944410494062*^9, 3.610944423152092*^9}, 
   3.610944493829073*^9, {3.610944558922003*^9, 3.6109446020137577`*^9}, 
   3.610945254498023*^9, 3.610945426572442*^9, 3.610948240994158*^9, 
   3.614415463480206*^9, 3.614486285021056*^9, 3.6144885778180447`*^9, 
   3.614495169704899*^9, 3.6145005369307613`*^9, 3.614500759392585*^9, 
   3.6145009014048977`*^9, 3.6145056275063553`*^9, 3.614577107883246*^9, 
   3.614937118829254*^9, 3.615633701481723*^9, 3.6162145556432123`*^9, 
   3.617336064143417*^9, 3.6173381836442738`*^9, 3.61821733075316*^9, 
   3.619333558353387*^9, 3.6197749257632313`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Lag4e$nicer", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.610872657627907*^9, 3.610872659044886*^9}, {
   3.610872939019191*^9, 3.610872942388152*^9}, 3.610944594933577*^9}],

Cell[BoxData[
 FormBox["12", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610872659376094*^9, {3.61087293522755*^9, 3.610872942628978*^9}, {
   3.610944595208178*^9, 3.6109446066038237`*^9}, 3.610945261103282*^9, 
   3.610945429262931*^9, 3.610948244895814*^9, 3.614415463516206*^9, 
   3.614486285058992*^9, 3.6144885778386803`*^9, 3.6144951697204514`*^9, 
   3.614500536958709*^9, 3.614500759414123*^9, 3.614500901419858*^9, 
   3.6145056275120487`*^9, 3.614577107906872*^9, 3.614937118833932*^9, 
   3.615633701498728*^9, 3.616214555674533*^9, 3.617336064159258*^9, 
   3.617338183678979*^9, 3.618217330776919*^9, 3.6193335584381313`*^9, 
   3.619774925789475*^9}]
}, Open  ]],

Cell["\<\
Take indices at h, Dh, DDh all downstairs and all indices at BG, BGG \
upstairs.
Then transition to world indices is easy:
h -> e
Dh -> partial e
DDh -> partial e
BG -> -1/2 G
BGG -> 1/2 G\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag4e$nicer$world", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"(", 
     RowBox[{"Lag4e$nicer", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"BG", "[", 
          RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "2"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"BGG", "[", 
          RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"1", "/", "2"}], 
          RowBox[{"d", "[", 
           RowBox[{"aa", ",", "bb"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"h", "[", 
          RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
         RowBox[{"e", "[", 
          RowBox[{"a", ",", "aa"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Dh", "[", 
          RowBox[{"e_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
         RowBox[{"de", "[", 
          RowBox[{"e", ",", "a", ",", "aa"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"DDh", "[", 
          RowBox[{"ee_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
         RowBox[{"de", "[", 
          RowBox[{"ee", ",", "a", ",", "aa"}], "]"}]}]}], "}"}]}], ")"}], 
    ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", "a"}], ",", 
     RowBox[{"uu", "\[Rule]", "b"}], ",", 
     RowBox[{"v", "\[Rule]", "g"}], ",", 
     RowBox[{"vv", "\[Rule]", "h"}], ",", 
     RowBox[{"m", "\[Rule]", "c"}], ",", 
     RowBox[{"mm", "\[Rule]", "d"}], ",", 
     RowBox[{"n", "\[Rule]", "e"}], ",", 
     RowBox[{"nn", "\[Rule]", "f"}], ",", 
     RowBox[{"xx", "\[Rule]", "x"}], ",", 
     RowBox[{"yy", "\[Rule]", "y"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.610945740400408*^9, 3.6109457999168787`*^9}, 
   3.6109461128323193`*^9, {3.610948254574554*^9, 3.610948274648202*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "b"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "b"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "y"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "y"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "b"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "y"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "64"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "b"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    RowBox[{"e", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"e", "(", 
     RowBox[{"g", ",", "h"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"x", ",", "c", ",", "d"}], ")"}], " ", 
    RowBox[{"de", "(", 
     RowBox[{"y", ",", "e", ",", "f"}], ")"}]}]}], TraditionalForm]], "Output",\

 CellChangeTimes->{
  3.610945561611257*^9, 3.6109458009021883`*^9, 3.6109461139799232`*^9, {
   3.61094824844833*^9, 3.61094827522922*^9}, 3.61441546383092*^9, 
   3.6144862851269493`*^9, 3.614488577899082*^9, 3.6144951697820044`*^9, 
   3.614500537051341*^9, 3.614500759474907*^9, 3.614500901487747*^9, 
   3.614505627575255*^9, 3.6145771080045347`*^9, 3.614937118898687*^9, 
   3.615633701560472*^9, 3.616214555740308*^9, 3.617336064223825*^9, 
   3.617338183745376*^9, 3.618217330842984*^9, 3.619333558546547*^9, 
   3.6197749258563147`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lag4e$nicer$world", "]"}]], "Input",
 CellChangeTimes->{{3.610948277344809*^9, 3.610948278461933*^9}}],

Cell[BoxData[
 FormBox["12", TraditionalForm]], "Output",
 CellChangeTimes->{3.610948278833323*^9, 3.6144154638927794`*^9, 
  3.6144862851618767`*^9, 3.614488577903694*^9, 3.61449516979741*^9, 
  3.614500537078022*^9, 3.614500759495171*^9, 3.614500901504013*^9, 
  3.6145056279257812`*^9, 3.614577108043001*^9, 3.6149371189126883`*^9, 
  3.615633701578596*^9, 3.6162145558028173`*^9, 3.617336064240284*^9, 
  3.617338183750663*^9, 3.6182173308666563`*^9, 3.619333558551581*^9, 
  3.619774925883355*^9}]
}, Open  ]],

Cell["This coincides with the result from the manual computation.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}, {
  3.610949486610433*^9, 3.610949505151391*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[TextData[{
 "Do ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "3"], "\[CurlyPhi]"}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QPSEuIyvIJrHpwhMb9vl/3Dh7VeOWxaVPwHRYdeNeHSev3Ls2aXDC6I3ffGW
AtG/VtUrgehm1fk6IPpBapcBiI55ohUI5kcYh4JoBbaWehD9Znd+I5gfy94D
oj9wOoFp855bpiZAOm67hhmI/rBxq2owkK6v+K4GoptfXdIB0S4Fe3VBtEnf
ASMQzepfaQyi/WqjZwp/eOXYNeHlLBB9rF5OP/XjK0dmB0cwDQAtQ6bF
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3ev", "=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"Filter", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Filter", "[", 
         RowBox[{"Lexpanded$scaled$strip", ",", 
          RowBox[{"\[Lambda]", "^", "4"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[Lambda]", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Phi]", "\[Rule]", 
           RowBox[{"\[Mu]", " ", "\[Phi]"}]}], ",", 
          RowBox[{
           RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", 
           RowBox[{"\[Mu]", " ", 
            RowBox[{"D\[Phi]", "[", "a", "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", 
           RowBox[{"\[Mu]", " ", 
            RowBox[{"DD\[Phi]", "[", "aa", "]"}]}]}]}], "}"}]}], ",", 
       "\[Mu]"}], "]"}], "/", "\[Mu]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{"\[Mu]", "\[Rule]", "0"}], "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.610862697072743*^9, {3.61086301200909*^9, 3.610863013753297*^9}, {
   3.6108633360176363`*^9, 3.610863372875196*^9}, {3.610869509199832*^9, 
   3.610869517459168*^9}, {3.610869564542656*^9, 3.610869588213954*^9}, {
   3.61087170251621*^9, 3.610871704828367*^9}, {3.610941856927662*^9, 
   3.610941858863269*^9}, {3.615530205337118*^9, 3.61553020883549*^9}, {
   3.615530516520918*^9, 3.61553055093182*^9}, {3.615530690516735*^9, 
   3.6155307313395357`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[Phi]", " ", 
     RowBox[{"BG", "(", 
      RowBox[{"a", ",", "b"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"aa", ",", "bb"}], ")"}], " ", 
     RowBox[{"h", "(", 
      RowBox[{"e", ",", "aa"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"cc", ",", "dd"}], ")"}], " ", 
     RowBox[{"Dh", "(", 
      RowBox[{"e", ",", "a", ",", "cc"}], ")"}], " ", 
     RowBox[{"DDh", "(", 
      RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}]}], "-", 
   RowBox[{"\[Phi]", " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"f", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"f", ",", "b", ",", "bb"}], ")"}]}], "-", 
   RowBox[{"\[Phi]", " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ee"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "c", ",", "cc"}], ")"}]}], "+", 
   RowBox[{"\[Phi]", " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ee"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{"\[Phi]", " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{"\[Phi]", " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"D\[Phi]", "(", "e", ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ee"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"e", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "b", ",", "cc"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"DD\[Phi]", "(", "ee", ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ee"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"e", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"e", ",", "a", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"D\[Phi]", "(", "b", ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"cc", ",", "a", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"DD\[Phi]", "(", "dd", ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "b", ",", "cc"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"D\[Phi]", "(", "b", ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"cc", ",", "a", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"DD\[Phi]", "(", "dd", ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "b", ",", "cc"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610862697723528*^9, 3.610863014019474*^9, {3.610863336204615*^9, 
   3.6108633731110277`*^9}, {3.610869509930108*^9, 3.6108695181669188`*^9}, {
   3.610869573919915*^9, 3.610869588982315*^9}, 3.61087170595199*^9, 
   3.610941862996011*^9, 3.610948228093824*^9, 3.614415463111462*^9, 
   3.614486284812029*^9, 3.614488577697297*^9, 3.614495169555485*^9, 
   3.6145005367620707`*^9, 3.614500759268187*^9, 3.614500901288477*^9, 
   3.6145056273718357`*^9, 3.6145771076001377`*^9, 3.61493711870348*^9, 
   3.615530554827862*^9, {3.615530708288027*^9, 3.615530733813485*^9}, 
   3.615633701631208*^9, 3.616214555859277*^9, 3.617336064293028*^9, 
   3.6173381838050137`*^9, 3.618217330921468*^9, 3.619333558649008*^9, 
   3.619774925940411*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lag3ev", "]"}]], "Input",
 CellChangeTimes->{{3.610869528473722*^9, 3.6108695332416697`*^9}, 
   3.6108717121083107`*^9, 3.610941866403091*^9, 3.6155307503776617`*^9}],

Cell[BoxData[
 FormBox["12", TraditionalForm]], "Output",
 CellChangeTimes->{3.6108695335010767`*^9, 3.610869593595397*^9, 
  3.61087171255167*^9, 3.610941866506708*^9, 3.61094823895366*^9, 
  3.6144154631479273`*^9, 3.6144862848470373`*^9, 3.6144885777142773`*^9, 
  3.6144951695889683`*^9, 3.614500536793625*^9, 3.614500759287805*^9, 
  3.614500901293407*^9, 3.614505627396461*^9, 3.614577107679256*^9, 
  3.614937118716325*^9, 3.615530750963792*^9, 3.615633701636815*^9, 
  3.616214555891693*^9, 3.617336064298267*^9, 3.617338183839703*^9, 
  3.618217330944612*^9, 3.619333558733533*^9, 3.619774925968392*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3ev\[Phi]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"Simplify", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Lag3ev", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", "0"}]}], 
               "}"}]}], ")"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"h", "[", 
                RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
               RowBox[{
                RowBox[{"BG", "[", 
                 RowBox[{"a", ",", "E$"}], "]"}], 
                RowBox[{"BGG", "[", 
                 RowBox[{"aa", ",", "FF"}], "]"}], 
                RowBox[{"h", "[", 
                 RowBox[{"E$", ",", "FF"}], "]"}]}]}], ",", 
              RowBox[{
               RowBox[{"Dh", "[", 
                RowBox[{"a_", ",", "b_", ",", "cc_"}], "]"}], "\[Rule]", 
               RowBox[{
                RowBox[{"BG", "[", 
                 RowBox[{"a", ",", "X"}], "]"}], 
                RowBox[{"BG", "[", 
                 RowBox[{"b", ",", "A"}], "]"}], 
                RowBox[{"BGG", "[", 
                 RowBox[{"cc", ",", "BB"}], "]"}], 
                RowBox[{"Dh", "[", 
                 RowBox[{"X", ",", "A", ",", "BB"}], "]"}]}]}], ",", 
              RowBox[{
               RowBox[{"DDh", "[", 
                RowBox[{"aa_", ",", "b_", ",", "cc_"}], "]"}], "\[Rule]", 
               RowBox[{
                RowBox[{"BGG", "[", 
                 RowBox[{"aa", ",", "YY"}], "]"}], 
                RowBox[{"BG", "[", 
                 RowBox[{"b", ",", "C"}], "]"}], 
                RowBox[{"BGG", "[", 
                 RowBox[{"cc", ",", "DD"}], "]"}], 
                RowBox[{"DDh", "[", 
                 RowBox[{"YY", ",", "C", ",", "DD"}], "]"}]}]}]}], "}"}]}], 
           "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"BG", "[", 
             RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
            RowBox[{"d", "[", 
             RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{"d", "[", 
            RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
          RowBox[{"BG", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"BGG", "[", 
         RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
        RowBox[{"d", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"d", "[", 
        RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
      RowBox[{"BGG", "[", 
       RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.615531507916568*^9, 3.6155315306226063`*^9}, {
  3.615531566177968*^9, 3.615531595844247*^9}, {3.615531635088354*^9, 
  3.615531804003574*^9}, {3.6155318342955313`*^9, 3.615531997619622*^9}, {
  3.615532071750292*^9, 3.615532151873975*^9}, {3.616737527696186*^9, 
  3.616737547091413*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[Phi]", " ", 
   RowBox[{"h", "(", 
    RowBox[{"E$", ",", "FF"}], ")"}], " ", 
   RowBox[{"Dh", "(", 
    RowBox[{"X", ",", "A", ",", "BB"}], ")"}], " ", 
   RowBox[{"DDh", "(", 
    RowBox[{"YY", ",", "C", ",", "DD"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"BG", "(", 
       RowBox[{"A", ",", "E$"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"BB", ",", "DD"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"C", ",", "X"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"FF", ",", "YY"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"BG", "(", 
       RowBox[{"A", ",", "C"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"E$", ",", "X"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"BGG", "(", 
          RowBox[{"BB", ",", "YY"}], ")"}], " ", 
         RowBox[{"BGG", "(", 
          RowBox[{"DD", ",", "FF"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"BGG", "(", 
          RowBox[{"BB", ",", "DD"}], ")"}], " ", 
         RowBox[{"BGG", "(", 
          RowBox[{"FF", ",", "YY"}], ")"}]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615531531618869*^9, {3.615531651573779*^9, 3.615531804662285*^9}, 
   3.615531913348155*^9, 3.6155319985197678`*^9, 3.6155320812827682`*^9, 
   3.615532111493273*^9, {3.6155321437637167`*^9, 3.615532152306188*^9}, 
   3.615633701738948*^9, 3.6162145559950657`*^9, 3.617336064399548*^9, 
   3.617338183946891*^9, 3.618217331047193*^9, 3.619333558882656*^9, 
   3.619774926101265*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3ev\[Phi]$nicer$world", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{"Lag3ev\[Phi]", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"BG", "[", 
           RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], 
           RowBox[{"d", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"BGG", "[", 
           RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "2"}], 
           RowBox[{"d", "[", 
            RowBox[{"aa", ",", "bb"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"h", "[", 
           RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
          RowBox[{"e", "[", 
           RowBox[{"a", ",", "aa"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Dh", "[", 
           RowBox[{"e_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
          RowBox[{"de", "[", 
           RowBox[{"e", ",", "a", ",", "aa"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"DDh", "[", 
           RowBox[{"ee_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
          RowBox[{"de", "[", 
           RowBox[{"ee", ",", "a", ",", "aa"}], "]"}]}]}], "}"}]}], ")"}], 
     ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"E$", "\[Rule]", "e"}], ",", 
      RowBox[{"FF", "\[Rule]", "f"}], ",", 
      RowBox[{"X", "\[Rule]", "x"}], ",", 
      RowBox[{"YY", "\[Rule]", "y"}], ",", 
      RowBox[{"A", "\[Rule]", "a"}], ",", 
      RowBox[{"BB", "\[Rule]", "b"}], ",", 
      RowBox[{"C", "\[Rule]", "c"}], ",", 
      RowBox[{"DD", "\[Rule]", "d"}]}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.615532202855454*^9, 3.615532285482737*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "8"]}], " ", "\[Phi]", " ", 
   RowBox[{"e", "(", 
    RowBox[{"e", ",", "f"}], ")"}], " ", 
   RowBox[{"de", "(", 
    RowBox[{"x", ",", "a", ",", "b"}], ")"}], " ", 
   RowBox[{"de", "(", 
    RowBox[{"y", ",", "c", ",", "d"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "y"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "x"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"b", "y"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "f"}]]}], "-", 
        RowBox[{
         SuperscriptBox["g", 
          RowBox[{"b", "d"}]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "y"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615532228799724*^9, {3.61553227681817*^9, 3.6155322859991283`*^9}, 
   3.615633701776463*^9, 3.616214556046199*^9, 3.6173360644343224`*^9, 
   3.617338184002757*^9, 3.618217331074139*^9, 3.619333558946596*^9, 
   3.6197749261309566`*^9}]
}, Open  ]],

Cell["This coincides with the result from the manual computation.", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QPSEuIyvIJrHpwhMb9vl/3Dh7VeOWxaVPwHRYdeNeHSev3Ls2aXDC6I3ffGW
AtG/VtUrgehm1fk6IPpBapcBiI55ohUI5kcYh4JoBbaWehD9Znd+I5gfy94D
oj9wOoFpZZGz1oZAWoR7mi2IFmCLXAuiOaQ37APRqzsuvw0D0kY3VD6A6Msb
Pi8S+fDKcVGW+GIQfUhRx1cMSF+6ZwimAXX6nj0=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3ev", "/.", 
  RowBox[{"{", 
   RowBox[{"\[Phi]", "\[Rule]", "0"}], "}"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"D\[Phi]", "(", "e", ")"}], " ", 
     RowBox[{"BG", "(", 
      RowBox[{"a", ",", "b"}], ")"}], " ", 
     RowBox[{"h", "(", 
      RowBox[{"a", ",", "ee"}], ")"}], " ", 
     RowBox[{"BGG", "(", 
      RowBox[{"cc", ",", "dd"}], ")"}], " ", 
     RowBox[{"h", "(", 
      RowBox[{"e", ",", "dd"}], ")"}], " ", 
     RowBox[{"DDh", "(", 
      RowBox[{"ee", ",", "b", ",", "cc"}], ")"}]}]}], "-", 
   RowBox[{
    RowBox[{"DD\[Phi]", "(", "ee", ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ee"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"e", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"e", ",", "a", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"D\[Phi]", "(", "b", ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"cc", ",", "a", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"DD\[Phi]", "(", "dd", ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "b", ",", "cc"}], ")"}]}], "-", 
   RowBox[{
    RowBox[{"D\[Phi]", "(", "b", ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"cc", ",", "a", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    RowBox[{"DD\[Phi]", "(", "dd", ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"-", 
      RowBox[{"BGG", "(", 
       RowBox[{"cc", ",", "dd"}], ")"}]}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "b", ",", "cc"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.615535859161058*^9, 3.6156337018155127`*^9, 
  3.616214556099348*^9, 3.6173360644713383`*^9, 3.6173381840362*^9, 
  3.61821733111732*^9, 3.619333559012545*^9, 3.619774926183756*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3evd\[Phi]", "=", 
  RowBox[{
   RowBox[{"First", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"PolynomialForm", "[", 
               RowBox[{
                RowBox[{"Lag3ev", "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"\[Phi]", "\[Rule]", "0"}], ",", 
                   RowBox[{
                    RowBox[{"Dh", "[", 
                    RowBox[{"a_", ",", "b_", ",", "cc_"}], "]"}], "\[Rule]", 
                    RowBox[{
                    RowBox[{"BG", "[", 
                    RowBox[{"a", ",", "X"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"b", ",", "A"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"cc", ",", "BB"}], "]"}], 
                    RowBox[{"Dh", "[", 
                    RowBox[{"X", ",", "A", ",", "BB"}], "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{"DDh", "[", 
                    RowBox[{"aa_", ",", "b_", ",", "cc_"}], "]"}], "\[Rule]", 
                    
                    RowBox[{
                    RowBox[{"BGG", "[", 
                    RowBox[{"aa", ",", "XX"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"b", ",", "A"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"cc", ",", "BB"}], "]"}], 
                    RowBox[{"DDh", "[", 
                    RowBox[{"XX", ",", "A", ",", "BB"}], "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", 
                    RowBox[{
                    RowBox[{"BG", "[", 
                    RowBox[{"a", ",", "Y"}], "]"}], 
                    RowBox[{"D\[Phi]", "[", "Y", "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", 
                    RowBox[{
                    RowBox[{"BGG", "[", 
                    RowBox[{"aa", ",", "Y"}], "]"}], 
                    RowBox[{"D\[Phi]", "[", "Y", "]"}]}]}]}], "}"}]}], ",", 
                RowBox[{"TraditionalOrder", "\[Rule]", "True"}]}], "]"}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"h", "[", 
                  RowBox[{"a_", ",", "aa_"}], "]"}], 
                 RowBox[{"h", "[", 
                  RowBox[{"b_", ",", "bb_"}], "]"}]}], "\[Rule]", 
                RowBox[{
                 RowBox[{"BG", "[", 
                  RowBox[{"a", ",", "C"}], "]"}], 
                 RowBox[{"BGG", "[", 
                  RowBox[{"aa", ",", "DD"}], "]"}], 
                 RowBox[{"BG", "[", 
                  RowBox[{"b", ",", "E$"}], "]"}], 
                 RowBox[{"BGG", "[", 
                  RowBox[{"bb", ",", "FF"}], "]"}], 
                 RowBox[{"h", "[", 
                  RowBox[{"C", ",", "DD"}], "]"}], 
                 RowBox[{"h", "[", 
                  RowBox[{"E$", ",", "FF"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
            
            RowBox[{"{", 
             RowBox[{
              RowBox[{"BG", "[", 
               RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
              RowBox[{"d", "[", 
               RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{"d", "[", 
              RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
            RowBox[{"BG", "[", 
             RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"BGG", "[", 
           RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{"d", "[", 
          RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
        RowBox[{"BGG", "[", 
         RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.615531507916568*^9, 3.6155315306226063`*^9}, {
  3.615531566177968*^9, 3.615531595844247*^9}, {3.615531635088354*^9, 
  3.615531804003574*^9}, {3.6155318342955313`*^9, 3.615531997619622*^9}, {
  3.615532071750292*^9, 3.615532151873975*^9}, {3.615535806189039*^9, 
  3.615535839234036*^9}, {3.6155359929264803`*^9, 3.6155361148421783`*^9}, {
  3.615536172919396*^9, 3.615536201654532*^9}, {3.615536256093408*^9, 
  3.615536422339962*^9}, {3.6155365232190323`*^9, 3.6155365853443727`*^9}, {
  3.6155366362832003`*^9, 3.615536698375824*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"D\[Phi]", "(", "Y", ")"}], " ", 
   RowBox[{"h", "(", 
    RowBox[{"C", ",", "DD"}], ")"}], " ", 
   RowBox[{"h", "(", 
    RowBox[{"E$", ",", "FF"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"BG", "(", 
         RowBox[{"A", ",", "C"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"BG", "(", 
            RowBox[{"E$", ",", "Y"}], ")"}], " ", 
           RowBox[{"DDh", "(", 
            RowBox[{"XX", ",", "A", ",", "BB"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"BGG", "(", 
               RowBox[{"BB", ",", "XX"}], ")"}], " ", 
              RowBox[{"BGG", "(", 
               RowBox[{"DD", ",", "FF"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"BGG", "(", 
               RowBox[{"BB", ",", "FF"}], ")"}], " ", 
              RowBox[{"BGG", "(", 
               RowBox[{"DD", ",", "XX"}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"BGG", "(", 
            RowBox[{"BB", ",", "FF"}], ")"}], " ", 
           RowBox[{"BG", "(", 
            RowBox[{"E$", ",", "X"}], ")"}], " ", 
           RowBox[{"BGG", "(", 
            RowBox[{"DD", ",", "Y"}], ")"}], " ", 
           RowBox[{"Dh", "(", 
            RowBox[{"X", ",", "A", ",", "BB"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"BG", "(", 
         RowBox[{"A", ",", "Y"}], ")"}], " ", 
        RowBox[{"BGG", "(", 
         RowBox[{"BB", ",", "FF"}], ")"}], " ", 
        RowBox[{"BG", "(", 
         RowBox[{"C", ",", "E$"}], ")"}], " ", 
        RowBox[{"BGG", "(", 
         RowBox[{"DD", ",", "XX"}], ")"}], " ", 
        RowBox[{"DDh", "(", 
         RowBox[{"XX", ",", "A", ",", "BB"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"Dh", "(", 
         RowBox[{"X", ",", "A", ",", "BB"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"BG", "(", 
            RowBox[{"A", ",", "E$"}], ")"}], " ", 
           RowBox[{"BGG", "(", 
            RowBox[{"BB", ",", "Y"}], ")"}], " ", 
           RowBox[{"BG", "(", 
            RowBox[{"C", ",", "X"}], ")"}], " ", 
           RowBox[{"BGG", "(", 
            RowBox[{"DD", ",", "FF"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"BG", "(", 
            RowBox[{"A", ",", "X"}], ")"}], " ", 
           RowBox[{"BGG", "(", 
            RowBox[{"BB", ",", "DD"}], ")"}], " ", 
           RowBox[{"BG", "(", 
            RowBox[{"C", ",", "E$"}], ")"}], " ", 
           RowBox[{"BGG", "(", 
            RowBox[{"FF", ",", "Y"}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615531531618869*^9, {3.615531651573779*^9, 3.615531804662285*^9}, 
   3.615531913348155*^9, 3.6155319985197678`*^9, 3.6155320812827682`*^9, 
   3.615532111493273*^9, {3.6155321437637167`*^9, 3.615532152306188*^9}, {
   3.615536360699029*^9, 3.61553642320261*^9}, {3.615536597398005*^9, 
   3.615536601110271*^9}, {3.615536646274024*^9, 3.6155366995035467`*^9}, 
   3.615633701894155*^9, 3.616214556168085*^9, 3.617336064548234*^9, 
   3.617338184135989*^9, 3.618217331200988*^9, 3.619333559118766*^9, 
   3.6197749262693977`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag3evd\[Phi]$nicer$world", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"(", 
      RowBox[{"Lag3evd\[Phi]", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"BG", "[", 
           RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "2"}], 
           RowBox[{"d", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"BGG", "[", 
           RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "2"}], 
           RowBox[{"d", "[", 
            RowBox[{"aa", ",", "bb"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"h", "[", 
           RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
          RowBox[{"e", "[", 
           RowBox[{"a", ",", "aa"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"Dh", "[", 
           RowBox[{"e_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
          RowBox[{"de", "[", 
           RowBox[{"e", ",", "a", ",", "aa"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"DDh", "[", 
           RowBox[{"ee_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
          RowBox[{"de", "[", 
           RowBox[{"ee", ",", "a", ",", "aa"}], "]"}]}]}], "}"}]}], ")"}], 
     ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"E$", "\[Rule]", "e"}], ",", 
      RowBox[{"FF", "\[Rule]", "f"}], ",", 
      RowBox[{"X", "\[Rule]", "x"}], ",", 
      RowBox[{"YY", "\[Rule]", "y"}], ",", 
      RowBox[{"Y", "\[Rule]", "y"}], ",", 
      RowBox[{"A", "\[Rule]", "a"}], ",", 
      RowBox[{"BB", "\[Rule]", "b"}], ",", 
      RowBox[{"C", "\[Rule]", "c"}], ",", 
      RowBox[{"DD", "\[Rule]", "d"}], ",", 
      RowBox[{"XX", "\[Rule]", "x"}]}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.615532202855454*^9, 3.615532285482737*^9}, {
  3.615535818984447*^9, 3.615535823052005*^9}, {3.6155367146178837`*^9, 
  3.61553671629021*^9}, {3.615536751864827*^9, 3.615536754853858*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", 
   RowBox[{"D\[Phi]", "(", "y", ")"}], " ", 
   RowBox[{"e", "(", 
    RowBox[{"e", ",", "f"}], ")"}], " ", 
   RowBox[{"e", "(", 
    RowBox[{"c", ",", "d"}], ")"}], " ", 
   RowBox[{"de", "(", 
    RowBox[{"x", ",", "a", ",", "b"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "y"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "x"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "x"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "y"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "y"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615532228799724*^9, {3.61553227681817*^9, 3.6155322859991283`*^9}, 
   3.6155364474869967`*^9, {3.6155367062302732`*^9, 3.615536716880876*^9}, 
   3.615536755507143*^9, 3.6156337019261837`*^9, 3.6162145562254143`*^9, 
   3.6173360645915728`*^9, 3.61733818419942*^9, 3.618217331249447*^9, 
   3.619333559191016*^9, 3.619774926320566*^9}]
}, Open  ]],

Cell["This coincides with the result from the manual computation.", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QPSEuIyvIJrHpwhMb9vl/3Dh7VeOWxaVPwHRYdeNeHSev3Ls2aXDC6I3ffGW
AtG/VtUrgehm1fk6IPpBapcBiI55ohUI5kcYh4JoBbaWehD9Znd+I5gfy94D
oj9wOoFpZZGz1oZAWoR7mi2IFmCLXAuiOaQ37APRqzsuvw0D0kY3VD6A6Msb
Pi8S+fDKcVGW+GIQfUhRx1cMSF+6ZwimAXX6nj0=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Order", " ", 
  SuperscriptBox["\[Lambda]", "5"]}]], "Subsection",
 CellChangeTimes->{{3.610941781870956*^9, 3.610941793017185*^9}, 
   3.6144863111905813`*^9, {3.614495279674573*^9, 3.614495280246891*^9}}],

Cell[TextData[{
 "Just do ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "5"], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610878382829616*^9, 
  3.6108783852723837`*^9}, {3.610941741677971*^9, 3.610941751733459*^9}, {
  3.610941798591127*^9, 3.6109418059199543`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag5e", "=", 
  RowBox[{
   RowBox[{"Filter", "[", 
    RowBox[{"Lexpanded$scaled$strip", ",", 
     RowBox[{"\[Lambda]", "^", "5"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "\[Rule]", "1"}], ",", 
     RowBox[{"\[Phi]", "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"D\[Phi]", "[", "a_", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"DD\[Phi]", "[", "aa_", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.610862697072743*^9, {3.61086301200909*^9, 3.610863013753297*^9}, {
   3.6108633360176363`*^9, 3.610863372875196*^9}, {3.610869509199832*^9, 
   3.610869517459168*^9}, {3.610869564542656*^9, 3.610869588213954*^9}, {
   3.61087170251621*^9, 3.610871704828367*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"e", ",", "aa"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "aa"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "bb"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"e", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"e", ",", "aa"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"e", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "aa"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "bb"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"f", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"f", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"f", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"f", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"e", ",", "aa"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"e", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"dd", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"aa", ",", "bb"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"f", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"aa", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"f", ",", "b", ",", "bb"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ee"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "c", ",", "cc"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ee"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ee"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ll"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "c", ",", "cc"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ee"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ll"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"b", ",", "ll"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ll"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BGG", "(", 
     RowBox[{"cc", ",", "dd"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ll"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ll"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"a", ",", "ee"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "c", ",", "cc"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"c", ",", "ee"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ee", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"d", ",", "b", ",", "dd"}], ")"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"a", ",", "c", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"a", ",", "b"}], ")"}], " ", 
    RowBox[{"BG", "(", 
     RowBox[{"c", ",", "d"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "cc"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"d", ",", "ff"}], ")"}], " ", 
    RowBox[{"h", "(", 
     RowBox[{"i", ",", "dd"}], ")"}], " ", 
    RowBox[{"Dh", "(", 
     RowBox[{"c", ",", "a", ",", "cc"}], ")"}], " ", 
    RowBox[{"DDh", "(", 
     RowBox[{"ff", ",", "b", ",", "dd"}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610862697723528*^9, 3.610863014019474*^9, {3.610863336204615*^9, 
   3.6108633731110277`*^9}, {3.610869509930108*^9, 3.6108695181669188`*^9}, {
   3.610869573919915*^9, 3.610869588982315*^9}, 3.61087170595199*^9, 
   3.610948327354187*^9, 3.614415464004671*^9, 3.614486285252597*^9, 
   3.614488577987924*^9, 3.614495169884572*^9, 3.614500537190811*^9, 
   3.614500759580029*^9, 3.6145009015931387`*^9, 3.614505628011756*^9, 
   3.614577108154134*^9, 3.6149371190006323`*^9, 3.615633702022862*^9, 
   3.6162145563414*^9, 3.6173360646798573`*^9, 3.617338184314481*^9, 
   3.6182173313532257`*^9, 3.619333559332487*^9, 3.619774926427765*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Lag5e", "]"}]], "Input",
 CellChangeTimes->{{3.610869528473722*^9, 3.6108695332416697`*^9}, 
   3.6108717121083107`*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 CellChangeTimes->{3.6108695335010767`*^9, 3.610869593595397*^9, 
  3.61087171255167*^9, 3.610948332257307*^9, 3.614415464012644*^9, 
  3.614486285260572*^9, 3.614488578004034*^9, 3.614495169889463*^9, 
  3.6145005372153683`*^9, 3.6145007599140387`*^9, 3.614500901598371*^9, 
  3.6145056280362177`*^9, 3.614577108161312*^9, 3.6149371190136337`*^9, 
  3.615633702040637*^9, 3.616214556372739*^9, 3.617336064696417*^9, 
  3.617338184319429*^9, 3.618217331403963*^9, 3.6193335593797607`*^9, 
  3.61977492643283*^9}]
}, Open  ]],

Cell["\<\
Note that each term appears twice so one has 9 terms if one were to relabel \
dummy indices.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.6168343728384447`*^9, 3.616834444851013*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["\<\
In what follows it is important to maintain the order of replacement rules.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag5e$nicer", "=", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"u", ",", "uu"}], "]"}], 
   RowBox[{"h", "[", 
    RowBox[{"v", ",", "vv"}], "]"}], " ", 
   RowBox[{"h", "[", 
    RowBox[{"w", ",", "ww"}], "]"}], " ", 
   RowBox[{"Dh", "[", 
    RowBox[{"x", ",", "m", ",", "mm"}], "]"}], " ", 
   RowBox[{"Dh", "[", 
    RowBox[{"yy", ",", "n", ",", "nn"}], "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"Lag5e", "/.", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Dh", "[", 
                    RowBox[{"e_", ",", "a_", ",", "cc_"}], "]"}], "\[Rule]", 
                    RowBox[{
                    RowBox[{"BG", "[", 
                    RowBox[{"e", ",", "x"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"a", ",", "m"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"cc", ",", "mm"}], "]"}], 
                    RowBox[{"Dh", "[", 
                    RowBox[{"x", ",", "m", ",", "mm"}], "]"}]}]}], ",", 
                   RowBox[{
                    RowBox[{"DDh", "[", 
                    RowBox[{"dd_", ",", "b_", ",", "bb_"}], "]"}], "\[Rule]", 
                    
                    RowBox[{
                    RowBox[{"BGG", "[", 
                    RowBox[{"dd", ",", "yy"}], "]"}], 
                    RowBox[{"BG", "[", 
                    RowBox[{"b", ",", "n"}], "]"}], 
                    RowBox[{"BGG", "[", 
                    RowBox[{"bb", ",", "nn"}], "]"}], 
                    RowBox[{"Dh", "[", 
                    RowBox[{"yy", ",", "n", ",", "nn"}], "]"}]}]}]}], "}"}]}],
                 ")"}], "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"h", "[", 
                   RowBox[{"a_", ",", "ee_"}], "]"}], " ", 
                  RowBox[{"h", "[", 
                   RowBox[{"c_", ",", "ff_"}], "]"}], " ", 
                  RowBox[{"h", "[", 
                   RowBox[{"b_", ",", "gg_"}], "]"}]}], "\[Rule]", 
                 RowBox[{
                  RowBox[{"BG", "[", 
                   RowBox[{"a", ",", "u"}], "]"}], 
                  RowBox[{"BGG", "[", 
                   RowBox[{"ee", ",", "uu"}], "]"}], 
                  RowBox[{"BG", "[", 
                   RowBox[{"c", ",", "v"}], "]"}], 
                  RowBox[{"BGG", "[", 
                   RowBox[{"ff", ",", "vv"}], "]"}], 
                  RowBox[{"BG", "[", 
                   RowBox[{"b", ",", "w"}], "]"}], 
                  RowBox[{"BGG", "[", 
                   RowBox[{"gg", ",", "ww"}], "]"}], 
                  RowBox[{"h", "[", 
                   RowBox[{"u", ",", "uu"}], "]"}], 
                  RowBox[{"h", "[", 
                   RowBox[{"v", ",", "vv"}], "]"}], 
                  RowBox[{"h", "[", 
                   RowBox[{"w", ",", "ww"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
             
             RowBox[{"{", 
              RowBox[{
               RowBox[{"BG", "[", 
                RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
               RowBox[{"d", "[", 
                RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Contract", "[", 
              RowBox[{"d", "[", 
               RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
             RowBox[{"BG", "[", 
              RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"BGG", "[", 
            RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
           RowBox[{"d", "[", 
            RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{"d", "[", 
           RowBox[{"a_", ",", "b_"}], "]"}], "]"}], "\[Rule]", 
         RowBox[{"BGG", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"u", ",", "uu"}], "]"}], 
        RowBox[{"h", "[", 
         RowBox[{"v", ",", "vv"}], "]"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"w", ",", "ww"}], "]"}], " ", 
        RowBox[{"Dh", "[", 
         RowBox[{"x", ",", "m", ",", "mm"}], "]"}], " ", 
        RowBox[{"Dh", "[", 
         RowBox[{"yy", ",", "n", ",", "nn"}], "]"}]}], "\[Rule]", "1"}], 
      "}"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.610871714854949*^9, 3.6108717524276943`*^9}, {
   3.610871792868222*^9, 3.610871828546763*^9}, {3.610871860064332*^9, 
   3.610871988648801*^9}, {3.610872141630171*^9, 3.610872278032997*^9}, {
   3.61087236730477*^9, 3.6108726820248947`*^9}, {3.6108727130845327`*^9, 
   3.610872770672801*^9}, 3.610872926054221*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"h", "(", 
    RowBox[{"u", ",", "uu"}], ")"}], " ", 
   RowBox[{"h", "(", 
    RowBox[{"v", ",", "vv"}], ")"}], " ", 
   RowBox[{"h", "(", 
    RowBox[{"w", ",", "ww"}], ")"}], " ", 
   RowBox[{"Dh", "(", 
    RowBox[{"x", ",", "m", ",", "mm"}], ")"}], " ", 
   RowBox[{"Dh", "(", 
    RowBox[{"yy", ",", "n", ",", "nn"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "yy"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "vv"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"ww", ",", "yy"}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"ww", ",", "yy"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "yy"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "ww"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "w"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "x"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "yy"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "ww"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "w"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "x"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "yy"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "ww"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "yy"}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "yy"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "yy"}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "yy"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "v"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "yy"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"vv", ",", "ww"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "w"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "x"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "yy"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"vv", ",", "ww"}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "w"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "x"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "yy"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"vv", ",", "ww"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "uu"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"vv", ",", "yy"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "v"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "w"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"vv", ",", "yy"}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "w"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "x"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"vv", ",", "yy"}], ")"}]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "u"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"n", ",", "w"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "x"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "nn"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"uu", ",", "ww"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"vv", ",", "yy"}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"m", ",", "n"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"u", ",", "x"}], ")"}], " ", 
      RowBox[{"BG", "(", 
       RowBox[{"v", ",", "w"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"mm", ",", "vv"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"nn", ",", "uu"}], ")"}], " ", 
      RowBox[{"BGG", "(", 
       RowBox[{"ww", ",", "yy"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.61087277173464*^9, 3.6108729277434473`*^9, 
  3.6109483353344*^9, 3.614415464393178*^9, 3.614486285652422*^9, 
  3.614488578372788*^9, 3.6144951702763567`*^9, 3.61450053764157*^9, 
  3.6145007602879744`*^9, 3.614500901978115*^9, 3.614505628471363*^9, 
  3.614577108569888*^9, 3.61493711939373*^9, 3.6156337024135227`*^9, 
  3.616214556751717*^9, 3.617336065072776*^9, 3.6173381846956167`*^9, 
  3.61821733178082*^9, 3.6193335597950563`*^9, 3.619774926815431*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Lag5e$nicer", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.610872657627907*^9, 3.610872659044886*^9}, {
  3.610872939019191*^9, 3.610872942388152*^9}}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610872659376094*^9, {3.61087293522755*^9, 3.610872942628978*^9}, 
   3.6109483384655733`*^9, 3.614415464612212*^9, 3.614486285955612*^9, 
   3.61448857837994*^9, 3.61449517055791*^9, 3.614500537647081*^9, 
   3.614500760295273*^9, 3.61450090225412*^9, 3.614505628488991*^9, 
   3.6145771086506653`*^9, 3.614937119399157*^9, 3.6156337024507027`*^9, 
   3.6162145568149977`*^9, 3.617336065109991*^9, 3.617338184736203*^9, 
   3.618217331788911*^9, 3.619333559804304*^9, 3.619774926820724*^9}]
}, Open  ]],

Cell["\<\
Take indices at h, Dh, DDh all downstairs and all indices at BG, BGG \
upstairs.
Then transition to world indices is easy:
h -> e
Dh -> partial e
DDh -> partial e
BG -> -1/2 G
BGG -> 1/2 G\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Lag5e$nicer$world", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Lag5e$nicer", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"BG", "[", 
         RowBox[{"a_", ",", "b_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], 
         RowBox[{"d", "[", 
          RowBox[{"a", ",", "b"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"BGG", "[", 
         RowBox[{"aa_", ",", "bb_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "2"}], 
         RowBox[{"d", "[", 
          RowBox[{"aa", ",", "bb"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"h", "[", 
         RowBox[{"a_", ",", "aa_"}], "]"}], "\[Rule]", 
        RowBox[{"e", "[", 
         RowBox[{"a", ",", "aa"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Dh", "[", 
         RowBox[{"e_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
        RowBox[{"de", "[", 
         RowBox[{"e", ",", "a", ",", "aa"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"DDh", "[", 
         RowBox[{"ee_", ",", "a_", ",", "aa_"}], "]"}], "\[Rule]", 
        RowBox[{"de", "[", 
         RowBox[{"ee", ",", "a", ",", "aa"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "\[Rule]", "a"}], ",", 
     RowBox[{"uu", "\[Rule]", "b"}], ",", 
     RowBox[{"v", "\[Rule]", "c"}], ",", 
     RowBox[{"vv", "\[Rule]", "d"}], ",", 
     RowBox[{"w", "\[Rule]", "e"}], ",", 
     RowBox[{"ww", "\[Rule]", "f"}], ",", 
     RowBox[{"m", "\[Rule]", "g"}], ",", 
     RowBox[{"mm", "\[Rule]", "h"}], ",", 
     RowBox[{"n", "\[Rule]", "i"}], ",", 
     RowBox[{"nn", "\[Rule]", "j"}], ",", 
     RowBox[{"yy", "\[Rule]", "y"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.610873166402734*^9, 3.610873178499647*^9}, {
  3.6108733510464487`*^9, 3.61087346623492*^9}, {3.610951454001822*^9, 
  3.610951609101659*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"e", "(", 
    RowBox[{"e", ",", "f"}], ")"}], " ", 
   RowBox[{"e", "(", 
    RowBox[{"a", ",", "b"}], ")"}], " ", 
   RowBox[{"e", "(", 
    RowBox[{"c", ",", "d"}], ")"}], " ", 
   RowBox[{"de", "(", 
    RowBox[{"x", ",", "g", ",", "h"}], ")"}], " ", 
   RowBox[{"de", "(", 
    RowBox[{"y", ",", "i", ",", "j"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]]}], "+", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]]}], "+", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]]}], "+", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "x"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "j"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "x"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "b"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "y"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "b"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "f"}]]}], "+", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "f"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "y"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "y"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "y"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "x"}]]}], "+", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "f"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "i"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "y"}]]}], "-", 
     RowBox[{
      FractionBox["1", "128"], " ", 
      SuperscriptBox["g", 
       RowBox[{"g", "a"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"h", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"j", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"i", "x"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.610873376278751*^9, 3.610873383123464*^9}, {
   3.6108734246788483`*^9, 3.6108734683330936`*^9}, 3.6109483409033537`*^9, {
   3.610951504924159*^9, 3.610951577597515*^9}, 3.610951609403201*^9, 
   3.614415464738339*^9, 3.6144862860581207`*^9, 3.6144885784500732`*^9, 
   3.614495170628004*^9, 3.614500537723549*^9, 3.6145007603656263`*^9, 
   3.614500902324642*^9, 3.6145056285582237`*^9, 3.6145771087691383`*^9, 
   3.6149371194769382`*^9, 3.615633702528212*^9, 3.6162145568881702`*^9, 
   3.617336065193254*^9, 3.617338184817762*^9, 3.618217331861981*^9, 
   3.6193335598893833`*^9, 3.6197749268965816`*^9}]
}, Open  ]],

Cell["As of now, we don\[CloseCurlyQuote]t want to check this by hand.", \
"Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}, {
  3.61095184326226*^9, 3.6109518571404533`*^9}, {3.614488287441825*^9, 
  3.6144882932954483`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Te5", "[", 
   RowBox[{
   "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
    ",", "h_", ",", "i_", ",", "j_", ",", "x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"4", "Lag5e$nicer$world"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"e_", ",", "f_"}], "]"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"de", "[", 
        RowBox[{"x_", ",", "g_", ",", "h_"}], "]"}], "\[Rule]", "1"}]}], 
     "}"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.610951690167588*^9, 3.61095178981669*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "b"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "b"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "a"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.610951760161627*^9, 3.610951790172855*^9}, 
   3.614415464865177*^9, 3.61448628614642*^9, 3.6144885785270023`*^9, 
   3.6144951706990557`*^9, 3.614500537806335*^9, 3.614500760446597*^9, 
   3.61450090239748*^9, 3.614505628635091*^9, 3.614577108869308*^9, 
   3.614937119550378*^9, 3.615633702605826*^9, 3.616214556985175*^9, 
   3.6173360652653503`*^9, 3.6173381849167337`*^9, 3.618217331944642*^9, 
   3.619333560003518*^9, 3.619774926980958*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"18", "*", "120"}]], "Input",
 CellChangeTimes->{{3.610878406453113*^9, 3.610878407456635*^9}}],

Cell[BoxData[
 FormBox["2160", TraditionalForm]], "Output",
 CellChangeTimes->{3.6108784075558157`*^9, 3.6144154649147882`*^9, 
  3.614486286181673*^9, 3.61448857854679*^9, 3.614495170713623*^9, 
  3.6145005378497133`*^9, 3.614500760474093*^9, 3.614500902412909*^9, 
  3.614505628904948*^9, 3.614577108885192*^9, 3.6149371195806923`*^9, 
  3.6156337026231537`*^9, 3.616214557018571*^9, 3.617336065282061*^9, 
  3.617338184950613*^9, 3.618217331969853*^9, 3.619333560050927*^9, 
  3.619774927017737*^9}]
}, Open  ]],

Cell["\<\
The factor of 4 is because we rescale Siegel\[CloseCurlyQuote]s Lagrangian in \
Hohm\[CloseCurlyQuote]s paper by an overall factor of 4.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QPSEuIyvIJrHpwhMb9vl/3Dh7VeOWxaVPwHRYdeNeHSev3Ls2aXDC6I3ffGW
AtG/VtUrgehm1fk6IPpBapcBiI55ohUI5kcYh4JoBbaWehD9Znd+I5gfy94D
oj9wOoFpZZGz1oZAWoR7mi2IFmCLXAuiOaQ37APR+SkZIhFAekadihiIzlN+
d1vs3SvHgJKVd0D0jjn2BUmfgO5bb10KogEMg5yU
  "],
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["DFT Vertices", "Section",
 CellChangeTimes->{{3.5916907485189943`*^9, 3.591690811930585*^9}, {
  3.601882516907148*^9, 3.601882518176723*^9}, {3.6023972862113867`*^9, 
  3.602397286658449*^9}}],

Cell["\<\
Using momentum conservation I always eliminate the momentum associated to \
internal lines. This effects in reducing the number of terms in the vertex by \
means of transversality of polarization vectors.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}, {
  3.6018981768367767`*^9, 3.60189824292979*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[TextData[{
 "evv vertex ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["e", "ij"], "[", 
     SubscriptBox["k", "1"], "]"}]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"varphi", "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"varphi", "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 "):"
}], "Subsection",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018912535763903`*^9, 3.601891268031275*^9}, {
  3.601891393714752*^9, 3.601891395384281*^9}, {3.601892474737091*^9, 
  3.601892475957505*^9}, {3.60189288581454*^9, 3.6018930184433737`*^9}, {
  3.6018931370008802`*^9, 3.6018931470476007`*^9}, {3.6144952963168383`*^9, 
  3.614495296647709*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], "I", " ", 
   RowBox[{"k", "[", 
    RowBox[{"1", ",", "i"}], "]"}], 
   RowBox[{"k", "[", 
    RowBox[{"1", ",", "j"}], "]"}]}], "+", 
  RowBox[{"4", "I", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"k", "[", 
       RowBox[{"2", ",", "i"}], "]"}], 
      RowBox[{"k", "[", 
       RowBox[{"3", ",", "j"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"k", "[", 
       RowBox[{"3", ",", "i"}], "]"}], 
      RowBox[{"k", "[", 
       RowBox[{"2", ",", "j"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.601892804387533*^9, 3.601892843591131*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", "\[ImaginaryI]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], "i"], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], "j"]}], "+", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], "i"], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], "j"]}]}], ")"}]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "i"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "j"]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz1tMkmEcBnBSp+XMcVHTJUSGs4OUlGkqs3pdWuGqhSxAWSuHLslllk6Z
brJlbc1O4kJnWro1NyWJJevwSTNXmq2oLiyQDxEoKt4UU2C0pMP/vXj2u3ku
nie5rFpUvoLBYByD3Nh97RnzE0aClypZNrgxk0UTA3Rh8TAYK3cEidmrNDFG
sDRlLJkY1xGup0D19s2sHAtGrY+uHKFB678CNbGyuU8htWJUYOUoSsFbLDW1
yYaRlK9tTwO7w0FJOmhUZ3r5YETr2zBxl9I5YQFLfLIvxLVJ2jVW0o/OyyAm
1U7uIepiepXTYGLVTQ9x67IkRDTWrL9uA/VXvU9pMKvIc09EY8Q8cVojBnWH
KW0/2IXbhogHU+frBsCSVzUzZpDRWa4PgytV3Rai6YLmB5EXXxv3Bzz3bWQf
0bPadoY40UA9IC6c9+XetmNETUcP3gFHytxF/eAhD5daBHl1UXNEaf3ztCXQ
1KNqIYpTJzt/g3juYoiY5z7LXgaF+xvNCzMYtaTL2QmzGCl2HHAKnRi52/du
ELjgd518WOvGaBbJ7B3glJGLXKD8Y2ND22eM8quEiQ/BKd1oxCi40/56zAGa
PlDjQx6MKuqzBp0gX/9m4O9XjOijhoLxeYzecUWMBB9GvU2S7HWgLyCwsMCK
40w/0fHEHMUGDV13izlgfKAnNx/8HuuPXALfGywphT8xarrf9+LUIuzUbjl5
yY+RSsOpvAwaPM36jCBGym2Rj8UhjLzVrhzeL4z+A5Cneok=
  "]]
}, Open  ]],

Cell["\<\
For onshell external leg e one would get (using transversality):\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"4", "I", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"k", "[", 
      RowBox[{"2", ",", "i"}], "]"}], 
     RowBox[{"k", "[", 
      RowBox[{"3", ",", "j"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"k", "[", 
      RowBox[{"3", ",", "i"}], "]"}], 
     RowBox[{"k", "[", 
      RowBox[{"2", ",", "j"}], "]"}]}]}], ")"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"4", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], "i"], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], "j"]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], "i"], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], "j"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0VtMkmEcBnAwp61Rq61lNTCgpk1ch3mD1MzXVTJprdAmiHPlMJdeVKjT
Fgmr9KJlW7KMaisPREOHbmInOrhUuLBhq5UQH9inItLrIZSIQtD+78Wz357b
5+GVX5RWMBkMxmmIK9jh2jyO0fKKWi4EBzdxKOLRz/mFFjDaQoeJH9+1Jg+A
O6aHeMSK+Fq9FUwd2cvOdmLU1Xf7JAXSdrGWeL2mUylzYRRv4CsVIP9SkzXd
jVFA/1AnAA21seL9oDJJ+PMA+Fw/FiOWVc7aneCGJwofUZWh3+oCTz09kkW8
5R/NIWayjFXfwRqJboY4oSmJEJ0K3h03yO9aeE2BX80Bg5TC6NW+qtYisDRs
bTOCtXP3zETT+2CdCbxcoPI6wJSW870x8AWz3Un8otTNEWlFHSsOjvve5hLl
u6lqonb2TR8xIAiKHnkw2ti4vvsxaHX4JEYwNy3NugTm3EiaJ564OixYBqlk
9U3iH82oPgp6Vu0RIuugirMC4oRrjl9e2INdxkn5gZHIm08X0NAZedxDkxid
+VdqaZuCfyxyz31w0Z+OJkHDgLrh7jTsUyzZ3g9KSoYSBsGSRMeHCdD9bNBm
nsFIXC7qpkFN9SfTqh8jnqz/mG0Bowe/pYyURYzKU2XCnWBP9LCTDTaKt4SI
qcqxRA44z+0o3AVyje2iPPCKLrRuGVzTufYcD2LE9HQOn1vCqFKYcbYphJFt
nHuhGWwe0fZmhTFK+pb4siiC0bb6qezMvxj9B1UBgKo=
  "]]
}, Open  ]],

Cell["\<\
Note that this vertex is not needed for the 4e tree-level scattering \
amplitude.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}, {
  3.602226206226873*^9, 3.602226218098637*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
   3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
   3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}, 
   3.6018932060464363`*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eev vertex ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["e", "ab"], "[", 
     SubscriptBox["k", "1"], "]"}]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"varphi", "[", 
     SubscriptBox["k", "3"], "]"}]}], TraditionalForm]]],
 "):"
}], "Subsection",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018912535763903`*^9, 3.601891268031275*^9}, {
  3.601891393714752*^9, 3.601891395384281*^9}, {3.601893071374762*^9, 
  3.6018931315676117`*^9}, {3.601893173911818*^9, 3.601893175291648*^9}, {
  3.614495303603099*^9, 3.614495303919539*^9}}],

Cell["\<\
Define the following spacetime tensors that appear in this vertex.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601893456182308*^9, 3.6018934653103437`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T1", "[", 
   RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "a"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "y"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "d"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "b"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}]}]}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.6017894162385187`*^9, 3.6017894870146027`*^9}, {
  3.601789584159692*^9, 3.601789585391869*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0WtMElAUAGAyH7O5NcvNNPDR7KG4YnNzgIxxmboiswRqmEXaqFXY3Fwk
q5XOFX9szDChlSsnRsKCGrBaLCiXVD9iWawgHoYiua5lIpisrHXuj7tv95zt
nLNzSo93CE+soVAoTfDe6nj1Ux8xepFqERJDfT3NzE8YWb1FQeKHxd0iG6hp
jy4TBbLBLDu42ewuJaY705QOsFZUQWX5MEpJ+xuD4N3z+3qIDNWoTOLHyJC9
TdYCNkT6HNsDkD85PEAHD9nTJLtA6x72Nwb43jW5SnzDW3jlA/vzpLPEUMNQ
np/Eq/lVROpBD5cY6Dae+QyWGbUxYu7E0RXiox1b1QFStzP+NAjeV86PCoMY
OcfaNWLw2mGn1gAWnr1lJkYqkwojWD2oCHvAMbPcsgo+Pqf3EWdzdfPEpowL
OX/BuZxxHlGuDsuJDJbrIbHzWIJ9O4SRJWOd6Q5oss/tNYASf7kjDhYVZH8n
2ne+pi+BqvWXrxCPPPPc/A0mGxW0P+ABebfnZxiji11ttPwv8C8XRAQRjOoe
1JbUTGNUfKrVpp3ByDUiDelATYyOpsEOao/yehT2k7l/kxW8tNGd9hxMxSfH
p8CaoQm3OQZ9+FxTBOQkvMZ/XzEqmbHVuX/APjvElPwFjHoHmpmF4I0Cro8K
3gtsSBC10+/SaSBTrxcVg5zYCJsPSpLJtUtghTpQVr+I0S/v6Mu2OKint15N
kLtvOa0CM7t6LVXLMC8n64l4BSPHcJRVmcLoP3B8e2o=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T2", "[", 
   RowBox[{"a_", ",", "b_", ",", "i_", ",", "j_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "i"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "a"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "j"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "a"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "i"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "j"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "b"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "i"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "j"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "j"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "i"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "b"}], "]"}]}]}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.6017895067142143`*^9, 3.6017895936657887`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.601789578764471*^9, 3.601789594226276*^9}, 
   3.601973964153541*^9, 3.6019750010260487`*^9, 3.602225818341359*^9, 
   3.602227119201438*^9, 3.602227260728923*^9, 3.602227470229423*^9, 
   3.6022404481715403`*^9, 3.602499809378223*^9, 3.6028319885900307`*^9, 
   3.602832386530897*^9, 3.603088165213447*^9, 3.603094305306612*^9, 
   3.604037076480433*^9, 3.6040449571563883`*^9, 3.604052672320191*^9, 
   3.604055881934833*^9, 3.6040560386235733`*^9, 3.604397623704483*^9, 
   3.604397858992403*^9, 3.604398244951819*^9, 3.6043984901892157`*^9, 
   3.604398582528446*^9, 3.604400981415333*^9, 3.604401964819985*^9, 
   3.604402107010306*^9, 3.604403313255857*^9, 3.604405712040655*^9, 
   3.604649255477004*^9, 3.604653203561613*^9, 3.60482117401153*^9, 
   3.604821356954891*^9, 3.604827055787112*^9, 3.604901611793281*^9, 
   3.604997491493676*^9, 3.604997821255968*^9, 3.604997980937477*^9, 
   3.60499824391955*^9, 3.604998662121272*^9, 3.604999007039194*^9, 
   3.604999550068486*^9, 3.60532219971542*^9, 3.605329232400839*^9, 
   3.6053448633411417`*^9, 3.605499345410748*^9, 3.605499744368561*^9, 
   3.6055002543460903`*^9, 3.605500964048168*^9, 3.605517510606249*^9, 
   3.605518571800866*^9, 3.606019692063045*^9, 3.606624491146577*^9, 
   3.6072547863793287`*^9, 3.6077468182359324`*^9, 3.608458651158875*^9, 
   3.6084610271030807`*^9, 3.6086113375354023`*^9, 3.608972228155966*^9, 
   3.609039042555521*^9, 3.609065494245462*^9, 3.609130510628025*^9, 
   3.610078766300055*^9, 3.610182994099846*^9, 3.6107687194430723`*^9, 
   3.614321197715268*^9, 3.61448857868357*^9, 3.6144951708534203`*^9, 
   3.614500538000307*^9, 3.614500760891762*^9, 3.6145009025507803`*^9, 
   3.614505629224084*^9, 3.614577109203548*^9, 3.614937119698279*^9, 
   3.615633702891416*^9, 3.616214557221353*^9, 3.61733606541672*^9, 
   3.617338185163064*^9, 3.618217332120614*^9, 3.619333560324346*^9, 
   3.619774927176012*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T1", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "x", ",", "y"}], "]"}], 
  "-", 
  RowBox[{"T2", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "x", ",", "y"}], "]"}], 
  "+", 
  RowBox[{"T1", "[", 
   RowBox[{"c", ",", "d", ",", "a", ",", "b", ",", "y", ",", "x"}], "]"}], 
  "-", 
  RowBox[{"T2", "[", 
   RowBox[{"c", ",", "d", ",", "a", ",", "b", ",", "y", ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.601789607571065*^9, 3.601789652574258*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "x"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "y"}]]}]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0GtI02EUBvClkoWZQiMjXCmtRAxXTEoNqjdw0sWRboSXoJIpqwihMFZp
jObE+mBaNKXFsiyn003Y1GLUzGozwkkq8782d2+j3ta8DJ20NTrvh8MPnk/P
c7JrGyrqNtBotAo4HB2qdlowOtsRCRClmwevp89j1PPgYVUh2F/OtBP9PC5P
B457g6vEa1+eJo+AE6apbKIhJ12kBw/58zOLKIwwXc61g4HpGjFRSKkElVaM
7o2xBTVg+/tn+hwbRllo9HEemLiHWckCL3SV/DoAOly2GHHMkDJJgQnVdT+I
5qrXdCv4wc1lE+MW61Fij3b0yneQrnjpJ46IhRFid9/Bdhv4uYGut4O03LVX
FXaMmntFj/igSvNR1ge+S+tVEwsMscYBcEnU5DCD2skbmhjoPTNIEW9ZX/wm
OmvFW/6B/G+m48TgsO8q0dVmHCa2pcaL5QsY3VRuVSlAzbbQ6T7w9iaWfhlk
6VKDxFDAnLcC7l2TtBCl2+e7/4Lpac2MKKi4LzEvOjAamqtnZLhg764y9yk3
RscEJ7OOeKC/WqiTeTFKahQudIHl5sPIA7YsSkWdPoyaZng7tKBs9mvCOEjv
pCacYOnzGaPaD3lyqcoN2jzhgXgA/jr1tsT4B6N1yzlaRgj20s8X7gTlDERl
gvoORpgo4s0mMcAnnH7ebrBeoiw+AXIKIokrYOyug8lZwmi6tf/TpWWMcsvy
L0rDGPmU+y63gnMbpRr2KkamaMobfgSjOz8DRfvXMfoPfwqKHg==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEVarphi", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "I"}], "/", "2"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "y"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"T1", "[", 
           RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "x", ",", "y"}], 
           "]"}], "-", 
          RowBox[{"T2", "[", 
           RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "x", ",", "y"}], 
           "]"}], "+", 
          RowBox[{"T1", "[", 
           RowBox[{"c", ",", "d", ",", "a", ",", "b", ",", "y", ",", "x"}], 
           "]"}], "-", 
          RowBox[{"T2", "[", 
           RowBox[{"c", ",", "d", ",", "a", ",", "b", ",", "y", ",", "x"}], 
           "]"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "y"}], "]"}], 
        RowBox[{"T2", "[", 
         RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "x", ",", "y"}], 
         "]"}]}], "-", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "y"}], "]"}], 
        RowBox[{"T2", "[", 
         RowBox[{"c", ",", "d", ",", "a", ",", "b", ",", "x", ",", "y"}], 
         "]"}]}]}], ")"}]}], "//", "Expand"}], "//", "Contract"}]}]], "Input",\

 CellChangeTimes->{{3.60481098964629*^9, 3.604811097199898*^9}, {
   3.6048111318356667`*^9, 3.6048111405342293`*^9}, 3.604811430458123*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604811132659042*^9, 3.604811141183158*^9}, 
   3.604811431475914*^9, 3.604821174173012*^9, 3.604821357230606*^9, 
   3.604827056154512*^9, 3.60490161203293*^9, 3.604997491732175*^9, 
   3.6049978216234903`*^9, 3.604997981178953*^9, 3.60499824415624*^9, 
   3.60499866235787*^9, 3.604999007224132*^9, 3.604999550272337*^9, 
   3.605322200110696*^9, 3.605329232586961*^9, 3.6053448636703253`*^9, 
   3.605499345597546*^9, 3.6054997445586643`*^9, 3.605500254602614*^9, 
   3.605500964271229*^9, 3.6055175108433113`*^9, 3.60551857200904*^9, 
   3.606019692232768*^9, 3.606624491369512*^9, 3.607254786511277*^9, 
   3.6077468184376593`*^9, 3.608458651461705*^9, 3.608461027437421*^9, 
   3.608611337878314*^9, 3.608972228302409*^9, 3.609039042702209*^9, 
   3.609065494501326*^9, 3.6091305109104567`*^9, 3.610078766783864*^9, 
   3.610182994592451*^9, 3.610768719983745*^9, 3.6143211979057217`*^9, 
   3.6144885788132763`*^9, 3.614495170977206*^9, 3.614500538148203*^9, 
   3.6145007610286207`*^9, 3.6145009026723127`*^9, 3.614505629368354*^9, 
   3.614577109338982*^9, 3.61493711982216*^9, 3.615633703023793*^9, 
   3.616214557381877*^9, 3.617336065546208*^9, 3.617338185322565*^9, 
   3.618217332261148*^9, 3.6193335605018873`*^9, 3.6197749273283*^9}]
}, Open  ]],

Cell["\<\
If the two e\[CloseCurlyQuote]s are onshell using transversality simplifies \
the vertex.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEVARPHIonshell12", "=", 
  RowBox[{"verEEVarphi", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.604811249490872*^9, 3.6048112609824543`*^9}, 
   3.604811482513871*^9, {3.614488644409807*^9, 3.614488682718004*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   RowBox[{
    FormBox[
     SubscriptBox["k", "1"],
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "2"],
     TraditionalForm]}], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6048112620351753`*^9, 3.604811434224794*^9, 3.604811483957315*^9, 
   3.6048211742353687`*^9, 3.604821357390602*^9, 3.604827056180586*^9, 
   3.60490161206254*^9, 3.6049974919991093`*^9, 3.6049978216666603`*^9, 
   3.6049979812088423`*^9, 3.604998244256411*^9, 3.60499866246132*^9, 
   3.6049990072878733`*^9, 3.604999550353257*^9, 3.605322200153384*^9, 
   3.6053292326355057`*^9, 3.605344863804853*^9, 3.605499345644883*^9, 
   3.605499744609663*^9, 3.6055002547873287`*^9, 3.6055009643450413`*^9, 
   3.60551751091882*^9, 3.605518572113522*^9, 3.6060196922927*^9, 
   3.606624491434911*^9, 3.607254786535459*^9, 3.607746818501131*^9, 
   3.608458651698627*^9, 3.608461027590166*^9, 3.60861133803335*^9, 
   3.6089722284286423`*^9, 3.609039042767797*^9, 3.609065494584264*^9, 
   3.6091305111103086`*^9, 3.610078766938858*^9, 3.610182994720662*^9, 
   3.610768720181116*^9, 3.614321197954088*^9, 3.614488578842798*^9, {
   3.6144886483134403`*^9, 3.6144886832003603`*^9}, 3.614495170997897*^9, 
   3.61450053817232*^9, 3.614500761052937*^9, 3.614500902693625*^9, 
   3.614505629397423*^9, 3.614577109403846*^9, 3.6149371198383636`*^9, 
   3.6156337030423393`*^9, 3.6162145574152822`*^9, 3.617336065565217*^9, 
   3.617338185356821*^9, 3.618217332286209*^9, 3.6193335605509567`*^9, 
   3.619774927357888*^9}]
}, Open  ]],

Cell["\<\
This is the e e varphi vertex with two onshell external legs e1 and e2.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["\<\
For later use in the 6e amplitude, we also define a vertex function for the \
ee varphi vertex with one onshell e:\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.60489420998473*^9, 3.6048942328677387`*^9}, {3.604894273873197*^9, 
  3.604894283418239*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEVarphionshellem", "[", 
   RowBox[{"m_", ",", "n_", ",", "a_", ",", "b_", ",", "c_", ",", "d_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"verEEVarphi", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "a_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"m", ",", "a"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "a_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"n", ",", "a"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
        RowBox[{"kdotk", "[", 
         RowBox[{"m", ",", "n"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"m", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"m", ",", "b"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.604894307755622*^9, 3.604894319616037*^9}, {
   3.604894351288178*^9, 3.6048943531438637`*^9}, {3.604894433588751*^9, 
   3.604894446889791*^9}, 3.604894619220447*^9, {3.604894726767516*^9, 
   3.60489477747863*^9}, {3.6048948105404987`*^9, 3.604894836902709*^9}, {
   3.604895086667124*^9, 3.604895088591473*^9}, {3.6048951191329947`*^9, 
   3.604895147605044*^9}, {3.604895278773123*^9, 3.6048952959322243`*^9}, {
   3.614488712873962*^9, 3.614488778234728*^9}, {3.614488882197124*^9, 
   3.614488925242697*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "m"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "n"],
      TraditionalForm]}]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604895148067862*^9, 3.604895303857538*^9, 3.604901612308297*^9, 
   3.604997492039898*^9, 3.60499782170794*^9, 3.604997981244581*^9, 
   3.604998244357575*^9, 3.6049986625507174`*^9, 3.604999007420578*^9, 
   3.604999550529579*^9, 3.6053222002101994`*^9, 3.6053292326991787`*^9, 
   3.605344863878566*^9, 3.605499345708823*^9, 3.605499744726705*^9, 
   3.605500254886924*^9, 3.605500964429884*^9, 3.605517511083807*^9, 
   3.605518572340138*^9, 3.606019692390787*^9, 3.606624491507718*^9, 
   3.607254786573455*^9, 3.607746818569578*^9, 3.6084586518207197`*^9, 
   3.6084610277428293`*^9, 3.608611338160371*^9, 3.6089722285947313`*^9, 
   3.609039042836166*^9, 3.609065494675082*^9, 3.609130511302341*^9, 
   3.610078767107895*^9, 3.610182994845312*^9, 3.6107687202942038`*^9, 
   3.61432119804178*^9, 3.6144885790688066`*^9, 3.614488742201964*^9, 
   3.614488782445526*^9, {3.614488885416812*^9, 3.6144889257924356`*^9}, 
   3.614495171022786*^9, 3.614500538201149*^9, 3.614500761081376*^9, 
   3.614500902718926*^9, 3.6145056294247513`*^9, 3.6145771094740868`*^9, 
   3.614937119860621*^9, 3.615633703069257*^9, 3.616214557457266*^9, 
   3.617336065589966*^9, 3.617338185400036*^9, 3.618217332317583*^9, 
   3.619333560605369*^9, 3.619774927385203*^9}]
}, Open  ]],

Cell["There we\[CloseCurlyQuote]ll also use the following vertices.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.60489420998473*^9, 3.6048942328677387`*^9}, {3.604894273873197*^9, 
  3.604894283418239*^9}, {3.604998569623143*^9, 3.604998588016172*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEVarphionshellemMod1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"verEEVarphionshellem", "[", 
     RowBox[{"3", ",", "12", ",", "e", ",", "f", ",", "i", ",", "j"}], "]"}], 
    "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"12", ",", "e_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "e"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "e"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"3", ",", "12"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"3", ",", "1"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"3", ",", "2"}], "]"}]}]}]}], "}"}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.604895342412258*^9, 3.6048953730677977`*^9}, {
  3.604896619809071*^9, 3.604896818492854*^9}, {3.604896871422901*^9, 
  3.6048968736710577`*^9}, {3.604896949174205*^9, 3.604896972816546*^9}, {
  3.614489028036065*^9, 3.6144891628269577`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604895373530587*^9, 3.604896624154449*^9, {3.604896732528427*^9, 
   3.6048967903276253`*^9}, 3.6048968740969477`*^9, 3.604896975023645*^9, 
   3.604901675938511*^9, 3.6049044203399563`*^9, 3.604904450876053*^9, 
   3.60499665144049*^9, 3.604997575506256*^9, 3.604998062998085*^9, 
   3.604998325327511*^9, 3.604998662670767*^9, 3.6049990074826508`*^9, 
   3.60499955061764*^9, 3.605322200297578*^9, 3.605329232769217*^9, 
   3.605344863962634*^9, 3.605499345842638*^9, 3.605499744807642*^9, 
   3.6055002549721937`*^9, 3.605500964522304*^9, 3.6055175111787233`*^9, 
   3.605518276558817*^9, 3.6055185724584303`*^9, 3.606019692447878*^9, 
   3.606624491604466*^9, 3.607254786623478*^9, 3.607746818662867*^9, 
   3.608458651930723*^9, 3.6084610279130993`*^9, 3.608611338315983*^9, 
   3.608972228724139*^9, 3.6090390429117327`*^9, 3.609065494871396*^9, 
   3.609130511396497*^9, 3.610078767261591*^9, 3.6101829950580463`*^9, 
   3.610768720400835*^9, 3.614321198359598*^9, 3.614488579109231*^9, {
   3.614489038365506*^9, 3.614489063023028*^9}, 3.61448911618325*^9, 
   3.614489163802743*^9, 3.6144951710579367`*^9, 3.61450053824609*^9, 
   3.614500761119749*^9, 3.614500902755265*^9, 3.614505629467957*^9, 
   3.614577109552483*^9, 3.614937119892776*^9, 3.6156337031073008`*^9, 
   3.616214557508143*^9, 3.61733606561444*^9, 3.617338185453002*^9, 
   3.618217332360898*^9, 3.61933356065401*^9, 3.6197749274315767`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEVarphionshellemMod2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"verEEVarphionshellem", "[", 
     RowBox[{"4", ",", "56", ",", "g", ",", "h", ",", "ii", ",", "jj"}], 
     "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"56", ",", "e_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "e"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"6", ",", "e"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"i_", ",", "56"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"i", ",", "5"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"i", ",", "6"}], "]"}]}]}]}], "}"}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.604895387461796*^9, 3.604895396256098*^9}, {
  3.604895483437841*^9, 3.604895484280203*^9}, {3.604896879865027*^9, 
  3.604896916404258*^9}, {3.604896979474276*^9, 3.604896980926681*^9}, {
  3.604904423053707*^9, 3.6049044248319483`*^9}, {3.614489208466453*^9, 
  3.614489291145294*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["ii",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "jj"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["ii",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "jj"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["ii",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "jj"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["ii",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "jj"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "ii"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["jj",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "ii"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["jj",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "ii"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["jj",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "ii"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["jj",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "ii"}]], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "4"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "5"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "jj"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "ii"}]], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "4"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "6"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "jj"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz00ow3Ecx/G/hxLtwmEWW6PGgR00EpbyJcqSZ0rtME/JQ4nykKImTwcP
s8MILQc5LPM0sZZI2ogQBw8Zm4fN+uVhG9rC8P0dPr1O78Mnuqq5uNaPYZhk
nPBcYzm4JqCUrysP0avBpSnq80mv7Qjd4yenn6DqBz5QWxS67B+UXeTWUyd1
tk9qwayW7UM3yy8zqMNN7kaqWXyxRM3vYYmnzQRE3giNGl3wMXnzaFhwhsGF
xrVxn6lrW/fxbnQwRtVHfUpxTH6h5U6dlyrtU/K+0Q+j4ujthgCX28ULtxBw
dJRZJVYCQx2yKPEdAY5HrlPdEzA55OYJVCTNhzu0VDjdOf5AIERSzVlFLUkW
/21U3e3cuUXPfC9GrY2A1tugsaKs+FDNrx27yONs4wuBkusaJvyVgGFstILa
6qlKiUDbIfeCi+7PCN6pZ4VXgTxUX7dcwkdNc2tpmahkyhfgRoNUj4IcJ4Ff
+8pupQv/mJJk/e8EYmMT6gdQwenIYuIn9n/sjVIPga+st1Shl8A/LS4EYQ==

  "]]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
   3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
   3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}, 
   3.6018932060464363`*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eee vertex (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ij"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 "):"
}], "Subsection",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018912535763903`*^9, 3.601891268031275*^9}, {
  3.601891393714752*^9, 3.601891395384281*^9}, {3.601892474737091*^9, 
  3.601892481717288*^9}, {3.601893602853229*^9, 3.601893627868618*^9}, {
  3.601893806135117*^9, 3.6018938063238163`*^9}, {3.614495306605837*^9, 
  3.614495306911564*^9}}],

Cell["\<\
Define the following spacetime tensor that appears in the 3e vertex.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601893471365479*^9, 3.6018934835151567`*^9}, {
  3.601895907968973*^9, 3.6018959081819973`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T3", "[", 
   RowBox[{
   "a_", ",", "b_", ",", "c_", ",", "d_", ",", "i_", ",", "j_", ",", "x_", 
    ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "i"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "j"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "j"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "i"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"x", ",", "d"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"y", ",", "i"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "j"}], "]"}]}]}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.601722498187365*^9, 3.601722605586205*^9}, {
  3.601790112222909*^9, 3.601790113639989*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "x"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "y"}]]}]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0ltI02EUAPClo0gHZdY2bdZGOR8mminqVMJPyGiJsblysQytJWxByy6y
h4oe1ojQrFyrFg2CMdzIpW4UjSQlRhAIJehsN//Tbejnqk2bq1yr8z0cfpyX
c+Pwzqol5zfRaDQpBG6dfD4+g1G0u04fBB3Fkc15sxiFOwynakG/scRHzLOK
2xxg07VEkng027TFCeYLP/OI1cxdGhcYNFVwhB6MRmMvWn3gdPriLeJs1K6Q
zWGUZWxUyMHgObOrxIuRVT8xKABPrtbIysH+IdHyATBTGUoTHRuFHz1gvEwZ
JlLjtp1zYF+PtJLIvxs8RNQyxlVfwdwqa4TY36lOEZvFwntekP6a7/KBKmfG
LPFBXnDzoRSUHflksICarpFhYpVsa68VNKX6AlNgS47Wnga5bJeHGL/0coXY
KB5g/AWvtAcaia2c5AUio9f7inj/9Lb6Z36MvA1cmwmUHKe3WMBypsiVALXy
fTFiyhsVrIJyy1MtcQe18uQP2MCk/SYWrxuKNsB3S4NTPwIY2SQ3iljzGC0p
2ikRhZG7R8GtD2EUG9U5DAsYCZh3/I9BV4UUhcAzSpPmwSLcZb6bPQaaqXDW
ezDAXp8MgruTP93DEYw6y67aKDBRyrJlorBHx0LNiWWMJkRfDru/wVzT3TTW
d+g3o6gtBGfkxzwcEOv4a8QcoY9eBKpyx9r2giP5b+uawO28f9mroF8d3d8c
x+gycn7oSkBdc3Xn7TWM9hgPKnXgo8UBe2US/sJd8Eaawkh/PSEs/YXRf4NU
huY=
  "]]
}, Open  ]],

Cell["The vertex is:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601893471365479*^9, 3.6018934835151567`*^9}, {
  3.601894876050704*^9, 3.601894877496203*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEE", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "I"}], "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}]}], 
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "y"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"T3", "[", 
          RowBox[{
          "a", ",", "b", ",", "i", ",", "j", ",", "c", ",", "d", ",", "x", 
           ",", "y"}], "]"}], "+", 
         RowBox[{"T3", "[", 
          RowBox[{
          "i", ",", "j", ",", "a", ",", "b", ",", "c", ",", "d", ",", "x", 
           ",", "y"}], "]"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "y"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"T3", "[", 
          RowBox[{
          "c", ",", "d", ",", "i", ",", "j", ",", "a", ",", "b", ",", "x", 
           ",", "y"}], "]"}], "+", 
         RowBox[{"T3", "[", 
          RowBox[{
          "i", ",", "j", ",", "c", ",", "d", ",", "a", ",", "b", ",", "x", 
           ",", "y"}], "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "y"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"T3", "[", 
          RowBox[{
          "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", ",", "x", 
           ",", "y"}], "]"}], "-", 
         RowBox[{"T3", "[", 
          RowBox[{
          "a", ",", "b", ",", "i", ",", "j", ",", "c", ",", "d", ",", "x", 
           ",", "y"}], "]"}], "-", 
         RowBox[{"T3", "[", 
          RowBox[{
          "i", ",", "j", ",", "c", ",", "d", ",", "a", ",", "b", ",", "x", 
           ",", "y"}], "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "y"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"T3", "[", 
          RowBox[{
          "c", ",", "d", ",", "a", ",", "b", ",", "i", ",", "j", ",", "x", 
           ",", "y"}], "]"}], "-", 
         RowBox[{"T3", "[", 
          RowBox[{
          "c", ",", "d", ",", "i", ",", "j", ",", "a", ",", "b", ",", "x", 
           ",", "y"}], "]"}], "-", 
         RowBox[{"T3", "[", 
          RowBox[{
          "i", ",", "j", ",", "a", ",", "b", ",", "c", ",", "d", ",", "x", 
           ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], "//", 
   "Contract"}]}]], "Input",
 CellChangeTimes->{{3.601894655093924*^9, 3.601894756155834*^9}, {
  3.601894816709182*^9, 3.60189486491238*^9}, {3.602226898240872*^9, 
  3.602226899118088*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0FtM0mEYgHFAt5bzwlpNMijNQwebadxIbI6volkTN08M7bC/ZiupaZva
aHPOEVJzrSVtHGo6jUULAytMFjU0SyinXZQFAQaaMP06CJrTQKn3u3j2u3/S
ahpKz9FpNFoJlNh7vzL/C0aFD/M8RL+lqswMmugKN1HWvb5MbO7p3zAAfjS4
04jKYLrUCrqO8lhcJ0b1H/qKPWBIe7WNWHPtRa3YhdEOobD2JDjaaLbudmOk
547dyQbPJhSKD4CaItF8LnhajdeIf/T7HE5w7EnjLNHAGNziAld3URxii3W+
gJiy+b3kK5gaGwgQx59LV4gpZsEtN+j9lGf1gLzBhAelHoxsVIeyHJyJfFbp
wdxNNiOx9RLzyiOwZ0g7NQG2vOw0rYEaocNJbPVZfhCZ1N3EdXAya45PPDX5
7yIR9wb7iU9vbOfd82IkycwxdIMxTlKRHrT7KqxhMKky5yfxpi6UvQhGSnRy
YpV8RRMBi1W8v0THcR07Cr6z6ycWpuCHtIOd7MPotajaf8IP3+MaUnnTGAlk
t82qGYzeZim9alC99zyaBrW0Pmnnd4xEzU3MZ2D0wgJjCHxMMUa+gcPCOLsx
gJG4QGbwg94A1xALYlRn8ApGf2F05vplWvJvjPaI6vNTwK30CicLHBfmLhFZ
w7PxbNAoeVW2E9zWNnLoMMg/sjF+ETyYHso4FsJI3mV7Ux3GqKuJT7UvYdQ2
x6tTgFRYa+IsY5TZnmEpX8FIYYxy969i9B/ZSX7U
  "]]
}, Open  ]],

Cell["For onshell legs 1 and 2 this simplifies to:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601893471365479*^9, 3.6018934835151567`*^9}, {
   3.6018948932110662`*^9, 3.601894929280425*^9}, 3.601984013815667*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEonshell12", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"verEEE", "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.601894940857958*^9, 3.6018949559097013`*^9}, {
  3.60189503652812*^9, 3.601895060881495*^9}, {3.6022268930906897`*^9, 
  3.602226918567645*^9}, {3.61448938327419*^9, 3.614489420894012*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0V1Ik2EYBuBpg49qaZml1UZbKVIOiqSaW8jeaGUjl81lYkw0LHAt6yBq
HmSRS4goSmMmhoI/oy2d2GbBZ8tYlBRZbVKbztmmTuvNzP3odNnoeQ8erpP7
4OZ+eGcuys/GMRiME3AcV7rH/A2jtISVC8RKi5WygMX3p3nEmcuODCJfKtLQ
oOH8UGwM/LziEDvbidGnqEXmBsPqmzeIzfm28iIXRheeFpafBg3USzpjBKNH
8476TDBvKr9oFyh+WPZzN8gdiywT685lDThB1rbqSWLSsC3ZBc5GVFnEATqc
Q2yfsKuGwdoeq5+YW10TIT75Krs3ApauEdNusHPHhg65G6ONNfV1ClCq9On0
oMo00EUURHlXDGDr8TbPIKj0NpmWQarB7iRy022/iHkL7ax/YPG+oJhI7V2l
JrJ757qJ4umdoqZRjAr79hubwY93Nx3TgxFtCR0AnzuzZ4jRyaXMIGjv6dQS
c/rjGqNg7GjjEjFRbub8BWm6e/CPB6PxtTpOynfIMSu9Ui9GwkQNV+SDfSZb
zLpx6H2ybbQB/GK8hHwge3uv5sEERjLFtdRnYEHVYnw/mMxbZxsDKQfrXZcf
I73njtELvnJJjbEpjCxBv+Ttb4xSt1QxUmYx2tPyuoIoOXVdsBlkHlA62WCC
VhAi9gXCTA5osQ4WbAVXD30QHgQ16iRmEHxMRdMOz2F0Nf79m7IARj9cuaW3
QhjdLpFU1ILrDa2mrHnoHeK/UETgn0eYQv4iRv8BxE986A==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEonshell12", "//", "Length"}]], "Input",
 CellChangeTimes->{{3.6018949613922787`*^9, 3.601894962436325*^9}, 
   3.602226931694207*^9}],

Cell[BoxData[
 FormBox["14", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.601894962799378*^9, 3.601973965582621*^9, 3.601975002009049*^9, 
   3.602225819212208*^9, {3.602226926208872*^9, 3.602226932537305*^9}, 
   3.6022271202969227`*^9, 3.602227261947298*^9, 3.60222747124209*^9, 
   3.602240449908935*^9, 3.6024998101691217`*^9, 3.60283198966516*^9, 
   3.6028323881195583`*^9, 3.603088166176794*^9, 3.603094306904443*^9, 
   3.6040370780770884`*^9, 3.604044958795144*^9, 3.60405267453542*^9, 
   3.604055883053912*^9, 3.604056039751266*^9, 3.6043976258164377`*^9, 
   3.6043978599499807`*^9, 3.604398246093833*^9, 3.6043984913496313`*^9, 
   3.604398583654661*^9, 3.604400982566349*^9, 3.604401965935265*^9, 
   3.60440210811514*^9, 3.604403314472118*^9, 3.604405714009329*^9, 
   3.60464925674212*^9, 3.604653204628511*^9, 3.604821175063777*^9, 
   3.604821358301416*^9, 3.6048270573170633`*^9, 3.604901613180182*^9, 
   3.6049974929816837`*^9, 3.604997822797104*^9, 3.604997982180344*^9, 
   3.60499824519862*^9, 3.6049986636701393`*^9, 3.60499900842869*^9, 
   3.604999551732782*^9, 3.605322201401122*^9, 3.6053292337539797`*^9, 
   3.605344864962826*^9, 3.605499346964615*^9, 3.6054997458717613`*^9, 
   3.60550025600788*^9, 3.605500965412149*^9, 3.605517512246481*^9, 
   3.605518573617888*^9, 3.606019693512238*^9, 3.6066244928251133`*^9, 
   3.607254787445327*^9, 3.607746819960609*^9, 3.6084586530122643`*^9, 
   3.6084610291201763`*^9, 3.60861133953983*^9, 3.60897222989229*^9, 
   3.6090390441519623`*^9, 3.6090654959510593`*^9, 3.6091305125518847`*^9, 
   3.610078768419447*^9, 3.61018299666646*^9, 3.610768722358198*^9, 
   3.614321199422008*^9, 3.614488579799143*^9, 3.614495171984956*^9, 
   3.614500538960022*^9, 3.614500762043027*^9, 3.6145009036595697`*^9, 
   3.614505630461707*^9, 3.614577110348259*^9, 3.614937120599654*^9, 
   3.615633703821493*^9, 3.6162145582902*^9, 3.617336066316989*^9, 
   3.61733818617719*^9, 3.618217333088667*^9, 3.619333561477077*^9, 
   3.6197749281801987`*^9}]
}, Open  ]],

Cell["For only one onshell leg, say leg 1:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601893471365479*^9, 3.6018934835151567`*^9}, {
   3.6018948932110662`*^9, 3.601894929280425*^9}, 3.601984013815667*^9, {
   3.610858458386956*^9, 3.610858464354888*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEonshell1", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"verEEE", "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.601894940857958*^9, 3.6018949559097013`*^9}, {
  3.60189503652812*^9, 3.601895060881495*^9}, {3.6022268930906897`*^9, 
  3.602226918567645*^9}, {3.610858473644292*^9, 3.61085848835853*^9}, {
  3.614489438016013*^9, 3.6144894510191727`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0F1IU2EcBvCZg0NhWmFpcUZbNSQVika1TZK9mZEjl0wTMYwZVrTUugix
SMuPJOhbYyaSQdpoUydrs+iUCYtaQVab1JnO2eamozc1nbrp0tH/vXj43TwX
D4/g1AXl6SgOh6OE8BxCl+knRjtiVweJ5eY+ygwW3vcLiJOX7EnEVHlaJQPq
zg9GRsFv0YdoCYvR17BZ4QTnS2uvE9tyLCUFDozKOvNLToA66i2TNIzRowV7
UwqYPZFTsAuUPSz+vRvkj4aWiY1nRFYWjNlW7SNuGLLEO8DpkFpEtDLz6cQO
r009BDYY+8aJR6rrQsTnPxR3h0HVWhnjBLt2bnymdGK0qa6pMQ+UF3k0WlBt
sHYTxWFBhQ58eqzdNQAWuVsNyyDVbGOJfKHlDzE72BGzAhbuC8iI1N41pUS6
d6aHKPMnp7WOYJT/Zr++DfxyZ/NRLRiqP8nMgi9ZySQx7FtKCYA2Y1c9Mb0/
qiUMRrJalohxShPvH8gwPQN/XRiNrdPwEn5Bj1vulrsxksZV8tM88I/viUkz
BruPt480g9/1F5EHpLf3Vj7wYqTIq0p8AeZeXlzVD8YL1ltGQcoe87F7HCOt
65beDb5zyPWRCYymJMJryX6MSh4HMz9MYZRB13ISpjG6sqemjJhZc1O8Bax4
fZalQVU4a474+dMKlwd6q9jcreAB36D0IOjJoLkB0JgYLTw8gxGm7O+LZzHy
UbmqG3MY2W8rzjWAV+91GkQLsEcofpUXwqgvEitNXcToPwdogl8=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "verEEEonshell1", "]"}]], "Input",
 CellChangeTimes->{{3.6108584923796883`*^9, 3.610858494295974*^9}}],

Cell[BoxData[
 FormBox["20", TraditionalForm]], "Output",
 CellChangeTimes->{3.610858494570341*^9, 3.614321199721766*^9, 
  3.614488580291451*^9, 3.614495172272049*^9, 3.614500539249476*^9, 
  3.61450076232092*^9, 3.614500903939517*^9, 3.6145056307395267`*^9, 
  3.614577110631022*^9, 3.614937120887856*^9, 3.615633704102302*^9, 
  3.6162145585680656`*^9, 3.617336066602972*^9, 3.617338186463729*^9, 
  3.6182173333672953`*^9, 3.619333561763888*^9, 3.619774928474409*^9}]
}, Open  ]],

Cell["\<\
For later use in the 4e amplitude we define the following 3e vertex function:\
\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
  3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
  3.602226951402175*^9, 3.602226958496961*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEEonshellmn", "[", 
   RowBox[{
   "m_", ",", "n_", ",", "a_", ",", "b_", ",", "c_", ",", "d_", ",", "i_", 
    ",", "j_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "I"}], "/", "4"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"k", "[", 
           RowBox[{"m", ",", "x"}], "]"}]}], 
         RowBox[{"k", "[", 
          RowBox[{"m", ",", "y"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"T3", "[", 
            RowBox[{
            "a", ",", "b", ",", "i", ",", "j", ",", "c", ",", "d", ",", "x", 
             ",", "y"}], "]"}], "+", 
           RowBox[{"T3", "[", 
            RowBox[{
            "i", ",", "j", ",", "a", ",", "b", ",", "c", ",", "d", ",", "x", 
             ",", "y"}], "]"}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"k", "[", 
          RowBox[{"n", ",", "x"}], "]"}], 
         RowBox[{"k", "[", 
          RowBox[{"n", ",", "y"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"T3", "[", 
            RowBox[{
            "c", ",", "d", ",", "i", ",", "j", ",", "a", ",", "b", ",", "x", 
             ",", "y"}], "]"}], "+", 
           RowBox[{"T3", "[", 
            RowBox[{
            "i", ",", "j", ",", "c", ",", "d", ",", "a", ",", "b", ",", "x", 
             ",", "y"}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"k", "[", 
          RowBox[{"m", ",", "x"}], "]"}], 
         RowBox[{"k", "[", 
          RowBox[{"n", ",", "y"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"T3", "[", 
            RowBox[{
            "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", ",", "x", 
             ",", "y"}], "]"}], "+", 
           RowBox[{"T3", "[", 
            RowBox[{
            "c", ",", "d", ",", "a", ",", "b", ",", "i", ",", "j", ",", "y", 
             ",", "x"}], "]"}], "-", 
           RowBox[{"T3", "[", 
            RowBox[{
            "a", ",", "b", ",", "i", ",", "j", ",", "c", ",", "d", ",", "x", 
             ",", "y"}], "]"}], "-", 
           RowBox[{"T3", "[", 
            RowBox[{
            "c", ",", "d", ",", "i", ",", "j", ",", "a", ",", "b", ",", "y", 
             ",", "x"}], "]"}], "-", 
           RowBox[{"T3", "[", 
            RowBox[{
            "i", ",", "j", ",", "c", ",", "d", ",", "a", ",", "b", ",", "x", 
             ",", "y"}], "]"}], "-", 
           RowBox[{"T3", "[", 
            RowBox[{
            "i", ",", "j", ",", "a", ",", "b", ",", "c", ",", "d", ",", "y", 
             ",", "x"}], "]"}]}], ")"}]}]}], ")"}]}], "//", "Contract"}], 
    ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"m", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"m", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"n", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"n", ",", "d"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.6018005497236633`*^9, 3.601800553377142*^9}, {
   3.601800590703354*^9, 3.601800690962652*^9}, {3.60180073678732*^9, 
   3.601800751886629*^9}, {3.601800792856122*^9, 3.601800915040948*^9}, 
   3.60180094858832*^9, {3.601800982040934*^9, 3.60180103243976*^9}, {
   3.6018012778684807`*^9, 3.601801283218445*^9}, {3.6018976990824347`*^9, 
   3.6018977010208607`*^9}, {3.602227087470744*^9, 3.602227096165265*^9}, {
   3.602227524391502*^9, 3.602227563378263*^9}, 3.602228463202833*^9, 
   3.6048944613672647`*^9, {3.614489458533093*^9, 3.614489497128623*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "i"}]], " ", 
     SubsuperscriptBox["k", "n", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", "m", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "j"}]]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVzUsoA3AcwPGtUUtcOHi0MWVFKUWyx8VvyiSvGOWVEUkpr8uEi7yJPCJ5
JMlhWF4hikxGKyTKwcZG2+HnvWUbRn7/w7fP8RtZUZdbxeVwOPHUcr6+zHiL
MCBcM5+RmLys85KlatsNs8dx+cTUuzb9f0ljBReYYxehtcykNt4qU3otlU+Z
EIq9KdpZ0pMSk7FIypw1ux+k2Cftmdle7RfrIIOUOx3M/rLAyW/SLXr4YnoG
94U/pCtx7+zNjCBxLwiD7xG0ao0l3YJg4PeK5FaEjqSljfEHhORznWmCPJa1
gpX0KzrVDD8izCuHQtZJ7yGfd0A2Zwr0d2TDcIhhxYawqJjTWsiZygLtnx3h
085NPX6hj3KUE/yK0BKnaGKqrkYkYWSrvPFGQGaPqpzMHAnfV0j22ax5EeR0
/Z1MQUaFR/s4SNdJgDj1HcEMpqPyD4T47lJ1pxNBlFhY00VmlWzpEj4RdvYU
2yo3wm9XqCzWg/APb1Toog==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEEonshellm", "[", 
   RowBox[{
   "m_", ",", "a_", ",", "b_", ",", "c_", ",", "d_", ",", "i_", ",", "j_"}], 
   "]"}], "=", 
  RowBox[{"verEEEonshell1", "/.", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["k", "1"], "\[Rule]", 
     SubscriptBox["k", "m"]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.611048441386137*^9, 3.611048463410584*^9}, {
  3.6110484939352703`*^9, 3.6110485023663054`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "i"}]], " ", 
     SubsuperscriptBox["k", "m", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "j"}]]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6110484696565228`*^9, 3.611048504022983*^9, 
  3.614321200163803*^9, 3.6144885806688766`*^9, 3.614495172901457*^9, 
  3.6145005396255302`*^9, 3.614500762701902*^9, 3.614500904575242*^9, 
  3.61450563150191*^9, 3.614577111041544*^9, 3.6149371213195963`*^9, 
  3.615633704521964*^9, 3.616214558952251*^9, 3.6173360670293293`*^9, 
  3.617338186843689*^9, 3.618217333846932*^9, 3.61933356219833*^9, 
  3.619774928911165*^9}]
}, Open  ]],

Cell["A quick consistency check of this definition:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
  3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
  3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
  3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verEEEonshell12", "-", 
    RowBox[{"verEEEonshellmn", "[", 
     RowBox[{
     "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", 
      "j"}], "]"}]}], "//", "Contract"}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.602227021997345*^9, 3.602227066711019*^9}, {
  3.602227572543538*^9, 3.60222757381598*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.602227058375511*^9, 3.602227120674861*^9}, 
   3.60222726243694*^9, 3.602227471562661*^9, 3.602227529136385*^9, 
   3.6022275744669447`*^9, 3.602228481821661*^9, 3.602240450224358*^9, 
   3.602499810476574*^9, 3.602831990044777*^9, 3.602832388498126*^9, 
   3.603088166619178*^9, 3.603094307268774*^9, 3.604037078427971*^9, 
   3.604044959201037*^9, 3.6040526749849577`*^9, 3.604055883403288*^9, 
   3.604056040095057*^9, 3.604397626299716*^9, 3.604397860287261*^9, 
   3.604398246433322*^9, 3.604398491731051*^9, 3.604398584020936*^9, 
   3.604400982948017*^9, 3.604401966300852*^9, 3.604402108477315*^9, 
   3.6044033148665237`*^9, 3.604405714484893*^9, 3.604649257293681*^9, 
   3.604653204954091*^9, 3.604821175394157*^9, 3.604821358621031*^9, 
   3.604827057646578*^9, 3.604894467577805*^9, 3.6049016135576677`*^9, 
   3.604997493425007*^9, 3.604997823208208*^9, 3.604997982609071*^9, 
   3.604998245754095*^9, 3.6049986640891657`*^9, 3.60499900887329*^9, 
   3.604999552147313*^9, 3.60532220187326*^9, 3.6053292342444563`*^9, 
   3.605344865302188*^9, 3.605499347448865*^9, 3.6054997463702097`*^9, 
   3.605500256414571*^9, 3.6055009659248238`*^9, 3.605517512660491*^9, 
   3.605518289193366*^9, 3.605518574065647*^9, 3.606019694000106*^9, 
   3.606624493225795*^9, 3.607254787785173*^9, 3.607746820370222*^9, 
   3.608458653369939*^9, 3.6084610294802427`*^9, 3.608611340195786*^9, 
   3.6089722302894363`*^9, 3.60903904456607*^9, 3.609065496379622*^9, 
   3.609130512987718*^9, 3.61007876899687*^9, 3.610182997029552*^9, 
   3.610768722726839*^9, 3.614321200261753*^9, 3.614488580702289*^9, 
   3.614495172919158*^9, 3.61450053965447*^9, 3.61450076272941*^9, 
   3.614500904581695*^9, 3.614505631528759*^9, 3.614577111083701*^9, 
   3.614937121351268*^9, 3.6156337045833483`*^9, 3.61621455899891*^9, 
   3.617336067060607*^9, 3.617338186889377*^9, 3.618217333872175*^9, 
   3.6193335622519484`*^9, 3.619774928949924*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEonshell1", "-", 
  RowBox[{"verEEEonshellm", "[", 
   RowBox[{"1", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.611048551818585*^9, 3.611048568875527*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.611048559949285*^9, 3.611048569223948*^9}, 
   3.614321200503516*^9, 3.6144885807130623`*^9, 3.614495172925077*^9, 
   3.614500539659734*^9, 3.61450076273556*^9, 3.6145009045998774`*^9, 
   3.614505631535117*^9, 3.614577111096192*^9, 3.6149371213589487`*^9, 
   3.61563370460821*^9, 3.616214559091733*^9, 3.617336067086644*^9, 
   3.617338186934534*^9, 3.618217333897332*^9, 3.6193335622986298`*^9, 
   3.6197749289872932`*^9}]
}, Open  ]],

Cell["\<\
For later use we also give the 3e vertex with without eliminating one of the \
three momenta. This is because in the 5e amplitude the 3e-vertex in diagrams \
with two e propagators is more symmetric.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
  3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
  3.602226951402175*^9, 3.602226958496961*^9}, {3.611994327799087*^9, 
  3.611994336547359*^9}, {3.611994390410664*^9, 3.611994435201358*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEgeneric", "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "I"}], "/", "4"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "y"}], "]"}], 
        RowBox[{"T3", "[", 
         RowBox[{
         "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "y"}], "]"}], 
        RowBox[{"T3", "[", 
         RowBox[{
         "c", ",", "d", ",", "a", ",", "b", ",", "i", ",", "j", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "y"}], "]"}], 
        RowBox[{"T3", "[", 
         RowBox[{
         "c", ",", "d", ",", "i", ",", "j", ",", "a", ",", "b", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "y"}], "]"}], 
        RowBox[{"T3", "[", 
         RowBox[{
         "i", ",", "j", ",", "c", ",", "d", ",", "a", ",", "b", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "y"}], "]"}], 
        RowBox[{"T3", "[", 
         RowBox[{
         "a", ",", "b", ",", "i", ",", "j", ",", "c", ",", "d", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "y"}], "]"}], 
        RowBox[{"T3", "[", 
         RowBox[{
         "i", ",", "j", ",", "a", ",", "b", ",", "c", ",", "d", ",", "x", ",",
           "y"}], "]"}]}]}], ")"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61199444114529*^9, 3.611994661662019*^9}, {
  3.611994717096663*^9, 3.611994733915145*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "j"}]]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.611994547302281*^9, 3.611994573170973*^9}, {
   3.611994645222177*^9, 3.61199466278088*^9}, 3.6119949696362543`*^9, 
   3.6143212007312593`*^9, 3.614488580929541*^9, 3.6144951731426497`*^9, 
   3.614500539870955*^9, 3.614500762958353*^9, 3.614500904815258*^9, 
   3.614505631746821*^9, 3.614577111319557*^9, 3.614937121578272*^9, 
   3.615633704833016*^9, 3.616214559304138*^9, 3.617336067302936*^9, 
   3.617338187184548*^9, 3.618217334113859*^9, 3.6193335625164022`*^9, 
   3.619774929216415*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEEgenericmnl", "[", 
   RowBox[{
   "m_", ",", "a_", ",", "b_", ",", "n_", ",", "c_", ",", "d_", ",", "l_", 
    ",", "i_", ",", "j_"}], "]"}], "=", 
  RowBox[{"verEEEgeneric", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "1"}], "]"}], "\[Rule]", 
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "m"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "n"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"Subscript", "[", 
       RowBox[{"k", ",", "l"}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.611994739281912*^9, 3.611994766841762*^9}, {
  3.611994873042769*^9, 3.611994974242688*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "l", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6119948851592703`*^9, {3.611994934697959*^9, 3.611994975256865*^9}, 
   3.614321200793948*^9, 3.614488580988173*^9, 3.614495173193445*^9, 
   3.6145005399224997`*^9, 3.61450076327284*^9, 3.6145009048712273`*^9, 
   3.614505631799909*^9, 3.6145771113784227`*^9, 3.61493712165448*^9, 
   3.61563370489765*^9, 3.616214559354414*^9, 3.617336067379806*^9, 
   3.617338187242743*^9, 3.618217334176947*^9, 3.619333562628346*^9, 
   3.6197749294023743`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEEgenericmnl", "[", 
   RowBox[{
   "1", ",", "a", ",", "b", ",", "2", ",", "c", ",", "d", ",", "3", ",", "i", 
    ",", "j"}], "]"}], "-", "verEEEgeneric"}]], "Input",
 CellChangeTimes->{{3.611994984491314*^9, 3.611994997098156*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.6119949975342712`*^9, 3.614321200859255*^9, 
  3.614488581023497*^9, 3.614495173217082*^9, 3.614500539951105*^9, 
  3.614500763294139*^9, 3.614500904894732*^9, 3.614505631864462*^9, 
  3.614577111417704*^9, 3.614937121677525*^9, 3.6156337049166403`*^9, 
  3.61621455938725*^9, 3.617336067406581*^9, 3.617338187286098*^9, 
  3.618217334204483*^9, 3.619333562683597*^9, 3.619774929428584*^9}]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
   3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
   3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}, 
   3.6018932060464363`*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eeee vertex (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ef"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SuperscriptBox["e", "gh"], "[", 
     SubscriptBox["k", "4"], "]"}]}], TraditionalForm]]],
 "):"
}], "Subsection",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018912535763903`*^9, 3.601891268031275*^9}, {
  3.601891393714752*^9, 3.601891395384281*^9}, {3.601892474737091*^9, 
  3.601892481717288*^9}, {3.601893602853229*^9, 3.6018936627165337`*^9}, {
  3.601893797936005*^9, 3.60189380042028*^9}, {3.6144953116300077`*^9, 
  3.614495313111722*^9}}],

Cell["\<\
Define the following spacetime tensor that appears in the 4e vertex.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601893471365479*^9, 3.6018934835151567`*^9}, {
  3.601895903433138*^9, 3.601895903661861*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T4", "[", 
   RowBox[{
   "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "i_", 
    ",", "j_", ",", "x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "i"}], "]"}]}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"j", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"e", ",", "i"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"j", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "c"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"i", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"j", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "d"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"i", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "j"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"e", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "i"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "j"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"x", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "j"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "i"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"e", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "j"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "i"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"x", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "i"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "j"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"i", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "j"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"j", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "i"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"f", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "i"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "j"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"f", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "j"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "i"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "e"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6017287824982157`*^9, 3.6017288022998047`*^9}, {
  3.601729005485304*^9, 3.6017293577159243`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0FtM0nEcBfC/ZeXWZdVKmEHKytWGoQu3uDzUrzGajNFUVpSxmaNW4qK2
VvhgY2WuTWeLSkrLLitKJuKCkmhpWpla9OAyiItigpNfBgqUjcD1/fVw9nk7
ZzusKk3ZsQyKokoh7D3D4TdjGI2Iuez1XzE6aH11iAcmtPu8xDVZmnIr2FOc
95s4lQ6ssIH280kWMWGUah1g50olg+/CCAvHZF5woN+sI659kFAp3Bi1ympV
FaCqz+/Y5sHo5p3F62xwC+eiohBcfqkuXAQKVNlpYtJW9cEFzhS1BomZosAG
N7hjYxOXWLN/3W4iJYpVfwNzDL7Qf8X3F4gn/JpmD+hpVDu84MQs/3GZF6Pe
SoteDl4YzzAYwaQ1biba9bJzHWC15Z3fCbZohrtS4OHtlJvIbpj5QRxKja5K
g7cK6Yh4g8WpIRpdjG7i6jm5sM2H0abgAVM7iDv5UiMojeoc8+ApyZFZomk6
vyAGRuo+1xO/KNi3k2DJPR/zL2iTjTqjfox0zJdM2gRGZ0VXApIARlrGozzh
JOxzeq0t32E/y+kzgCPRu2gSlGSHtNemMLra1E1/Bi6xbF3aBza/5g2Mg9Jg
8aA5hBFdbTcFQENbu2lxGn5gy8Tvf8LfzE8ULYKRs6SDlwN66nUuBqhUquPE
477Ny5jgk3C6PBd8oY8K9oKlH3dlxsDB2tx88Rz0nY68PTqP0cMKTeXlOEb9
Z9QnG8CngaEu7i+MUjRFj3wBo+eNOwUFfzD6B5zLfy0=
  "]]
}, Open  ]],

Cell["The following combination proves to be useful.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601893471365479*^9, 3.6018934835151567`*^9}, {
  3.601895903433138*^9, 3.601895903661861*^9}, {3.601896031064571*^9, 
  3.601896037493848*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T4mod", "[", 
   RowBox[{
   "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "i_", 
    ",", "j_", ",", "x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"T4", "[", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", 
      "j", ",", "x", ",", "y"}], "]"}], "+", 
    RowBox[{"T4", "[", 
     RowBox[{
     "i", ",", "j", ",", "c", ",", "d", ",", "e", ",", "f", ",", "a", ",", 
      "b", ",", "x", ",", "y"}], "]"}], "+", 
    RowBox[{"T4", "[", 
     RowBox[{
     "a", ",", "b", ",", "e", ",", "f", ",", "c", ",", "d", ",", "i", ",", 
      "j", ",", "y", ",", "x"}], "]"}], "+", 
    RowBox[{"T4", "[", 
     RowBox[{
     "i", ",", "j", ",", "e", ",", "f", ",", "c", ",", "d", ",", "a", ",", 
      "b", ",", "y", ",", "x"}], "]"}]}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.601729389062508*^9, 3.601729494496484*^9}, 
   3.6017298201114883`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0W9I02EQB/CZjSJUZJMMc+oSF61Zy/VibaQ+g1ZYWTiZy0HUmGDMMEqm
1YwIE6c4SsMVjbAXSS5cOUd/fhjWosUqqRTd3Pyz2Qx8rKVbzdra6p5eHB84
uOPLHVtVX1GTRKPRZFBHoxtjLyYwMp1+l/8SlL0PljEmMdp81nlMCBbdrfAS
qdbzsiFQP1YYIdoVwXU2sKWRvuW/hfIpYkSiaKJAZqA2e48Lo7F6X7kXDAWp
y8RrH/+qFW6MArmdaiU4qVumtnowytKk3tgOVld1K3aCxQfbF/kglceOE9NG
zr1xgbX59wNEg2kpww2mF90UEEV2VgnRoU/STIF04+IC8VPxwCrRZ7lo8IAZ
Yh3lBS079t+r8GIkaRvuqgTHH6Ya+8D00jUWYl37cW0/aM6ZnBkFDyRclj/g
mcY0N/EII7pE5Mn8KXGwt20bIv7QlNQRo0LuI6JGrhLfnoa5pyrzHbA8vu9Q
H9jC7qRWwN1KzVfier6AFwJ1Tk8LscslvBUFH/OXWDHwkn5u9PsMRs3Mt6zM
OYxWGrp9ZT6MEsmDeWI/Rjkc51DPPEbDHPe0EbTJrMgP8ubDTdc/Y8Sofr7J
Cj4Y3JU8Aso5UvsseIVZ6hhYgHxKh9kHphRYzIkv0J+olr7+Bn/rmKFlBiGv
wSbMAkPKDlc2aK3ShokfGFw6C8yPbKjMBU11MZEEbIhK1obA3mZugXQZ7uf/
/erkCkY9hy+cuBrGaPaZ9lQrWJMYtwh+YlTGUT+pXIW90r0i3i+M/gEFqoIW

  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T4mod", "[", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", "j", 
    ",", "x", ",", "y"}], "]"}], "//", "Length"}]], "Input",
 CellChangeTimes->{{3.601729528445592*^9, 3.601729550477291*^9}, {
  3.6017298006472197`*^9, 3.6017298183681583`*^9}}],

Cell[BoxData[
 FormBox["24", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6017295352955503`*^9, 3.601729550796906*^9}, {
   3.6017298028500023`*^9, 3.601729829588647*^9}, 3.601973966315524*^9, 
   3.601975002615295*^9, 3.602225819816197*^9, 3.602227121448386*^9, 
   3.60222726356109*^9, 3.602227472323043*^9, 3.6022404507733393`*^9, 
   3.602499811313121*^9, 3.602831991026471*^9, 3.602832389848445*^9, 
   3.603088168008815*^9, 3.6030943084156733`*^9, 3.604037079522236*^9, 
   3.604044960430986*^9, 3.604052676614884*^9, 3.604055884332062*^9, 
   3.604056041139022*^9, 3.604397627624309*^9, 3.6043978612621098`*^9, 
   3.604398247370285*^9, 3.604398492761538*^9, 3.604398584939749*^9, 
   3.604400984147901*^9, 3.6044019674018173`*^9, 3.6044021094337053`*^9, 
   3.6044033159716797`*^9, 3.604405716089079*^9, 3.604649258403358*^9, 
   3.604653205915501*^9, 3.604821176451926*^9, 3.604821360094226*^9, 
   3.604827058976491*^9, 3.604901614713964*^9, 3.604997494777446*^9, 
   3.6049978244769993`*^9, 3.604997983845182*^9, 3.604998247074215*^9, 
   3.60499866533869*^9, 3.604999010006051*^9, 3.604999553346469*^9, 
   3.6053222031275454`*^9, 3.605329235097659*^9, 3.605344866327858*^9, 
   3.6054993485569553`*^9, 3.605499747488838*^9, 3.605500257612042*^9, 
   3.605500966988131*^9, 3.605517513783889*^9, 3.6055185753589687`*^9, 
   3.606019695136238*^9, 3.606624494388509*^9, 3.607254788620304*^9, 
   3.60774682154396*^9, 3.608458654297928*^9, 3.608461030767704*^9, 
   3.6086113415881233`*^9, 3.608972231647208*^9, 3.6090390459284267`*^9, 
   3.609065497566616*^9, 3.609130514206092*^9, 3.610078770216045*^9, 
   3.610182998209889*^9, 3.6107687255763397`*^9, 3.614321202857965*^9, 
   3.614488582944673*^9, 3.61449517392585*^9, 3.614500540365109*^9, 
   3.614500763711204*^9, 3.6145009055847263`*^9, 3.6145056326643753`*^9, 
   3.614577111869319*^9, 3.614937122101527*^9, 3.615633705338496*^9, 
   3.616214559817932*^9, 3.617336067828693*^9, 3.617338187722014*^9, 
   3.618217334636306*^9, 3.619333563144815*^9, 3.619774929928307*^9}]
}, Open  ]],

Cell["\<\
What follows illustrates that transversality does not drastically simplify \
the 4e vertex.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.602229352067738*^9, 3.6022293878273373`*^9}, {3.60231657507976*^9, 
   3.602316576566577*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"k", "[", 
      RowBox[{"2", ",", "x"}], "]"}], 
     RowBox[{"k", "[", 
      RowBox[{"3", ",", "y"}], "]"}], 
     RowBox[{"T4mod", "[", 
      RowBox[{
      "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", 
       "j", ",", "x", ",", "y"}], "]"}]}], "//", "Contract"}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"kdotk", "[", 
      RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
     RowBox[{"u", "/", "2"}]}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.601730117137895*^9, 3.601730227907177*^9}, {
  3.601794174491272*^9, 3.601794194208774*^9}, {3.6017942274577503`*^9, 
  3.601794240338092*^9}, {3.601794301714774*^9, 3.601794319078364*^9}, {
  3.614490013132576*^9, 3.614490069511599*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "u"}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.601730126046905*^9, 3.601730166461277*^9}, {
   3.601730203575115*^9, 3.6017302288965683`*^9}, {3.601794176168653*^9, 
   3.6017941948708477`*^9}, {3.601794228922124*^9, 3.601794240721368*^9}, {
   3.601794303571601*^9, 3.601794319651621*^9}, 3.601973966465535*^9, 
   3.6019750027792387`*^9, 3.6022258199545937`*^9, 3.602227121596483*^9, 
   3.60222726377803*^9, 3.602227472474668*^9, 3.602229310552969*^9, 
   3.602240450903141*^9, 3.602499811454822*^9, 3.602831991190394*^9, 
   3.602832389998928*^9, 3.603088168156362*^9, 3.603094308556139*^9, 
   3.604037079664912*^9, 3.6040449605761423`*^9, 3.604052676812755*^9, 
   3.604055884478259*^9, 3.604056041330723*^9, 3.60439762783846*^9, 
   3.604397861424213*^9, 3.6043982475122433`*^9, 3.6043984929027557`*^9, 
   3.604398585089748*^9, 3.6044009842969*^9, 3.6044019675508423`*^9, 
   3.6044021095861177`*^9, 3.604403316117176*^9, 3.604405716282836*^9, 
   3.604649258558401*^9, 3.604653206066882*^9, 3.604821176611994*^9, 
   3.604821360258643*^9, 3.604827059127017*^9, 3.604901614874612*^9, 
   3.604997494931819*^9, 3.604997824646138*^9, 3.604997984008358*^9, 
   3.604998247237208*^9, 3.604998665505591*^9, 3.6049990101626797`*^9, 
   3.604999553500608*^9, 3.605322203343235*^9, 3.605329235244038*^9, 
   3.605344866467169*^9, 3.605499348751008*^9, 3.605499747633554*^9, 
   3.605500257762107*^9, 3.605500967122664*^9, 3.605517513931082*^9, 
   3.6055185755847397`*^9, 3.606019695275507*^9, 3.6066244945833807`*^9, 
   3.607254788764344*^9, 3.607746821698345*^9, 3.608458654462913*^9, 
   3.6084610309247437`*^9, 3.608611341750511*^9, 3.6089722318163443`*^9, 
   3.609039046076893*^9, 3.6090654977095423`*^9, 3.6091305143615217`*^9, 
   3.6100787703732233`*^9, 3.610182998357573*^9, 3.61076872579078*^9, 
   3.614321203006658*^9, 3.614488583085445*^9, 3.614490021414978*^9, 
   3.6144900701929398`*^9, 3.6144951740539093`*^9, 3.6145005405011663`*^9, 
   3.61450076385396*^9, 3.6145009057184753`*^9, 3.614505632809183*^9, 
   3.614577112007142*^9, 3.614937122244032*^9, 3.6156337054802637`*^9, 
   3.61621455999587*^9, 3.6173360679779263`*^9, 3.617338187857664*^9, 
   3.618217334778216*^9, 3.6193335632915487`*^9, 3.61977493006352*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.602229312964471*^9, 3.602229314735384*^9}}],

Cell[BoxData[
 FormBox["24", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0V1I02EYBfBJVpK7CIxptTGDzHJCk43KdlHviFU2jOYKKZCpOfKDjBUx
ZMmStcALbTFyWWQECg1aYqziT58jrS5mS8ytbebUrezNMrdqkdvsvBcPv5vD
4cCzqa5V05DF4/EqcCqLLsc9QUlLb42Rg8+etgrL/ZRMjM9VhmBXh8fM7O1c
3VAdoERTbz95Au54meSKg5TEMwK7BLrEt6u3Q+F721cpvMOVpJnDsYuv/VDt
vR9lOnLi6wLQfrpPxsyrL9rDPFbLb/4IrbpfMaaz3Z1kXqDWriCc7O/mQnC9
QtOvCWFP6M1VLdQrBD0D0Kfku5ij8sbzd2Huw6lJL9zaEXWl4M22ggDz4KHs
eSZf/42fhk25csJsH9/fwiwekg0yNy+dVdwIUzLItThvwVXiw+oBeKbMwS3C
SsO5eeYWiaI0DpfzohbmjHnv9X/w1JEl0RIM/JnzLkxi37sxUf4U+jKOSEWE
kjbf40LFNCWCvrEH12YoGQl+CfdAS9UTMg0TkmWjbZaSVPptwRDUHy9f8Ryu
sVd5PsG1ZeqRezFKot0+ZwRaOl84M58pMUjrVMPfKXH7Znn5P5CTe3ZtgM6F
K34hTO0zJZgG086VIii8vFErhmFblkIJa6wHsuOQK5EWqX5SYtyW9ap2kf3X
rLuUoOToqKnRCgvjQZfsNyXNH5oeaZPI+5S7S/9S8h/vylyU
  "]]
}, Open  ]],

Cell["\<\
The vertex with 4 is:\[LineSeparator]\[LineSeparator]In here we use the \
Mandelstam variables as defined above.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.604648869521611*^9, 3.604648881253089*^9}, {3.6108580309963303`*^9, 
   3.610858031852108*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEE", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "I"}], "/", "16"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "y"}], "]"}], 
        RowBox[{"T4mod", "[", 
         RowBox[{
         "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",",
           "h", ",", "x", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"4", ",", "y"}], "]"}], 
        RowBox[{"T4mod", "[", 
         RowBox[{
         "a", ",", "b", ",", "c", ",", "d", ",", "g", ",", "h", ",", "e", ",",
           "f", ",", "x", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"4", ",", "y"}], "]"}], 
        RowBox[{"T4mod", "[", 
         RowBox[{
         "a", ",", "b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "c", ",",
           "d", ",", "x", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "y"}], "]"}], 
        RowBox[{"T4mod", "[", 
         RowBox[{
         "e", ",", "f", ",", "a", ",", "b", ",", "c", ",", "d", ",", "g", ",",
           "h", ",", "x", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "y"}], "]"}], 
        RowBox[{"T4mod", "[", 
         RowBox[{
         "c", ",", "d", ",", "a", ",", "b", ",", "e", ",", "f", ",", "g", ",",
           "h", ",", "x", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"4", ",", "y"}], "]"}], 
        RowBox[{"T4mod", "[", 
         RowBox[{
         "c", ",", "d", ",", "a", ",", "b", ",", "g", ",", "h", ",", "e", ",",
           "f", ",", "x", ",", "y"}], "]"}]}]}], "//", "Contract"}], ")"}]}], 
   "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.610857981781527*^9, 3.610858003706655*^9}, {
  3.6108580955304623`*^9, 3.610858096998294*^9}, {3.614490084115925*^9, 
  3.6144901424697533`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.610858005758772*^9, 3.6108580986553593`*^9, 
  3.6143212038958397`*^9, 3.614488583904066*^9, 3.614490143850643*^9, 
  3.6144951748031893`*^9, 3.614500541295411*^9, 3.6145007646312513`*^9, 
  3.614500906489814*^9, 3.614505633638535*^9, 3.6145771128040524`*^9, 
  3.6149371230758677`*^9, 3.6156337062855988`*^9, 3.616214560854025*^9, 
  3.6173360687711353`*^9, 3.6173381886877947`*^9, 3.618217335606539*^9, 
  3.619333564113199*^9, 3.619774930866419*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEE$noMandel", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "I"}], "/", "16"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"3", ",", "y"}], "]"}], 
       RowBox[{"T4mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
         "h", ",", "x", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"4", ",", "y"}], "]"}], 
       RowBox[{"T4mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "g", ",", "h", ",", "e", ",", 
         "f", ",", "x", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"3", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"4", ",", "y"}], "]"}], 
       RowBox[{"T4mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "e", ",", "f", ",", "g", ",", "h", ",", "c", ",", 
         "d", ",", "x", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "y"}], "]"}], 
       RowBox[{"T4mod", "[", 
        RowBox[{
        "e", ",", "f", ",", "a", ",", "b", ",", "c", ",", "d", ",", "g", ",", 
         "h", ",", "x", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"3", ",", "y"}], "]"}], 
       RowBox[{"T4mod", "[", 
        RowBox[{
        "c", ",", "d", ",", "a", ",", "b", ",", "e", ",", "f", ",", "g", ",", 
         "h", ",", "x", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"4", ",", "y"}], "]"}], 
       RowBox[{"T4mod", "[", 
        RowBox[{
        "c", ",", "d", ",", "a", ",", "b", ",", "g", ",", "h", ",", "e", ",", 
         "f", ",", "x", ",", "y"}], "]"}]}]}], "//", "Contract"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.612674277326209*^9, 3.612674316702033*^9}, {
  3.612676788972698*^9, 3.6126768010822887`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612674318411907*^9, 3.6126768030546303`*^9, 
  3.61432120494305*^9, 3.6144885849300137`*^9, 3.6144951758097773`*^9, 
  3.614500542078318*^9, 3.61450076562554*^9, 3.614500907488183*^9, 
  3.614505634709194*^9, 3.6145771135487022`*^9, 3.6149371239437103`*^9, 
  3.615633707077215*^9, 3.616214561598069*^9, 3.617336069559836*^9, 
  3.617338189436082*^9, 3.618217336346727*^9, 3.619333564926803*^9, 
  3.619774931708131*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "verEEEE$noMandel", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6168380625854397`*^9, 3.6168380698900423`*^9}}],

Cell[BoxData[
 FormBox["144", TraditionalForm]], "Output",
 CellChangeTimes->{{3.616838064596744*^9, 3.616838070118545*^9}, 
   3.617336069580666*^9, 3.6173381894824743`*^9, 3.6182173364101753`*^9, 
   3.61933356497608*^9, 3.619774931732044*^9}]
}, Open  ]],

Cell["The vertex with 4 onshell legs is:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.604648869521611*^9, 3.604648881253089*^9}, {3.6108580511809607`*^9, 
   3.6108580516604357`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEEonshell", "=", 
  RowBox[{"verEEEE", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.60189611242404*^9, 3.6018961161817617`*^9}, {
  3.610857999190826*^9, 3.610858002063492*^9}, {3.610858082023098*^9, 
  3.610858087910548*^9}, {3.614490220950108*^9, 3.6144902933606*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0W1I01EUx/Hp5lawlUlqicsKncNGSethU7NuhkSUS7doM4zpXDkcjTIk
X0TSg5jEKhOHCiJSZoNW6qSYQZHaIHJWyDa3ZpurSdf/tCnTUZt17ovD5+WB
33dHla5MHUej0WRwI7NhRZIdI1EPVojA6sw6N/EuZZAOgZ1MyQox2p2yzgwm
fuHvJDJVTv4wuGitv2YBz680p4sdGF1S0iVu0Ph0ppE4NZmjljsx2qs2VZ8D
P/M2jWS7MGq8erBtF9irssj3gJqQ8VcuaJ8rihFb6F1WB9jN/viDWDDJTnaC
5v43QiIjcugw8Ywtq3Ya9BdxAkSmyrZKbFnr1bvAZLHJ4iZ/ZmqflLkx2vfJ
1yoDC7S5hj6wbJxnIj6qulX/DMyYjngmwNM3/5miYCd/v5Noe8yliM0lLE4M
bAyfQkRpTaWW2HNF8pLIuf4gv+sbRjJRk7EbnJBfPNkHbmANWkLgBYOeIuoC
UsESyDgbvU2UJZV3/AHlis3b/oLFXfG2RQ9Gx3UUN/U7RmzjoPeEF/bt+Lo9
34eRQD8/1D6L0T0NzWMAE4UO5AOp3VsbHvoxqqjwbxkEefOl9Lfg6wTt+xmw
vVT94flP6F1OGb2gpHDauBaA7sEjx3LmMDKpLSXEOnt/8XgQo7TM7LjUBYxa
g6N2IqeKLk4Da9pGHekga/3wMtHKvZzABS0GpSwDjHcJ84+CUws3GEtgSkyV
Vfwbo3fUgbHKEEZr983KO8sYxQYGNE1gnmbjC2EYo7HC3leyVegobsgTRDD6
D/3igNg=
  "]]
}, Open  ]],

Cell["\<\
The vertex with 3 onshell legs is: (the 4th leg being off-shell)\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.604648869521611*^9, 3.604648881253089*^9}, {3.610858045078164*^9, 
   3.6108580551324873`*^9}, {3.610858124052711*^9, 3.610858133243865*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEEonshell3legs", "=", 
  RowBox[{"verEEEE", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.610858065134444*^9, 3.610858065858199*^9}, {
   3.6108581106124277`*^9, 3.610858118913672*^9}, 3.610858149678071*^9, {
   3.614490301248827*^9, 3.614490354229938*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "u", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", "t", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.610858150008347*^9, 3.6143212054173603`*^9, 
  3.614488586028434*^9, 3.61449035486982*^9, 3.61449517614566*^9, 
  3.61450054216111*^9, 3.614500765968524*^9, 3.614500907840358*^9, 
  3.614505635067292*^9, 3.614577113684908*^9, 3.614937124061377*^9, 
  3.615633707196273*^9, 3.616214561789784*^9, 3.617336069704615*^9, 
  3.617338189611909*^9, 3.618217336544388*^9, 3.6193335651596413`*^9, 
  3.619774931842648*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "verEEEEonshell3legs", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.610858154923258*^9, 3.6108581648732243`*^9}}],

Cell[BoxData[
 FormBox["132", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6108581598449383`*^9, 3.610858165096327*^9}, 
   3.614321205536056*^9, 3.614488586318099*^9, 3.614495176165224*^9, 
   3.614500542193118*^9, 3.614500765992096*^9, 3.614500907861186*^9, 
   3.614505635095261*^9, 3.6145771137142887`*^9, 3.61493712408759*^9, 
   3.6156337072182207`*^9, 3.616214561827921*^9, 3.617336069723983*^9, 
   3.617338189650358*^9, 3.618217336568256*^9, 3.619333565222373*^9, 
   3.6197749318662777`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEEonshell3legs$noMandel", "=", 
  RowBox[{"verEEEE$noMandel", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.61267437171562*^9, 3.612674380448221*^9}, {
   3.6126767661724777`*^9, 3.612676767280973*^9}, 3.612676817702056*^9, {
   3.614490375867214*^9, 3.614490424033436*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "16"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "h"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6126743814396133`*^9, 3.612676820057094*^9, 
  3.6143212056111927`*^9, 3.6144885863641033`*^9, 3.614490425321595*^9, 
  3.614495176209988*^9, 3.61450054225143*^9, 3.614500766037715*^9, 
  3.614500907914556*^9, 3.614505635147678*^9, 3.614577113750595*^9, 
  3.614937124151157*^9, 3.6156337072724533`*^9, 3.616214561897512*^9, 
  3.6173360697777023`*^9, 3.6173381897114964`*^9, 3.618217336632744*^9, 
  3.619333565308536*^9, 3.6197749319258127`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "verEEEEonshell3legs$noMandel", "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{3.612674421765182*^9, 3.61267682660845*^9}],

Cell[BoxData[
 FormBox["144", TraditionalForm]], "Output",
 CellChangeTimes->{3.612674422341776*^9, 3.612676827408731*^9, 
  3.614321205735367*^9, 3.6144885864359283`*^9, 3.614495176230276*^9, 
  3.614500542276602*^9, 3.614500766061973*^9, 3.614500907931161*^9, 
  3.6145056351755657`*^9, 3.6145771137818947`*^9, 3.614937124167644*^9, 
  3.615633707292268*^9, 3.6162145619290133`*^9, 3.617336069794239*^9, 
  3.617338189745297*^9, 3.618217336658433*^9, 3.619333565357316*^9, 
  3.619774931956674*^9}]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
   3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
   3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}, 
   3.6018932060464363`*^9},
 Background->RGBColor[1, 0.9, 0.8]],

Cell["A few inspections of this vertex:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896420776207*^9, 3.60189643156511*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEEEonshell", "//", "Expand"}], "//", "Length"}]], "Input",
 CellChangeTimes->{{3.6018963138362617`*^9, 3.6018963200661297`*^9}}],

Cell[BoxData[
 FormBox["132", TraditionalForm]], "Output",
 CellChangeTimes->{{3.60189631510907*^9, 3.60189632039715*^9}, 
   3.60197396748703*^9, 3.601975003761548*^9, 3.602225820828744*^9, 
   3.602227122603455*^9, 3.602227264802047*^9, 3.602227473427187*^9, 
   3.6022295770667963`*^9, 3.6022404518378963`*^9, 3.6024998123666973`*^9, 
   3.6028319921838913`*^9, 3.602832391140189*^9, 3.603088169582223*^9, 
   3.6030943096968927`*^9, 3.604037080786491*^9, 3.6040449620527897`*^9, 
   3.60405267810253*^9, 3.604055885417911*^9, 3.6040560422802*^9, 
   3.604397629053046*^9, 3.604397862373417*^9, 3.6043982485396852`*^9, 
   3.604398493990117*^9, 3.604398586023983*^9, 3.604400985375708*^9, 
   3.6044019685477743`*^9, 3.604402110623437*^9, 3.604403317268413*^9, 
   3.6044057176789227`*^9, 3.6046492594403152`*^9, 3.604653207114917*^9, 
   3.604821177696679*^9, 3.604821361232429*^9, 3.604827060129882*^9, 
   3.604901615845621*^9, 3.604997496100183*^9, 3.604997825759791*^9, 
   3.604997985034634*^9, 3.604998248259696*^9, 3.604998666535729*^9, 
   3.60499901113451*^9, 3.604999554512971*^9, 3.605322204708743*^9, 
   3.6053292362400017`*^9, 3.60534486737941*^9, 3.605499349724949*^9, 
   3.6054997485725613`*^9, 3.605500258811037*^9, 3.605500968033081*^9, 
   3.605517514983556*^9, 3.6055185768693743`*^9, 3.6060196962094707`*^9, 
   3.606624495493291*^9, 3.607254789622643*^9, 3.607746822772847*^9, 
   3.608458655578272*^9, 3.608461032185732*^9, 3.608611342816025*^9, 
   3.608972232812922*^9, 3.609039047292038*^9, 3.609065498736569*^9, 
   3.609130515579525*^9, 3.610078771392655*^9, 3.61018299939907*^9, 
   3.610768726998621*^9, 3.614321205805369*^9, 3.6144885864567547`*^9, 
   3.6144951762483873`*^9, 3.614500542300448*^9, 3.614500766083495*^9, 
   3.6145009079457827`*^9, 3.6145056351994534`*^9, 3.6145771138139772`*^9, 
   3.614937124183758*^9, 3.6156337073328037`*^9, 3.6162145619666348`*^9, 
   3.61733606982086*^9, 3.6173381897835417`*^9, 3.6182173366852627`*^9, 
   3.619333565406056*^9, 3.619774931981935*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEEEonshell", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"x_", ",", "a_"}], "]"}], "\[Rule]", "0"}], "}"}]}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{
  3.601896401840364*^9, {3.614490455683282*^9, 3.614490479013276*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVyWtI01EYgPGJGs1hwbIW7tIdQ8UtBra1qE7FAhMa259a2c3hosiYXRwl
ZJZMoVpRlLYUKSjJYU7mLNsSa23JkIaZtOU2mzlHHtR2yZkrpfd8ePh9eNap
NHJ1Co1Gk0ORWUUV8ytGjmDssAgc31rlI7YrmxVdINt2MEFsH+AttYD2ef56
ojnak9sNDuZUX7aCE049R+zBKFFIP+ADF+/+rCEamYVqpRej5UNvykpASz3X
ljOC0ZP6fQ/yiH0uJR80/O6cFICW4f0LxKP+tn4P6PK6Q8RiTtZKL2iS2YXE
c4f27iTyZIKz38ACTlaYuMflmSPmJNrvjICvdDarD2x4W/Fc7sNoePPkfQqs
7BU1toKNF/M6iMmZW9o2sCB1MfAJpBRLTP9AZdN2L3G0duMUMbeFkbkA5m2g
ELGl7lQ50RmWdxKZfQZJkx+jZZU3jS0gJdIUt4KrGFZrFJSxH04RM2qP5cfI
H0rVEQffqQxJUGHm8f6CAjHd/SuAUVFGnMv6jlHP0+5gURCjI+n+tZIxjLje
RFfDD4wudTECjWAFexSNgc+2cK/cG8fo0dWp1WawmlmS2ge+KNPaR0G3/sLH
lxMYaU9EjEGwNxIyLoYx8p+3SZ3TGD0WylJYMxhlapLTxB1qujgb9HcMeDhg
qfNDnJjWfy2dC9Z8Pk2tAXukEslu8La+Pi0Gqvjlm6QRjG7EdjlKoxg1O2wn
dXGM5pm2M3Vg6D3LJJzFKPu46TU1h9GXFde35f/B6D9d5n9e
  "]]
}, Open  ]],

Cell["Let us check Bose symmetry.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896420776207*^9, 3.60189643156511*^9}, {3.602229606643499*^9, 
  3.602229617610721*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"verEEEEonshell", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEEonshell", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "b"}], ",", 
        RowBox[{"t", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "t"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"verEEEEonshell", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEEonshell", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "b"}], ",", 
        RowBox[{"s", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"verEEEEonshell", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEEonshell", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "b"}], ",", 
        RowBox[{"t", "\[Rule]", "s"}], ",", 
        RowBox[{"s", "\[Rule]", "t"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"verEEEEonshell", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEEonshell", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "c"}], ",", 
        RowBox[{"d", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "d"}], ",", 
        RowBox[{"s", "\[Rule]", "t"}], ",", 
        RowBox[{"t", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"verEEEEonshell", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEEonshell", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "c"}], ",", 
        RowBox[{"d", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "d"}], ",", 
        RowBox[{"u", "\[Rule]", "s"}], ",", 
        RowBox[{"s", "\[Rule]", "u"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"verEEEEonshell", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEEonshell", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"e", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "e"}], ",", 
        RowBox[{"f", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "f"}], ",", 
        RowBox[{"u", "\[Rule]", "t"}], ",", 
        RowBox[{"t", "\[Rule]", "u"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.60222962884649*^9, 3.6022297444944696`*^9}, {
  3.602230842499771*^9, 3.60223086800941*^9}, {3.614490595776083*^9, 
  3.614490634236747*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.602229731594522*^9, 3.602229744760645*^9}, 
   3.602230868287122*^9, 3.60224045209443*^9, 3.6024998124961367`*^9, 
   3.602831992421928*^9, 3.6028323913575497`*^9, 3.603088169822309*^9, 
   3.603094309937789*^9, 3.604037081054785*^9, 3.604044962414337*^9, 
   3.6040526784932833`*^9, 3.6040558856394567`*^9, 3.604056042443378*^9, 
   3.604397629550974*^9, 3.604397862550357*^9, 3.604398248733636*^9, 
   3.604398494190844*^9, 3.604398586242111*^9, 3.6044009856205378`*^9, 
   3.604401968738554*^9, 3.604402110815292*^9, 3.604403317518663*^9, 
   3.6044057180628*^9, 3.604649259631174*^9, 3.6046532074254923`*^9, 
   3.604821177848062*^9, 3.6048213615295563`*^9, 3.604827060434173*^9, 
   3.604901616077817*^9, 3.604997496324129*^9, 3.6049978261318817`*^9, 
   3.6049979852878523`*^9, 3.604998248630701*^9, 3.604998666760453*^9, 
   3.604999011270927*^9, 3.604999554712777*^9, 3.6053222049084787`*^9, 
   3.605329236486205*^9, 3.6053448675456467`*^9, 3.6054993498960648`*^9, 
   3.605499748763566*^9, 3.605500259015192*^9, 3.60550096820971*^9, 
   3.605517515169345*^9, 3.605518577063212*^9, 3.606019696384848*^9, 
   3.6066244957078457`*^9, 3.6072547897517548`*^9, 3.6077468229755173`*^9, 
   3.608458655831635*^9, 3.60846103252072*^9, 3.608611343098269*^9, 
   3.608972233152596*^9, 3.609039047486825*^9, 3.609065498940879*^9, 
   3.6091305158030453`*^9, 3.610078771749024*^9, 3.6101829996739817`*^9, 
   3.610768727282456*^9, 3.614321205969746*^9, 3.614488586562323*^9, {
   3.614490596950143*^9, 3.614490635010194*^9}, 3.6144951763446827`*^9, 
   3.614500542422613*^9, 3.6145007661737013`*^9, 3.614500908059558*^9, 
   3.6145056353363943`*^9, 3.6145771139200706`*^9, 3.6149371243079433`*^9, 
   3.61563370744973*^9, 3.616214562112349*^9, 3.617336069935061*^9, 
   3.617338189920063*^9, 3.61821733681868*^9, 3.619333565554996*^9, 
   3.619774932107731*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Double-check: eeee vertex rederived directly from DFT (not Siegel's formalism)\
\>", "Subsection",
 CellChangeTimes->{{3.60310828197171*^9, 3.603108361961527*^9}, 
   3.604037217043652*^9, {3.614495316704475*^9, 3.614495317205903*^9}}],

Cell["\<\
In order to double-check the quartic e coupling terms in the Lagrangian I\
\[CloseCurlyQuote]m now using the DFT Lagrangian (as opposed to Siegel\
\[CloseCurlyQuote]s frame formalism) and the non-linear field redefinition.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603108371539927*^9, 
  3.6031084481628*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"x", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "c"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "d"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "d"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "c"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6030064071088877`*^9, 3.60300645548549*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "y"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "x"}]]}]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0F1I02EYxuGZRYEsCqqtpZYxU0pwIrl0M3liiK0d6BxhGKWTPhfswJCC
HLhyUFD4j0osGxE4arkpTmwYLYpcI0gIba59by3DF2tzU7bZtnreg5vr7D74
lSjV8nN5LBarCZe4mdYIXAT4r1KqNrSwcrOqHe1e08iU6NeGt119aPlZ/psy
NzrV8uAQau+cb6tEBeapJQF6V92cpQo11k8LqGt+LkLdIdm904Vue+6oprbu
lzZQuVVC1XeUdZi3SJ2IepPUI3HLPTfqvuqY9qA6Z8+I3EPgxUD0vgK1yuoH
DWjOXGumOrczPS/RyeP5/i/or6GCsQx6RtPkotprDi5TQ1kOO4uKtaeAeiB2
+QrVYWsfp1oCetETL/5vYIx6dF3fLTOg1wK26RWUET5epq72dlXEUfHoln6q
9t+FoXV05ERp8V/0fJI9G/UR+DyTKuIECEhz1qA0SIAtCe8ThQiExTnLozB2
0XF9g6jyWQRCqC9Tdp35QcBfHOdOoDWejvx3aMnqjQ9+9CK/1276SaC+PGMM
ouPfYsbcIoFdvPeNM78J1DnleZw/BLYaCmp56MmnswuF6ABjT1DDfdpNRegw
USn2ognTUdExNG26szGOnm5VlzbGCDSnJR87Vwg8nLN19CcIeJdsl3RoVcue
seo1ApFhy2tFksDo7Vt1FSkC/wE7E1aE
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S", "[", 
   RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "b"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "d"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "d"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "b"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.603006476150899*^9, 3.603006527596593*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "b"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "b"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVy2tIE3AUxuENMzK0JDBLt1mRJkxyMQl06ThRa45FuEaNQildq5yXETVy
SCi1DCIpkUwU6TpwZIoYtkVMRmURGQS1pW5utS08bOpmqXnt/D+8PF/e387y
WtU5LofDkdP8mQW3RG6E7zf+6TUk1ifoT5N9B+zKcvLC7k3aRjKylvV6zyjC
5LUTrUJSfsetySUVWtukiEw2qVaY7t+OYReZN/ctwPyoS09xk2lln8TMortK
KVPuydf/IKemeSFmrmlinnl+/2DzKPlQOmIfIw01dc9UYwgZJ6MtajJ5vLDN
Qq7WFL5gNgdajd3kLvF672fyandi7zL71Re7mT0pwjDTm749aYU0VpwCpiCm
r2JuiC/tY2LokaRjHOGps8XaRVrbrygtpCIyZI+SnuWOMFNzSJcTI/c92Ghm
VtZWti+Sl0qyBUvkka7NI9MehCzuEj91AuHyE5tP4UNocAV2SPwIjwe4A/d/
IsRt5XvayP65IPhJUTC77t4vhOfGP9v6yerOijgHuZDQ4PSSBmfj+54gQnhx
zeojddVR62oIobP0g+xdBGGL8Tg3dQpBeDQxP4181fTFxSNNJcOzTG3e9Xg+
aZmpUmeQAptUcpA0Hru9Lka+STJkymaoi5e9PRtF2NvoOGOeRfgqGLp4kzxc
zOsV/0WIFb0cVM8jlDWZC3IWEP4D1kVOHg==
  "]]
}, Open  ]],

Cell["The part only containing metrices can be written as follows:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603108371539927*^9, 
  3.603108481041254*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ver", "[", 
   RowBox[{
   "a_", ",", "b_", ",", "c_", ",", "d_", ",", "i_", ",", "j_", ",", "u_", 
    ",", "v_", ",", "x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"i", ",", "b"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"j", ",", "u"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"a", ",", "v", ",", "c", ",", "d", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "j"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "u"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "v", ",", "c", ",", "d", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "v"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"j", ",", "u"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "b", ",", "c", ",", "d", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "i"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "u"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"a", ",", "j", ",", "c", ",", "v", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "i"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "v"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"a", ",", "j", ",", "u", ",", "d", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "j"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "u"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "b", ",", "c", ",", "v", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "j"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "v"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"i", ",", "b", ",", "u", ",", "d", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "i"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"j", ",", "u"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"a", ",", "b", ",", "c", ",", "v", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "j"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "u"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"a", ",", "b", ",", "i", ",", "v", ",", "x", ",", "y"}], 
        "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"j", ",", "u"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "v"}], "]"}], 
       RowBox[{"T", "[", 
        RowBox[{"a", ",", "b", ",", "i", ",", "d", ",", "x", ",", "y"}], 
        "]"}]}], "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "i"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "x", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "j"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "c"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "j"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "j"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "c", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "j"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "j"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "j"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "j", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "c"}], "]"}]}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "x", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "i", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "d", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "i"}], "]"}]}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "i"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "x", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "d"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "c"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "d"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "j", ",", "v", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "c", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "j", ",", "v", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "d", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "j", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "a", ",", "v", ",", "c"}], "]"}]}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "x", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "c"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "i", ",", "v", ",", "c"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"x", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "c"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "c", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "i", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "d", ",", "v", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "c"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "x"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "b", ",", "v", ",", "y"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "c"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "y"}], "]"}], 
          RowBox[{"S", "[", 
           RowBox[{"u", ",", "i", ",", "v", ",", "c"}], "]"}]}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"u", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "x"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"v", ",", "y"}], "]"}]}]}], ")"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"x", ",", "y"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "u"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "v"}], "]"}]}]}], ")"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"x", ",", "y"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "u"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"u", ",", "x"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"v", ",", "x"}], "]"}]}]}], ")"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "y"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "x"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"u", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"v", ",", "y"}], "]"}]}]}], ")"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "x"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "y"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "u"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "v"}], "]"}]}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "d"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"u", ",", "x"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"d", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"v", ",", "x"}], "]"}]}]}], ")"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "y"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "x"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"u", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"b", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"v", ",", "y"}], "]"}]}]}], ")"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "x"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "y"}], "]"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"j", ",", "v"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "u"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"i", ",", "u"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "j"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "v"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "x", ",", "j", ",", "y"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "a", ",", "v", ",", "c"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "x", ",", "j", ",", "y"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"x", ",", "y"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "a", ",", "j", ",", "c"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "c", ",", "j", ",", "x"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "a", ",", "v", ",", "y"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "c", ",", "j", ",", "x"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "y"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "x"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "a", ",", "j", ",", "y"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "b", ",", "v", ",", "d"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "d", ",", "j", ",", "x"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "b", ",", "v", ",", "y"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "d", ",", "j", ",", "x"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "y"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "a", ",", "v", ",", "c"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "x"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"i", ",", "b", ",", "j", ",", "y"}], "]"}], 
       RowBox[{"S", "[", 
        RowBox[{"u", ",", "a", ",", "v", ",", "c"}], "]"}]}]}], "//", 
     "Expand"}], "//", "FCE"}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.60299809771104*^9, 3.602998125047517*^9}, {
   3.603006343210557*^9, 3.603006404526059*^9}, {3.6030065779711113`*^9, 
   3.603006896475556*^9}, {3.603006929756557*^9, 3.6030071978016768`*^9}, {
   3.603007360832499*^9, 3.603007538326334*^9}, 3.603012960099112*^9, {
   3.603013765191349*^9, 3.603015374123498*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["g", 
      RowBox[{"a", "y"}]]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "v"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "v"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "u"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "u"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "u"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "u"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6030065501349916`*^9, {3.6030067840245867`*^9, 3.603006798222933*^9}, 
   3.603006843635022*^9, 3.603006897275257*^9, {3.6030071104273577`*^9, 
   3.603007131003687*^9}, 3.603007544109008*^9, {3.603014336454915*^9, 
   3.603014380590638*^9}, 3.60301538007248*^9, 3.603088225089155*^9, 
   3.603094361573556*^9, {3.603172131559455*^9, 3.6031721609060802`*^9}, 
   3.6040370825096273`*^9, 3.604044963974*^9, 3.6040526800211*^9, 
   3.6040558870855618`*^9, 3.604056043838306*^9, 3.604397631231041*^9, 
   3.604397864061201*^9, 3.604398250164565*^9, 3.6043984956574373`*^9, 
   3.604398587681057*^9, 3.6044009870902033`*^9, 3.6044019701980352`*^9, 
   3.604402112300887*^9, 3.604403319055278*^9, 3.604405719857995*^9, 
   3.604649261026514*^9, 3.6046532088234167`*^9, 3.604821179191674*^9, 
   3.604821363255188*^9, 3.6048270618791237`*^9, 3.604901617506575*^9, 
   3.604997497695923*^9, 3.6049978275446577`*^9, 3.604997986616413*^9, 
   3.604998250054522*^9, 3.604998668076038*^9, 3.604999012692665*^9, 
   3.604999556150638*^9, 3.60532220641494*^9, 3.605329237829734*^9, 
   3.605344868930066*^9, 3.6054993512945957`*^9, 3.605499750230752*^9, 
   3.605500260397153*^9, 3.605500969585277*^9, 3.6055175166280947`*^9, 
   3.605518578470336*^9, 3.6060196977974033`*^9, 3.606624497183547*^9, 
   3.6072547910378323`*^9, 3.607746824440447*^9, 3.608458657267968*^9, 
   3.6084610342769737`*^9, 3.6086113444590816`*^9, 3.608972234529715*^9, 
   3.609039048958578*^9, 3.609065500365484*^9, 3.609130517246766*^9, 
   3.6100787734082317`*^9, 3.610183001260912*^9, 3.61076872883076*^9, 
   3.614321207552346*^9, 3.614488587865223*^9, 3.614495177580996*^9, 
   3.6145005436944933`*^9, 3.6145007674661713`*^9, 3.6145009093153667`*^9, 
   3.6145056366386843`*^9, 3.614577115274652*^9, 3.61493712572294*^9, 
   3.615633708752501*^9, 3.616214563424314*^9, 3.6173360712073193`*^9, 
   3.617338191257256*^9, 3.618217338161265*^9, 3.619333566910294*^9, 
   3.619774933484207*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ver", "[", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", ",", "u", ",", "v", 
    ",", "x", ",", "y"}], "]"}], "//", "Length"}]], "Input",
 CellChangeTimes->{{3.603015400080224*^9, 3.6030154127768784`*^9}}],

Cell[BoxData[
 FormBox["82", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6030154073752003`*^9, 3.6030154132799587`*^9}, 
   3.603088225291039*^9, 3.6030943617444*^9, 3.60317216266614*^9, 
   3.604037082739848*^9, 3.6040449642104073`*^9, 3.604052680139031*^9, 
   3.604055887177875*^9, 3.604056043986555*^9, 3.6043976314498177`*^9, 
   3.6043978641285887`*^9, 3.6043982502923937`*^9, 3.60439849575865*^9, 
   3.604398587769183*^9, 3.604400987223507*^9, 3.604401970286989*^9, 
   3.6044021123863573`*^9, 3.6044033191501427`*^9, 3.6044057200543337`*^9, 
   3.604649261094207*^9, 3.604653208992774*^9, 3.604821179366947*^9, 
   3.604821363310308*^9, 3.60482706194912*^9, 3.604901617596354*^9, 
   3.604997497822708*^9, 3.604997827612233*^9, 3.6049979867214127`*^9, 
   3.604998250238353*^9, 3.604998668192032*^9, 3.604999012776231*^9, 
   3.604999556282097*^9, 3.605322206556127*^9, 3.605329237935543*^9, 
   3.6053448690674753`*^9, 3.605499351410988*^9, 3.605499750358979*^9, 
   3.6055002605868683`*^9, 3.605500969723723*^9, 3.605517516817298*^9, 
   3.605518578701475*^9, 3.606019697933375*^9, 3.606624497320293*^9, 
   3.607254791078183*^9, 3.60774682463021*^9, 3.608458657409911*^9, 
   3.608461034537558*^9, 3.608611344586772*^9, 3.60897223463104*^9, 
   3.609039049138393*^9, 3.609065500545232*^9, 3.609130517450172*^9, 
   3.610078773630662*^9, 3.6101830013805227`*^9, 3.610768728905415*^9, 
   3.614321207783381*^9, 3.6144885880928802`*^9, 3.6144951778499537`*^9, 
   3.614500543728364*^9, 3.6145007677404337`*^9, 3.6145009095933247`*^9, 
   3.614505636932423*^9, 3.614577115319861*^9, 3.6149371257525253`*^9, 
   3.6156337088047323`*^9, 3.616214563497385*^9, 3.617336071238394*^9, 
   3.6173381913028097`*^9, 3.61821733822128*^9, 3.619333566990489*^9, 
   3.619774933509348*^9}]
}, Open  ]],

Cell["\<\
Already, here many terms cancel out. One finds 12 allowed (in terms of \
factorization of their indices) contractions, while 70 are disallowed.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603108371539927*^9, 
  3.60310850168952*^9}, {3.603108694424838*^9, 3.603108717033133*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["\<\
The crucial thing is to observe that in the Lagrangian only the term \
symmetric under exchange of (i,j) with (u,v) and vice versa contributes. This \
kills all the disallowed terms.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603088841780861*^9, 
  3.603088860083173*^9}, {3.603089211341029*^9, 3.6030892255060787`*^9}, {
  3.60310861724958*^9, 3.603108687145239*^9}, {3.603108722858136*^9, 
  3.603108726609105*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ver", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", ",", "u", ",", 
         "v", ",", "x", ",", "y"}], "]"}], "+", 
       RowBox[{"ver", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "u", ",", "v", ",", "i", ",", 
         "j", ",", "x", ",", "y"}], "]"}]}], ")"}]}], "//", "Contract"}], "//",
    "Expand"}]}]], "Input",
 CellChangeTimes->{{3.603089539649775*^9, 3.603089563250415*^9}, {
   3.603089595967271*^9, 3.603089675236309*^9}, {3.603089821613021*^9, 
   3.603089821952715*^9}, 3.6030905455899973`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6030895601769323`*^9, 3.60308956346478*^9}, {
   3.603089632047057*^9, 3.6030896760735826`*^9}, {3.603089822638546*^9, 
   3.603089832789624*^9}, 3.60309054691626*^9, 3.603094362685245*^9, 
   3.603108757355235*^9, 3.603172202510297*^9, 3.6040370831766453`*^9, 
   3.604044964725007*^9, 3.604052680620014*^9, 3.6040558876238003`*^9, 
   3.6040560444121923`*^9, 3.604397631843113*^9, 3.604397864543888*^9, 
   3.604398250729107*^9, 3.604398496215506*^9, 3.60439858825251*^9, 
   3.60440098765968*^9, 3.604401970664653*^9, 3.604402112765648*^9, 
   3.604403319615678*^9, 3.604405720428075*^9, 3.604649261471608*^9, 
   3.6046532094055233`*^9, 3.604821179764722*^9, 3.6048213637003508`*^9, 
   3.6048270623577423`*^9, 3.6049016179866657`*^9, 3.604997498268642*^9, 
   3.604997828014612*^9, 3.604997987145137*^9, 3.6049982507448187`*^9, 
   3.6049986686140423`*^9, 3.604999013191052*^9, 3.604999556689993*^9, 
   3.605322207005721*^9, 3.6053292383053913`*^9, 3.605344869479546*^9, 
   3.605499351775749*^9, 3.605499750769607*^9, 3.605500260951922*^9, 
   3.605500970135044*^9, 3.6055175172013187`*^9, 3.605518579149171*^9, 
   3.606019698362962*^9, 3.606624497745351*^9, 3.607254791458674*^9, 
   3.607746825062003*^9, 3.608458657878482*^9, 3.608461034913535*^9, 
   3.6086113449849157`*^9, 3.608972235038559*^9, 3.609039049569968*^9, 
   3.6090655009882708`*^9, 3.609130517898966*^9, 3.610078774152293*^9, 
   3.610183001775055*^9, 3.610768729291589*^9, 3.6143212082032013`*^9, 
   3.6144885884573393`*^9, 3.614495178218754*^9, 3.614500544092428*^9, 
   3.6145007681166677`*^9, 3.614500909955778*^9, 3.614505637312937*^9, 
   3.6145771156937943`*^9, 3.6149371261691523`*^9, 3.615633709217607*^9, 
   3.616214563910757*^9, 3.6173360716276712`*^9, 3.617338191697497*^9, 
   3.6182173386137943`*^9, 3.619333567404758*^9, 3.6197749338801537`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "tmp", "]"}]], "Input",
 CellChangeTimes->{{3.603172195369061*^9, 3.6031721969420547`*^9}}],

Cell[BoxData[
 FormBox["24", TraditionalForm]], "Output",
 CellChangeTimes->{{3.603172197696865*^9, 3.603172204718145*^9}, 
   3.6040370831928377`*^9, 3.604044964730463*^9, 3.604052680740149*^9, 
   3.604055887631504*^9, 3.6040560444199123`*^9, 3.604397631851164*^9, 
   3.6043978645658007`*^9, 3.604398250737384*^9, 3.604398496223015*^9, 
   3.60439858825675*^9, 3.6044009876662188`*^9, 3.604401970672173*^9, 
   3.6044021127730513`*^9, 3.604403319625422*^9, 3.604405720435615*^9, 
   3.60464926148312*^9, 3.6046532094208*^9, 3.6048211797798843`*^9, 
   3.604821363718172*^9, 3.604827062394416*^9, 3.604901618013554*^9, 
   3.6049974983023376`*^9, 3.6049978280502777`*^9, 3.6049979871724*^9, 
   3.604998250819873*^9, 3.6049986686354513`*^9, 3.604999013224246*^9, 
   3.6049995567154903`*^9, 3.60532220705241*^9, 3.605329238313493*^9, 
   3.6053448694891376`*^9, 3.605499351782926*^9, 3.6054997507755632`*^9, 
   3.605500260960135*^9, 3.6055009701434097`*^9, 3.605517517207282*^9, 
   3.6055185791571503`*^9, 3.60601969836975*^9, 3.606624497751059*^9, 
   3.607254791467073*^9, 3.6077468250701857`*^9, 3.60845865788772*^9, 
   3.608461034924539*^9, 3.60861134499949*^9, 3.608972235070182*^9, 
   3.6090390495778933`*^9, 3.609065500997168*^9, 3.60913051790876*^9, 
   3.610078774162064*^9, 3.610183001786484*^9, 3.610768729306511*^9, 
   3.614321208212658*^9, 3.614488588465033*^9, 3.6144951782238894`*^9, 
   3.6145005441005573`*^9, 3.6145007681256866`*^9, 3.614500909964671*^9, 
   3.61450563732259*^9, 3.614577115699368*^9, 3.614937126177183*^9, 
   3.6156337092225237`*^9, 3.61621456391992*^9, 3.617336071636909*^9, 
   3.617338191705974*^9, 3.6182173386229877`*^9, 3.619333567413146*^9, 
   3.61977493388509*^9}]
}, Open  ]],

Cell["\<\
Type in the allowed terms from before symmetrization (because I didn\
\[CloseCurlyQuote]t find a convenient way to separate them). 

In what follows I\[CloseCurlyQuote]ll just do the same symmetrization to find \
that what I typed in is precisely the right answer.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603088841780861*^9, 
  3.603088860083173*^9}, {3.603089211341029*^9, 3.6030892255060787`*^9}, {
  3.60310861724958*^9, 3.603108687145239*^9}, {3.603108722858136*^9, 
  3.603108726609105*^9}, {3.6031088372015057`*^9, 3.603108968751172*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bla", "=", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "y"}], "]"}]}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "j"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"d", ",", "v"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"i", ",", "u"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"d", ",", "j"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"v", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"i", ",", "u"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "j"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"d", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"v", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"i", ",", "u"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"j", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"v", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"i", ",", "u"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "j"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"d", ",", "v"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"i", ",", "u"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "i"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "u"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"d", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"j", ",", "v"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "i"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"j", ",", "v"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"u", ",", "x"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "v"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"d", ",", "j"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"i", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"u", ",", "y"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "i"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"j", ",", "v"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"u", ",", "y"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"i", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"j", ",", "v"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"u", ",", "y"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "u"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "i"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"j", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"v", ",", "y"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "i"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "u"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"j", ",", "v"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.603090145041568*^9, 3.603090426694209*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0FtIE3AYBfC5dJC0slKsMRdS1kMrF2aQw+qTcCYiONZlq4c5UDYMRIjQ
zGTkIspE12i0ZMQyY5qaq7BUDMViRNdBuTadWzWhz8sulRvapO//cPg9nYdz
sjW18qokDocjo7xw1jYr3Qhp+qdtzEOllTVnSVWfsE5PblzUjezxIExoO017
yfaMLGUuqc2N/ZKQInl7gvl5kOucIhuN6UHmpVRVhpusWko9yAw8unmUadzU
UPON3FmonGPy9gnjzOujsTYPeT+cPuIlxS7HQ7kXAdMktxXkcrjR3E1aeJf7
mVe4rot2Mrb5uO896TOVDfwjd7ca3MzhTt0C08NX8xOsHzID03qj5zyz+oDl
CbNcE5Tem0Z4WfGux0qGuxxl3eSUbXU4QrrqvAvMLfU2cZTkNskMzJVb9rsr
pJ+jE62SQ9vKP4RmEEoSBaLMWYSWMxF/qR+huCsnWxpA+Hr12LM73xF+ftLM
mEnj811FATLIr27o+IEgNOdvd5Bq2YN1r8hzyeMTPlLS9PZNX5B+Ol3Y6ydV
+v29a3MIcct62etFhK2CjqTMJYSPR04cFpD5rSluIblWwvvD1PLGU7JIW8Vj
xQ7SZa2XFpGmPGdylJwX2HOKwwhfPM2TlRGE6OCy2vAbYcN8XHeNbDl5aiDv
L8KFydCQIkY7nGMF4jjCf/TSS/Y=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"blabla", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"bla", "+", 
        RowBox[{"(", 
         RowBox[{"bla", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "\[Rule]", "u"}], ",", 
            RowBox[{"u", "\[Rule]", "i"}], ",", 
            RowBox[{"j", "\[Rule]", "v"}], ",", 
            RowBox[{"v", "\[Rule]", "j"}]}], "}"}]}], ")"}]}], ")"}]}], "//", 
     "Expand"}], "//", "Contract"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.603090444675189*^9, 3.6030904797503138`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"i", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"u", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"v", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"j", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6030904720692883`*^9, 3.603090480289077*^9}, 
   3.603090552759042*^9, 3.603094363436335*^9, 3.603172235004719*^9, 
   3.604037083711405*^9, 3.604044965376728*^9, 3.6040526812464647`*^9, 
   3.604055888127447*^9, 3.6040560448958387`*^9, 3.6043976326251373`*^9, 
   3.6043978650511208`*^9, 3.604398251206938*^9, 3.604398496749988*^9, 
   3.6043985888306627`*^9, 3.6044009882252493`*^9, 3.604401971199074*^9, 
   3.6044021132874403`*^9, 3.6044033201977*^9, 3.604405721162623*^9, 
   3.6046492620015383`*^9, 3.604653209916133*^9, 3.6048211804068193`*^9, 
   3.604821364333425*^9, 3.60482706302209*^9, 3.604901618565362*^9, 
   3.6049974988358593`*^9, 3.604997828623775*^9, 3.604997987759871*^9, 
   3.6049982514981194`*^9, 3.604998669195651*^9, 3.604999013723651*^9, 
   3.604999557256803*^9, 3.605322207636176*^9, 3.605329238762549*^9, 
   3.605344869966374*^9, 3.605499352253757*^9, 3.605499751241685*^9, 
   3.6055002614888763`*^9, 3.605500970633174*^9, 3.605517517698065*^9, 
   3.6055185796965017`*^9, 3.60601969881069*^9, 3.6066244982477007`*^9, 
   3.6072547918879757`*^9, 3.60774682558118*^9, 3.608458658453827*^9, 
   3.608461035555237*^9, 3.6086113456091967`*^9, 3.6089722356214647`*^9, 
   3.609039050066783*^9, 3.609065501536594*^9, 3.60913051846172*^9, 
   3.6100787748015842`*^9, 3.6101830023657007`*^9, 3.610768729895893*^9, 
   3.6143212086989403`*^9, 3.614488588878038*^9, 3.614495178626295*^9, 
   3.614500544520022*^9, 3.614500768547258*^9, 3.6145009103780107`*^9, 
   3.614505637739407*^9, 3.6145771161272163`*^9, 3.614937126635661*^9, 
   3.615633709624276*^9, 3.616214564353364*^9, 3.6173360720576963`*^9, 
   3.617338192146535*^9, 3.6182173390615463`*^9, 3.6193335678651953`*^9, 
   3.619774934401084*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "-", "blabla"}]], "Input",
 CellChangeTimes->{{3.6030904893307962`*^9, 3.603090502117168*^9}, {
  3.603090554531683*^9, 3.603090554637779*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.603090491421245*^9, 3.603090502401721*^9}, 
   3.603090555207097*^9, 3.603094363448469*^9, 3.6040370839071913`*^9, 
   3.604044965585753*^9, 3.6040526813718987`*^9, 3.6040558882161007`*^9, 
   3.604056045042804*^9, 3.604397632840104*^9, 3.604397865058528*^9, 
   3.604398251334117*^9, 3.6043984968373737`*^9, 3.604398588914007*^9, 
   3.604400988306468*^9, 3.604401971206294*^9, 3.604402113295104*^9, 
   3.604403320300811*^9, 3.604405721359326*^9, 3.60464926201768*^9, 
   3.604653209971031*^9, 3.604821180482518*^9, 3.604821364390428*^9, 
   3.604827063081725*^9, 3.6049016186343117`*^9, 3.6049974989519444`*^9, 
   3.604997828709234*^9, 3.60499798783675*^9, 3.604998251668461*^9, 
   3.604998669312921*^9, 3.6049990138204927`*^9, 3.604999557360779*^9, 
   3.605322207783567*^9, 3.605329238768322*^9, 3.6053448701097813`*^9, 
   3.605499352262306*^9, 3.6054997513549137`*^9, 3.6055002616783133`*^9, 
   3.6055009707896214`*^9, 3.605517517875361*^9, 3.605518579943577*^9, 
   3.606019698951281*^9, 3.606624498393059*^9, 3.607254791895186*^9, 
   3.607746825769559*^9, 3.608458658498864*^9, 3.608461035819704*^9, 
   3.608611345714855*^9, 3.608972235689139*^9, 3.609039050272491*^9, 
   3.6090655017866592`*^9, 3.6091305187396927`*^9, 3.610078775012814*^9, 
   3.610183002465787*^9, 3.61076872996868*^9, 3.61432120893078*^9, 
   3.61448858910577*^9, 3.6144951788966503`*^9, 3.6145005445280313`*^9, 
   3.614500768817809*^9, 3.614500910643806*^9, 3.614505638024806*^9, 
   3.6145771161340027`*^9, 3.614937126643036*^9, 3.615633709630329*^9, 
   3.6162145643618307`*^9, 3.617336072064529*^9, 3.61733819215516*^9, 
   3.6182173390679207`*^9, 3.619333567871749*^9, 3.6197749345069437`*^9}]
}, Open  ]],

Cell["\<\
Let\[CloseCurlyQuote]s now compare it to the expression from Siegel\
\[CloseCurlyQuote]s formalism:\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603088841780861*^9, 
  3.603088860083173*^9}, {3.603089211341029*^9, 3.6030892255060787`*^9}, {
  3.6031092376887417`*^9, 3.603109255303714*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T4", "[", 
   RowBox[{
   "u", ",", "v", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", 
    ",", "x", ",", "y"}], "]"}], "//", "Length"}]], "Input",
 CellChangeTimes->{{3.603109575019354*^9, 3.603109577343975*^9}}],

Cell[BoxData[
 FormBox["12", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0FFIU2EABeBpWRkIJYi11Uopau2SQoLLSeuXUJBRYSOamLBRCS4rpAYN
kpCM5pAlRZeIjLKENkoZI6kFZeklqq2Sgdet3a6L7eFvrbSyVVfp/A+H7+0c
OGX2k01H81Qq1R4k/NowbRcpsVWdC22JUSIKo1f1cPdWzloB11Qvp5VwV+/t
BaZANK+mYHRjeYp5vtBRIsKDqzRVzKTjpon5POd2TEP3+2NpZoegyzFPvSn0
xqAnqA/FYW3x2L2mOCV6k+mKBR4Z9PJDsEjX95CZiSSd92GtZJHCcCDQOqzA
O3FeZMbmXRmm1+YsWoCLWR9hbjvz5Dizbdw/wtzLK8YbHykxJETfALwrvTQP
wW7fitAsrPd8yTCLVz7i5qC509rDbOaeXv8LL7d0af/Bd7daI98SlKjDZm3p
J0pq/ihyo0zJ4Q+GMuMM+rfvD15LUlLZ70rwsERTXTcDTzc4z/Z/poS3N64N
QG388ZJnMCtPvZBg54gsPEhRcqh8n1+Gb90m/2Kakq58bcPEV+zJg3mlWZhs
2amGvdxqcR0MNKt/MoVwtGA9lFRjlg3QeumCsQ4uS0WXzsGIK7i5/jslJ+Y9
47ZZStId+baeH5QoBwraL8LuPvvwjl/4V6eMWn5TsmlisobLUfIfZFg+1Q==

  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"bla", "-", 
      RowBox[{"T4", "[", 
       RowBox[{
       "u", ",", "v", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", 
        "j", ",", "x", ",", "y"}], "]"}]}], ")"}], "+", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"bla", "-", 
        RowBox[{"T4", "[", 
         RowBox[{
         "u", ",", "v", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",",
           "j", ",", "x", ",", "y"}], "]"}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"i", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "i"}], ",", 
        RowBox[{"j", "\[Rule]", "v"}], ",", 
        RowBox[{"v", "\[Rule]", "j"}]}], "}"}]}], ")"}]}], "//", "Contract"}],
   "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6031092624803677`*^9, 3.603109303327396*^9}, {
  3.6031093511511803`*^9, 3.603109414527337*^9}, {3.6031095073681583`*^9, 
  3.603109513211422*^9}, {3.6031095973379307`*^9, 3.603109636268405*^9}, {
  3.603109732034227*^9, 3.60310976787706*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.603109292761744*^9, 3.603109304841752*^9}, {
   3.60310940204088*^9, 3.603109416624901*^9}, 3.6031095154492826`*^9, {
   3.603109598765191*^9, 3.603109636732987*^9}, 3.603109771575034*^9, 
   3.604037083991226*^9, 3.6040449659016523`*^9, 3.604052681498118*^9, 
   3.604055888304171*^9, 3.6040560451118383`*^9, 3.60439763306019*^9, 
   3.604397865130858*^9, 3.604398251397043*^9, 3.604398496928463*^9, 
   3.604398588998885*^9, 3.604400988396134*^9, 3.604401971299246*^9, 
   3.604402113394435*^9, 3.604403320393097*^9, 3.604405721549612*^9, 
   3.604649262171568*^9, 3.6046532100413933`*^9, 3.604821180559061*^9, 
   3.604821364545895*^9, 3.604827063202098*^9, 3.604901618756956*^9, 
   3.6049974990459948`*^9, 3.604997828851452*^9, 3.604997987955245*^9, 
   3.6049982517238913`*^9, 3.6049986694440107`*^9, 3.604999013888646*^9, 
   3.604999557455326*^9, 3.6053222079329557`*^9, 3.605329238830634*^9, 
   3.605344870192421*^9, 3.6054993523363647`*^9, 3.605499751412648*^9, 
   3.605500261776825*^9, 3.605500970852277*^9, 3.60551751795418*^9, 
   3.605518580039981*^9, 3.606019699009707*^9, 3.606624498467926*^9, 
   3.6072547919303637`*^9, 3.607746825848915*^9, 3.608458658619416*^9, 
   3.608461035972752*^9, 3.608611345879755*^9, 3.608972235802424*^9, 
   3.609039050349133*^9, 3.6090655018948507`*^9, 3.60913051883646*^9, 
   3.610078775172752*^9, 3.610183002588726*^9, 3.610768730117361*^9, 
   3.6143212089923563`*^9, 3.6144885891521072`*^9, 3.614495178922306*^9, 
   3.6145005445654163`*^9, 3.614500768847498*^9, 3.614500910665766*^9, 
   3.614505638057722*^9, 3.614577116179352*^9, 3.614937126683134*^9, 
   3.615633709669064*^9, 3.616214564425462*^9, 3.617336072105047*^9, 
   3.617338192213046*^9, 3.618217339118932*^9, 3.619333567946725*^9, 
   3.619774934611638*^9}]
}, Open  ]],

Cell["Hence, the two computations yield identical results!", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603088841780861*^9, 
  3.603088860083173*^9}, {3.603089211341029*^9, 3.6030892255060787`*^9}, {
  3.6031092376887417`*^9, 3.603109255303714*^9}, {3.603109780566339*^9, 
  3.603109789950222*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6029980616574163`*^9, 3.6029980939734898`*^9}, {3.603088841780861*^9, 
  3.603088860083173*^9}, {3.603089211341029*^9, 3.6030892255060787`*^9}, {
  3.6031092376887417`*^9, 3.603109255303714*^9}, {3.603109780566339*^9, 
  3.603109795223254*^9}},
 Background->RGBColor[1, 0.9, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eeev vertex (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ef"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"varphi", "[", 
    SubscriptBox["k", "4"]}], TraditionalForm]]],
 "]):"
}], "Subsection",
 CellChangeTimes->{{3.60480638059011*^9, 3.60480645410249*^9}, {
  3.614495323621714*^9, 3.6144953243600616`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T5", "[", 
   RowBox[{
   "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "x_", 
    ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"e", ",", "x"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"f", ",", "y"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"f", ",", "x"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"e", ",", "y"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"c", ",", "x"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"f", ",", "y"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "e"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"f", ",", "x"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "y"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "d"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"c", ",", "e"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"d", ",", "x"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"e", ",", "y"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "f"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"e", ",", "x"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"b", ",", "y"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"a", ",", "c"}], "]"}], 
     RowBox[{"d", "[", 
      RowBox[{"d", ",", "f"}], "]"}]}]}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{
  3.604806475229677*^9, {3.604806510767028*^9, 3.604806691021945*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "y"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "x"}]]}]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "y"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "x"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6048066649497957`*^9, 3.604806692238125*^9}, 
   3.604821180678371*^9, 3.604821364689027*^9, 3.6048270633497477`*^9, 
   3.6049016188715277`*^9, 3.60499749918167*^9, 3.604997828958358*^9, 
   3.604997988093932*^9, 3.604998251860997*^9, 3.604998669555654*^9, 
   3.604999014046793*^9, 3.6049995575994368`*^9, 3.605322208056954*^9, 
   3.605329238972299*^9, 3.605344870336932*^9, 3.6054993525422993`*^9, 
   3.6054997515421*^9, 3.605500261870083*^9, 3.6055009709878387`*^9, 
   3.605517518045413*^9, 3.605518580138192*^9, 3.6060196991391172`*^9, 
   3.606624498628475*^9, 3.6072547920347223`*^9, 3.607746825944831*^9, 
   3.608458658736558*^9, 3.6084610362023478`*^9, 3.60861134601018*^9, 
   3.608972235946207*^9, 3.6090390505568438`*^9, 3.609065502054564*^9, 
   3.6091305190121403`*^9, 3.610078775327981*^9, 3.610183002706705*^9, 
   3.6107687302481403`*^9, 3.614321209089774*^9, 3.6144885892459707`*^9, 
   3.614495179015091*^9, 3.6145005446736794`*^9, 3.6145007689466677`*^9, 
   3.614500910764625*^9, 3.614505638160677*^9, 3.614577116298809*^9, 
   3.61493712678469*^9, 3.615633709773466*^9, 3.616214564543996*^9, 
   3.617336072218177*^9, 3.617338192343697*^9, 3.618217339256462*^9, 
   3.619333568108244*^9, 3.61977493471756*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T6", "[", 
   RowBox[{
   "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "x_", 
    ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"f", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "d"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"e", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "c"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "f"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "f"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"f", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "d"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "e"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"e", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "c"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"d", "[", 
     RowBox[{"b", ",", "y"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"c", ",", "x"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"a", ",", "e"}], "]"}], 
    RowBox[{"d", "[", 
     RowBox[{"d", ",", "f"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.604806679104878*^9, 3.604806843909944*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "y"}]]}], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "y"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuK2KxOmz7/9yvEG74zpy4D0C6VZ60D06TXvylYC6R6m
+HtngfQqp/T1f4D0tPWLboBoX+H2NyB6w6x63r9AumL1FkcQ/XTm4RwQrSO7
bQOILrjEZjP7zivHL28erZoHpJ1+n/FZBqSXFQrv/giirT+/AdH1/vt1PgHp
ss2JrSC66MWRmb+AtLxgh9xvIF0Rn3bu/d1XjlETwuTE779yzDnK9NDrwSvH
pmBHReuHrxzvSEdvmfbolaNIRvfd6UDap8PV6SGQNjveWDnx8SvHzGshkpuA
tNi0I8z7gbSA4ZND94D0F6UPx9Y+feWYohK1+gGQ/vzZe/W/Z68cLzSpuh99
CzRPbSWj+LtXjiz7Ei2lgLSamPgNGSB9a4/8FxD9+vhNVlkg/WPLsRB5IM3Q
3G3tBFK/8RbLJyAtwLJb1e3DK0e5xClHEj++cjzzmiOx9TPQX4q8WW1A+sHG
rPXGX185lu5l3RHy/ZWjM9MNK50frxwBfeTuKw==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEVarphi", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "I"}], "/", "4"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "y"}], "]"}], 
        RowBox[{"T5", "[", 
         RowBox[{
         "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "y"}], "]"}], 
        RowBox[{"T5", "[", 
         RowBox[{
         "c", ",", "d", ",", "a", ",", "b", ",", "e", ",", "f", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "y"}], "]"}], 
        RowBox[{"T5", "[", 
         RowBox[{
         "c", ",", "d", ",", "e", ",", "f", ",", "a", ",", "b", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "y"}], "]"}], 
        RowBox[{"T5", "[", 
         RowBox[{
         "e", ",", "f", ",", "c", ",", "d", ",", "a", ",", "b", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "y"}], "]"}], 
        RowBox[{"T5", "[", 
         RowBox[{
         "a", ",", "b", ",", "e", ",", "f", ",", "c", ",", "d", ",", "x", ",",
           "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "x"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "y"}], "]"}], 
        RowBox[{"T5", "[", 
         RowBox[{
         "e", ",", "f", ",", "a", ",", "b", ",", "c", ",", "d", ",", "x", ",",
           "y"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"I", "/", "4"}], 
     RowBox[{"k", "[", 
      RowBox[{"4", ",", "y"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "x"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"T6", "[", 
           RowBox[{
           "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "x", 
            ",", "y"}], "]"}], "+", 
          RowBox[{"T6", "[", 
           RowBox[{
           "a", ",", "b", ",", "e", ",", "f", ",", "c", ",", "d", ",", "x", 
            ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "x"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"T6", "[", 
           RowBox[{
           "c", ",", "d", ",", "a", ",", "b", ",", "e", ",", "f", ",", "x", 
            ",", "y"}], "]"}], "+", 
          RowBox[{"T6", "[", 
           RowBox[{
           "c", ",", "d", ",", "e", ",", "f", ",", "a", ",", "b", ",", "x", 
            ",", "y"}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "x"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"T6", "[", 
           RowBox[{
           "e", ",", "f", ",", "a", ",", "b", ",", "c", ",", "d", ",", "x", 
            ",", "y"}], "]"}], "+", 
          RowBox[{"T6", "[", 
           RowBox[{
           "e", ",", "f", ",", "c", ",", "d", ",", "a", ",", "b", ",", "x", 
            ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}]}], "//", 
   "Contract"}]}]], "Input",
 CellChangeTimes->{{3.604806861181693*^9, 3.604807110876603*^9}, {
  3.604807146996176*^9, 3.604807199332614*^9}, {3.604807354677855*^9, 
  3.6048073631330557`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.60480701049771*^9, 3.6048070278545103`*^9}, 
   3.604807201003928*^9, 3.604821181434257*^9, 3.6048213655465508`*^9, 
   3.604827064170464*^9, 3.604901619674836*^9, 3.6049974998727703`*^9, 
   3.604997829796608*^9, 3.6049979889130917`*^9, 3.604998252639711*^9, 
   3.6049986703046017`*^9, 3.604999014811355*^9, 3.604999558392387*^9, 
   3.605322208917165*^9, 3.605329239725864*^9, 3.605344871098027*^9, 
   3.605499353272365*^9, 3.6054997522485943`*^9, 3.605500262650703*^9, 
   3.6055009717140923`*^9, 3.6055175188604717`*^9, 3.605518580940357*^9, 
   3.606019699861266*^9, 3.606624499423354*^9, 3.6072547927283163`*^9, 
   3.6077468267224197`*^9, 3.6084586595497837`*^9, 3.608461037105744*^9, 
   3.608611346806953*^9, 3.608972236756968*^9, 3.609039051266651*^9, 
   3.6090655028633327`*^9, 3.609130519823263*^9, 3.610078776125657*^9, 
   3.61018300357253*^9, 3.610768731083086*^9, 3.614321209851267*^9, 
   3.614488589895466*^9, 3.614495179664385*^9, 3.614500545339806*^9, 
   3.6145007696079206`*^9, 3.6145009114248667`*^9, 3.6145056388316393`*^9, 
   3.614577116976508*^9, 3.6149371274543743`*^9, 3.615633710467154*^9, 
   3.6162145652704573`*^9, 3.617336072884987*^9, 3.6173381930079517`*^9, 
   3.6182173399393272`*^9, 3.619333568801942*^9, 3.6197749354559803`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "verEEEVarphi", "]"}]], "Input",
 CellChangeTimes->{{3.604807258923153*^9, 3.604807261075231*^9}}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 CellChangeTimes->{3.610775772092308*^9, 3.614321210117578*^9, 
  3.614488590232747*^9, 3.6144951799260263`*^9, 3.614500545344589*^9, 
  3.614500769889143*^9, 3.6145009116929483`*^9, 3.614505639111569*^9, 
  3.6145771169868793`*^9, 3.6149371274634533`*^9, 3.615633710474146*^9, 
  3.616214565276431*^9, 3.617336072890813*^9, 3.617338193013699*^9, 
  3.618217339948345*^9, 3.619333568808399*^9, 3.6197749355235157`*^9}]
}, Open  ]],

Cell["Quickly checking Bose symmetry of legs 1 2 3:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, 3.608460810568369*^9, {
   3.6107757772306967`*^9, 3.6107757869899387`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"verEEEVarphi", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEVarphi", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "1"}], "]"}], "\[Rule]", 
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "1"}], "]"}]}], ",", 
        RowBox[{"a", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "b"}]}], "}"}]}], ")"}]}], ",", 
   RowBox[{"verEEEVarphi", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEVarphi", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "1"}], "]"}], "\[Rule]", 
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], "\[Rule]", 
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "1"}], "]"}]}], ",", 
        RowBox[{"a", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "b"}]}], "}"}]}], ")"}]}], ",", 
   RowBox[{"verEEEVarphi", "-", 
    RowBox[{"(", 
     RowBox[{"verEEEVarphi", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], "\[Rule]", 
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}]}], ",", 
        RowBox[{"e", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "e"}], ",", 
        RowBox[{"f", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "f"}]}], "}"}]}], ")"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.610775801706353*^9, 3.61077591049541*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.610775867514348*^9, 3.6107759113552113`*^9}, 
   3.6143212101751833`*^9, 3.614488590258819*^9, 3.6144951799503527`*^9, 
   3.614500545369915*^9, 3.614500769913146*^9, 3.614500911712487*^9, 
   3.6145056391422167`*^9, 3.6145771170299273`*^9, 3.61493712750644*^9, 
   3.6156337105133038`*^9, 3.616214565317997*^9, 3.617336072920959*^9, 
   3.617338193063271*^9, 3.6182173399780483`*^9, 3.619333568927299*^9, 
   3.6197749355824633`*^9}]
}, Open  ]],

Cell["\<\
In case that the three e are onshell and the varphi is offshell, then \
eliminate k4 and use transversality for legs 1,2,3.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, 3.608460810568369*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEVarphionshell123", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"verEEEVarphi", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "bb_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "bb"}], "]"}]}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "bb"}], "]"}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "bb"}], "]"}]}]}], "}"}]}], "//", "Expand"}], 
    ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.604807408673676*^9, 3.604807589563745*^9}, {
  3.604812934622579*^9, 3.604812940980936*^9}, {3.6107757060551662`*^9, 
  3.610775712245915*^9}, {3.614491886341941*^9, 3.6144919858809967`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604807410898376*^9, {3.604807446938031*^9, 3.604807453844843*^9}, {
   3.604807533582675*^9, 3.604807590256959*^9}, 3.604812942968244*^9, 
   3.604821181606221*^9, 3.604821365751759*^9, 3.604827064365876*^9, 
   3.60490161987799*^9, 3.604997500099564*^9, 3.6049978300107*^9, 
   3.604997989150735*^9, 3.6049982529183826`*^9, 3.604998670526523*^9, 
   3.604999015017757*^9, 3.604999558600583*^9, 3.6053222092457647`*^9, 
   3.605329239797763*^9, 3.605344871310314*^9, 3.605499353353711*^9, 
   3.6054997524257917`*^9, 3.605500262928123*^9, 3.605500971924843*^9, 
   3.605517519184351*^9, 3.605518581261147*^9, 3.606019700042164*^9, 
   3.606624499655223*^9, 3.6072547927956543`*^9, 3.607746826987215*^9, 
   3.608458659874831*^9, 3.6084610373217363`*^9, 3.608611347055953*^9, 
   3.608972236953706*^9, 3.6090390515390387`*^9, 3.609065503147423*^9, 
   3.6091305202153893`*^9, 3.610078776372692*^9, 3.610183003797546*^9, 
   3.610768731510076*^9, 3.610775713417007*^9, 3.614321210295393*^9, 
   3.614488590314479*^9, 3.614491926342046*^9, 3.614491986487048*^9, 
   3.6144951800064573`*^9, 3.614500545450384*^9, 3.614500769975382*^9, 
   3.614500911774206*^9, 3.614505639210474*^9, 3.614577117107244*^9, 
   3.61493712760115*^9, 3.6156337105960207`*^9, 3.616214565405677*^9, 
   3.617336072984729*^9, 3.617338193150478*^9, 3.618217340060088*^9, 
   3.619333569019496*^9, 3.619774935653926*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.604807460420136*^9, 3.604807461950547*^9}}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604807462266244*^9, {3.604807534956493*^9, 3.604807593112554*^9}, 
   3.604821181638607*^9, 3.6048213658902903`*^9, 3.604827064387525*^9, 
   3.604901619997941*^9, 3.6049975001448603`*^9, 3.604997830143775*^9, 
   3.6049979891890993`*^9, 3.6049982529631*^9, 3.604998670632872*^9, 
   3.604999015110845*^9, 3.6049995586369143`*^9, 3.605322209424224*^9, 
   3.6053292398421793`*^9, 3.605344871368306*^9, 3.6054993534807787`*^9, 
   3.605499752477899*^9, 3.605500262936537*^9, 3.6055009719804792`*^9, 
   3.605517519191559*^9, 3.605518581266369*^9, 3.606019700088088*^9, 
   3.606624499716528*^9, 3.607254792813387*^9, 3.607746826995652*^9, 
   3.60845865988356*^9, 3.6084610373381863`*^9, 3.608611347082364*^9, 
   3.608972236981181*^9, 3.609039051550866*^9, 3.609065503174728*^9, 
   3.609130520322249*^9, 3.610078776390687*^9, 3.610183003959359*^9, 
   3.610768731642844*^9, 3.614321210353964*^9, 3.6144885903357487`*^9, 
   3.614495180022162*^9, 3.6145005454711857`*^9, 3.614500769996232*^9, 
   3.6145009117887278`*^9, 3.614505639234964*^9, 3.614577117133752*^9, 
   3.614937127618853*^9, 3.615633710623233*^9, 3.616214565447207*^9, 
   3.6173360730093403`*^9, 3.617338193187736*^9, 3.618217340086316*^9, 
   3.619333569077104*^9, 3.619774935680605*^9}]
}, Open  ]],

Cell["\<\
For later use in the 6e amplitude we define the following 3e varphi vertex \
function:\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
  3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
  3.602226951402175*^9, 3.602226958496961*^9}, {3.604984847964712*^9, 
  3.604984864568191*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"verEEEVarphionshellmnp", "[", 
   RowBox[{
   "m_", ",", "n_", ",", "p_", ",", "a_", ",", "b_", ",", "c_", ",", "d_", 
    ",", "e_", ",", "f_"}], "]"}], "=", "\[IndentingNewLine]", 
  RowBox[{"verEEEVarphionshell123", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Momentum", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
      RowBox[{"Momentum", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"k", ",", "m"}], "]"}], ",", "D"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Momentum", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
      RowBox[{"Momentum", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"k", ",", "n"}], "]"}], ",", "D"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Momentum", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
      RowBox[{"Momentum", "[", 
       RowBox[{
        RowBox[{"Subscript", "[", 
         RowBox[{"k", ",", "p"}], "]"}], ",", "D"}], "]"}]}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6018005497236633`*^9, 3.601800553377142*^9}, {
   3.601800590703354*^9, 3.601800690962652*^9}, {3.60180073678732*^9, 
   3.601800751886629*^9}, {3.601800792856122*^9, 3.601800915040948*^9}, 
   3.60180094858832*^9, {3.601800982040934*^9, 3.60180103243976*^9}, {
   3.6018012778684807`*^9, 3.601801283218445*^9}, {3.6018976990824347`*^9, 
   3.6018977010208607`*^9}, {3.602227087470744*^9, 3.602227096165265*^9}, {
   3.602227524391502*^9, 3.602227563378263*^9}, 3.602228463202833*^9, 
   3.6048944613672647`*^9, {3.6049848816702137`*^9, 3.604985001112131*^9}, {
   3.604985031847303*^9, 3.604985054378976*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", "n", 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", "m", 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "m", 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", "n", 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", "p", 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVyksoA3AcwPEJFyVRGuad12EHa7swl9+UVzhoDlxE7MBMSSIHrzGllUeN
tZrH4mBp8zgoygHNQSukLYwN0/bLsA0T8/j9D98+l29WS1ddWwSHwymkpiwP
uo8rhN7N/UWmHCZMYdJ9ZrEzz1rXnpiDhcuxP2Tinw2Y979uOTNv2mZmznuE
JbprBEU4vKYnm7Z81aukdUCw6ydX4+J9zG6Nkx8gY4TDY0y51qP9IlWdxvRv
8littL44EDaS+tO5twjSAM9V5UQYqmzJErsQZtWD25o7hNMZk2OObAzKJC5S
lGnon75HyEjoSd4klcveyH1SxIs7uCEdinjLuhvhXDVqdJL6jj7j7yNCjaym
/MhHX/1JBPcZoUA3UpRChqUCeyq5MApvzIKk7+g00iP2SjNIzdeKWEJeLr1H
Bcjg3kVu2SvCRIP5sNmPoM7Pbh4LItQe5LePk8JJpUn4jlBanLMjDSFUGELF
/E+Ef/oi5e8=
  "]]
}, Open  ]],

Cell["A quick consistency check of this definition:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
  3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
  3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
  3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"verEEEVarphionshell123", "-", 
    RowBox[{"verEEEVarphionshellmnp", "[", 
     RowBox[{
     "1", ",", "2", ",", "3", ",", "a", ",", "b", ",", "c", ",", "d", ",", 
      "e", ",", "f"}], "]"}]}], "//", "Contract"}], "//", "Expand"}]], "Input",\

 CellChangeTimes->{{3.602227021997345*^9, 3.602227066711019*^9}, {
  3.602227572543538*^9, 3.60222757381598*^9}, {3.604985068932806*^9, 
  3.604985109557016*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.602227058375511*^9, 3.602227120674861*^9}, 
   3.60222726243694*^9, 3.602227471562661*^9, 3.602227529136385*^9, 
   3.6022275744669447`*^9, 3.602228481821661*^9, 3.602240450224358*^9, 
   3.602499810476574*^9, 3.602831990044777*^9, 3.602832388498126*^9, 
   3.603088166619178*^9, 3.603094307268774*^9, 3.604037078427971*^9, 
   3.604044959201037*^9, 3.6040526749849577`*^9, 3.604055883403288*^9, 
   3.604056040095057*^9, 3.604397626299716*^9, 3.604397860287261*^9, 
   3.604398246433322*^9, 3.604398491731051*^9, 3.604398584020936*^9, 
   3.604400982948017*^9, 3.604401966300852*^9, 3.604402108477315*^9, 
   3.6044033148665237`*^9, 3.604405714484893*^9, 3.604649257293681*^9, 
   3.604653204954091*^9, 3.604821175394157*^9, 3.604821358621031*^9, 
   3.604827057646578*^9, 3.604894467577805*^9, 3.6049016135576677`*^9, {
   3.604985075517826*^9, 3.604985123056797*^9}, 3.604997500344509*^9, 
   3.604997830345463*^9, 3.604997989553043*^9, 3.604998253207225*^9, 
   3.6049986708698387`*^9, 3.60499901525373*^9, 3.604999558819482*^9, 
   3.605322209734768*^9, 3.605329239961091*^9, 3.6053448714865294`*^9, 
   3.6054993536076927`*^9, 3.605499752584528*^9, 3.605500263109474*^9, 
   3.605500972097432*^9, 3.605517519348619*^9, 3.605518581459052*^9, 
   3.6060197001917887`*^9, 3.606624499846382*^9, 3.607254792897872*^9, 
   3.607746827151763*^9, 3.608458660088481*^9, 3.608461037644169*^9, 
   3.608611347364365*^9, 3.60897223712813*^9, 3.609039051709494*^9, 
   3.609065503428862*^9, 3.609130520569098*^9, 3.6100787767021723`*^9, 
   3.610183004141268*^9, 3.610768731894052*^9, 3.6143212104834833`*^9, 
   3.614488590408258*^9, 3.614495180099309*^9, 3.6145005455660753`*^9, 
   3.614500770069676*^9, 3.614500911864476*^9, 3.614505639316161*^9, 
   3.614577117216988*^9, 3.614937127716796*^9, 3.6156337107067537`*^9, 
   3.616214565549465*^9, 3.617336073088256*^9, 3.617338193284474*^9, 
   3.61821734016868*^9, 3.6193335691808147`*^9, 3.6197749357677937`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eeeee vertex (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ef"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SuperscriptBox["e", "gh"], "[", 
     SubscriptBox["k", "4"], "]"}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SuperscriptBox["e", "ij"], "[", 
     SubscriptBox["k", "5"], "]"}]}], TraditionalForm]]],
 "):"
}], "Subsection",
 CellChangeTimes->{{3.610951869272139*^9, 3.6109518765930977`*^9}, {
  3.6144949234873657`*^9, 3.614494928214679*^9}, {3.614495327680194*^9, 
  3.614495328605796*^9}, {3.614587404474114*^9, 3.614587407239572*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Te5mod", "[", 
    RowBox[{
    "a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", "f_", ",", "g_", 
     ",", "h_", ",", "i_", ",", "j_", ",", "x_", ",", "y_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Te5", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
         "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "+", 
       RowBox[{"Te5", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", 
         "j", ",", "g", ",", "h", ",", "y", ",", "x"}], "]"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Te5", "[", 
        RowBox[{
        "a", ",", "b", ",", "e", ",", "f", ",", "c", ",", "d", ",", "g", ",", 
         "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "+", 
       RowBox[{"Te5", "[", 
        RowBox[{
        "a", ",", "b", ",", "e", ",", "f", ",", "c", ",", "d", ",", "i", ",", 
         "j", ",", "g", ",", "h", ",", "y", ",", "x"}], "]"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Te5", "[", 
        RowBox[{
        "c", ",", "d", ",", "a", ",", "b", ",", "e", ",", "f", ",", "g", ",", 
         "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "+", 
       RowBox[{"Te5", "[", 
        RowBox[{
        "c", ",", "d", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
         "j", ",", "g", ",", "h", ",", "y", ",", "x"}], "]"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Te5", "[", 
        RowBox[{
        "e", ",", "f", ",", "a", ",", "b", ",", "c", ",", "d", ",", "g", ",", 
         "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "+", 
       RowBox[{"Te5", "[", 
        RowBox[{
        "e", ",", "f", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", 
         "j", ",", "g", ",", "h", ",", "y", ",", "x"}], "]"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Te5", "[", 
        RowBox[{
        "e", ",", "f", ",", "c", ",", "d", ",", "a", ",", "b", ",", "g", ",", 
         "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "+", 
       RowBox[{"Te5", "[", 
        RowBox[{
        "e", ",", "f", ",", "c", ",", "d", ",", "a", ",", "b", ",", "i", ",", 
         "j", ",", "g", ",", "h", ",", "y", ",", "x"}], "]"}]}], ")"}], "+", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Te5", "[", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "f", ",", "a", ",", "b", ",", "g", ",", 
         "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "+", 
       RowBox[{"Te5", "[", 
        RowBox[{
        "c", ",", "d", ",", "e", ",", "f", ",", "a", ",", "b", ",", "i", ",", 
         "j", ",", "g", ",", "h", ",", "y", ",", "x"}], "]"}]}], ")"}]}], "//",
     "Contract"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.610953110924081*^9, 3.610953325459907*^9}, 
   3.6109537571695147`*^9, {3.611043829661234*^9, 3.61104383470691*^9}, {
   3.611043875016159*^9, 3.6110439346050043`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Te5mod", "[", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", "h", 
    ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.61095334209007*^9, 3.610953352495007*^9}}],

Cell[BoxData[
 FormBox["108", TraditionalForm]], "Output",
 CellChangeTimes->{3.610953352848384*^9, 3.611043939510437*^9, 
  3.614415467497854*^9, 3.614486288607264*^9, 3.6144885968851433`*^9, 
  3.614495182379848*^9, 3.614500547652463*^9, 3.6145007723222322`*^9, 
  3.614500914130467*^9, 3.6145056415850563`*^9, 3.61457711923245*^9, 
  3.6149371300673513`*^9, 3.615633712793441*^9, 3.616214567649158*^9, 
  3.6173360751171007`*^9, 3.617338195346572*^9, 3.6182173422376966`*^9, 
  3.6193335712416763`*^9, 3.619774937908252*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ver5e", "=", 
  RowBox[{
   RowBox[{"-", "I"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"4", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"5", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
         "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"3", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"5", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "g", ",", "h", ",", "e", ",", 
         "f", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"5", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "g", ",", "h", ",", "e", ",", "f", ",", "c", ",", 
         "d", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"5", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "g", ",", "h", ",", "c", ",", "d", ",", "e", ",", "f", ",", "a", ",", 
         "b", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"3", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"4", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", "j", ",", "e", ",", 
         "f", ",", "g", ",", "h", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"4", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", "j", ",", "c", ",", 
         "d", ",", "g", ",", "h", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"4", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "e", ",", "f", ",", "c", ",", "d", ",", "i", ",", "j", ",", "a", ",", 
         "b", ",", "g", ",", "h", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"3", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "a", ",", "b", ",", "i", ",", "j", ",", "g", ",", "h", ",", "c", ",", 
         "d", ",", "e", ",", "f", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"3", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "c", ",", "d", ",", "i", ",", "j", ",", "g", ",", "h", ",", "a", ",", 
         "b", ",", "e", ",", "f", ",", "x", ",", "y"}], "]"}]}], "]"}], "+", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "x"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"2", ",", "y"}], "]"}], 
       RowBox[{"Te5mod", "[", 
        RowBox[{
        "e", ",", "f", ",", "i", ",", "j", ",", "g", ",", "h", ",", "a", ",", 
         "b", ",", "c", ",", "d", ",", "x", ",", "y"}], "]"}]}], "]"}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.610953780986624*^9, 3.610953859483612*^9}, {
  3.610953899476602*^9, 3.610953911152892*^9}, {3.610953952660041*^9, 
  3.610954161301886*^9}, {3.61104583849069*^9, 3.611045886689419*^9}, {
  3.6110462424652967`*^9, 3.6110462477777433`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", "\[ImaginaryI]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "16"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "i"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["c",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "i"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["c",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "i"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["d",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "i"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["d",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], "+", 
             RowBox[{"\[LeftSkeleton]", "1790", "\[RightSkeleton]"}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "e"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "f"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["j",
                 TraditionalForm],
                TraditionalForm]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "f"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "e"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["j",
                 TraditionalForm],
                TraditionalForm]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "c"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "f"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["j",
                 TraditionalForm],
                TraditionalForm]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "c"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "f"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["j",
                 TraditionalForm],
                TraditionalForm]]}], "+", 
             RowBox[{
              FractionBox["1", "16"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "c"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "f"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["j",
                 TraditionalForm],
                TraditionalForm]]}]}], ")"}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 113, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 113, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 113, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[113]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.610954100378675*^9, 3.6109541284044647`*^9}, 
   3.611043951522461*^9, 3.611045897372861*^9, 3.6110462584963408`*^9, 
   3.61441547763309*^9, 3.614486298693214*^9, 3.614488606875395*^9, 
   3.614495192378881*^9, 3.614500557605145*^9, 3.614500782116798*^9, 
   3.6145009238925123`*^9, 3.614505651793004*^9, 3.614577129113326*^9, 
   3.6149371401012783`*^9, 3.615633722978798*^9, 3.6162145776674356`*^9, 
   3.617336085092764*^9, 3.617338205451776*^9, 3.61821735204392*^9, 
   3.619333581046556*^9, 3.61977494801318*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "ver5e", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6109541215105343`*^9, 3.610954124281389*^9}, {
  3.6110462666134357`*^9, 3.611046269742858*^9}}],

Cell[BoxData[
 FormBox["1080", TraditionalForm]], "Output",
 CellChangeTimes->{3.610954128491734*^9, 3.61104395168157*^9, 
  3.611045897472825*^9, 3.611046270185033*^9, 3.614415477932971*^9, 
  3.614486299019515*^9, 3.6144886070219707`*^9, 3.614495192677009*^9, 
  3.6145005576751833`*^9, 3.614500782425939*^9, 3.614500924178237*^9, 
  3.6145056521976013`*^9, 3.61457712918117*^9, 3.614937140141161*^9, 
  3.6156337230533237`*^9, 3.6162145783641644`*^9, 3.617336085151636*^9, 
  3.617338205526647*^9, 3.618217352130932*^9, 3.619333581142223*^9, 
  3.619774948057065*^9}]
}, Open  ]],

Cell["\<\
18 x 120 = 2160 / 2 = 1080 (the factor of 2 is because of pairwise equivalent \
terms in Lag5e.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QPSEuIyvIJrHpwhMb9vl/3Dh7VeOWxaVPwHRYdeNeHSev3Ls2aXDC6I3ffGW
AtG/VtUrgehm1fk6IPpBapcBiI55ohUI5kcYh4JoBbaWehD9Znd+I5gfy94D
oj9wOoFpZZGz1oZAWoR7mi2IFmCLXAuiOaQ37APR+SkZIhFA+t/qw5IgumXm
FvY2IN32g5ULRBdlZu6e8OmVY/U+56MgGgA2KJ4L
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["Transversality doesn\[CloseCurlyQuote]t reduce the number of terms.", \
"Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}, {
  3.61095184326226*^9, 3.610951886114745*^9}, {3.6110459496437397`*^9, 
  3.6110459681865873`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ver5e", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "j"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], "//",
    "Expand"}], "//", "Length"}]], "Input",
 CellChangeTimes->{{3.610954164033826*^9, 3.6109541858297997`*^9}, {
  3.611045930910946*^9, 3.611045946500383*^9}, {3.6110462820993557`*^9, 
  3.6110462830795*^9}, {3.6144949657572308`*^9, 3.614495057871079*^9}}],

Cell[BoxData[
 FormBox["1080", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61095418648534*^9, 3.611043954275812*^9, {3.611045900556182*^9, 
   3.611045946943886*^9}, {3.6110462747132397`*^9, 3.611046283556188*^9}, 
   3.614415478012879*^9, 3.614486299097536*^9, 3.614488607093828*^9, 
   3.614495058798853*^9, 3.61449519272328*^9, 3.6145005577511597`*^9, 
   3.614500782476295*^9, 3.614500924228282*^9, 3.61450565227107*^9, 
   3.614577129259691*^9, 3.61493714019*^9, 3.6156337231240673`*^9, 
   3.616214578404523*^9, 3.6173360852119837`*^9, 3.617338205602903*^9, 
   3.618217352184499*^9, 3.619333581225387*^9, 3.6197749481097307`*^9}]
}, Open  ]],

Cell["Checking Bose symmetry of the vertex...", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
  3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
  3.601892326949563*^9}, {3.6018932912615433`*^9, 3.601893291571783*^9}, {
  3.604811530491542*^9, 3.604811555738611*^9}, {3.610861665588786*^9, 
  3.610861673397772*^9}, {3.61086177837362*^9, 3.610861843989621*^9}, {
  3.610861924973329*^9, 3.610861956324936*^9}, {3.610862217340376*^9, 
  3.610862249604599*^9}, {3.6108625881257477`*^9, 3.6108626034916897`*^9}, {
  3.610862688230118*^9, 3.610862690063713*^9}, {3.610872286408708*^9, 
  3.6108723006888523`*^9}, {3.61087319478199*^9, 3.6108733335032997`*^9}, {
  3.61095184326226*^9, 3.610951886114745*^9}, {3.6109542514182796`*^9, 
  3.610954257239551*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"Te5mod", "[", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Te5mod", "[", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "b"}]}], "}"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"Te5mod", "[", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Te5mod", "[", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "b"}]}], "}"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"Te5mod", "[", 
     RowBox[{
     "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
      "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Te5mod", "[", 
       RowBox[{
       "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
        "h", ",", "i", ",", "j", ",", "x", ",", "y"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"e", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "e"}], ",", 
        RowBox[{"f", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "f"}]}], "}"}]}], ")"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.611043407665289*^9, 3.611043498144733*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6110434459817657`*^9, 3.611043498809581*^9}, 
   3.611045905410494*^9, 3.611046286394299*^9, 3.614415478102573*^9, 
   3.614486299165227*^9, 3.614488607139455*^9, 3.614495192767167*^9, 
   3.614500557817141*^9, 3.614500782524931*^9, 3.614500924275319*^9, 
   3.614505652325732*^9, 3.614577129322132*^9, 3.6149371402400503`*^9, 
   3.6156337231904097`*^9, 3.616214578646462*^9, 3.617336085274983*^9, 
   3.617338205674943*^9, 3.618217352238134*^9, 3.619333581299697*^9, 
   3.619774948161804*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "\[Rule]", "c"}], ",", 
         RowBox[{"c", "\[Rule]", "a"}], ",", 
         RowBox[{"b", "\[Rule]", "d"}], ",", 
         RowBox[{"d", "\[Rule]", "b"}], ",", 
         RowBox[{
          SubscriptBox["k", "1"], "\[Rule]", 
          SubscriptBox["k", "2"]}], ",", 
         RowBox[{
          SubscriptBox["k", "2"], "\[Rule]", 
          SubscriptBox["k", "1"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "\[Rule]", "e"}], ",", 
         RowBox[{"e", "\[Rule]", "a"}], ",", 
         RowBox[{"b", "\[Rule]", "f"}], ",", 
         RowBox[{"f", "\[Rule]", "b"}], ",", 
         RowBox[{
          SubscriptBox["k", "1"], "\[Rule]", 
          SubscriptBox["k", "3"]}], ",", 
         RowBox[{
          SubscriptBox["k", "3"], "\[Rule]", 
          SubscriptBox["k", "1"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "\[Rule]", "g"}], ",", 
         RowBox[{"g", "\[Rule]", "a"}], ",", 
         RowBox[{"b", "\[Rule]", "h"}], ",", 
         RowBox[{"h", "\[Rule]", "b"}], ",", 
         RowBox[{
          SubscriptBox["k", "1"], "\[Rule]", 
          SubscriptBox["k", "4"]}], ",", 
         RowBox[{
          SubscriptBox["k", "4"], "\[Rule]", 
          SubscriptBox["k", "1"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "\[Rule]", "i"}], ",", 
         RowBox[{"i", "\[Rule]", "a"}], ",", 
         RowBox[{"b", "\[Rule]", "j"}], ",", 
         RowBox[{"j", "\[Rule]", "b"}], ",", 
         RowBox[{
          SubscriptBox["k", "1"], "\[Rule]", 
          SubscriptBox["k", "5"]}], ",", 
         RowBox[{
          SubscriptBox["k", "5"], "\[Rule]", 
          SubscriptBox["k", "1"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "\[Rule]", "e"}], ",", 
         RowBox[{"e", "\[Rule]", "c"}], ",", 
         RowBox[{"d", "\[Rule]", "f"}], ",", 
         RowBox[{"f", "\[Rule]", "d"}], ",", 
         RowBox[{
          SubscriptBox["k", "2"], "\[Rule]", 
          SubscriptBox["k", "3"]}], ",", 
         RowBox[{
          SubscriptBox["k", "3"], "\[Rule]", 
          SubscriptBox["k", "2"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "\[Rule]", "g"}], ",", 
         RowBox[{"g", "\[Rule]", "c"}], ",", 
         RowBox[{"d", "\[Rule]", "h"}], ",", 
         RowBox[{"h", "\[Rule]", "d"}], ",", 
         RowBox[{
          SubscriptBox["k", "2"], "\[Rule]", 
          SubscriptBox["k", "4"]}], ",", 
         RowBox[{
          SubscriptBox["k", "4"], "\[Rule]", 
          SubscriptBox["k", "2"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c", "\[Rule]", "i"}], ",", 
         RowBox[{"i", "\[Rule]", "c"}], ",", 
         RowBox[{"d", "\[Rule]", "j"}], ",", 
         RowBox[{"j", "\[Rule]", "d"}], ",", 
         RowBox[{
          SubscriptBox["k", "2"], "\[Rule]", 
          SubscriptBox["k", "5"]}], ",", 
         RowBox[{
          SubscriptBox["k", "5"], "\[Rule]", 
          SubscriptBox["k", "2"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"e", "\[Rule]", "g"}], ",", 
         RowBox[{"g", "\[Rule]", "e"}], ",", 
         RowBox[{"f", "\[Rule]", "h"}], ",", 
         RowBox[{"h", "\[Rule]", "f"}], ",", 
         RowBox[{
          SubscriptBox["k", "3"], "\[Rule]", 
          SubscriptBox["k", "4"]}], ",", 
         RowBox[{
          SubscriptBox["k", "4"], "\[Rule]", 
          SubscriptBox["k", "3"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"e", "\[Rule]", "i"}], ",", 
         RowBox[{"i", "\[Rule]", "e"}], ",", 
         RowBox[{"f", "\[Rule]", "j"}], ",", 
         RowBox[{"j", "\[Rule]", "f"}], ",", 
         RowBox[{
          SubscriptBox["k", "3"], "\[Rule]", 
          SubscriptBox["k", "5"]}], ",", 
         RowBox[{
          SubscriptBox["k", "5"], "\[Rule]", 
          SubscriptBox["k", "3"]}]}], "}"}]}], ")"}]}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"ver5e", "-", 
     RowBox[{"(", 
      RowBox[{"ver5e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"g", "\[Rule]", "i"}], ",", 
         RowBox[{"i", "\[Rule]", "g"}], ",", 
         RowBox[{"h", "\[Rule]", "j"}], ",", 
         RowBox[{"j", "\[Rule]", "h"}], ",", 
         RowBox[{
          SubscriptBox["k", "4"], "\[Rule]", 
          SubscriptBox["k", "5"]}], ",", 
         RowBox[{
          SubscriptBox["k", "5"], "\[Rule]", 
          SubscriptBox["k", "4"]}]}], "}"}]}], ")"}]}], "]"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.610954265223276*^9, 3.6109543212982597`*^9}, {
  3.610954475866201*^9, 3.610954517163405*^9}, {3.611043271054131*^9, 
  3.61104332822367*^9}, {3.611043966882207*^9, 3.6110440495122433`*^9}, {
  3.611044100518415*^9, 3.611044102473649*^9}, {3.611044148816453*^9, 
  3.6110442209807253`*^9}, {3.611044319866544*^9, 3.61104439676667*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610954322108486*^9, {3.6109544788875647`*^9, 3.6109545180939074`*^9}, {
   3.6110432912631702`*^9, 3.611043340849855*^9}, {3.611043963011318*^9, 
   3.6110439784927187`*^9}, {3.611044029375358*^9, 3.6110440334357033`*^9}, 
   3.6110440726875963`*^9, 3.611044102934039*^9, {3.611044173735938*^9, 
   3.6110442218756523`*^9}, {3.611044346507393*^9, 3.61104439786506*^9}, 
   3.611045908270135*^9, 3.611046288291647*^9, 3.614415478408967*^9, 
   3.614486299507844*^9, 3.614488607419145*^9, 3.61449519305409*^9, 
   3.6145005581600437`*^9, 3.614500782818953*^9, 3.614500924564773*^9, 
   3.61450565262532*^9, 3.614577129635989*^9, 3.614937140563656*^9, 
   3.615633723504369*^9, 3.61621457893815*^9, 3.617336085566287*^9, 
   3.6173382060007677`*^9, 3.618217352538224*^9, 3.619333581585401*^9, 
   3.619774948475844*^9}]
}, Open  ]],

Cell["Hence, Bose symmetry checked.", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQHaz8rlB5zyvHl9uESkC0DmONdxCQXpO4FEz7L1q7
mfvaK0e9q9e3guhJ3zYlCADpPV8dk0F0xzm7bBDtFFGRD6LPsjJWguhLSfdq
QPSEuIyvIJrHpwhMb9vl/3Dh7VeOWxaVPwHRYdeNeHSev3Ls2aXDC6I3ffGW
AtG/VtUrgehm1fk6IPpBapcBiI55ohUI5kcYh4JoBbaWehD9Znd+I5gfy94D
oj9wOoFpZZGz1oZAWoR7mi2IFmCLXAuiOaQ37APR+SkZIhFA+t/qw5Iguicp
1zESSKevUncC0Sr/znK3Aenrd8t4QDQAJGCdKA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\[OpenCurlyDoubleQuote]Amplitudes\[CloseCurlyDoubleQuote] with \
\[CurlyPhi]", "Section",
 CellChangeTimes->{{3.6144899462507257`*^9, 3.61448995234538*^9}, {
  3.614587380257214*^9, 3.614587385342601*^9}, {3.616221468898872*^9, 
  3.616221470994053*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "eee\[CurlyPhi] \[OpenCurlyDoubleQuote]amplitude\[CloseCurlyDoubleQuote] (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ef"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "4"]}], TraditionalForm]]],
 "]):"
}], "Subsection",
 CellChangeTimes->{{3.60480638059011*^9, 3.60480645410249*^9}, {
   3.604810122854487*^9, 3.604810125021324*^9}, 3.614494897720536*^9, {
   3.614495354780902*^9, 3.614495370855404*^9}, {3.6162216125623693`*^9, 
   3.6162216356593533`*^9}}],

Cell["\[CurlyPhi] exchange", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.604811888522533*^9, 3.604811888647065*^9}, 
   3.614494897720769*^9, 3.616221658026443*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D1varphi", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], "I", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"4", ",", "a"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "b"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "b"}], "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "a"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "a"}], "]"}]}], ")"}], 
          RowBox[{"k", "[", 
           RowBox[{"4", ",", "b"}], "]"}]}]}], ")"}], 
       RowBox[{
        RowBox[{"I", "/", "4"}], "/", "2"}], " ", "I", " ", 
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "e"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "f"}], "]"}]}], "//", "Expand"}], "//", 
     "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.604810131179126*^9, 3.604810213443531*^9}, {
   3.604810384986705*^9, 3.6048103856763678`*^9}, {3.604810423327317*^9, 
   3.604810451669894*^9}, {3.604816656041491*^9, 3.6048166618945303`*^9}, {
   3.61449201262151*^9, 3.614492056545841*^9}, 3.6144948977244387`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9, 3.615633723552614*^9, 3.616214582077084*^9, 
   3.617336085613434*^9, 3.617338206054729*^9, 3.6182173525886793`*^9, 
   3.619333581642956*^9, 3.6197749485308733`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9, 3.615633723552614*^9, 3.616214582077084*^9, 
   3.617336085613434*^9, 3.617338206054729*^9, 3.6182173525886793`*^9, 
   3.619333581642956*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9, 3.615633723552614*^9, 3.616214582077084*^9, 
   3.617336085613434*^9, 3.617338206054729*^9, 3.6182173525886793`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9, 3.615633723552614*^9, 3.616214582077084*^9, 
   3.617336085613434*^9, 3.617338206054729*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9, 3.615633723552614*^9, 3.616214582077084*^9, 
   3.617336085613434*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9, 3.615633723552614*^9, 3.616214582077084*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9, 3.615633723552614*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"c", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"d", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481045195896*^9, 3.6048104702936373`*^9}, 
   3.604816663389896*^9, 3.604821181719679*^9, 3.604821366014374*^9, 
   3.604827064503038*^9, 3.604901620097224*^9, 3.604997500471797*^9, 
   3.604997830496558*^9, 3.604997989708632*^9, 3.6049982534515743`*^9, 
   3.604998670965029*^9, 3.60499901533685*^9, 3.604999558947241*^9, 
   3.6053222098287907`*^9, 3.605329240011532*^9, 3.6053448715497417`*^9, 
   3.605499353705847*^9, 3.605499752671447*^9, 3.60550026322438*^9, 
   3.6055009721886787`*^9, 3.605517519450736*^9, 3.605518581569345*^9, 
   3.606019700276429*^9, 3.60662449994413*^9, 3.607254792945706*^9, 
   3.607746827230424*^9, 3.60845866022963*^9, 3.608461037795373*^9, 
   3.608611347504879*^9, 3.608972237229508*^9, 3.6090390518160267`*^9, 
   3.6090655035432034`*^9, 3.60913052069882*^9, 3.610078776857848*^9, 
   3.610183004283185*^9, 3.610768732016794*^9, 3.614321210591283*^9, 
   3.6144885904507647`*^9, 3.6144920572817698`*^9, 3.61449489773011*^9, 
   3.614495194424942*^9, 3.6145005593429203`*^9, 3.61450078419951*^9, 
   3.6145009258917437`*^9, 3.614505654040498*^9, 3.614577130801311*^9, 
   3.614937140603462*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D2varphi", "=", 
  RowBox[{"D1varphi", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "b"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "b_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}]}], ",", 
     RowBox[{"a", "\[Rule]", "c"}], ",", 
     RowBox[{"c", "\[Rule]", "a"}], ",", 
     RowBox[{"b", "\[Rule]", "d"}], ",", 
     RowBox[{"d", "\[Rule]", "b"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604810266571011*^9, 3.6048103616092787`*^9}, 
   3.60481047447218*^9, {3.604816683651881*^9, 3.604816685597945*^9}, {
   3.6144920692274313`*^9, 3.6144921226965857`*^9}, 3.614494897734645*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9, 
   3.615633723583943*^9, 3.616214582388338*^9, 3.617336085647828*^9, 
   3.617338206105832*^9, 3.6182173526171303`*^9, 3.619333581704174*^9, 
   3.619774948556568*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9, 
   3.615633723583943*^9, 3.616214582388338*^9, 3.617336085647828*^9, 
   3.617338206105832*^9, 3.6182173526171303`*^9, 3.619333581704174*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9, 
   3.615633723583943*^9, 3.616214582388338*^9, 3.617336085647828*^9, 
   3.617338206105832*^9, 3.6182173526171303`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9, 
   3.615633723583943*^9, 3.616214582388338*^9, 3.617336085647828*^9, 
   3.617338206105832*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9, 
   3.615633723583943*^9, 3.616214582388338*^9, 3.617336085647828*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9, 
   3.615633723583943*^9, 3.616214582388338*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9, 
   3.615633723583943*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["d",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "e"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "f"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048103663147583`*^9, 3.604810391038212*^9}, {
   3.604810454453536*^9, 3.604810474985262*^9}, 3.6048166867231216`*^9, 
   3.6048211817420263`*^9, 3.6048213661452*^9, 3.604827064609078*^9, 
   3.604901620193891*^9, 3.6049975005051003`*^9, 3.604997830526134*^9, 
   3.6049979898479967`*^9, 3.604998253641637*^9, 3.604998671047776*^9, 
   3.604999015397496*^9, 3.604999558986837*^9, 3.605322209879916*^9, 
   3.605329240110165*^9, 3.6053448716338654`*^9, 3.605499353769631*^9, 
   3.605499752726466*^9, 3.605500263308379*^9, 3.605500972251936*^9, 
   3.605517519482973*^9, 3.605518581663371*^9, 3.606019700332686*^9, 
   3.6066245000117617`*^9, 3.6072547929716063`*^9, 3.607746827318369*^9, 
   3.608458660245078*^9, 3.60846103781157*^9, 3.608611347646112*^9, 
   3.608972237341426*^9, 3.609039051890624*^9, 3.6090655036367903`*^9, 
   3.609130520800091*^9, 3.6100787770130587`*^9, 3.6101830044102592`*^9, 
   3.6107687321336527`*^9, 3.614321210662939*^9, 3.6144885904702673`*^9, 
   3.61449212418042*^9, 3.614494897735612*^9, 3.614495194744268*^9, 
   3.61450055939284*^9, 3.6145007845053663`*^9, 3.6145009259216957`*^9, 
   3.614505654085864*^9, 3.614577130841763*^9, 3.614937140630639*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D3varphi", "=", 
  RowBox[{"D1varphi", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "b"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "b_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}]}], ",", 
     RowBox[{"a", "\[Rule]", "e"}], ",", 
     RowBox[{"e", "\[Rule]", "a"}], ",", 
     RowBox[{"b", "\[Rule]", "f"}], ",", 
     RowBox[{"f", "\[Rule]", "b"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604810480552979*^9, 3.6048105178509007`*^9}, {
   3.614492139560999*^9, 3.614492187131268*^9}, 3.6144948977380333`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwA+Jnd54nLbz9ynHVh/q0JUD62tOd05cB6duVJ9aBaN6/
YuUrgfS8T233zgJpE8OJ6/8A6VP7L94A0TVxe96AaK2b23n/AukFSY8cQbT6
97c5IJqj78EGEG2m62Az+84rxyJp1tXzgLTc4e8+y4C0zBar3R+B9DNmybcg
2un2G51PQDr1fWcriD4q8G3mLyDtUb1D7jeQNgrvOff+7itH7sQmOfH7rxzd
dsg/9HrwytFgdo6i9cNXjpvsu7dMewRUt3rf3elAujGn1OkhkP52ZnXlxMev
HGu/1UluAtL//L8z7wfST47LHL4HpP9/Vzi+9ukrR5XAiasfAGkR5q7V/569
cgxxD3c/+vaVY/yD84zi7145Vh2rPiwBpC88NReTAtKL9kdYg2i3Je9uygDp
jwyC30C0/OR97LJA+gTHkTB5IP2NK8bWCUg/2jWF7ROQDm8rVnf7APTXzxvH
Ej++clxxf2tS6+dXjkIPjmS3AelvF0U2Gn995diSsWNnyPdXjknzJtno/Hjl
CABP1QPD
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVz1sog2Ecx/FpOUQKyYzZKKVEOSuHeHYxkhItcyGyImWlSHKOWDmkFpGU
0BLenBaZQ3Yxp+S0G00z3o1NPW1mk/fN2f+5+PW5+d18Y+SNZbVeHA4nHWa/
e5bPmTBafu2pU4M3tp3JBdDUdrpKDPwJa10CZzzK+wswLVm19g2e6QxGYmfV
voMYf7sd+APOyq2IGMc6FUS/UXqdmJGYnzN9h1FTpDc1Awr1bPECKNjM2nOD
di7fSRSbHAkesNY1OEA8CmKmPsHCDq3wC0yRjVy6zBgF1PQJeQ8YSbQiSxGN
UdK0IibbgpEmb3hzwgo/6sA8CfYqWsQWkDmn2lSPGHUx3XwN+FvCcnXg04lA
fw/+sdEnKzaMYktVFA2GcoeoXztG0gJZwZETo2r6yov3glH7cYc+HLy2ZYZF
gPO6imyiRP1yKwDdnGCGKBo78I0CT/0Oy0Ug41+ZKwatu+M+HlCmbI6TvELX
h/G4xo3R4sOWfOANoxD6sEEJMobQjdR3jPrrtTtSFqN/P1L/lg==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVz1sog2Ecx/FpYdEKLTNms1JKlFOUEc8uRlIimQvRVtxYKZLmGLWVQ2oR
SQlp4c1pkWN2MafktBtNc3g3NvVkbJN3OY3/c/Hrc/O7+UpUTRX1QSwWKwvm
un1WzdgwWvT0NMyB187tcQNo05wsE7m/0W0L4JRPd38OZqXrV37AU5PFSuys
3XshJt9scn/BaZUDEZP8bjWRM0yvErNTC/MmbzFqjgumpkCR2V9qAIXrubte
0MUWuIky20uKD6x/69cSDyOYiS+wuGNL9A1mKIYu3u4wClf2ifgPGMm3xPYS
GqO0SbVEasfIWDC4PuaAH7V/Nw72qltldpA5ozT6R4y6mG6BEQyU+dkm8OlY
aL4H//wJx0tOjBLL9RQN8tgDVMCFUWWRoujQjVEdfRnEf8Wo/ajDHANeOXOi
Y8FZU7WUKJ97vRGCXlYkQxSP7IfGgyecgyoxyITV5MtAx85oiA9U6FqS5B7o
+rQeKb0YzT9sqLTvGEXRB406kLHw1jI/MPoHUe/6wg==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVz1sog2Ecx/Gt5RCtkMyYzUopUU5RDvHsYiQlkrkQbcWNlSJp5hBl5ZBa
ZGm1kIQ3h0SO2cWYJccbbW3j3djU04ZNvcvZ/7n49bn53XzFio66VjaLxcqD
eR3Pink7Rqtvg22L4J1nX7cE2lWWdSL3J6FnBTQENfeXYH6OduMbPDfeWol9
zUc+YoZtl/sDzinciJge8iuJkZP0JrEgq7xE78CoMzmMMoBCU6h6CRRsFx0G
QC+H7ydK7L7MINj6OjpCPI1hZj/BSvWe8AvMlU1cvToxipYPC3kPGEn3RK4q
GqNsvVJc7MJoq2x8e8YNP+rYqQOHlN0SF8hcUCrtI0b9zAB/C/ytCXGM4NOZ
wHQP/oVSz9Y8GKXVaikajOeMUb9ejOorZBWnfoxa6Gs27wWjXrPalAjeeAoT
ksAFY2MxUbr4YhOAAVYsQxRNHUekgJbIkwYRyEQ1lUpA98F0eBCUabrSpW/Q
9WE1ywMYLT/sKEbeMYqjT9o14D+Jr/Xi
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVz1sog2Ecx/FpYdGKkhmzUWolCoky4tnFSEokcyHaW3O1UiQ5R005pBZZ
Wi0k4c2hNZlD28WwJccb0WYnNvVkY1PvcvZ/Ln59bn4332yqs1EZw2KximAB
5zO15MBo422kYwW89e9rV0FHn32LyP1J7V0H9ZFx1wVYXKjZ/gbPLDd3xMG2
oxdi7v0e9wdcpHyIKI4GVUTOjGeHWJJfVa5zYtSVEUvrQaE1WrcKCoxlh2Ew
wOYHiVLHS14EVL5OqIknSczCJ1gzYBJ+gUXy6cvXB4wSFWNCnhsjmUnkrfVg
VKBTZUu8GBkqp4zzPvjR5gctOKrqkXpB5pzu0zxiNMQM8w3gb32UbQGfbAKr
C/yLZtk2/RjlNGhoD5jCnqR/Axg1VcurT4IYtXuuYnghjPpPB6xp4LW/NDUd
XLa0SIiyldC9AAyzkhmiaNYcnwnaOcfNIpBJaK2Qgr6DubgIKB/vFsveoOvj
7lQRxmjNvUup3zH6B+pW8Rw=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBOJnd54nLbz9ynHVh/q0JUD62tOd05cB6duVJ9aBaN6/
YuUrgfS8T233zgJpE8OJ6/8A6VP7L94A0TVxe96AaK2b23n/AukFSY8cQbT6
97c5IJqj78EGEG2m62Az+84rxyJp1tXzgLTc4e8+y4C0zBar3R+B9DNmybcg
2un2G51PQDr1fWcriD4q8G3mLyDtUb1D7jeQNgrvOff+7itH7sQmOfH7rxzd
dsg/9HrwytFgdo6i9cNXjpvsu7dMewRUt3rf3elAujGn1OkhkP52ZnXlxMev
HGu/1UluAtL//L8z7wfST47LHL4HpP9/Vzi+9ukrR5XAiasfAGkR5q7V/569
cgxxD3c/+vaVY/yD84zi7145Vh2rPiwBpC88NReTAtKL9kdYg2i3Je9uygDp
jwyC30C0/OR97LJA+gTHkTB5IP2NK8bWCUg/2jWF7ROQDm8rVnf7APTXzxvH
Ej++cgQAcQbr2g==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOJnd54nLbz9ynHVh/q0JUD62tOd05cB6duVJ9aBaN6/
YuUrgfS8T233zgJpE8OJ6/8A6VP7L94A0TVxe96AaK2b23n/AukFSY8cQbT6
97c5IJqj78EGEG2m62Az+84rxyJp1tXzgLTc4e8+y4C0zBar3R+B9DNmybcg
2un2G51PQDr1fWcriD4q8G3mLyDtUb1D7jeQNgrvOff+7itH7sQmOfH7rxzd
dsg/9HrwytFgdo6i9cNXjpvsu7dMewRUt3rf3elAujGn1OkhkP52ZnXlxMev
HGu/1UluAtL//L8z7wfST47LHL4HpP9/Vzi+9ukrR5XAiasfAGkR5q7V/569
cgxxD3c/+vaVY/yD84zi7145Vh2rPiwBpC88NReTAtKL9kdYg2i3Je9uygDp
jwyC30C0/OR97LJA+gTHkTB5IP2NK8bWCUg/2jWF7ROQDm8rVnf78MoRACLA
5n0=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{"\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["e",
      TraditionalForm],
     TraditionalForm]], " ", 
   SubsuperscriptBox["k", 
    FormBox["4",
     TraditionalForm], 
    FormBox[
     FormBox["f",
      TraditionalForm],
     TraditionalForm]], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+Jnd54nLbz9ynHVh/q0JUD62tOd05cB6duVJ9aBaN6/
YuUrgfS8T233zgJpE8OJ6/8A6VP7L94A0TVxe96AaK2b23n/AukFSY8cQbT6
97c5IJqj78EGEG2m62Az+84rxyJp1tXzgLTc4e8+y4C0zBar3R+B9DNmybcg
2un2G51PQDr1fWcriD4q8G3mLyDtUb1D7jeQNgrvOff+7itH7sQmOfH7rxzd
dsg/9HrwytFgdo6i9cNXjpvsu7dMewRUt3rf3elAujGn1OkhkP52ZnXlxMev
HGu/1UluAtL//L8z7wfST47LHL4HpP9/Vzi+9ukrR5XAiasfAGkR5q7V/569
cgxxD3c/+vaVY/yD84zi7145Vh2rPiwBpC88NReTAtKL9kdYg2i3Je9uygDp
jwyC30C0/OR97LJA+gTHkTB5IP2NK8bWCUg/2jWF7ROQBgD70OKk
  "]]
}, Open  ]],

Cell["e exchange", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, 
   3.614494897747674*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData["verEEVarphi"], "Input",
 CellChangeTimes->{3.6144948977478247`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVxUsow3EcAPD/mnDgMu/XPEooJSFi0tcBiZKkiIMVF0q0mjliKPp7k0hy
EC3zWnlmIqRsjXaYxmyGw9djNmHevr/Dp0+0tLG0VsBxXCoRtf0JZswIeTvb
Y7N0S5NOzXZzYfJ52vjSZdHRZ/WDi9+08tRoYsdPax/Y6nat7w9d1nwDbIXQ
0cDuiLAvsf3rCiQTFwjme0/VFP0X8Fk0Swe3SractJsPfWSLjY5EF70b0Ktk
Jxnc4590d/K2+IvW5/B6xyXC+kKHOOgKwWSKshVaEfZ6GqOzbAh917xm9BrB
urV/OUZPlihybbRyVa0YsCNkVreFrNCi4w+hll7WxO5b6Ji52KOFW4R++ajK
SvvoedXvHYJFUJF/8IiQoTMIgp4QTr7TA0Np3rsyiz08/HwezvYSvbHx/Mgr
gvabPyiPpGXOquxcWtg14umifXZlcXnPCB6c9bDGiTCVsCZVviBIqw/rO+mS
tMDllFeEYvPmRtk7gkszJEl0I/wDSL74Jw==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVxUsow3EcAPD/mnDgMu/XPEooJUnkkb4OI1GSFNnBigu1SDFHDEV/j8YS
SQ6iZZ7lmS1CyhbaYWs2m+Hw9ZgR5u37O3z6xMvkFfUCjuMyiKjzTzBjRZDs
7qhn6fZmg5bt5aLa5mnTS6/dQJ83jix+08ozk5mdPK27Z2u7dIE/dGXLNbAV
QncTuzvGtcQObijOm7hAsN75aqbov5DP0lk6vCNv20N7+cgHttjkTn2m9SED
SnbaqXf8k+5L3xF/0cYC3ui2IWwsdIvDLhHM5jhniQNhr18en+tEGLzi18au
EBzb+zY1PVmuKHTSylWtYtiFkCPtjFihRccfQh29vJa4b6cT5hKPFm4QhtrG
NA46wMhrfm8R7ILqooMHhGzDqSDsEeHkOys0kub9a3LZKtWTJZrtJ3pjo+XI
L4YOmj+oiqVbPbX5hbSwd9T3mQ7QtyZJnhB8OMdhnQdhKmVdpnxBkEkPG3vo
8szQ5YxXhDLr1mblO8I/lMvzYg==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVxUsow3EcAPD/msyBy7wfm0cJpYRETPo6IDlIUsTBigu1SDFHNhT9PfJI
JDmIlnmtKLJFSNlCO0xs/ttw+HrMiIZ5fH+HT59EpaqqScRxXBaR9vyJFq4Q
SvZ2pxbprjaznu3jYjuXaetbv8NMX7SMrfpp7bnVxk6dNz6y9b3GkB+6uv0W
2Gqxp5WtkbnX2GHNZYqZa4Srh0DdHP0X/lWxSEd1K3a8tI+PeWLLrZ70V9oU
PqRlZ5z5pr/ogcxd+TdtKeItHjvC9opGHnmDYLMlOMsFhP1BVWKBE2HYxRsm
XQjCzoF9ip6tVBc7ae2mXj3qRshv6IneoKUnn2IjvW5IPnDQSUvJxyt3CCOd
kzqBDrbwut97BIeotvTwCSHPfCaKfEY49edGxNB8UF0Be3z85TKOLZF+sPHy
WCKjQ5cPa+LpDm99YTEt7p8IfKWDTR0pJS8IAZxw1OhFmEvbUmrfEJQNRy19
dGVOxHr2O8I/CZ7uUA==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVxUsow3EcAPD/mjYHLmMeY2NqoZScyEi/HZAcJCmygxWXqUWrmSObKfp7
NCSSHGStzWtFbZmsbSlbox22xmzzOPw8Zltp5vn9HT59hDJF9xCDoqg6wJn8
Y2yHMGo9ta3uwOOjHjM5TZWoDLA/pQt74Gv50t43rL3yB8hVW/YXsnnKnvsD
94w9ILKaGR8ha/j3++T84fam9RuMQs8s4yb8x8107sBFE03WBJymea9kgT9e
k4TPuHNacq0vvZaBZ+psgi/Y20J747cYnZg0gsI7jAKB8mhHBKPzWYVQHMVo
PkZbVmIYRayO21V4o0sticLaI7N68R6jRulk8SHMufhk2uEDi8gRhit2RW7T
I0YLqhVjBM7x0sbfJ4zCjL425ytGDR4fo/ANo8vv+gIeTGf3i8l6/XuwlMzm
fJBx0M3mw3kGZ28ZrEwMNEtgpm6ZlYRzzpSVre8YZVER12ACo83qY5k2hZFM
6pJPw/+kZuqw
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVxUsow3EcAPD/mnDgMu9hHiWUwok80neHkRwkKeJgxYUSrZjjbFH094gt
keQga22eRZGJkLKFdtgas83j8PWYbaWZx3x/h0+fHHlfU5eA47gSIlJFBCtO
BNnhgW6VHuq3mNghLn1QT9uCoy4LfdMzs/5Da65tdnbBsvmVbRoxx//SzQOP
wFYKfb1sdebDBjuxu65q4RbB+RJtWKIjSeGGVTp1uGrfT4d48RtbYvMVBeij
pAkNu/gqNB+mx0oPJN+0tYa3+u4Q9oxqSco9gt2e7al3IxyP9+VUehAmvfyO
1ovg3j+509GLjUqph9Zsm5TTDwgVHaq0LVp08SU005s7eScuOnct79z4hDA1
qDW46Tgrb/h7RnAJWmtP3xDKLVeClHeEy5+yZDHNx7ZVsmdnPxwZ7BjRJxsd
5zGZdIL+tCWLVvjbq6W0cHQuOkDHHSnyZR8IUZz7rNOPsFS4K9cEEf4BXj3m
Gw==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVxU0og2EcAPB3TeYwlzEfY2NqcVDLiYz07DCSgyRFHCgu1KLVzJEtil4f
zZZIcli0Nl87KMuWNVK2RjtszWYfODzMPpRmxvyfw6+fcEzeN86gKEoMOPN5
xn4AI9mlVW+AZ6ddZnKGqlIewt7PxZALfpjcOMrBmnuvj9ywZ3snmxdsxb9w
/8wzIquYiSmymh87JpdOdLVtP2IUeCs07sJ5brbHAFfMtV2k4AzNi5MF3kRj
GrZzVzRksSezlYWXmqyCH9jdQbsTQYzOTWpB+RNGPl9tpDuM0dWyXCiJYLQa
pS26KEbhC0dQD+/0qqQRWHNmVq3HMGodma88hTm330wbfGIROUJw3YHoxvSC
0ZpSZwzDbDdt/HvFKMQY7HTGMWpxeRjlHxjd5ZrLeDBdNCQha7VJfzWZxfki
Y/8Niw+XHDoHamBFarhdCjMXNwvTMNuuqJclMSqgwtejKYz+ATxT4Zc=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA2Khpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIX/nc
fu8skL6UPWn9HyDdevHKDRCtsWD/GxC9rnk/718gHVL0xBFEVzK/zwHRLbKP
N4BokTQPm9l3Xjnefs22eh6Q/i/6y2cZkJaostn9EUj/6JN6C6LlrrzX+QSk
D4j2tIJo/Qs/Zv4C0h2Ge+R+A+lz9n3n3t995bhjbYuc+P1XjjduKDz0evDK
8VB3vqL1w1eO/Y/6tkx79Mrxwe7Dd6cD6TkBlU4PgXTr5nWVEx+/crSKbZLc
BKSFTv5k3g+kN25RPXwPSCutUD2+9ukrxwnl01Y/ANI85/pW/3v2yvEeY6T7
0bevHC3OXmAUf/fK8cwfczEpIN3HEWUNoqdM+XBTBkSzC30D0a9uHmeXBdLC
K4+GyQPpko8xtk5Amrl9KtsnIM1zoETd7cMrRwA/TN1v
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBWKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIX/nc
fu8skL6UPWn9HyDdevHKDRCtsWD/GxC9rnk/718gHVL0xBFEVzK/zwHRLbKP
N4BokTQPm9l3Xjnefs22eh6Q/i/6y2cZkJaostn9EUj/6JN6C6LlrrzX+QSk
D4j2tIJo/Qs/Zv4C0h2Ge+R+A+lz9n3n3t995bhjbYuc+P1XjjduKDz0evDK
8VB3vqL1w1eO/Y/6tkx79Mrxwe7Dd6cD6TkBlU4PgXTr5nWVEx+/crSKbZLc
BKSFTv5k3g+kN25RPXwPSCutUD2+9ukrxwnl01Y/ANI85/pW/3v2yvEeY6T7
0bevHC3OXmAUf/fK8cwfczEpIN3HEWUNoqdM+XBTBkSzC30D0a9uHmeXBdLC
K4+GyQPpko8xtk5Amrl9KtsnIA0AYSfZpg==
  "]]
}, Open  ]],

Cell["\<\
Modify verEEVarphi by eliminating k2 = -k1-k4 because it is now an internal \
momentum. Moreover, substitute (cd) -> (ij)\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048175877526617`*^9, 3.6048176227157993`*^9}, {3.6048176757364683`*^9, 
   3.604817678723796*^9}, {3.604817764591837*^9, 3.6048177920344276`*^9}, 
   3.614494897750712*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEVarphimod", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"verEEVarphi", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "b_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "b"}], "]"}]}], "-", 
          RowBox[{"kc", "[", 
           RowBox[{"4", ",", "b"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"kdotk", "[", 
          RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"kdotk", "[", 
            RowBox[{"1", ",", "1"}], "]"}]}], "-", 
          RowBox[{"kdotk", "[", 
           RowBox[{"1", ",", "4"}], "]"}]}]}]}], "}"}]}], "//", "Expand"}], 
    ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "i"}], ",", 
     RowBox[{"d", "\[Rule]", "j"}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.6048118019554462`*^9, {3.604811860128257*^9, 3.604811867862918*^9}, {
   3.604811928271016*^9, 3.6048119292450438`*^9}, {3.6048119912125273`*^9, 
   3.604812139141265*^9}, {3.6048122480315733`*^9, 3.604812267208663*^9}, {
   3.6048124103533287`*^9, 3.6048124104906178`*^9}, {3.604812672116448*^9, 
   3.60481267525301*^9}, {3.60481806149019*^9, 3.6048180616894093`*^9}, {
   3.6144923273016453`*^9, 3.614492447304255*^9}, 3.614494897752122*^9, {
   3.615529154255802*^9, 3.615529157762741*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9, 3.6156337236887617`*^9, 3.616214583211031*^9, 
   3.617336085758266*^9, 3.617338206247725*^9, 3.618217352746785*^9, 
   3.6193335819049053`*^9, 3.6197749486521072`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9, 3.6156337236887617`*^9, 3.616214583211031*^9, 
   3.617336085758266*^9, 3.617338206247725*^9, 3.618217352746785*^9, 
   3.6193335819049053`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9, 3.6156337236887617`*^9, 3.616214583211031*^9, 
   3.617336085758266*^9, 3.617338206247725*^9, 3.618217352746785*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9, 3.6156337236887617`*^9, 3.616214583211031*^9, 
   3.617336085758266*^9, 3.617338206247725*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9, 3.6156337236887617`*^9, 3.616214583211031*^9, 
   3.617336085758266*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9, 3.6156337236887617`*^9, 3.616214583211031*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9, 3.6156337236887617`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.604901620348057*^9, 
   3.6049975006559343`*^9, 3.604997830771994*^9, 3.604997990225471*^9, 
   3.604998254092044*^9, 3.604998671238288*^9, 3.604999015510756*^9, 
   3.604999559197541*^9, 3.6053222104028387`*^9, 3.605329240282977*^9, 
   3.6053448719050093`*^9, 3.605499353972082*^9, 3.6054997529008703`*^9, 
   3.6055002635808973`*^9, 3.605500972453684*^9, 3.605517519854224*^9, 
   3.605518581979854*^9, 3.606019700500086*^9, 3.6066245002268353`*^9, 
   3.607254793065572*^9, 3.607746827582903*^9, 3.608458660591587*^9, 
   3.608461038269837*^9, 3.608611347952455*^9, 3.608972237576599*^9, 
   3.609039052190782*^9, 3.609065503903317*^9, 3.6091305212888737`*^9, 
   3.610078777404763*^9, 3.610183005011695*^9, 3.6107687325852137`*^9, 
   3.6143212108668833`*^9, 3.6144885905646048`*^9, 3.614492351436857*^9, {
   3.614492419088052*^9, 3.614492447953063*^9}, 3.614494897754251*^9, 
   3.6144951948554897`*^9, 3.614500559572176*^9, 3.6145007845980673`*^9, 
   3.6145009262789507`*^9, 3.614505654216345*^9, 3.614577130946703*^9, 
   3.614937140700941*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["verEEEonshell12"], "Input",
 CellChangeTimes->{3.6144948977628613`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy1sow2EYgPEtokhyyJoYkkNSckyZi3eKiBukJGKaGwoXjrlzqrWSFXMo
Sixa5tBGcrHGMEKhNPljo4k3hi0jh/F+F0+/qydG2lwq4/N4vEzKYp8vmblE
aCnTBs+R/gqjSk3+Pp5rmZwotmOBNM0MXR+R3p1jSz+kK4izMFvyDp+YWYHm
gF/yS0IvKY5zNjG55YdlpjmkVDzJIdTr/TRTZE8Sr0RNmhyw+UbmtUY9M9WF
7mQnaSke7mfK1jzjX2SDfU/0TWp7lccvVwjrQrlIcIMwrYy1FVkRovltMTk2
hLXKCd3oLUJi9MmVipRZ+yQ2slqu7xq+QyhUKoSrpFLi5W0gB29Stq/JJmPa
3qId4fRvVmMl500qjeceIV5eU7DzjOBQnPEFDgTDRHZYOCnNrs5hLnGuiwjS
uBvqZnZVHfhGkgHr5ooosj21NldCqu9UPk6ye64jIf8VocKDu3VvCH7GDWm/
CyHDvd84QCbqhCvp7wiXI4aN8g+Erd5RcfInwj9lwf20
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy1sow2EYgPEtokhyyJoYkkNSckgKF+8UETdoJRHT3FC4cMwdo9ZKVsyh
KLFomUPbJBdrmRmhUJr8sdHEG8OWKYfxfhdPv6snSdpRLePzeLw8yu5arlq4
Quis0UUukaFKs1pD/j5d6JicKLl3hbQsjN0ck4F9U2s/pDeCszM7S46emfnh
trBf8ktML1mU4mlncuuP60xbVHXRLIfQYgjRzpGDGbwqDWlxw847WdKV8MLU
lPsyPaS9clzOlBn9019kq2tf9E3qhlQnr9cIW0KFSHCLMK9KdlY4EBL53UmF
TgRj3Yx+8g4hPfH0Wk3KHMNiJ9mgMPSP3yOUq5TCTVIlDgg0kaO3Wbs3ZLs5
Z3/VhXD2t6h1kMsWtdb/gJCqaCzbe0FwK8/5AjeCaaYgJpaUFjQUMtc472Uc
abZG+5j99YfB8WTYlk2SQPZkNxWLSc29OshDDiz1ppW+IUj8aG1+Rwgxb0vl
XoQ830HbCJmuF27kfiBcTZi2az8R/gGFM/lN
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy00ow3EYwPEtokjyEk2MJS9JyUtajcMzRcSFUhIxzYUyB6+5MWqtZAfz
UpRsTcu8hCUHLbONUChN/tho4smGLTt4Gc/v8O1z+opkPfVyPo/HK6acHkPd
0g2CosEUryOj1Ratnvx9uTIxOWHmwAppXZq8OyXDB2fWfshAHOdkKipOXpml
sY6YX/JLSi9ZluXvZnLrz+tMR0J92TyH0LEdZVwgR/J4dXrS6oO9D7KiN93L
1FcH8/2ks3ZKyZTvhGa/yE6PXfhNmkY1Z2+3CGaBSph8j7CoyXTXuBAy+H0i
iRthp2lua/oBITfj/FZLyl1jUjfZotoemnpEqNaoBZukRhoWvk9O3Bcc3JHd
liL7qgfh4m/Z6CINVq0x9ISQrWqtOvQi+NSX/GQfwv6cOCmFlIlbJMw1LnCd
SlpsiUHmUPNxZBoZY3Y0ppP9hW3lUlL/qI3wk8O6gZzKd4TGENraPxCiLLsy
ZQChJHjUNU7mbgk2ij8R/gHKW/Pu
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy00ow2EcwPEti5qWvETERstLUiJptTk8UzTZhVpJxDQXK3PwMrkxaq20
HcxLUcvWtGxLtiWHtQwjFEqT/96siScbttoBG7/n8O1z+tZIJ/tkdBqN1gr5
Y2ax4QkjRb+1yAjmazx6E5h5e7ASKTZ3dg/0GlaD1yBjbt32C6YKKT9R0Xn1
Tmwv8LEy4LcQXlBQm5QTKfurnegr7hNsURiNOZiWbXChkSY2gd4EOv4CO6c4
caJJlG5Kgv5erYooc2Y3vsHx2Dn7B7Qu6m4+Ahi5ytXsshBGOzpupCeMUTV9
uoYfwcg5sHm49oxRQ/VtQA/KwkvCCDikdii1UYxEOk35AagT5jDc4Eqo+SQI
yj2t5/sxjO7+di1h0OzVW7IvGNWph7tP4xglNPf0sgRG7k1eaQUo5Q3xiTYq
9VgJes5K0kTl4GVeFchy+SQccKZlpEMImqL63CQ4b5yt7/rESJLFZ6NfGDE9
R1JVCqO29MXEMvgPOL/v9A==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy00ow3EYwPEtokjykkVs0/KSlDhI4fBsRRMXSknENCeFAzO5sdRaaf+D
v5eixKJllmxLDlqGJRRKk//YaOKJYSsHbDy/w7fP6VuoGWzVikUiUSXlC623
rNwiDLXZMtfIVJObt5Cxl2sbU5AqdBukZ2Xm7oxMHJvb+iWjGYKPOaQ6fWVW
p3vTYuS3kl6yrigywBTsz3amN6u1blFA6HOkWJfIiTJRi4X0hGHvk1QNy96Y
FvVXeYT0NZsNTK0zPv9N9oeOpT+kbZI7f/cjuHKNUsk9wjKnCDYFEOTikcLa
IIKzY2Fn9gGhVH7h50ltYEoZJLuMDr35EUHNmXK3SU6ZkLhPTt9XHNyRA+6q
480QwuXfqjVArnt4a/wJodjY3Xj4hhA2XYklYYT9hZqcPFJT01XL3BKiN/mk
+yj7i6nvPEkuINNc3nYZOVrZU68kLY98UoQcX9OVNHwgtMfxqPcTIcW9qzFE
Ef4ByP7q8Q==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy00og3EcwPFnWRQtecmamC15ScrLQWpz+D8rIrtQK4mY5qTMgZnckFor
eQ4epijxRMtIth0c1jLbEgqlyTPbaOKfDVvtMIzf//Dtc/rKteM9OgFFUY1Q
ILqr3nrASN9rK9wB88xulgN/3+5sRF5aadgDPVtLj5egcHr14AdMFvABol51
8U5syfeLfsE0DS+orEqMEfnD10Oiv6hHuc5jNGLPtW6As3WUmgM9cXTyBaom
KmJErjNVnwAD3csLRJ0js5YGR6M+6Tdom2OuPoIYOSUmqTiE0SZTGekKYyQT
TMoVEYwcfZbjlSeMamXXQRbUhefpCDhgshuXnzHqZMySI5Chs4QucDHUcPoI
jrmbfftRjG7+tq1hcNfDWjMvGFWbBjvOYhjFzbcCcRwjl6W1pBTUtg4oiAd8
8r4MdHuLU0Rj/3lOOShy+jUV4FTTUBsNcs9sdgKc2THUtH9ipMlg7/AXRv+A
+OZn
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+IbT1f4Lrr9yrEgeJ3QUiDN3XNw+jIg/ffltXUg+o6c
cvlKIH1kUf+9s0CapWLG+j9A+rPgnRsgusD5zBsQbcZ/gvcvkP7lBNQLpG1U
P+WA6DsbXmwA0SeEg2xm33nlmLyVa/U8IF2jxeC7DEgfeee4+yOQdi6Ufwui
l3l+0/kEpG/4TGwF0anb/s38BaTTnh6X+w2k1zVPOvf+7ivH7ZJdcuL3XznO
n6T80OvBK0cFxlJF64evHLdFztoy7dErRw2Fi3enA+nUBy1OD4F0bNfWyomP
Xzl6TuqR3ASkJzkxs+wH0u339Q/fA9I5B42Or336yvHS/yWrHwDpFUemr/73
7JWjWlec+9G3rxzf9VxmFH/3ynH/LAsxKSCdZBFrDaLX3/l8UwZIHzwm8g1E
V0afYpcF0rzbT4TJA+kywwRbJyC97PF0tk9Aumppubrbh1eOAF574OU=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+IbT1f4Lrr9yrEgeJ3QUiDN3XNw+jIg/ffltXUg+o6c
cvlKIH1kUf+9s0CapWLG+j9A+rPgnRsgusD5zBsQbcZ/gvcvkP7lBNQLpG1U
P+WA6DsbXmwA0SeEg2xm33nlmLyVa/U8IF2jxeC7DEgfeee4+yOQdi6Ufwui
l3l+0/kEpG/4TGwF0anb/s38BaTTnh6X+w2k1zVPOvf+7ivH7ZJdcuL3XznO
n6T80OvBK0cFxlJF64evHLdFztoy7dErRw2Fi3enA+nUBy1OD4F0bNfWyomP
Xzl6TuqR3ASkJzkxs+wH0u339Q/fA9I5B42Or336yvHS/yWrHwDpFUemr/73
7JWjWlec+9G3rxzf9VxmFH/3ynH/LAsxKSCdZBFrDaLX3/l8UwZIHzwm8g1E
V0afYpcF0rzbT4TJA+kywwRbJyC97PF0tk9AGgBkidzG
  "]]
}, Open  ]],

Cell["\<\
Modify verEEEonshell12 by replacing k1 by k3. Moreover, substitute (ab) -> \
(ef)\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048175877526617`*^9, 3.6048176227157993`*^9}, {3.6048176757364683`*^9, 
   3.604817678723796*^9}, {3.604817764591837*^9, 3.6048177920344276`*^9}, {
   3.604817887873568*^9, 3.604817959315727*^9}, 3.6144948977700768`*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEonshell12mod", "=", 
  RowBox[{"verEEEonshell12", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "b"}], "]"}]}], ",", 
     RowBox[{"a", "\[Rule]", "e"}], ",", 
     RowBox[{"b", "\[Rule]", "f"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604812425309675*^9, 3.6048124400638313`*^9}, {
   3.60481247480357*^9, 3.604812541968614*^9}, {3.614492463755364*^9, 
   3.614492480241889*^9}, 3.61449489777143*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+K3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkK0Iq1d0+vHKcZvD2WOJH
oP1hu5NaPwPDz+R0dhuQ3vRRaqPx11eOl1kO7Qz5/spRzm6Gjc6PV44AWwTg
oQ==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+K3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkK0Iq1d0+vHKcZvD2WOJH
oP1hu5NaPwPDz+R0dhuQ3vRRaqPx11eOl1kO7Qz5/soRAGMM3SE=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeK3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkK0Iq1d0+vHKcZvD2WOJH
oP1hu5NaPwPDz+R0dhuQ3vRRaqPx11eOAIlI2Fg=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAeK3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkK0Iq1d0+vHKcZvD2WOJH
oP1hu5NaPwPDz+R0dhuQBgDUy9OW
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuK3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkK0Iq1d0+vHKcZvD2WOJH
oP1hu5NaP79yBABHis8L
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuK3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkK0Iq1d0+vHKcZvD2WOLH
V44A3n3Kog==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBOK3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkK0Iq1d0+vHIEAJmfxas=

  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAOK3MhfjF91+5Sh57Y7QUiA9Qffo9GVAuibgzjoQPfmq
WvlKIG2nM+XeWSB9qWb2+j9AumTR4xsgOqzpwhsQHZ93mvcvkNYrf+8IosuK
v+WA6L0ubzaA6Htnw2xm3wHqj+BdPQ9IN/5i9l0GpN0euOz+CKR3KCq9BdFP
fv3R+QSkV+lMbgXR3x6wzPoFpLdNOSP3G0jvl5567v1doDtVeuTE779yDDiq
+tDrwSvHNacqFK0fvnIMejhvy7RHrxw3H7p2dzqQjq3ucnoIpIX/7ayc+Bho
jsdkyU1AWp6JnWU/kN7Fb3L4HpAuWWl+fO3TV449bqtXPwDSuSdmr/737JXj
cqF096NvXzm2uV1lFH/3yvFcltwLCSDNL2UpJgWkAXlvwd0=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D1e", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"verEEVarphimod", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], 
         RowBox[{"I", "/", "u"}]}], ")"}], "verEEEonshell12mod"}], "//", 
      "Expand"}], "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6048106133280497`*^9, 3.604810615846615*^9}, {
   3.604811695600348*^9, 3.604811747349456*^9}, {3.604812273479548*^9, 
   3.6048122886768007`*^9}, 3.604812337944728*^9, {3.604812415027938*^9, 
   3.604812417749338*^9}, {3.604812557719632*^9, 3.604812570501999*^9}, {
   3.604815814761529*^9, 3.604815913905527*^9}, {3.604816152234918*^9, 
   3.604816162545404*^9}, {3.604818008615548*^9, 3.604818008986813*^9}, {
   3.604818081768404*^9, 3.604818108154407*^9}, 3.604818145917482*^9, {
   3.6144929489279833`*^9, 3.614493043503051*^9}, 3.614494897787465*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9, 3.615633725252239*^9, 
   3.616214584832563*^9, 3.617336087194909*^9, 3.617338207744666*^9, 
   3.618217354230438*^9, 3.619333583506138*^9, 3.619774950121818*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9, 3.615633725252239*^9, 
   3.616214584832563*^9, 3.617336087194909*^9, 3.617338207744666*^9, 
   3.618217354230438*^9, 3.619333583506138*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9, 3.615633725252239*^9, 
   3.616214584832563*^9, 3.617336087194909*^9, 3.617338207744666*^9, 
   3.618217354230438*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9, 3.615633725252239*^9, 
   3.616214584832563*^9, 3.617336087194909*^9, 3.617338207744666*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9, 3.615633725252239*^9, 
   3.616214584832563*^9, 3.617336087194909*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9, 3.615633725252239*^9, 
   3.616214584832563*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9, 3.615633725252239*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"4", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048125588463097`*^9, 3.60481257286021*^9}, {
   3.6048158497705097`*^9, 3.604815884730722*^9}, 3.604815916131546*^9, 
   3.604816164726831*^9, 3.604816426687993*^9, 3.604818011351283*^9, 
   3.604818084102106*^9, 3.6048181484573193`*^9, 3.6048211836266823`*^9, 
   3.6048213683739557`*^9, 3.604827066759491*^9, 3.604901622015264*^9, 
   3.604997502358149*^9, 3.6049978325122213`*^9, 3.604997991986874*^9, 
   3.604998255879534*^9, 3.6049986729582872`*^9, 3.604999017184197*^9, 
   3.60499956081775*^9, 3.6053222121973553`*^9, 3.605329241839677*^9, 
   3.605344873578637*^9, 3.6054993555080547`*^9, 3.605499754423003*^9, 
   3.605500265317478*^9, 3.605500973999625*^9, 3.605517521636451*^9, 
   3.605518583902081*^9, 3.606019702078643*^9, 3.606624501802678*^9, 
   3.607254794553308*^9, 3.6077468293282022`*^9, 3.6084586623208733`*^9, 
   3.6084610402850447`*^9, 3.60861134970363*^9, 3.608972239307632*^9, 
   3.609039054019176*^9, 3.609065505641609*^9, 3.609130523065292*^9, 
   3.610078779243227*^9, 3.6101830068122168`*^9, 3.61076873433675*^9, 
   3.6143212126729307`*^9, 3.6144885920300703`*^9, 3.614493046270402*^9, 
   3.6144948978162813`*^9, 3.61449519631588*^9, 3.614500561108026*^9, 
   3.614500786094337*^9, 3.614500927713429*^9, 3.614505655659904*^9, 
   3.6145771324237413`*^9, 3.614937142252181*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "D1e", "]"}]], "Input",
 CellChangeTimes->{{3.6048159503972473`*^9, 3.604815953144623*^9}, 
   3.614494897817539*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwB+IObT2uJbdfOf5L81AF0UYVE0WXAum6/xdlQPSpad+n
LwPSVl5860G02Kzo8pVAek7MkXtngfQ87gvr/wBpP3+RmyCaKZD5LYhec5iB
7y+QvvdEyQlEa9Vr5oLod9VyG0H0FMFem9l3Xjmq29qtngekjzOZ+y4D0tOM
S3Z/BNINmoFvQfQsVQPdTyDxs0daQXTVUstZv0B0HIv8byC96Oqxc+/vvnLs
5N4nJ37/leOL+0EPvR68cmwq3aho/fCV4/tPZ7ZMe/TKUc6V+950IL1u+y6n
h0C6rvht5cTHrxz9FY5LbgLS5/WsWfYD6T98OYfvAek73/KPr336ytHhxd3V
D4D0SpHLq/89e+XYc2uu+9G3rxyTojmZxN+9cjxmaCUmBaT1/ky2BtEsZ1Ru
yQBp5b0+30B0oDIDhyyQllL6HyYPpD/t7bN1AtJ+F0+xfQLSDC6r1N0+vHKU
lZM7nvjxleOHyS+SWj8D3WX4M7sNSGuFem00/vrKca/Ml50h3185Pok7ZqPz
45UjAMST+6M=
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzlsow2EcxvG/WcJqpbBo/o5rjSyHIoa8y6mFtYUbUlbcoF0gp0KKKJRo
atiFUAxrUkLjAlvJacmFw8acWm+NmcPCmN978fSp5+obrVDKa30oikqDDSQI
A2evMPqrK+IRU9pGQ+bALq+ZSzxQuSfmwUwJW0cMVVe2LoBTVXvWI1DDOtV5
wFJp8AWRIfN1EJd2KfYvaH2IERPjuwWNxOdOWk8cDxrOmrzGiJ+do9WAJkZ6
yTyoSm3eegV7BDIHUc1LSnSR/2ivj9gxl6H+JlYzI3/AmXPj8YsFo0HWNs25
wch+I7dJbjHqbdFHi2wYvbgO11R3GNH5LOsEuLK+KbaBXU2O9tF7jKRRprBV
8EQoYu6AHnbDrhW8/lSalh8xyrVbtLfgQvCZ9u8Jo6HL6cJ9B0aKygAG5xkj
Y3JmaDgo9IyJiMzDuEsuGGso/iTKYin/CDA8xlsRCboMI9lisNR84OcCqbxF
foETowiaNtW8YuQcsyv63qAr+au+H4wvl+hTPzAycN83ytwY/QP0uPcP
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzlsow2EcxvG/WcJqpWYi/o5rIQtLsiHvcmoxTXFDyoobtAvkVCNFFEq0
1RwuZGrm0KQU4WJjJcfkwmxjTq23hk0mjPm9F0+feq6+iQpldVMQRVE5sJF0
QfjiDUZ/zeU8Ynb3ZKQOVAUuYolH6k/NEiiSsteJXG1dlx6crTc7TsB51vm6
H5RVca6JDHmwm7hioti/oOMxSUJM609tI7700UbidMR4/owNI35BoWEetDBy
K5dAtbBjxwMOpMrdRC0vM8NL/hPzELFXl6f9JjYw43/AhavD01c7RqOsPTrq
FiPXbbVTeofRYKcxUezE6NV7vKm+x4guYTk04NrWtsQJqtrdPZMPGFUlWKI3
wDOBmLkP+tmtJgdo8yktq08YFbnshjtQz7k0/D1jNGadKztwY6SoC2NEvWB0
mCXixoAC/5SYyDxOscaCybsVPqI8mQqNA2OSArXxoHd3okACyi6OQrwgVbzM
L33DKI6mLY0ejN6mXIqhd+jK+moZBtNqpEbhB0b/S8DyEg==
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAeIObT2uJbdfOf5L81AF0UYVE0WXAum6/xdlQPSpad+n
LwPSVl5860G02Kzo8pVAek7MkXtngfQ87gvr/wBpP3+RmyCaKZD5LYhec5iB
7y+QvvdEyQlEa9Vr5oLod9VyG0H0FMFem9l3Xjmq29qtngekjzOZ+y4D0tOM
S3Z/BNINmoFvQfQsVQPdTyDxs0daQXTVUstZv0B0HIv8byC96Oqxc+/vvnLs
5N4nJ37/leOL+0EPvR68cmwq3aho/fCV4/tPZ7ZMe/TKUc6V+950IL1u+y6n
h0C6rvht5cTHrxz9FY5LbgLS5/WsWfYD6T98OYfvAek73/KPr336ytHhxd3V
D4D0SpHLq/89e+XYc2uu+9G3rxyTojmZxN+9cjxmaCUmBaT1/ky2BtEsZ1Ru
yQBp5b0+30B0oDIDhyyQllL6HyYPpD/t7bN1AtJ+F0+xfQLSDC6r1N0+vHKU
lZM7nvjxleOHyS+SWj8D3WX4M7sNSAMAyOjuRA==
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuIObT2uJbdfOf5L81AF0UYVE0WXAum6/xdlQPSpad+n
LwPSVl5860G02Kzo8pVAek7MkXtngfQ87gvr/wBpP3+RmyCaKZD5LYhec5iB
7y+QvvdEyQlEa9Vr5oLod9VyG0H0FMFem9l3Xjmq29qtngekjzOZ+y4D0tOM
S3Z/BNINmoFvQfQsVQPdTyDxs0daQXTVUstZv0B0HIv8byC96Oqxc+/vvnLs
5N4nJ37/leOL+0EPvR68cmwq3aho/fCV4/tPZ7ZMe/TKUc6V+950IL1u+y6n
h0C6rvht5cTHrxz9FY5LbgLS5/WsWfYD6T98OYfvAek73/KPr336ytHhxd3V
D4D0SpHLq/89e+XYc2uu+9G3rxyTojmZxN+9cjxmaCUmBaT1/ky2BtEsZ1Ru
yQBp5b0+30B0oDIDhyyQllL6HyYPpD/t7bN1AtJ+F0+xfQLSDC6r1N0+vHKU
lZM7nvjxleOHyS+SWj+/cgQAZkHpuw==
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuIObT2uJbdfOf5L81AF0UYVE0WXAum6/xdlQPSpad+n
LwPSVl5860G02Kzo8pVAek7MkXtngfQ87gvr/wBpP3+RmyCaKZD5LYhec5iB
7y+QvvdEyQlEa9Vr5oLod9VyG0H0FMFem9l3Xjmq29qtngekjzOZ+y4D0tOM
S3Z/BNINmoFvQfQsVQPdTyDxs0daQXTVUstZv0B0HIv8byC96Oqxc+/vvnLs
5N4nJ37/leOL+0EPvR68cmwq3aho/fCV4/tPZ7ZMe/TKUc6V+950IL1u+y6n
h0C6rvht5cTHrxz9FY5LbgLS5/WsWfYD6T98OYfvAek73/KPr336ytHhxd3V
D4D0SpHLq/89e+XYc2uu+9G3rxyTojmZxN+9cjxmaCUmBaT1/ky2BtEsZ1Ru
yQBp5b0+30B0oDIDhyyQllL6HyYPpD/t7bN1AtJ+F0+xfQLSDC6r1N0+vHKU
lZM7nvjxlSMAKAvkSg==
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBOIObT2uJbdfOf5L81AF0UYVE0WXAum6/xdlQPSpad+n
LwPSVl5860G02Kzo8pVAek7MkXtngfQ87gvr/wBpP3+RmyCaKZD5LYhec5iB
7y+QvvdEyQlEa9Vr5oLod9VyG0H0FMFem9l3Xjmq29qtngekjzOZ+y4D0tOM
S3Z/BNINmoFvQfQsVQPdTyDxs0daQXTVUstZv0B0HIv8byC96Oqxc+/vvnLs
5N4nJ37/leOL+0EPvR68cmwq3aho/fCV4/tPZ7ZMe/TKUc6V+950IL1u+y6n
h0C6rvht5cTHrxz9FY5LbgLS5/WsWfYD6T98OYfvAek73/KPr336ytHhxd3V
D4D0SpHLq/89e+XYc2uu+9G3rxyTojmZxN+9cjxmaCUmBaT1/ky2BtEsZ1Ru
yQBp5b0+30B0oDIDhyyQllL6HyYPpD/t7bN1AtJ+F0+xfQLSDC6r1N0+vHIE
ABPx4Kw=
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOIObT2uJbdfOf5L81AF0UYVE0WXAum6/xdlQPSpad+n
LwPSVl5860G02Kzo8pVAek7MkXtngfQ87gvr/wBpP3+RmyCaKZD5LYhec5iB
7y+QvvdEyQlEa9Vr5oLod9VyG0H0FMFem9l3Xjmq29qtngekjzOZ+y4D0tOM
S3Z/BNINmoFvQfQsVQPdTyDxs0daQXTVUstZv0B0HIv8byC96Oqxc+/vvnLs
5N4nJ37/leOL+0EPvR68cmwq3aho/fCV4/tPZ7ZMe/TKUc6V+950IL1u+y6n
h0C6rvht5cTHrxz9FY5LbgLS5/WsWfYD6T98OYfvAek73/KPr336ytHhxd3V
D4D0SpHLq/89e+XYc2uu+9G3rxyTojmZxN+9cjxmaCUmBaT1/ky2BtEsZ1Ru
yQBp5b0+30B0oDIDhyyQllL6HyYPpD/t7bN1AtJ+F0+xfQLSABu83TU=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D2e", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D1e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b_"}], "]"}], "\[Rule]", 
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "b"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "b_"}], "]"}], "\[Rule]", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "c"}], ",", 
       RowBox[{"c", "\[Rule]", "a"}], ",", 
       RowBox[{"b", "\[Rule]", "d"}], ",", 
       RowBox[{"d", "\[Rule]", "b"}], ",", 
       RowBox[{"u", "\[Rule]", "t"}], ",", 
       RowBox[{"t", "\[Rule]", "u"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.6048127418568373`*^9, 3.6048127646700497`*^9}, {
   3.604812803090568*^9, 3.6048128055678473`*^9}, {3.60481592594799*^9, 
   3.604815927607259*^9}, {3.604816226771763*^9, 3.604816227856861*^9}, {
   3.6048181951129713`*^9, 3.604818221294298*^9}, {3.6144930624713306`*^9, 
   3.614493187061157*^9}, 3.614494897822517*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9, 3.615633725355297*^9, 
  3.616214584988072*^9, 3.617336087300054*^9, 3.617338207833564*^9, 
  3.618217354364574*^9, 3.619333583690939*^9, 3.6197749502368307`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9, 3.615633725355297*^9, 
  3.616214584988072*^9, 3.617336087300054*^9, 3.617338207833564*^9, 
  3.618217354364574*^9, 3.619333583690939*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9, 3.615633725355297*^9, 
  3.616214584988072*^9, 3.617336087300054*^9, 3.617338207833564*^9, 
  3.618217354364574*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9, 3.615633725355297*^9, 
  3.616214584988072*^9, 3.617336087300054*^9, 3.617338207833564*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9, 3.615633725355297*^9, 
  3.616214584988072*^9, 3.617336087300054*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9, 3.615633725355297*^9, 
  3.616214584988072*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9, 3.615633725355297*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "t"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6144931315469093`*^9, 3.614493187969054*^9, 
  3.6144948978408737`*^9, 3.6144951966574287`*^9, 3.614500561213601*^9, 
  3.614500786433687*^9, 3.614500928032729*^9, 3.614505656003298*^9, 
  3.61457713250382*^9, 3.614937142388461*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "D2e", "]"}]], "Input",
 CellChangeTimes->{{3.6048159565333023`*^9, 3.6048159597948313`*^9}, 
   3.614494897841865*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwA2KL6RzcS26/cgxpNtIF0Z9EmNSWAmmmWb+nLwPSTivF
14NoVbvk8pVAun7ymXtngTQf59X1f4C06WHpmyB6kzXnWxAtJMHG9xekv1TT
CUS3LNLNBdFf4lQ2gmgLgyk2s++8cnTrcVw9D0hf+2/luwxIl62u2P0RSH/+
EvIWRLdPN9b9BKTP/T/RCqKF5tnN+gWkDbazy/8G0pvqTp17f/eVY0/sITnx
+68cY2aHPPR68MpRLnmrovXDV45X9C5tmfYIKM4idG86kL4/44DTQyBt+/BT
5cTHrxxLb56S3ASkv/HYs+wH0jumFh++B6QTXlcdX/v0lWNg1uPVD4D0NYvb
q/89e+X44uUi96NvXznWePEwib975dj2w0pMCkiXvJ5qDaJVGDVuyQDpT71+
30B0xiRGDlkQ/zFDuDyIfj3B1glIu1qdZfsEpLtE16i7fXjlyHtE4Xjix1eO
cZmvklo/v3KU//I7uw1I78vy2Wj89ZVj0r7vO0O+v3LclnLCRufHK0cAz2T5
kw==
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy2kow3EcBvBtyZHjxcLco+Z6MYnU2hx9VyihaOUNYlKO5IVb4oWrRLkn
yguhNNIWIYUckfBCKNeYRXzXHH9zZK7v78XTp+epJ0hdnlnI5/F4MRSZxtF5
/BxB1RwlZXLugpAJUjBs00ySyinRLDM4vqBmimzq2zPsk25Ox7PfZMyG7ylT
r3CyMIVe9m4/7F8VrmS2jEnLmNZciY4pi+yPHblASOoE7Sh58idPmySrtbXL
L+SrVWVhtmuipRx58LfTyhSOxg9/kZELDmIbqW/cPXi6ROjMWQ8QXSFkj6iM
KdcIAQXzQQojwlHE4dzgDe12QoOGvBpaUxrJOCNX12NCqDrd9daT7y4Jdqvk
4kDFhoHMM9dvz9wiZJSYtNfkiexc+3uHcP8wlrxlQWhIcRGIHhHaPuWePmSl
eUDBlPDDzvxIriv9nVnUy3f0Z93EyxIzzd1xSjJRvm/PkR0e06FJzwium4Hb
+S8IucWobn1FEFttpW3kSkmqLvoNQb3ysaT6QPgHECr1JQ==
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAWKL6RzcS26/cgxpNtIF0Z9EmNSWAmmmWb+nLwPSTivF
14NoVbvk8pVAun7ymXtngTQf59X1f4C06WHpmyB6kzXnWxAtJMHG9xekv1TT
CUS3LNLNBdFf4lQ2gmgLgyk2s++8cnTrcVw9D0hf+2/luwxIl62u2P0RSH/+
EvIWRLdPN9b9BKTP/T/RCqKF5tnN+gWkDbazy/8G0pvqTp17f/eVY0/sITnx
+68cY2aHPPR68MpRLnmrovXDV45X9C5tmfYIKM4idG86kL4/44DTQyBt+/BT
5cTHrxxLb56S3ASkv/HYs+wH0jumFh++B6QTXlcdX/v0lWNg1uPVD4D0NYvb
q/89e+X44uUi96NvXznWePEwib975dj2w0pMCkiXvJ5qDaJVGDVuyQDpT71+
30B0xiRGDlkQ/zFDuDyIfj3B1glIu1qdZfsEpLtE16i7fXjlyHtE4Xjix1eO
cZmvklo/v3KU//I7uw1I78vy2Wj89ZUjAHcj794=
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBmKL6RzcS26/cgxpNtIF0Z9EmNSWAmmmWb+nLwPSTivF
14NoVbvk8pVAun7ymXtngTQf59X1f4C06WHpmyB6kzXnWxAtJMHG9xekv1TT
CUS3LNLNBdFf4lQ2gmgLgyk2s++8cnTrcVw9D0hf+2/luwxIl62u2P0RSH/+
EvIWRLdPN9b9BKTP/T/RCqKF5tnN+gWkDbazy/8G0pvqTp17f/eVY0/sITnx
+68cY2aHPPR68MpRLnmrovXDV45X9C5tmfYIKM4idG86kL4/44DTQyBt+/BT
5cTHrxxLb56S3ASkv/HYs+wH0jumFh++B6QTXlcdX/v0lWNg1uPVD4D0NYvb
q/89e+X44uUi96NvXznWePEwib975dj2w0pMCkiXvJ5qDaJVGDVuyQDpT71+
30B0xiRGDlkQ/zFDuDyIfj3B1glIu1qdZfsEpLtE16i7fXjlyHtE4Xjix1eO
cZmvklo/v3KU//I7uw1IAwAGG+tl
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAmKL6RzcS26/cgxpNtIF0Z9EmNSWAmmmWb+nLwPSTivF
14NoVbvk8pVAun7ymXtngTQf59X1f4C06WHpmyB6kzXnWxAtJMHG9xekv1TT
CUS3LNLNBdFf4lQ2gmgLgyk2s++8cnTrcVw9D0hf+2/luwxIl62u2P0RSH/+
EvIWRLdPN9b9BKTP/T/RCqKF5tnN+gWkDbazy/8G0pvqTp17f/eVY0/sITnx
+68cY2aHPPR68MpRLnmrovXDV45X9C5tmfYIKM4idG86kL4/44DTQyBt+/BT
5cTHrxxLb56S3ASkv/HYs+wH0jumFh++B6QTXlcdX/v0lWNg1uPVD4D0NYvb
q/89e+X44uUi96NvXznWePEwib975dj2w0pMCkiXvJ5qDaJVGDVuyQDpT71+
30B0xiRGDlkQ/zFDuDyIfj3B1glIu1qdZfsEpLtE16i7fXjlyHtE4Xjix1eO
cZmvklo/v3IEALss5kc=
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBGKL6RzcS26/cgxpNtIF0Z9EmNSWAmmmWb+nLwPSTivF
14NoVbvk8pVAun7ymXtngTQf59X1f4C06WHpmyB6kzXnWxAtJMHG9xekv1TT
CUS3LNLNBdFf4lQ2gmgLgyk2s++8cnTrcVw9D0hf+2/luwxIl62u2P0RSH/+
EvIWRLdPN9b9BKTP/T/RCqKF5tnN+gWkDbazy/8G0pvqTp17f/eVY0/sITnx
+68cY2aHPPR68MpRLnmrovXDV45X9C5tmfYIKM4idG86kL4/44DTQyBt+/BT
5cTHrxxLb56S3ASkv/HYs+wH0jumFh++B6QTXlcdX/v0lWNg1uPVD4D0NYvb
q/89e+X44uUi96NvXznWePEwib975dj2w0pMCkiXvJ5qDaJVGDVuyQDpT71+
30B0xiRGDlkQ/zFDuDyIfj3B1glIu1qdZfsEpLtE16i7fXjlyHtE4Xjix1eO
AJh44ZA=
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAGKL6RzcS26/cgxpNtIF0Z9EmNSWAmmmWb+nLwPSTivF
14NoVbvk8pVAun7ymXtngTQf59X1f4C06WHpmyB6kzXnWxAtJMHG9xekv1TT
CUS3LNLNBdFf4lQ2gmgLgyk2s++8cnTrcVw9D0hf+2/luwxIl62u2P0RSH/+
EvIWRLdPN9b9BKTP/T/RCqKF5tnN+gWkDbazy/8G0pvqTp17f/eVY0/sITnx
+68cY2aHPPR68MpRLnmrovXDV45X9C5tmfYIKM4idG86kL4/44DTQyBt+/BT
5cTHrxxLb56S3ASkv/HYs+wH0jumFh++B6QTXlcdX/v0lWNg1uPVD4D0NYvb
q/89e+X44uUi96NvXznWePEwib975dj2w0pMCkiXvJ5qDaJVGDVuyQDpT71+
30B0xiRGDlkQ/zFDuDyIfj3B1glIu1qdZfsEpLtE16i7fXjlCACa4N1a
  "]],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB2KL6RzcS26/cgxpNtIF0Z9EmNSWAmmmWb+nLwPSTivF
14NoVbvk8pVAun7ymXtngTQf59X1f4C06WHpmyB6kzXnWxAtJMHG9xekv1TT
CUS3LNLNBdFf4lQ2gmgLgyk2s++8cnTrcVw9D0hf+2/luwxIl62u2P0RSH/+
EvIWRLdPN9b9BKTP/T/RCqKF5tnN+gWkDbazy/8G0pvqTp17f/eVY0/sITnx
+68cY2aHPPR68MpRLnmrovXDV45X9C5tmfYIKM4idG86kL4/44DTQyBt+/BT
5cTHrxxLb56S3ASkv/HYs+wH0jumFh++B6QTXlcdX/v0lWNg1uPVD4D0NYvb
q/89e+X44uUi96NvXznWePEwib975dj2w0pMCkiXvJ5qDaJVGDVuyQDpT71+
30B0xiRGDlkQ/zFDuDyIfj3B1glIu1qdZfsEpAG9GNmG
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D3e", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D1e", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b_"}], "]"}], "\[Rule]", 
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "b"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "b_"}], "]"}], "\[Rule]", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "e"}], ",", 
       RowBox[{"e", "\[Rule]", "a"}], ",", 
       RowBox[{"b", "\[Rule]", "f"}], ",", 
       RowBox[{"f", "\[Rule]", "b"}], ",", 
       RowBox[{"u", "\[Rule]", "s"}], ",", 
       RowBox[{"s", "\[Rule]", "u"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.60481282660896*^9, 3.60481284830171*^9}, {
   3.604815997803871*^9, 3.604816000356163*^9}, {3.604816239285211*^9, 
   3.604816242058169*^9}, {3.604818229970171*^9, 3.604818243785556*^9}, {
   3.604820519474146*^9, 3.604820520857345*^9}, {3.604820833447481*^9, 
   3.604820842466094*^9}, {3.60482093256593*^9, 3.604820935367803*^9}, {
   3.614493201084248*^9, 3.614493303152424*^9}, 3.6144948978501596`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9, 3.6156337254067802`*^9, 3.616214585068761*^9, 
   3.617336087357766*^9, 3.617338207918776*^9, 3.6182173544298677`*^9, 
   3.619333583802985*^9, 3.6197749503067617`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9, 3.6156337254067802`*^9, 3.616214585068761*^9, 
   3.617336087357766*^9, 3.617338207918776*^9, 3.6182173544298677`*^9, 
   3.619333583802985*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9, 3.6156337254067802`*^9, 3.616214585068761*^9, 
   3.617336087357766*^9, 3.617338207918776*^9, 3.6182173544298677`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9, 3.6156337254067802`*^9, 3.616214585068761*^9, 
   3.617336087357766*^9, 3.617338207918776*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9, 3.6156337254067802`*^9, 3.616214585068761*^9, 
   3.617336087357766*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9, 3.6156337254067802`*^9, 3.616214585068761*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9, 3.6156337254067802`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "s"], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"4", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604812849176861*^9, 3.60481600175609*^9, 3.604816243036755*^9, 
   3.604816427993607*^9, 3.6048182449739647`*^9, 3.604820523996665*^9, {
   3.604820834413439*^9, 3.604820843057427*^9}, 3.604820936275344*^9, 
   3.604821183954714*^9, 3.6048213688792267`*^9, 3.6048270671557093`*^9, 
   3.604901622515164*^9, 3.604997502748766*^9, 3.604997832906149*^9, 
   3.604997992334124*^9, 3.604998256285158*^9, 3.6049986733900414`*^9, 
   3.6049990174958277`*^9, 3.604999561228187*^9, 3.605322212680666*^9, 
   3.6053292421067257`*^9, 3.6053448739708633`*^9, 3.605499355845536*^9, 
   3.605499754719761*^9, 3.605500265703854*^9, 3.605500974348604*^9, 
   3.605517522039278*^9, 3.605518584340108*^9, 3.606019702394423*^9, 
   3.606624502149747*^9, 3.607254794684111*^9, 3.607746829756592*^9, 
   3.6084586626922817`*^9, 3.608461040724684*^9, 3.608611350163638*^9, 
   3.6089722396965427`*^9, 3.609039054424499*^9, 3.609065506056548*^9, 
   3.609130523726927*^9, 3.6100787800005827`*^9, 3.6101830072497473`*^9, 
   3.610768734966434*^9, 3.614321213162215*^9, 3.61448859242188*^9, 
   3.614493251445364*^9, 3.614493303906506*^9, 3.614494897867262*^9, 
   3.614495196718614*^9, 3.614500561317971*^9, 3.614500786491803*^9, 
   3.614500928077898*^9, 3.61450565606085*^9, 3.614577132564034*^9, 
   3.614937142479649*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "D3e", "]"}]], "Input",
 CellChangeTimes->{3.604816013429905*^9, 3.614494897868474*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}, 3.615633725425192*^9, 
   3.6162145851047573`*^9, 3.617336087374805*^9, 3.617338207951955*^9, 
   3.618217354453212*^9, 3.6193335838081837`*^9, 3.619774950332168*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}, 3.615633725425192*^9, 
   3.6162145851047573`*^9, 3.617336087374805*^9, 3.617338207951955*^9, 
   3.618217354453212*^9, 3.6193335838081837`*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}, 3.615633725425192*^9, 
   3.6162145851047573`*^9, 3.617336087374805*^9, 3.617338207951955*^9, 
   3.618217354453212*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}, 3.615633725425192*^9, 
   3.6162145851047573`*^9, 3.617336087374805*^9, 3.617338207951955*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}, 3.615633725425192*^9, 
   3.6162145851047573`*^9, 3.617336087374805*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}, 3.615633725425192*^9, 
   3.6162145851047573`*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}, 3.615633725425192*^9}],

Cell[BoxData[
 FormBox["54", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.60481601407905*^9, 3.604816244150704*^9, 3.604818248514669*^9, 
   3.604820532117957*^9, 3.60482118402048*^9, 3.604821369026709*^9, 
   3.604827067201645*^9, 3.604901622632883*^9, 3.604997502850499*^9, 
   3.6049978329577227`*^9, 3.60499799239904*^9, 3.604998256394261*^9, 
   3.604998673534993*^9, 3.6049990175816097`*^9, 3.604999561331399*^9, 
   3.605322212750152*^9, 3.605329242111559*^9, 3.605344874079966*^9, 
   3.605499355901105*^9, 3.605499754724774*^9, 3.605500265786866*^9, 
   3.6055009744050903`*^9, 3.6055175221115*^9, 3.605518584429278*^9, 
   3.6060197024405117`*^9, 3.606624502208969*^9, 3.6072547947007513`*^9, 
   3.607746829861435*^9, 3.60845866273529*^9, 3.60846104089638*^9, 
   3.608611350323092*^9, 3.6089722398179293`*^9, 3.609039054523528*^9, 
   3.609065506162709*^9, 3.609130523851966*^9, 3.610078780245289*^9, 
   3.6101830074269943`*^9, 3.610768735505089*^9, 3.614321213254322*^9, 
   3.614488592469572*^9, 3.614494897869891*^9, 3.614495196746092*^9, 
   3.6145005613719788`*^9, 3.614500786510857*^9, 3.6145009280831413`*^9, 
   3.61450565608535*^9, 3.614577132591146*^9, 3.614937142487903*^9, {
   3.6150288449908257`*^9, 3.615028850945046*^9}}]
}, Open  ]],

Cell["The resulting eee \[CurlyPhi] \[OpenCurlyDoubleQuote]amplitude\
\[CloseCurlyDoubleQuote] is:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048129696254263`*^9, 3.604812980148488*^9}, 3.614494897871146*^9, {
   3.616221676138475*^9, 3.6162216845292463`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ampEEEVarphi", "=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
      "verEEEVarphionshell123", " ", "+", " ", "D1varphi", " ", "+", " ", 
       "D2varphi", " ", "+", " ", "D3varphi", " ", "+", " ", "D1e", " ", "+", 
       " ", "D2e", " ", "+", " ", "D3e"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "x_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"kc", "[", 
          RowBox[{"1", ",", "x"}], "]"}]}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "x"}], "]"}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "x"}], "]"}]}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.6048129825499*^9, 3.6048130077951307`*^9}, {
   3.604813200909709*^9, 3.604813207557535*^9}, {3.610166417619474*^9, 
   3.610166509104484*^9}, 3.6101665944517736`*^9, {3.610166886677898*^9, 
   3.610166892028933*^9}, {3.610168374442172*^9, 3.610168380175312*^9}, {
   3.6101685080695343`*^9, 3.610168513298273*^9}, {3.6144933167674417`*^9, 
   3.614493443000843*^9}, 3.614494897874848*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9, 3.615633725457939*^9, 3.616214585146089*^9, 
  3.6173360874066973`*^9, 3.6173382079898643`*^9, 3.618217354485963*^9, 
  3.6193335838594007`*^9, 3.619774950367689*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9, 3.615633725457939*^9, 3.616214585146089*^9, 
  3.6173360874066973`*^9, 3.6173382079898643`*^9, 3.618217354485963*^9, 
  3.6193335838594007`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9, 3.615633725457939*^9, 3.616214585146089*^9, 
  3.6173360874066973`*^9, 3.6173382079898643`*^9, 3.618217354485963*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9, 3.615633725457939*^9, 3.616214585146089*^9, 
  3.6173360874066973`*^9, 3.6173382079898643`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9, 3.615633725457939*^9, 3.616214585146089*^9, 
  3.6173360874066973`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9, 3.615633725457939*^9, 3.616214585146089*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9, 3.615633725457939*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], 
    RowBox[{"2", " ", "u"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "t"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["3", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", "s"}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101665947410583`*^9, 3.610166893169003*^9, 
  3.6101683852350063`*^9, 3.6101685144795*^9, 3.610183007550194*^9, 
  3.61076873575064*^9, 3.614321213357418*^9, 3.614488592505056*^9, 
  3.614493386403035*^9, 3.614493443757386*^9, 3.614494897892211*^9, 
  3.614495196780167*^9, 3.61450056143012*^9, 3.614500786539886*^9, 
  3.614500928115469*^9, 3.614505656116495*^9, 3.614577132624874*^9, 
  3.6149371425233727`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "ampEEEVarphi", "]"}]], "Input",
 CellChangeTimes->{{3.60481324382812*^9, 3.604813245157632*^9}, 
   3.610166498326269*^9, 3.614494897892997*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9, 3.6156337254771852`*^9, 
   3.6162145851796017`*^9, 3.617336087424191*^9, 3.617338208025103*^9, 
   3.61821735449144*^9, 3.619333583905035*^9, 3.619774950455339*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9, 3.6156337254771852`*^9, 
   3.6162145851796017`*^9, 3.617336087424191*^9, 3.617338208025103*^9, 
   3.61821735449144*^9, 3.619333583905035*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9, 3.6156337254771852`*^9, 
   3.6162145851796017`*^9, 3.617336087424191*^9, 3.617338208025103*^9, 
   3.61821735449144*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9, 3.6156337254771852`*^9, 
   3.6162145851796017`*^9, 3.617336087424191*^9, 3.617338208025103*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9, 3.6156337254771852`*^9, 
   3.6162145851796017`*^9, 3.617336087424191*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9, 3.6156337254771852`*^9, 
   3.6162145851796017`*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9, 3.6156337254771852`*^9}],

Cell[BoxData[
 FormBox["48", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048132454199038`*^9, 3.604816248364986*^9, 3.604818253946311*^9, 
   3.604820535613152*^9, 3.604820651291716*^9, 3.6048211840872726`*^9, 
   3.604821369064794*^9, 3.604827067321549*^9, 3.604901622670877*^9, 
   3.604997502910887*^9, 3.604997833021022*^9, 3.604997992529339*^9, 
   3.604998256450778*^9, 3.6049986735949183`*^9, 3.604999017631789*^9, 
   3.604999561387135*^9, 3.6053222129397*^9, 3.605329242120407*^9, 
   3.60534487409603*^9, 3.605499355912096*^9, 3.605499754777608*^9, 
   3.60550026579832*^9, 3.605500974463776*^9, 3.605517522185807*^9, 
   3.605518584521057*^9, 3.6060197024910316`*^9, 3.606624502217359*^9, 
   3.607254794724723*^9, 3.607746829944997*^9, 3.608458662756157*^9, 
   3.608461040915751*^9, 3.608611350360364*^9, 3.608972239873597*^9, 
   3.6090390545983973`*^9, 3.6090655061744223`*^9, 3.609130523865362*^9, 
   3.610078780267861*^9, {3.610166499006548*^9, 3.610166512982348*^9}, 
   3.610166894981304*^9, 3.610168390514762*^9, 3.610183007693779*^9, 
   3.6107687358956547`*^9, 3.614321213430231*^9, 3.614488592539241*^9, 
   3.614494897893505*^9, 3.6144951968062153`*^9, 3.614500561472747*^9, 
   3.61450078655945*^9, 3.614500928131743*^9, 3.614505656140238*^9, 
   3.614577132650401*^9, 3.6149371426222677`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ampEEEVarphi$simple", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"s", " ", "t", " ", "u"}], ")"}]}], 
      RowBox[{"Expand", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"s", " ", "t", " ", "u", " ", "ampEEEVarphi"}], "]"}], 
       "]"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "s"}], "-", "t"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.615529590411303*^9, 3.615529636198862*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.615529591076075*^9, 3.6155296376934223`*^9, 
  3.61563372561412*^9, 3.616214585313176*^9, 3.617336087554874*^9, 
  3.617338208164554*^9, 3.618217354637615*^9, 3.6193335840447273`*^9, 
  3.619774950600898*^9}]
}, Open  ]],

Cell["Note that the poles have disappeared.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048129696254263`*^9, 3.604812980148488*^9}, {3.6048193247700644`*^9, 
   3.604819330470724*^9}, 3.6144948978939466`*^9, {3.6155298944578533`*^9, 
   3.615529899935089*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["Let\[CloseCurlyQuote]s first check Bose symmetry:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048129696254263`*^9, 3.604812980148488*^9}, {3.6048193247700644`*^9, 
   3.604819330470724*^9}, 3.6144948978939466`*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ampEEEVarphi$simple", "-", 
    RowBox[{"(", 
     RowBox[{"ampEEEVarphi$simple", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "b"}], ",", 
        RowBox[{"t", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "t"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ampEEEVarphi$simple", "-", 
    RowBox[{"(", 
     RowBox[{"ampEEEVarphi$simple", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "b"}], ",", 
        RowBox[{"s", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"ampEEEVarphi$simple", "-", 
    RowBox[{"(", 
     RowBox[{"ampEEEVarphi$simple", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "c"}], ",", 
        RowBox[{"d", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "d"}], ",", 
        RowBox[{"s", "\[Rule]", "t"}], ",", 
        RowBox[{"t", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.610166525019972*^9, 3.610166559046633*^9}, {
   3.6101666327501497`*^9, 3.61016663456389*^9}, {3.610166666966453*^9, 
   3.610166711738093*^9}, {3.610166756075919*^9, 3.610166776853239*^9}, {
   3.610166914089284*^9, 3.610166935294664*^9}, 3.61449489790102*^9, {
   3.615529659309987*^9, 3.615529666226694*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}, 3.6156337256487217`*^9, 
   3.616214585366727*^9, 3.617336087586458*^9, 3.617338208211727*^9, 
   3.61821735468928*^9, 3.619333584114785*^9, 3.619774950641491*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}, 3.6156337256487217`*^9, 
   3.616214585366727*^9, 3.617336087586458*^9, 3.617338208211727*^9, 
   3.61821735468928*^9, 3.619333584114785*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}, 3.6156337256487217`*^9, 
   3.616214585366727*^9, 3.617336087586458*^9, 3.617338208211727*^9, 
   3.61821735468928*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}, 3.6156337256487217`*^9, 
   3.616214585366727*^9, 3.617336087586458*^9, 3.617338208211727*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}, 3.6156337256487217`*^9, 
   3.616214585366727*^9, 3.617336087586458*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}, 3.6156337256487217`*^9, 
   3.616214585366727*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}, 3.6156337256487217`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.6048209975668793`*^9, 3.604821184221303*^9, 3.6048213692057533`*^9, 
   3.6048270673685102`*^9, 3.6049016227033*^9, 3.6049975029463177`*^9, 
   3.6049978331347923`*^9, 3.6049979926443863`*^9, 3.6049982564874*^9, 
   3.604998673696241*^9, 3.604999017679673*^9, 3.604999561424316*^9, 
   3.605322212999407*^9, 3.605329242197857*^9, 3.605344874170731*^9, 
   3.60549935599457*^9, 3.6054997548535147`*^9, 3.6055002658903713`*^9, 
   3.605500974531514*^9, 3.605517522270474*^9, 3.6055185846253233`*^9, 
   3.6060197025675917`*^9, 3.606624502312172*^9, 3.60725479476972*^9, 
   3.6077468300431623`*^9, 3.608458662887504*^9, 3.608461041076496*^9, 
   3.6086113505081*^9, 3.6089722399819403`*^9, 3.609039054695669*^9, 
   3.6090655062745*^9, 3.6091305239679813`*^9, 3.610078780476522*^9, {
   3.610166528055584*^9, 3.610166559919984*^9}, 3.6101667154056053`*^9, {
   3.610166759578597*^9, 3.610166777285688*^9}, {3.6101669225274687`*^9, 
   3.61016693609163*^9}, 3.610168392466793*^9, 3.6101685174736032`*^9, 
   3.6101830078550177`*^9, 3.6107687359311647`*^9, 3.6143212134984303`*^9, 
   3.614488592560047*^9, 3.614494897902296*^9, 3.614495196843425*^9, 
   3.614500561538468*^9, 3.6145007865888767`*^9, 3.614500928162731*^9, 
   3.614505656173208*^9, 3.61457713269046*^9, 3.614937142651366*^9, {
   3.6155296613858747`*^9, 3.615529666818342*^9}}]
}, Open  ]],

Cell["This is probably nonzero:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048129696254263`*^9, 3.604812980148488*^9}, {3.604813181688973*^9, 
   3.60481319376462*^9}, 3.6144948979036007`*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", "=", 
  RowBox[{
   RowBox[{"ampEEEVarphi$simple", " ", 
    RowBox[{"xi", "[", 
     RowBox[{"1", ",", "a"}], "]"}], 
    RowBox[{"xibar", "[", 
     RowBox[{"1", ",", "b"}], "]"}], 
    RowBox[{"xi", "[", 
     RowBox[{"2", ",", "c"}], "]"}], 
    RowBox[{"xibar", "[", 
     RowBox[{"2", ",", "d"}], "]"}], 
    RowBox[{"xi", "[", 
     RowBox[{"3", ",", "e"}], "]"}], 
    RowBox[{"xibar", "[", 
     RowBox[{"3", ",", "f"}], "]"}]}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.604813210676127*^9, 3.6048132257132597`*^9}, {
   3.604813256644479*^9, 3.604813257070593*^9}, 3.604818522611809*^9, {
   3.610166945502449*^9, 3.610166964369639*^9}, 3.61449489790571*^9, 
   3.6155296795974693`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9, 3.6156337257162313`*^9, 
   3.616214585421918*^9, 3.617336087649558*^9, 3.617338208292018*^9, 
   3.6182173547756577`*^9, 3.6193335841814413`*^9, 3.619774950695962*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9, 3.6156337257162313`*^9, 
   3.616214585421918*^9, 3.617336087649558*^9, 3.617338208292018*^9, 
   3.6182173547756577`*^9, 3.6193335841814413`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9, 3.6156337257162313`*^9, 
   3.616214585421918*^9, 3.617336087649558*^9, 3.617338208292018*^9, 
   3.6182173547756577`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9, 3.6156337257162313`*^9, 
   3.616214585421918*^9, 3.617336087649558*^9, 3.617338208292018*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9, 3.6156337257162313`*^9, 
   3.616214585421918*^9, 3.617336087649558*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9, 3.6156337257162313`*^9, 
   3.616214585421918*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9, 3.6156337257162313`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.610166947607931*^9, 3.610166965566243*^9}, 
   3.610167165973464*^9, 3.61018300824065*^9, 3.6107687361235523`*^9, 
   3.614321213687825*^9, 3.614488592741784*^9, 3.614494897929985*^9, 
   3.6144951970394297`*^9, 3.614500561755636*^9, 3.6145007867858963`*^9, 
   3.6145009283519*^9, 3.614505656372734*^9, 3.6145771328657703`*^9, 
   3.61493714283803*^9, 3.615529680521446*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "res2", "]"}]], "Input",
 CellChangeTimes->{{3.6048132360800962`*^9, 3.604813260165078*^9}, 
   3.61449489793124*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9, 3.6156337257349997`*^9, 3.616214585456974*^9, 
   3.617336087666963*^9, 3.617338208296928*^9, 3.618217354781307*^9, 
   3.619333584234083*^9, 3.61977495071826*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9, 3.6156337257349997`*^9, 3.616214585456974*^9, 
   3.617336087666963*^9, 3.617338208296928*^9, 3.618217354781307*^9, 
   3.619333584234083*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9, 3.6156337257349997`*^9, 3.616214585456974*^9, 
   3.617336087666963*^9, 3.617338208296928*^9, 3.618217354781307*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9, 3.6156337257349997`*^9, 3.616214585456974*^9, 
   3.617336087666963*^9, 3.617338208296928*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9, 3.6156337257349997`*^9, 3.616214585456974*^9, 
   3.617336087666963*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9, 3.6156337257349997`*^9, 3.616214585456974*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9, 3.6156337257349997`*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60481323833216*^9, 3.604813262938463*^9}, 
   3.604816254350203*^9, 3.6048167261826887`*^9, 3.604818265730156*^9, 
   3.604820619469158*^9, 3.6048206596063957`*^9, 3.6048211857713947`*^9, 
   3.604821370776661*^9, 3.604827068851788*^9, 3.604901624277258*^9, 
   3.60499750452351*^9, 3.604997834638938*^9, 3.6049979942696333`*^9, 
   3.604998258044898*^9, 3.604998675300558*^9, 3.604999019199255*^9, 
   3.6049995629576473`*^9, 3.60532221466434*^9, 3.605329243783621*^9, 
   3.60534487565565*^9, 3.6054993575283337`*^9, 3.605499756368256*^9, 
   3.605500267395522*^9, 3.60550097620514*^9, 3.605517523886417*^9, 
   3.605518586315833*^9, 3.606019704115121*^9, 3.606624503848452*^9, 
   3.6072547962103443`*^9, 3.607746831663856*^9, 3.608458664430509*^9, 
   3.608461042659477*^9, 3.608611352041932*^9, 3.608972241468196*^9, 
   3.6090390562799473`*^9, 3.60906550781181*^9, 3.609130525759666*^9, 
   3.610078782238139*^9, {3.610166954853204*^9, 3.610166967853079*^9}, 
   3.610183008273782*^9, 3.610768736157487*^9, 3.6143212137601643`*^9, 
   3.61448859278084*^9, 3.61449489793244*^9, 3.614495197044153*^9, 
   3.6145005617620707`*^9, 3.614500786790992*^9, 3.614500928357341*^9, 
   3.614505656378501*^9, 3.614577132892864*^9, 3.61493714284301*^9, 
   3.615529704257237*^9}]
}, Open  ]],

Cell["\<\
Before we do the numerics, let\[CloseCurlyQuote]s also check the Ward \
identity. In the subsequent numerical check it turns out that it is not \
satisfied.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048129696254263`*^9, 3.604812980148488*^9}, {3.604813181688973*^9, 
   3.60481319376462*^9}, {3.6048185943095512`*^9, 3.604818606185451*^9}, {
   3.604819212252787*^9, 3.604819237816545*^9}, 3.614494897933572*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2ward", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"ampEEEVarphi$simple", " ", 
      RowBox[{"k", "[", 
       RowBox[{"1", ",", "a"}], "]"}], 
      RowBox[{"xibar", "[", 
       RowBox[{"1", ",", "b"}], "]"}], 
      RowBox[{"xi", "[", 
       RowBox[{"2", ",", "c"}], "]"}], 
      RowBox[{"xibar", "[", 
       RowBox[{"2", ",", "d"}], "]"}], 
      RowBox[{"xi", "[", 
       RowBox[{"3", ",", "e"}], "]"}], 
      RowBox[{"xibar", "[", 
       RowBox[{"3", ",", "f"}], "]"}]}], "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604818612850524*^9, 3.604818647230295*^9}, {
   3.604818695847652*^9, 3.604818705120142*^9}, {3.6101669903156633`*^9, 
   3.6101669939623623`*^9}, {3.614493465023666*^9, 3.614493554070139*^9}, 
   3.6144948979358683`*^9, 3.615529732288306*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9, 3.615633725809116*^9, 
  3.6162145855285*^9, 3.6173360877365437`*^9, 3.617338208367509*^9, 
  3.618217354854204*^9, 3.619333584311811*^9, 3.619774950795273*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9, 3.615633725809116*^9, 
  3.6162145855285*^9, 3.6173360877365437`*^9, 3.617338208367509*^9, 
  3.618217354854204*^9, 3.619333584311811*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9, 3.615633725809116*^9, 
  3.6162145855285*^9, 3.6173360877365437`*^9, 3.617338208367509*^9, 
  3.618217354854204*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9, 3.615633725809116*^9, 
  3.6162145855285*^9, 3.6173360877365437`*^9, 3.617338208367509*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9, 3.615633725809116*^9, 
  3.6162145855285*^9, 3.6173360877365437`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9, 3.615633725809116*^9, 
  3.6162145855285*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9, 3.615633725809116*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "3"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm]}]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Eta]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["\[Xi]", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Xi]", "3"],
      TraditionalForm]}], " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["\[Eta]", "1"],
      TraditionalForm]}]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6101669947048693`*^9, 3.610167211355348*^9, 
  3.610183008507806*^9, 3.6107687363358307`*^9, 3.6143212141699533`*^9, 
  3.614488592949404*^9, 3.614493555615312*^9, 3.614494897954732*^9, 
  3.614495197212988*^9, 3.614500561933846*^9, 3.6145007869522676`*^9, 
  3.6145009285242453`*^9, 3.61450565653932*^9, 3.614577133056041*^9, 
  3.6149371430171337`*^9, 3.615529735408781*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["eee\[CurlyPhi] \[OpenCurlyDoubleQuote]amplitude\[CloseCurlyDoubleQuote] \
is numerically nonzero:", "Subsection",
 CellChangeTimes->{{3.6040429149922333`*^9, 3.604042928995213*^9}, {
  3.604813330273131*^9, 3.604813330970839*^9}, {3.604818381907351*^9, 
  3.6048183895699873`*^9}, {3.614495377974313*^9, 3.614495399645191*^9}, {
  3.616221621329445*^9, 3.616221623401964*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s settle the question whether or not the eee varphi \
amplitude is zero by numerics.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604653076731629*^9, 3.604653095746648*^9}, {3.604813338917368*^9, 
  3.6048133589388523`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["\<\
Just do 4 dimensions... 
Furthermore, to help Mathematica\[CloseCurlyQuote]s FindInstance routine I \
pick the momenta manually.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.604303428586804*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", "=", 
  RowBox[{
   RowBox[{"-", "k1"}], "-", "k2", "-", "k3"}]}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "0", ",", 
    RowBox[{"-", "1"}], ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0FtIkwEUB/ClYYJdUNHBUpYSjawe+mRg6YozU0vyRYRh0WySPZS3lnYx
7K21lx4qMpeWICo0P2krNJm4hpWDyK2HSLfpbmLQodX2dRs1pXMeDj8O/M/D
+Rc1d9S3bJLJZMdozs7vzrb6EcwvTXms64rNu0iWGT3IRoWqnUvk7LruMNve
mKpip5zDl3yk1SjE2K/y3g3Wt6B/4CcbvYVzAbLpRd94fQBBmD3d30B6gvH5
YfJLVNo3SjoDF/rHyBaL+Rk7HfBefUoaXZWhBb4bqrGlyCGNycdKOb0xtjZ0
efs673cGtexPtaWNvX7/np0tXs7WDCwjvNkijj8hw87RujGy83Z4JkFq9TMx
9uOexwckzm09ZGJvToiP/pJS3g3lP7LHUur9voLw3lWilIcQ0tInI7VhhOqD
e4vLI9SH/OhkXxShu8scfEiuDagrI+SpaUPP3VWEgiMViuekSy1ufkUWdSde
B8mT9pR7Yg3BodMnl8hz9nwxTNrqVOLGZ4QMw7uatzGE3MFdafJvCF1Z1nIF
eW0F/AVkxwnDb/a4OyezkPQI+TolOZI5otGSrRDNkMhP53dczI0jyBYdqmqy
vUlwGxLUQ2ey+dYPBFG1rdVEKkrO2Et/IcTnshwNf+j/D/6K/UmE/09EQZ4=

  "]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi1", "=", 
   RowBox[{"{", 
    RowBox[{"xix1", ",", "xix2", ",", "xix3", ",", "xix4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043270708568*^9, 3.6040432967635603`*^9}, 
   3.604043499802985*^9, 3.604301554870967*^9, {3.6043021515175753`*^9, 
   3.604302152636281*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi2", "=", 
   RowBox[{"{", 
    RowBox[{"xiy1", ",", "xiy2", ",", "xiy3", ",", "xiy4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.6040433084930897`*^9, 
   3.6040433346916733`*^9}, 3.604043502795218*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{"xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et1", "=", 
   RowBox[{"{", 
    RowBox[{"etx1", ",", "etx2", ",", "etx3", ",", "etx4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, {3.6040433875103607`*^9, 3.604043405643474*^9}, 
   3.604043511306425*^9, 3.604301558638516*^9, {3.604302156974309*^9, 
   3.604302158069281*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et2", "=", 
   RowBox[{"{", 
    RowBox[{"ety1", ",", "ety2", ",", "ety3", ",", "ety4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.604043389260811*^9, 
   3.6040434154828787`*^9}, 3.6040435138414288`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{"etz1", ",", "etz2", ",", "etz3", ",", "etz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9}],

Cell["Define Minkowski product:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.604043634462092*^9, 3.604043700535356*^9}}],

Cell["The onshell and transversality conditions are: ", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "==", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "xi1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "et1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "xi2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "et2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}]}], "}"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.604301017553907*^9, 3.604301024231163*^9}, {
   3.604301077374564*^9, 3.604301078878018*^9}, {3.604301291832534*^9, 
   3.604301292457726*^9}, {3.604302579961836*^9, 3.604302586183782*^9}, 
   3.604813402604081*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{"xix2", "-", "xix1"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"etx2", "-", "etx1"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", "xiy1"}], "-", "xiy2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", "ety1"}], "-", "ety2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"xiz1", "+", "xiz3"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"etz1", "+", "etz3"}], "\[LongEqual]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604301019624743*^9, 3.604301024595703*^9}, 
   3.6043010794115887`*^9, 3.604301232160925*^9, 3.6043012968240767`*^9, 
   3.60430158140781*^9, 3.604302586942462*^9, 3.604303482957795*^9, 
   3.604304053350483*^9, 3.604397693783177*^9, 3.604397910568574*^9, 
   3.6043982982879553`*^9, 3.6043985468249607`*^9, 3.604398640157419*^9, 
   3.604401037215714*^9, 3.604402025752289*^9, 3.60440216407835*^9, 
   3.6044033712320147`*^9, 3.6044057771598577`*^9, 3.604649308915636*^9, 
   3.604653251066409*^9, 3.60481340343859*^9, 3.604818277912385*^9, 
   3.604821187549046*^9, 3.60482137254169*^9, 3.6048266908966513`*^9, 
   3.604827070729005*^9, 3.6049016263464317`*^9, 3.6049975064983053`*^9, 
   3.604997836505014*^9, 3.604997996222632*^9, 3.6049982599361563`*^9, 
   3.6049986772193336`*^9, 3.604999021082296*^9, 3.60499956485315*^9, 
   3.605322216963722*^9, 3.605329245491774*^9, 3.6053448772964573`*^9, 
   3.605499359126934*^9, 3.60549975796796*^9, 3.605500269056426*^9, 
   3.6055009779023867`*^9, 3.60551752551103*^9, 3.6055185879754744`*^9, 
   3.606019705732524*^9, 3.60662450544491*^9, 3.6072547977221003`*^9, 
   3.607746833400353*^9, 3.60845866615152*^9, 3.60846104448298*^9, 
   3.608611353928334*^9, 3.6089722432857637`*^9, 3.609039058006536*^9, 
   3.609065509524415*^9, 3.609130527773985*^9, 3.610078784119926*^9, 
   3.610167247398066*^9, 3.6101830091039667`*^9, 3.610768737425129*^9, 
   3.614321214508794*^9, 3.614488593076619*^9, 3.614495197775576*^9, 
   3.614500562284235*^9, 3.614500787106879*^9, 3.61450092865107*^9, 
   3.614505657120623*^9, 3.614577133190362*^9, 3.614937143125379*^9, 
   3.615529824315702*^9, 3.61563372589815*^9, 3.616214585661138*^9, 
   3.617336087817278*^9, 3.617338208477545*^9, 3.618217354971839*^9, 
   3.61933358446002*^9, 3.619774951086495*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"FindInstance", "[", 
   RowBox[{"conditions", ",", 
    RowBox[{"Join", "[", 
     RowBox[{
     "xi1", ",", "xi2", ",", "xi3", ",", "et1", ",", "et2", ",", "et3"}], 
     "]"}], ",", "Integers", ",", "5"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.6048212704228287`*^9, 3.604821274601413*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xix1", "\[Rule]", "17"}], ",", 
      RowBox[{"xix2", "\[Rule]", "17"}], ",", 
      RowBox[{"xix3", "\[Rule]", 
       RowBox[{"-", "902"}]}], ",", 
      RowBox[{"xix4", "\[Rule]", "49"}], ",", 
      RowBox[{"xiy1", "\[Rule]", "147"}], ",", 
      RowBox[{"xiy2", "\[Rule]", 
       RowBox[{"-", "147"}]}], ",", 
      RowBox[{"xiy3", "\[Rule]", 
       RowBox[{"-", "830"}]}], ",", 
      RowBox[{"xiy4", "\[Rule]", "110"}], ",", 
      RowBox[{"xiz1", "\[Rule]", "71"}], ",", 
      RowBox[{"xiz2", "\[Rule]", 
       RowBox[{"-", "579"}]}], ",", 
      RowBox[{"xiz3", "\[Rule]", 
       RowBox[{"-", "71"}]}], ",", 
      RowBox[{"xiz4", "\[Rule]", 
       RowBox[{"-", "329"}]}], ",", 
      RowBox[{"etx1", "\[Rule]", 
       RowBox[{"-", "220"}]}], ",", 
      RowBox[{"etx2", "\[Rule]", 
       RowBox[{"-", "220"}]}], ",", 
      RowBox[{"etx3", "\[Rule]", 
       RowBox[{"-", "687"}]}], ",", 
      RowBox[{"etx4", "\[Rule]", 
       RowBox[{"-", "534"}]}], ",", 
      RowBox[{"ety1", "\[Rule]", "37"}], ",", 
      RowBox[{"ety2", "\[Rule]", 
       RowBox[{"-", "37"}]}], ",", 
      RowBox[{"ety3", "\[Rule]", "476"}], ",", 
      RowBox[{"ety4", "\[Rule]", 
       RowBox[{"-", "487"}]}], ",", 
      RowBox[{"etz1", "\[Rule]", "163"}], ",", 
      RowBox[{"etz2", "\[Rule]", "488"}], ",", 
      RowBox[{"etz3", "\[Rule]", 
       RowBox[{"-", "163"}]}], ",", 
      RowBox[{"etz4", "\[Rule]", 
       RowBox[{"-", "451"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xix1", "\[Rule]", "226"}], ",", 
      RowBox[{"xix2", "\[Rule]", "226"}], ",", 
      RowBox[{"xix3", "\[Rule]", "778"}], ",", 
      RowBox[{"xix4", "\[Rule]", "49"}], ",", 
      RowBox[{"xiy1", "\[Rule]", 
       RowBox[{"-", "9"}]}], ",", 
      RowBox[{"xiy2", "\[Rule]", "9"}], ",", 
      RowBox[{"xiy3", "\[Rule]", "506"}], ",", 
      RowBox[{"xiy4", "\[Rule]", 
       RowBox[{"-", "141"}]}], ",", 
      RowBox[{"xiz1", "\[Rule]", "71"}], ",", 
      RowBox[{"xiz2", "\[Rule]", "874"}], ",", 
      RowBox[{"xiz3", "\[Rule]", 
       RowBox[{"-", "71"}]}], ",", 
      RowBox[{"xiz4", "\[Rule]", 
       RowBox[{"-", "1128"}]}], ",", 
      RowBox[{"etx1", "\[Rule]", 
       RowBox[{"-", "218"}]}], ",", 
      RowBox[{"etx2", "\[Rule]", 
       RowBox[{"-", "218"}]}], ",", 
      RowBox[{"etx3", "\[Rule]", 
       RowBox[{"-", "352"}]}], ",", 
      RowBox[{"etx4", "\[Rule]", "993"}], ",", 
      RowBox[{"ety1", "\[Rule]", 
       RowBox[{"-", "88"}]}], ",", 
      RowBox[{"ety2", "\[Rule]", "88"}], ",", 
      RowBox[{"ety3", "\[Rule]", "285"}], ",", 
      RowBox[{"ety4", "\[Rule]", "593"}], ",", 
      RowBox[{"etz1", "\[Rule]", 
       RowBox[{"-", "183"}]}], ",", 
      RowBox[{"etz2", "\[Rule]", "488"}], ",", 
      RowBox[{"etz3", "\[Rule]", "183"}], ",", 
      RowBox[{"etz4", "\[Rule]", "273"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xix1", "\[Rule]", "17"}], ",", 
      RowBox[{"xix2", "\[Rule]", "17"}], ",", 
      RowBox[{"xix3", "\[Rule]", "778"}], ",", 
      RowBox[{"xix4", "\[Rule]", 
       RowBox[{"-", "997"}]}], ",", 
      RowBox[{"xiy1", "\[Rule]", 
       RowBox[{"-", "9"}]}], ",", 
      RowBox[{"xiy2", "\[Rule]", "9"}], ",", 
      RowBox[{"xiy3", "\[Rule]", "1001"}], ",", 
      RowBox[{"xiy4", "\[Rule]", 
       RowBox[{"-", "141"}]}], ",", 
      RowBox[{"xiz1", "\[Rule]", 
       RowBox[{"-", "69"}]}], ",", 
      RowBox[{"xiz2", "\[Rule]", "457"}], ",", 
      RowBox[{"xiz3", "\[Rule]", "69"}], ",", 
      RowBox[{"xiz4", "\[Rule]", 
       RowBox[{"-", "893"}]}], ",", 
      RowBox[{"etx1", "\[Rule]", "16"}], ",", 
      RowBox[{"etx2", "\[Rule]", "16"}], ",", 
      RowBox[{"etx3", "\[Rule]", 
       RowBox[{"-", "687"}]}], ",", 
      RowBox[{"etx4", "\[Rule]", "1177"}], ",", 
      RowBox[{"ety1", "\[Rule]", "37"}], ",", 
      RowBox[{"ety2", "\[Rule]", 
       RowBox[{"-", "37"}]}], ",", 
      RowBox[{"ety3", "\[Rule]", "285"}], ",", 
      RowBox[{"ety4", "\[Rule]", 
       RowBox[{"-", "1236"}]}], ",", 
      RowBox[{"etz1", "\[Rule]", "212"}], ",", 
      RowBox[{"etz2", "\[Rule]", "193"}], ",", 
      RowBox[{"etz3", "\[Rule]", 
       RowBox[{"-", "212"}]}], ",", 
      RowBox[{"etz4", "\[Rule]", 
       RowBox[{"-", "451"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xix1", "\[Rule]", 
       RowBox[{"-", "68"}]}], ",", 
      RowBox[{"xix2", "\[Rule]", 
       RowBox[{"-", "68"}]}], ",", 
      RowBox[{"xix3", "\[Rule]", "778"}], ",", 
      RowBox[{"xix4", "\[Rule]", "271"}], ",", 
      RowBox[{"xiy1", "\[Rule]", "111"}], ",", 
      RowBox[{"xiy2", "\[Rule]", 
       RowBox[{"-", "111"}]}], ",", 
      RowBox[{"xiy3", "\[Rule]", "405"}], ",", 
      RowBox[{"xiy4", "\[Rule]", "110"}], ",", 
      RowBox[{"xiz1", "\[Rule]", "151"}], ",", 
      RowBox[{"xiz2", "\[Rule]", "457"}], ",", 
      RowBox[{"xiz3", "\[Rule]", 
       RowBox[{"-", "151"}]}], ",", 
      RowBox[{"xiz4", "\[Rule]", "833"}], ",", 
      RowBox[{"etx1", "\[Rule]", "84"}], ",", 
      RowBox[{"etx2", "\[Rule]", "84"}], ",", 
      RowBox[{"etx3", "\[Rule]", 
       RowBox[{"-", "687"}]}], ",", 
      RowBox[{"etx4", "\[Rule]", "993"}], ",", 
      RowBox[{"ety1", "\[Rule]", "37"}], ",", 
      RowBox[{"ety2", "\[Rule]", 
       RowBox[{"-", "37"}]}], ",", 
      RowBox[{"ety3", "\[Rule]", "285"}], ",", 
      RowBox[{"ety4", "\[Rule]", "470"}], ",", 
      RowBox[{"etz1", "\[Rule]", "212"}], ",", 
      RowBox[{"etz2", "\[Rule]", 
       RowBox[{"-", "839"}]}], ",", 
      RowBox[{"etz3", "\[Rule]", 
       RowBox[{"-", "212"}]}], ",", 
      RowBox[{"etz4", "\[Rule]", "1152"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xix1", "\[Rule]", "17"}], ",", 
      RowBox[{"xix2", "\[Rule]", "17"}], ",", 
      RowBox[{"xix3", "\[Rule]", "769"}], ",", 
      RowBox[{"xix4", "\[Rule]", "1248"}], ",", 
      RowBox[{"xiy1", "\[Rule]", "147"}], ",", 
      RowBox[{"xiy2", "\[Rule]", 
       RowBox[{"-", "147"}]}], ",", 
      RowBox[{"xiy3", "\[Rule]", "1001"}], ",", 
      RowBox[{"xiy4", "\[Rule]", "835"}], ",", 
      RowBox[{"xiz1", "\[Rule]", 
       RowBox[{"-", "69"}]}], ",", 
      RowBox[{"xiz2", "\[Rule]", "451"}], ",", 
      RowBox[{"xiz3", "\[Rule]", "69"}], ",", 
      RowBox[{"xiz4", "\[Rule]", "833"}], ",", 
      RowBox[{"etx1", "\[Rule]", "149"}], ",", 
      RowBox[{"etx2", "\[Rule]", "149"}], ",", 
      RowBox[{"etx3", "\[Rule]", "62"}], ",", 
      RowBox[{"etx4", "\[Rule]", "1177"}], ",", 
      RowBox[{"ety1", "\[Rule]", "37"}], ",", 
      RowBox[{"ety2", "\[Rule]", 
       RowBox[{"-", "37"}]}], ",", 
      RowBox[{"ety3", "\[Rule]", "430"}], ",", 
      RowBox[{"ety4", "\[Rule]", "470"}], ",", 
      RowBox[{"etz1", "\[Rule]", "163"}], ",", 
      RowBox[{"etz2", "\[Rule]", 
       RowBox[{"-", "839"}]}], ",", 
      RowBox[{"etz3", "\[Rule]", 
       RowBox[{"-", "163"}]}], ",", 
      RowBox[{"etz4", "\[Rule]", 
       RowBox[{"-", "802"}]}]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.60404353374229*^9, 3.6040435387080927`*^9}, {
   3.604043582136792*^9, 3.604043609408518*^9}, 3.6040437323439007`*^9, 
   3.604043823099341*^9, 3.604043929678233*^9, 3.6040444994070807`*^9, 
   3.6040445429906197`*^9, 3.6040446005845222`*^9, 3.604051430749251*^9, 
   3.604052328170712*^9, 3.604057182839678*^9, 3.6043009958982277`*^9, 
   3.6043010525128107`*^9, 3.6043012034532013`*^9, 3.604301238323127*^9, {
   3.6043012839251966`*^9, 3.604301299525257*^9}, 3.604301583968801*^9, {
   3.604302168395913*^9, 3.60430223334405*^9}, {3.604302591771811*^9, 
   3.604302610748776*^9}, {3.604303550602255*^9, 3.6043035522986717`*^9}, 
   3.604304057768405*^9, 3.60439769403824*^9, 3.604397910661558*^9, 
   3.604398298438121*^9, 3.6043983402146893`*^9, 3.604398546896904*^9, 
   3.604398640321415*^9, 3.604401037391128*^9, 3.60440202597158*^9, 
   3.6044021642437468`*^9, 3.604403371375636*^9, 3.6044057773886433`*^9, 
   3.6046493091027937`*^9, 3.604653251230954*^9, 3.604813406238997*^9, 
   3.604818280390945*^9, 3.60482118765982*^9, 3.604821372759521*^9, 
   3.604826659682489*^9, 3.604826695642488*^9, 3.604827070919959*^9, 
   3.604901626455186*^9, 3.6049975066072474`*^9, 3.60499783661518*^9, 
   3.604997996346459*^9, 3.60499826011628*^9, 3.6049986773414497`*^9, 
   3.604999021203876*^9, 3.604999564966835*^9, 3.605322217191379*^9, 
   3.605329245649239*^9, 3.605344877440589*^9, 3.6054993592592154`*^9, 
   3.605499758088213*^9, 3.6055002691454773`*^9, 3.605500978030263*^9, 
   3.605517525657899*^9, 3.6055185881324244`*^9, 3.606019706041814*^9, 
   3.606624505581765*^9, 3.60725479801544*^9, 3.607746833548758*^9, 
   3.608458666329492*^9, 3.608461044694048*^9, 3.608611354159727*^9, 
   3.6089722434812326`*^9, 3.609039058330908*^9, 3.60906550960861*^9, 
   3.609130527865802*^9, 3.610078784355793*^9, 3.610167250273677*^9, 
   3.6101830092936487`*^9, 3.61076873779526*^9, 3.61432121480719*^9, 
   3.6144885934916267`*^9, 3.614495197884832*^9, 3.6145005623386583`*^9, 
   3.614500787525106*^9, 3.614500928739376*^9, 3.6145056572218637`*^9, 
   3.6145771332572393`*^9, 3.6149371433971663`*^9, 3.615529827622561*^9, 
   3.615633725998543*^9, 3.6162145874226437`*^9, 3.617336088075095*^9, 
   3.6173382085499887`*^9, 3.618217355152993*^9, 3.619333584713401*^9, 
   3.619774951188404*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xi1", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302242426052*^9, 3.6043022482821207`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"17", ",", "17", ",", 
    RowBox[{"-", "902"}], ",", "49"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz11Ik2EcBfCpFQOtZEXLrXppF4nhRBxWzCQfZVZDM2wWFIG5BCv7mGCC
t60VXQy0zV4MDIpma3PN5bzog+YiqrGSoDad7bOMeOpVp5RhzjrPxZ8f5+Yc
/ttbLja2ZolEIg2ubnd5uT1CyWlRsIXpyhyYYNqaeelDOHBubDwMTbIwZW6M
NsgnINd5Us3cs7C2likPOA2TMCSpEZjm7OsrzAdvL1gjsEBf5p9iPfSeo3GK
ksDjM7wO9q62BO/CzZ4m5X3Ie7t4G8wP8I+YO4vFWjs8/jXaxYzpGuLv4BVr
k3sZupOWSWZvj1lgbhKM6zLQandUM/OHBs8zz/64M8xMBUsrb3+mpO3niGMA
9mtc9TbYbfj+NA0VGb/ADB0ZVM7DgxwxMZdV3v4luLT+GvcX7rpJxmejlIz4
yjhpnBKj25fUJijZl1YpKpKUXFYf8valsG/pi92CMYemJgnFVZe6e75Qcjik
lXmgO2901QuY2PDvZQy2u3LfDE1TMv2xyJmA5rF658o3Sj6cSO1/JVCirCrN
ls4gdz6vkEHhU11kCywxGX4z29QK8Vaojxce4+AOmb2yGhqfza2Zh/4bvsLa
OewUdLw+laYki+Tory7gH4+k3QQXJa3Dql+UbHsvf6JbpORomO4t/kPJf+PE
RBE=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"et1", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302257691936*^9, 3.6043022577554398`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "220"}], ",", 
    RowBox[{"-", "220"}], ",", 
    RowBox[{"-", "687"}], ",", 
    RowBox[{"-", "534"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwdz19Ik3EUxvGVIoUi1c3AP40NKokEWypMkzhKbzDdkLeh3RSkDcO24hWi
WlQ3ORUGUdC2TEzKVnNzumJCqTSV0AtTlEg3a26rVpyabWolc63Or4uHz90D
X2nDBV67RSQSHaWZ9dWldj+CUchqZI6Ibywyp996xX1kh3VsdoHs4ReQKb2o
yV0kTTMny5jOkmyOebOpX/CRweNVUaa6oD3FPJg4f9dPXu+Qjy/9/+l18Euk
otmqIfeo5qYfknW5LYWPyaL6y1Yb2au/N8B8btmrtJORK4FLzO/ptctvyD5X
3WCSbN5u9jGr/beizKn51uw/ZMzgrGQOWJ7qmdLhHjez66y84v57BMMOj6Ob
/CK4VDYyfOfrcJyMyCaiTN70pHCV7DwCRuZujaczQa6VtUk2Sd0gzP74gGAL
yCXiZYShd96QMohwTVosKw8hSEbUHnMYof2TOWAhM3muKkTqdgqG2x8Rkkll
zjOypHQo/RWZ4v5OBEhDPHOq/zPCmeL9ziB5tUbtTEUQRk3hY6+jCA+airaK
VxDWH42W55AurcqfR9a+EH4xZxpk2/LJyfyCegkpnLBXVJJpiVjGKulwe/dx
MeqtaZk8HUc4dS6tsXUNQe7bpTOS6wqt+9BPBEVW3kvNbwQu49vhAxsI/wAF
G0Se
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xi2", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302242426052*^9, 3.604302271492434*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"147", ",", 
    RowBox[{"-", "147"}], ",", 
    RowBox[{"-", "830"}], ",", "110"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604302249663*^9, 3.604302272365456*^9}, 
   3.604302625044812*^9, 3.60430355755547*^9, 3.604304065473878*^9, 
   3.604397694054823*^9, 3.6043979107329483`*^9, 3.6043982986436996`*^9, 
   3.6043985469382*^9, 3.604398640448835*^9, 3.604401037430286*^9, 
   3.604402026111125*^9, 3.604402164259289*^9, 3.604403371472107*^9, 
   3.604405777583832*^9, 3.604649309148058*^9, 3.604653251337596*^9, 
   3.604813415889946*^9, 3.604818284268214*^9, 3.6048211877824078`*^9, 
   3.60482137280995*^9, 3.6048267058965893`*^9, 3.6048270709707537`*^9, 
   3.604901626520162*^9, 3.604997506771797*^9, 3.604997836715526*^9, 
   3.604997996529029*^9, 3.604998260210477*^9, 3.604998677420588*^9, 
   3.604999021299811*^9, 3.6049995650450583`*^9, 3.605322217625547*^9, 
   3.605329245662465*^9, 3.605344877456551*^9, 3.605499359271729*^9, 
   3.605499758102728*^9, 3.6055002692404127`*^9, 3.605500978042571*^9, 
   3.6055175256703777`*^9, 3.605518588230302*^9, 3.6060197060562162`*^9, 
   3.606624505593152*^9, 3.607254798030802*^9, 3.6077468336336727`*^9, 
   3.608458666473112*^9, 3.608461044724474*^9, 3.608611354218421*^9, 
   3.608972243555984*^9, 3.6090390583482533`*^9, 3.609065509699834*^9, 
   3.609130527983253*^9, 3.610078784380374*^9, 3.6101830093323193`*^9, 
   3.610768738461611*^9, 3.614321215085484*^9, 3.6144885935183268`*^9, 
   3.614495197930686*^9, 3.614500562470319*^9, 3.614500787558488*^9, 
   3.614500929079753*^9, 3.614505657258774*^9, 3.614577133297474*^9, 
   3.614937143538807*^9, 3.615633726026651*^9, 3.616214587576919*^9, 
   3.617336088111557*^9, 3.617338208593074*^9, 3.618217355167592*^9, 
   3.619333584884623*^9, 3.619774951350017*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"et2", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302257691936*^9, 3.604302274547565*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"37", ",", 
    RowBox[{"-", "37"}], ",", "476", ",", 
    RowBox[{"-", "487"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604302258357127*^9, 3.604302275117543*^9}, 
   3.604302626788999*^9, 3.60430355907458*^9, 3.604304066313738*^9, 
   3.604397694059794*^9, 3.604397910786858*^9, 3.604398298648159*^9, 
   3.604398546946052*^9, 3.604398640453637*^9, 3.604401037448138*^9, 
   3.6044020261168747`*^9, 3.604402164263982*^9, 3.604403371555127*^9, 
   3.604405777587859*^9, 3.6046493091538754`*^9, 3.604653251350864*^9, 
   3.6048134169417677`*^9, 3.6048182850746202`*^9, 3.604821187845663*^9, 
   3.6048213728250227`*^9, 3.604826706889058*^9, 3.6048270709756813`*^9, 
   3.604901626525436*^9, 3.6049975067766047`*^9, 3.6049978368098717`*^9, 
   3.6049979965343122`*^9, 3.60499826025072*^9, 3.604998677454093*^9, 
   3.604999021305183*^9, 3.604999565049716*^9, 3.6053222176321507`*^9, 
   3.605329245667131*^9, 3.605344877460978*^9, 3.605499359275626*^9, 
   3.6054997581069727`*^9, 3.605500269244377*^9, 3.6055009780460052`*^9, 
   3.605517525674111*^9, 3.605518588318358*^9, 3.6060197060594473`*^9, 
   3.606624505596603*^9, 3.6072547980357103`*^9, 3.607746833707973*^9, 
   3.608458666478507*^9, 3.6084610447296886`*^9, 3.608611354223381*^9, 
   3.608972243561491*^9, 3.609039058354315*^9, 3.6090655097046347`*^9, 
   3.60913052798849*^9, 3.610078784385572*^9, 3.61018300933844*^9, 
   3.610768738479254*^9, 3.614321215090457*^9, 3.614488593523171*^9, 
   3.614495197934304*^9, 3.614500562531458*^9, 3.614500787562133*^9, 
   3.614500929083994*^9, 3.614505657262574*^9, 3.6145771333026867`*^9, 
   3.614937143546331*^9, 3.615633726031358*^9, 3.61621458758318*^9, 
   3.617336088119769*^9, 3.617338208596867*^9, 3.61821735517174*^9, 
   3.6193335848895683`*^9, 3.6197749513553877`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xi3", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302242426052*^9, 3.6043022482821207`*^9}, 
   3.604302279573079*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"71", ",", 
    RowBox[{"-", "579"}], ",", 
    RowBox[{"-", "71"}], ",", 
    RowBox[{"-", "329"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0FtIk2EAxvGvkhGzAiMPTGU4gowywrYl6YR3iwljK1ofJAQDV0kXroMU
oRZ1UTZGp4XW2GA0I235VSpImKA5kyxmWgS1Q7pNHPLqzE06UG71vF08/O6e
i3+J+bTxxBqO47SYfq9C4Q1ScsWUrmD6N9iPM2+eygkwc4vNBU/gGbFv8jN8
bA5Q5mKYL/wC9ddN+5ixvM1aZpWp72wA0kM1CWZDuzXDLHSfaw9C31K5LwTH
HV3dxhAlsgMWBw8/lFRPdMAk5y97BD++bXF0Qqvd+Zx5y9Ok88LXd2MXmFvT
h2cmIGc/2rMKP406A0x5fVuCKVVZN6Wh7/0zNfPGOsHC5OYe9v53sELlClPy
6lJ/txsu3O4xdEL58vxgEu4QjSWYQytdZSmYrdC0Mt3JF87fsIO3Sf/AppOa
yW9fKUml5dL8GUr260eiugh6TSlllVFKLl429t+Locewa/o+rI3rNFG4KD7f
bJ+lJC4YJH1QJBrIGoZt7/6OTsOMMmf86RwlassuIQIF10EhE6ekdONszViC
klB499r8JfRYHaqUQBtvDBbBiLvxB/OOX7a+GF5Vbj8ihZIpr0oNq/NSohQU
u0a2aZfxG298U5ekxODJOnZtBb1KtzS0wgfl9b17vlMy7yl6yf+kZMC2ULXz
FyX/ALtyS4U=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"et3", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302257691936*^9, 3.604302282395863*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"163", ",", "488", ",", 
    RowBox[{"-", "163"}], ",", 
    RowBox[{"-", "451"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604302258357127*^9, 3.604302282909603*^9}, 
   3.60430262994051*^9, 3.604303561928893*^9, 3.604304067722108*^9, 
   3.6043976942770987`*^9, 3.604397910797686*^9, 3.604398298706767*^9, 
   3.604398546972404*^9, 3.6043986405743427`*^9, 3.6044010375854483`*^9, 
   3.604402026235731*^9, 3.604402164382666*^9, 3.604403371648909*^9, 
   3.604405777769444*^9, 3.6046493093951187`*^9, 3.604653251432251*^9, 
   3.6048134189565907`*^9, 3.6048182870277452`*^9, 3.604821187887513*^9, 
   3.604821372926055*^9, 3.60482670871699*^9, 3.604827071101708*^9, 
   3.6049016266477127`*^9, 3.6049975069216337`*^9, 3.60499783686266*^9, 
   3.604997996669631*^9, 3.6049982603465233`*^9, 3.604998677547186*^9, 
   3.6049990214036922`*^9, 3.604999565156975*^9, 3.605322217815465*^9, 
   3.605329245718276*^9, 3.605344877524098*^9, 3.6054993593340054`*^9, 
   3.60549975816147*^9, 3.605500269328226*^9, 3.6055009781040297`*^9, 
   3.605517525818576*^9, 3.6055185883266573`*^9, 3.606019706114221*^9, 
   3.606624505660067*^9, 3.6072547980569143`*^9, 3.6077468337174263`*^9, 
   3.6084586665872927`*^9, 3.608461044880332*^9, 3.608611354366843*^9, 
   3.608972243686406*^9, 3.609039058436228*^9, 3.609065509789571*^9, 
   3.609130527997939*^9, 3.610078784550555*^9, 3.610183009462583*^9, 
   3.610768738654996*^9, 3.614321215147579*^9, 3.614488593541572*^9, 
   3.6144951979753036`*^9, 3.614500562579043*^9, 3.614500787586419*^9, 
   3.614500929100425*^9, 3.614505657293103*^9, 3.614577133334853*^9, 
   3.614937143569583*^9, 3.615633726055202*^9, 3.616214587625496*^9, 
   3.617336088150022*^9, 3.617338208634859*^9, 3.6182173551998577`*^9, 
   3.619333584940189*^9, 3.6197749513933697`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xi1", "/", "et1"}], " ", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302683707705*^9, 3.604302694812475*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["17", "220"]}], ",", 
    RowBox[{"-", 
     FractionBox["17", "220"]}], ",", 
    FractionBox["902", "687"], ",", 
    RowBox[{"-", 
     FractionBox["49", "534"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604302686830703*^9, 3.6043026953386793`*^9}, 
   3.604303567196437*^9, 3.60430407109601*^9, 3.604397694525444*^9, 
   3.604397910929071*^9, 3.6043982987196207`*^9, 3.604398546990081*^9, 
   3.604398640586755*^9, 3.604401037695382*^9, 3.6044020263585863`*^9, 
   3.604402164408586*^9, 3.6044033717408447`*^9, 3.604405777786632*^9, 
   3.6046493094993067`*^9, 3.604653251465596*^9, 3.6048182877260933`*^9, 
   3.604821187904893*^9, 3.604821372953458*^9, 3.6048267093537407`*^9, 
   3.604827071119484*^9, 3.604901626669372*^9, 3.604997507011104*^9, 
   3.604997836896015*^9, 3.6049979969040413`*^9, 3.6049982604061003`*^9, 
   3.604998677569916*^9, 3.604999021472476*^9, 3.60499956518815*^9, 
   3.6053222178645353`*^9, 3.6053292457640753`*^9, 3.6053448775292063`*^9, 
   3.605499359342333*^9, 3.6054997581654863`*^9, 3.605500269337385*^9, 
   3.6055009781076517`*^9, 3.605517525889989*^9, 3.6055185883308353`*^9, 
   3.606019706120634*^9, 3.606624505663879*^9, 3.607254798065781*^9, 
   3.607746833721847*^9, 3.608458666598359*^9, 3.608461044896954*^9, 
   3.6086113543897877`*^9, 3.608972243709255*^9, 3.609039058444697*^9, 
   3.609065509794949*^9, 3.609130528088194*^9, 3.610078784562108*^9, 
   3.61018300947709*^9, 3.6107687389862537`*^9, 3.6143212151542397`*^9, 
   3.614488593546371*^9, 3.614495197979726*^9, 3.6145005625921288`*^9, 
   3.6145007875906353`*^9, 3.6145009291077137`*^9, 3.614505657297518*^9, 
   3.614577133339802*^9, 3.614937143575511*^9, 3.615633726060204*^9, 
   3.616214587632012*^9, 3.617336088156651*^9, 3.617338208639544*^9, 
   3.6182173552081623`*^9, 3.6193335849456043`*^9, 3.61977495142463*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xi2", "/", "et2"}], " ", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.604302709791547*^9, 3.604302710623209*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox["147", "37"], ",", 
    FractionBox["147", "37"], ",", 
    RowBox[{"-", 
     FractionBox["415", "238"]}], ",", 
    RowBox[{"-", 
     FractionBox["110", "487"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0FtIk3EYx/Fl68DACJXJ1DY7UAS5iNiFzQXPJoavB8K9FhEoKZmVGnZg
sYsuYjpIDXZRreZUglY6S1caMYXFyIzAJhHa3uXmSgue7bV8O2hZ0vO/+PG5
/fHdWnOu4uQamUxmorWHE029AsIZZYbANCa1qj7SvjIZmiaHXseQuSN5LPs9
qX5bfYCZM6ksYvpPP20Ok7nuEpGp4DtWmW/mLDcEcvRwfjBC8o5Bb0UEoeVs
s5MnX+oKtPfImsQVp4e0N3YPMK/9CHG95CPbnIW5QXckNkGa79YP/iWXI51h
Ztczt8iUG65v+kem5T0xMm9XDjQynYLHx9RG9AbXB4TnKX5vF/ku1VfmISE7
MbJIJhvGRGap1JcnkfUOUyuT7xm984c8WNehWSF/pxeGvs4gtB/XaTJjCC4u
GOdmEcbd+dv0cYRyq3n45keEKrU7eouUl5SZ4uRmu8Xq+ER9beVZj8k2cUQe
IKdUa19ESaUt7dXDeYSZob39syTXdqp/9TP9LZw/NCYiFPfsS8lcQKi0BvRZ
5Jdas5BDJmQXfjEDru0bt5BX7+8+qiFTFV6Dkdz5QFovkYr04K6ibwjDTRfH
TywiXCpeV9vyHUHVmdHQSkrROt/+nwiXz6v9/BLCBLdQsGcZ4T/5mjmP
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "/", "et3"}], " ", "/.", 
  RowBox[{"(", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ")"}]}]], "Input",
 CellChangeTimes->{{3.6043027159582863`*^9, 3.604302717251813*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox["71", "163"], ",", 
    RowBox[{"-", 
     FractionBox["579", "488"]}], ",", 
    FractionBox["71", "163"], ",", 
    FractionBox["329", "451"]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz11IU3EcxvGTVvQCXoS1nHMjhSKxok4QaUv+G1tgpSjOpje9WKS9MMqo
EBpJNoJeF6VSYc1InDPbUXcuciEcKiOwIV2Ux5qbpsGv5qaShaX0/C8ePjyX
33VHHCXHFgmCYMac1987vCqx9dkWlTuwqiitHWZlDoY+wfCHKHFrrlSkf4Yp
tkO53MttWis3VC+fGYK5r/bGuHa9e4HrSb54X4W3kvKVYViZJvlKhonJwtmm
Uthzw7H5GbTb65pa4beqJy+47tFEgReuoO8XuOdN5SMDcKK62v8PFnU+HuJG
pOYYN3z3dso8bJvvNnHnGqXTXFeZV+Luzsk3PvxCTJR7fc1QN9a1vxUeLfzR
OwUrVvbHuP5U36ZpGCm0uLiKEnwwB1uu3TT8hbMBSyj+ldhP8w6DZgT/qRIt
iBDr/LgzMy9KLKiUBRpGiSX8nnAjbN9ebI7Ck49qa91jxARDsbYL9uiCi/tg
6r7k12F48JLm3fNxYkar2BGBkljVsTBBzOkc3/MmRsz6dmuSZpKY7V5fnhbW
p9tUHaxrqJnlrh3MWpYBt53IPmCAa0Sf0QTlLTNLp+HygLLBmiCmtpzrPzxF
TB9fUnl1Bn3y6lMuOOk5Lom/iG2U9C9LfxO7kxHflfOH2H/aBzr/
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"test", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"res2", "//", "FCE"}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "et1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "et1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "et1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "xi1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "xi1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "xi1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"et1", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"et1", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"et2", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"xi1", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"xi1", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"xi2", ",", "xi3"}], "]"}]}]}], "}"}]}], "//", "Expand"}],
       ")"}], "/.", 
     RowBox[{"(", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "5", "]"}], "]"}], ")"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k2"}], ",", 
        RowBox[{"k1", "+", "k2"}]}], "]"}]}], ",", 
     RowBox[{"t", "\[Rule]", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k3"}], ",", 
        RowBox[{"k1", "+", "k3"}]}], "]"}]}], ",", 
     RowBox[{"u", "\[Rule]", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k4"}], ",", 
        RowBox[{"k1", "+", "k4"}]}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604044919922616*^9, 3.60404499611751*^9}, {
   3.604045030843133*^9, 3.604045115405238*^9}, {3.60404525665703*^9, 
   3.604045347385274*^9}, {3.604045440119811*^9, 3.604045460228119*^9}, {
   3.604045524588771*^9, 3.6040455907108917`*^9}, {3.604045658999003*^9, 
   3.604045677809423*^9}, {3.604045718580467*^9, 3.6040458894515657`*^9}, {
   3.604052336374317*^9, 3.604052337047551*^9}, {3.604302334013274*^9, 
   3.6043023435553913`*^9}, {3.6043038935203*^9, 3.60430397953152*^9}, {
   3.60439835099683*^9, 3.604398364183023*^9}, {3.604398552317583*^9, 
   3.604398560012455*^9}, 3.604398667169958*^9, 3.604813595039596*^9, {
   3.604813654347238*^9, 3.604813665101145*^9}, {3.604816341046517*^9, 
   3.604816364209515*^9}, {3.604816468725563*^9, 3.604816500789916*^9}, {
   3.6048168020116167`*^9, 3.6048168076460648`*^9}, {3.604818307505035*^9, 
   3.604818323951458*^9}, {3.6048264439302683`*^9, 3.604826574542885*^9}, {
   3.604826633254245*^9, 3.60482663586487*^9}, 3.604826797181094*^9, {
   3.6048268356307793`*^9, 3.604826912741125*^9}, {3.604831050175721*^9, 
   3.6048310536386127`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"457368426147050301", " ", "\[ImaginaryI]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604826914112611*^9, 3.604826961173862*^9, 3.60482707136092*^9, {
   3.6048310510856323`*^9, 3.604831075154731*^9}, 3.60490162721242*^9, 
   3.604997507404849*^9, 3.604997837131289*^9, 3.6049979970679293`*^9, 
   3.604998260738103*^9, 3.6049986777312317`*^9, 3.604999021662887*^9, 
   3.604999565411901*^9, 3.605322218165793*^9, 3.605329246015355*^9, 
   3.60534487767556*^9, 3.605499359481996*^9, 3.605499758301557*^9, 
   3.6055002694996347`*^9, 3.605500978247998*^9, 3.605517525980104*^9, 
   3.605518588515276*^9, 3.606019706264455*^9, 3.606624505809309*^9, 
   3.607254798170508*^9, 3.6077468338939743`*^9, 3.608458666825232*^9, 
   3.608461045200494*^9, 3.608611354921537*^9, 3.608972244013455*^9, 
   3.609039058621035*^9, 3.609065509962146*^9, 3.609130528267295*^9, 
   3.610078784894745*^9, 3.6101671410635843`*^9, 3.610167188987337*^9, 
   3.610167254723977*^9, 3.6101830097902937`*^9, 3.610768739402194*^9, 
   3.6143212152300386`*^9, 3.614488593595973*^9, 3.614495198054603*^9, 
   3.6145005627332172`*^9, 3.614500787651906*^9, 3.614500929157646*^9, 
   3.6145056573681097`*^9, 3.614577133389987*^9, 3.614937143638358*^9, 
   3.6155298486295567`*^9, 3.615633726112295*^9, 3.616214587694014*^9, 
   3.617336088214752*^9, 3.6173382087180853`*^9, 3.61821735539098*^9, 
   3.619333585032502*^9, 3.6197749515145483`*^9}]
}, Open  ]],

Cell["\<\
As a result, res2 and, hence, the eee varphi amplitude is nonzero before \
setting the varphi polarization to zero. This ends the numerical check.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604816788903462*^9, 3.604816793573476*^9}, {3.6048183350872383`*^9, 
  3.604818360610065*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"test", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"res2ward", "//", "FCE"}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k1", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "et1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "et1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "et1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k2", ",", "xi1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "xi1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k3", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "xi1"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"k4", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"et1", ",", "et2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"et1", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Eta]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"et2", ",", "et3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"xi1", ",", "xi2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "1"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"xi1", ",", "xi3"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"SPD", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "2"}], "]"}], ",", 
             RowBox[{"Subscript", "[", 
              RowBox[{"\[Xi]", ",", "3"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{"xi2", ",", "xi3"}], "]"}]}]}], "}"}]}], "//", "Expand"}],
       ")"}], "/.", 
     RowBox[{"(", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "5", "]"}], "]"}], ")"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k2"}], ",", 
        RowBox[{"k1", "+", "k2"}]}], "]"}]}], ",", 
     RowBox[{"t", "\[Rule]", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k3"}], ",", 
        RowBox[{"k1", "+", "k3"}]}], "]"}]}], ",", 
     RowBox[{"u", "\[Rule]", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k4"}], ",", 
        RowBox[{"k1", "+", "k4"}]}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604044919922616*^9, 3.60404499611751*^9}, {
   3.604045030843133*^9, 3.604045115405238*^9}, {3.60404525665703*^9, 
   3.604045347385274*^9}, {3.604045440119811*^9, 3.604045460228119*^9}, {
   3.604045524588771*^9, 3.6040455907108917`*^9}, {3.604045658999003*^9, 
   3.604045677809423*^9}, {3.604045718580467*^9, 3.6040458894515657`*^9}, {
   3.604052336374317*^9, 3.604052337047551*^9}, {3.604302334013274*^9, 
   3.6043023435553913`*^9}, {3.6043038935203*^9, 3.60430397953152*^9}, {
   3.60439835099683*^9, 3.604398364183023*^9}, {3.604398552317583*^9, 
   3.604398560012455*^9}, 3.604398667169958*^9, 3.604813595039596*^9, {
   3.604813654347238*^9, 3.604813665101145*^9}, {3.604816341046517*^9, 
   3.604816364209515*^9}, {3.604816468725563*^9, 3.604816500789916*^9}, {
   3.6048168020116167`*^9, 3.6048168076460648`*^9}, {3.604818307505035*^9, 
   3.604818323951458*^9}, {3.6048264439302683`*^9, 3.604826574542885*^9}, {
   3.604826633254245*^9, 3.60482663586487*^9}, 3.604826797181094*^9, {
   3.6048268356307793`*^9, 3.604826941417639*^9}, 3.6048310824083633`*^9, {
   3.604831118567481*^9, 3.6048311188269444`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "349090380091894"}], " ", "\[ImaginaryI]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.604826942907626*^9, 3.604826967033189*^9}, 
   3.604827071683913*^9, {3.6048310780197783`*^9, 3.604831083542856*^9}, {
   3.6048311156230583`*^9, 3.60483112013482*^9}, 3.604901627459691*^9, 
   3.604997507494638*^9, 3.604997837474228*^9, 3.604997997190207*^9, 
   3.604998260820619*^9, 3.604998678029985*^9, 3.60499902188722*^9, 
   3.604999565702551*^9, 3.6053222182913923`*^9, 3.605329246101087*^9, 
   3.605344877774559*^9, 3.605499359580139*^9, 3.605499758392173*^9, 
   3.60550026961967*^9, 3.605500978345623*^9, 3.6055175260550756`*^9, 
   3.605518588607815*^9, 3.606019706353256*^9, 3.606624505909123*^9, 
   3.607254798236731*^9, 3.607746833971037*^9, 3.608458667137135*^9, 
   3.608461045560541*^9, 3.608611355103177*^9, 3.60897224430123*^9, 
   3.6090390586986847`*^9, 3.609065510079171*^9, 3.609130528644517*^9, 
   3.610078785224852*^9, 3.610167201092413*^9, 3.6101672581081257`*^9, 
   3.6101830099378*^9, 3.610768739572453*^9, 3.614321215296002*^9, 
   3.6144885936709642`*^9, 3.614495198114254*^9, 3.614500562809554*^9, 
   3.6145007876969976`*^9, 3.614500929201647*^9, 3.614505657400013*^9, 
   3.614577133442959*^9, 3.61493714367969*^9, 3.615529861457633*^9, 
   3.6156337261509*^9, 3.616214587738406*^9, 3.617336088362102*^9, 
   3.617338208769541*^9, 3.618217355435047*^9, 3.619333585103861*^9, 
   3.6197749515988207`*^9}]
}, Open  ]],

Cell["\<\
As a result, res2ward is nonzero and thus the Ward identity is not satisfied. \
This ends the numerical check.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604816788903462*^9, 3.604816793573476*^9}, {3.6048183350872383`*^9, 
  3.604818360610065*^9}, {3.604818729844631*^9, 3.604818749649289*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "\[CurlyPhi]\[CurlyPhi]\[CurlyPhi]",
 "\[CurlyPhi]",
 " \[OpenCurlyDoubleQuote]amplitude\[CloseCurlyDoubleQuote] (",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "1"]}], TraditionalForm]]],
 "] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "2"]}], TraditionalForm]]],
 "] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "3"]}], TraditionalForm]]],
 "] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "4"]}], TraditionalForm]]],
 "]):"
}], "Subsection",
 CellChangeTimes->{{3.60480638059011*^9, 3.60480645410249*^9}, {
   3.604810122854487*^9, 3.604810125021324*^9}, {3.6048284433576717`*^9, 
   3.604828470417059*^9}, 3.614494897966407*^9, {3.614495406059661*^9, 
   3.614495412951213*^9}, {3.616221627812334*^9, 3.616221645155693*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diags", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "I", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"k", "[", 
              RowBox[{"1", ",", "i"}], "]"}]}], "-", 
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "i"}], "]"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"k", "[", 
              RowBox[{"1", ",", "j"}], "]"}]}], "-", 
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "j"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"4", "I", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"1", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"2", ",", "j"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"2", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"1", ",", "j"}], "]"}]}]}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], 
         RowBox[{"I", "/", "s"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "i", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"3", ",", "i"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "i"}], "]"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"3", ",", "j"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "j"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"4", "I", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"3", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"4", ",", "j"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"4", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"3", ",", "j"}], "]"}]}]}], ")"}]}]}], ")"}]}], "//", 
      "Expand"}], "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604828479521257*^9, 3.6048287033321047`*^9}, {
   3.604828792063397*^9, 3.604828792944559*^9}, {3.604828862733468*^9, 
   3.6048288640169487`*^9}, {3.604828914952465*^9, 3.60482892045315*^9}, {
   3.614494115239868*^9, 3.614494179322528*^9}, 3.614494897969986*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9, 3.6156337262419977`*^9, 
   3.616214587857943*^9, 3.617336088462047*^9, 3.617338208889761*^9, 
   3.618217355524699*^9, 3.619333585231035*^9, 3.619774951705454*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9, 3.6156337262419977`*^9, 
   3.616214587857943*^9, 3.617336088462047*^9, 3.617338208889761*^9, 
   3.618217355524699*^9, 3.619333585231035*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9, 3.6156337262419977`*^9, 
   3.616214587857943*^9, 3.617336088462047*^9, 3.617338208889761*^9, 
   3.618217355524699*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9, 3.6156337262419977`*^9, 
   3.616214587857943*^9, 3.617336088462047*^9, 3.617338208889761*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9, 3.6156337262419977`*^9, 
   3.616214587857943*^9, 3.617336088462047*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9, 3.6156337262419977`*^9, 
   3.616214587857943*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9, 3.6156337262419977`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9, 3.614937143772996*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9, 
   3.614577133557493*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9, 3.614505657504787*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9, 3.614500929304728*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9, 
   3.6145007877905293`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9, 3.614500562939382*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9, 3.614495198241507*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "s"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "t", " ", "u"}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "s"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.60482854177919*^9, 3.604828564476119*^9}, {
   3.604828679418599*^9, 3.604828703883197*^9}, 3.604828794733371*^9, 
   3.6048288643543863`*^9, 3.6048289262746468`*^9, 3.604901627563026*^9, 
   3.604997507684312*^9, 3.60499783758541*^9, 3.604997997401163*^9, 
   3.6049982610054502`*^9, 3.604998678221259*^9, 3.6049990220303297`*^9, 
   3.604999565889724*^9, 3.60532221863463*^9, 3.605329246282538*^9, 
   3.605344877871756*^9, 3.605499359685841*^9, 3.6054997584940577`*^9, 
   3.605500269713518*^9, 3.605500978464038*^9, 3.605517526214005*^9, 
   3.605518588780678*^9, 3.6060197064541893`*^9, 3.6066245060125313`*^9, 
   3.607254798353942*^9, 3.60774683414775*^9, 3.608458667335133*^9, 
   3.608461045791657*^9, 3.608611355239485*^9, 3.608972244406602*^9, 
   3.6090390588603487`*^9, 3.609065510174357*^9, 3.609130528832446*^9, 
   3.61007878548587*^9, 3.610183010308676*^9, 3.610768739710987*^9, 
   3.614321215448977*^9, 3.614488593768108*^9, 3.6144941801324368`*^9, 
   3.6144948979707737`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diagt", "=", 
  RowBox[{"Diags", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "t"}], ",", 
     RowBox[{"t", "\[Rule]", "s"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "a"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a"}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.60482871606101*^9, 3.604828801601062*^9}, {
   3.604828986118425*^9, 3.604828988239271*^9}, {3.614494188527193*^9, 
   3.614494244806863*^9}, 3.6144948979720383`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9, 
   3.6156337262681293`*^9, 3.6162145878975067`*^9, 3.617336088482869*^9, 
   3.617338208924426*^9, 3.6182173555529537`*^9, 3.61933358527567*^9, 
   3.61977495173076*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9, 
   3.6156337262681293`*^9, 3.6162145878975067`*^9, 3.617336088482869*^9, 
   3.617338208924426*^9, 3.6182173555529537`*^9, 3.61933358527567*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9, 
   3.6156337262681293`*^9, 3.6162145878975067`*^9, 3.617336088482869*^9, 
   3.617338208924426*^9, 3.6182173555529537`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9, 
   3.6156337262681293`*^9, 3.6162145878975067`*^9, 3.617336088482869*^9, 
   3.617338208924426*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9, 
   3.6156337262681293`*^9, 3.6162145878975067`*^9, 3.617336088482869*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9, 
   3.6156337262681293`*^9, 3.6162145878975067`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9, 
   3.6156337262681293`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9, 3.614937143792836*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9, 3.614577133588807*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9, 
   3.6145056575344133`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9, 3.614500929331087*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9, 3.614500787827867*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9, 
   3.614500562987089*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9, 3.61449519827806*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "t"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "u"}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["u", "2"]}], "t"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604828787041*^9, 3.604828802587933*^9}, 
   3.604828875255471*^9, 3.6048289334512987`*^9, 3.6048289887573357`*^9, 
   3.604901627668145*^9, 3.604997507722156*^9, 3.604997837690413*^9, 
   3.604997997436961*^9, 3.6049982610389633`*^9, 3.6049986783058443`*^9, 
   3.604999022088352*^9, 3.604999565917809*^9, 3.605322218805229*^9, 
   3.605329246712027*^9, 3.605344877936008*^9, 3.605499359750181*^9, 
   3.605499758551141*^9, 3.605500269801077*^9, 3.605500978528789*^9, 
   3.605517526292038*^9, 3.605518588991582*^9, 3.6060197065084352`*^9, 
   3.606624506079851*^9, 3.607254798380081*^9, 3.607746834396824*^9, 
   3.608458667445237*^9, 3.608461045936281*^9, 3.6086113553789062`*^9, 
   3.6089722444992113`*^9, 3.6090390591320763`*^9, 3.609065510262796*^9, 
   3.609130528924753*^9, 3.610078785644333*^9, 3.610183010421629*^9, 
   3.6107687398480177`*^9, 3.614321215502646*^9, 3.614488593788474*^9, 
   3.6144942461037703`*^9, 3.614494897972898*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diagu", "=", 
  RowBox[{"Diags", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "u"}], ",", 
     RowBox[{"u", "\[Rule]", "s"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "a"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a"}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.604828810681723*^9, 3.604828825315983*^9}, {
   3.604828992641189*^9, 3.6048289939253197`*^9}, {3.6144942568954973`*^9, 
   3.6144943072544107`*^9}, 3.614494897974142*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVy1sow2EcxvGRNKXhYoyw4UJOLUQ5td7NKSX8iTTKJoWmISk0lCwXlEMh
InahMDGHlMlYW8TGBWVOYxbq1Ry2nEd+78XT5+b5hoilVJULjUZLgAkf+YVz
FxgN9U6XEme5ZyKiW1BtNbGM13xtBLPPW5ac4OrE+hmRyVi0EVV5CsYv2NNk
4BOTw3R1RJZToyKGRpSnjV9iZOo3z0+C6fTt3BnwxOtb/QrG1R/biOqinRg7
yLNSciK9/nDsGxzWKtg/YBeTOnq+wqhEk872u8Zo1MdoybnBSJyaF5piwajz
tGFt+BajCrXWPAJuPkgFFrBnqr91wIpRDaM6YBlsTDxw04Dteo7ODPLlSXsL
dxgJiguUN+BLfofy7x4jJ2XP0tvgZ0py9XvCiEPJDf7gZCzPNwD889hPIXLa
ReeBYJOw7Z1YyI2iB4EnHnElbLDOupLGBzcdX+528E5nCM98gc4h2xW9YtTH
8q7sdmAkMwRL5KDnYKMq/g2jLUnkRtEHRhnRn6nRnxj9Ax8r9Sw=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAeLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glI7/n8k+0TkH565Iy62wegvs+1xxM/vnLslRBIbv38
yrH2jFxOG5DmmVS00fjrK8d9OVq7Qr6/cgQAg0rxNw==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBuLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glI7/n8k+0TkH565Iy62wegvs+1xxM/vnLslRBIbv38
yrH2jFxOG5DmmVS00fjrK0cAB+Hssg==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAuLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glI7/n8k+0TkH565Iy62wegvs+1xxM/vnLslRBIbv38
yrH2jFxOG5AGALCm6J0=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBOLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glI7/n8k+0TkH565Iy62wegvs+1xxM/vnLslRBIbv38
yhEAei/kJQ==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glI7/n8k+0TkH565Iy62wegvs+1xxM/vnIEAGaR4Gk=

  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+Lo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glI7/n8k+0TkH565Iy624dXjgBzItuU
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+Lo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glI7/n8k+0TkAYApIHWlg==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJDOfbzZ1glIAwAAs9Dc
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAeLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QPoKp1G4PJAGAIf3zEA=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0cH62hyy
QBoAMhjIoQ==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSJdEV38D0QD4TcW1

  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBOLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQrVCXeEsGSAMA2YvBPw==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAOLo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJA+h/nKWsQDQDeHL0w
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["s", "2"]}], "u"], "-", 
   FractionBox[
    RowBox[{"16", " ", "\[ImaginaryI]", " ", "s", " ", "t"}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["t", "2"]}], "u"]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+Lo107Bq26/cpzcszASRK/Uv5kIollkszJAdIx92f2z
QNrjVuWGP0B6y9ztN0G0KN/6tyB6o/8ivr9AuqPkjBOItlI+kguiJf7s3wii
lTRjbWffeeV4Y8K91fOAtAvHAd9lQPoK/6/dH4G0UcHltyB6d8hB3U9A2v5x
UBuI5ig4N+sXkJ52aJH8byDdLBp0/v3dV47h+13kxe+/cpwhePah14NXjkk2
/krWD185Nlwv3Drt0SvHhN2H7k0H0nue5zs/BNIdCyZUTXz8yjGTL0NqE5Au
MjvNsh9I1x1VOHIPSDu1WZ5Y+/SVo3NY4JoHQPpDQP2af89eOf4J+uR+9C1Q
3Q1LJvF3rxwVgtrOSALpeYb2YlJAGgABtLjw
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4varphi", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"s", " ", "t", " ", "u"}], ")"}]}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"s", " ", "t", " ", "u", 
          RowBox[{"(", 
           RowBox[{"Diags", "+", "Diagt", "+", "Diagu"}], ")"}]}], "//", 
         "Expand"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{"u", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "s"}], "-", "t"}]}], "}"}]}], "//", "Expand"}], 
     ")"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.6048293428898783`*^9, 3.604829347710195*^9}, {
   3.60482951554661*^9, 3.604829538428527*^9}, {3.6048295729653873`*^9, 
   3.604829575018993*^9}, {3.604829796609785*^9, 3.6048298214066257`*^9}, 
   3.614494897976062*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9, 3.615633726424223*^9, 
   3.616214587976018*^9, 3.617336088526898*^9, 3.617338209003512*^9, 
   3.618217355609832*^9, 3.6193335853776712`*^9, 3.619774951785131*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9, 3.615633726424223*^9, 
   3.616214587976018*^9, 3.617336088526898*^9, 3.617338209003512*^9, 
   3.618217355609832*^9, 3.6193335853776712`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9, 3.615633726424223*^9, 
   3.616214587976018*^9, 3.617336088526898*^9, 3.617338209003512*^9, 
   3.618217355609832*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9, 3.615633726424223*^9, 
   3.616214587976018*^9, 3.617336088526898*^9, 3.617338209003512*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9, 3.615633726424223*^9, 
   3.616214587976018*^9, 3.617336088526898*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9, 3.615633726424223*^9, 
   3.616214587976018*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9, 3.615633726424223*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9, 3.6149371438324842`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9, 
   3.614577133651854*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9, 3.6145056575958643`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9, 3.614500929380618*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9, 
   3.6145007878849688`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9, 3.614500563103677*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9, 3.61449519835257*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"32", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["s", "2"], "+", 
        RowBox[{"s", " ", "t"}], "+", 
        SuperscriptBox["t", "2"]}], ")"}], "2"]}], 
    RowBox[{"s", " ", "t", " ", "u"}]]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829529714363*^9, 3.604829538972487*^9}, 
   3.60482957548942*^9, {3.604829797131337*^9, 3.604829822202551*^9}, 
   3.604901627737039*^9, 3.6049975078898897`*^9, 3.604997837775724*^9, 
   3.6049979975050287`*^9, 3.6049982611600113`*^9, 3.6049986784499187`*^9, 
   3.604999022156396*^9, 3.604999566089801*^9, 3.605322219065556*^9, 
   3.6053292470271597`*^9, 3.6053448780659847`*^9, 3.605499359880124*^9, 
   3.605499758666172*^9, 3.605500270129469*^9, 3.605500978651381*^9, 
   3.6055175265280247`*^9, 3.6055185891751127`*^9, 3.606019706763164*^9, 
   3.6066245062170258`*^9, 3.60725479843349*^9, 3.607746834560075*^9, 
   3.60845866766295*^9, 3.608461046231077*^9, 3.608611355613467*^9, 
   3.608972244559619*^9, 3.609039059415699*^9, 3.609065510600636*^9, 
   3.609130529120367*^9, 3.610078785960835*^9, 3.6101830106491127`*^9, 
   3.6107687401075068`*^9, 3.614321215634268*^9, 3.614488593826313*^9, 
   3.614494897976809*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"s", "^", "2"}], " ", 
        RowBox[{"u", "^", "2"}]}], "+", " ", 
       RowBox[{
        RowBox[{"s", "^", "2"}], " ", 
        RowBox[{"t", "^", "2"}]}], "+", 
       RowBox[{
        RowBox[{"t", "^", "2"}], " ", 
        RowBox[{"u", "^", "2"}]}]}], "/.", 
      RowBox[{"{", 
       RowBox[{"u", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "s"}], "-", "t"}]}], "}"}]}], "//", "Expand"}], ")"}], 
   "-", 
   RowBox[{"amp4varphi", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "32"}], "I"}], ")"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6048293077740517`*^9, 3.604829322332304*^9}, {
   3.604829352945257*^9, 3.604829366584869*^9}, {3.6048295945312643`*^9, 
   3.604829624222543*^9}, 3.614494897978036*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9, 3.61563372644347*^9, 3.6162145880094624`*^9, 
   3.617336088553329*^9, 3.617338209044778*^9, 3.618217355640918*^9, 
   3.619333585429331*^9, 3.619774951813836*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9, 3.61563372644347*^9, 3.6162145880094624`*^9, 
   3.617336088553329*^9, 3.617338209044778*^9, 3.618217355640918*^9, 
   3.619333585429331*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9, 3.61563372644347*^9, 3.6162145880094624`*^9, 
   3.617336088553329*^9, 3.617338209044778*^9, 3.618217355640918*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9, 3.61563372644347*^9, 3.6162145880094624`*^9, 
   3.617336088553329*^9, 3.617338209044778*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9, 3.61563372644347*^9, 3.6162145880094624`*^9, 
   3.617336088553329*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9, 3.61563372644347*^9, 3.6162145880094624`*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9, 3.61563372644347*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9, 
   3.614937143855257*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9, 3.614577133686062*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9, 3.614505657629363*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["s", "2"], "+", 
       RowBox[{"s", " ", "t"}], "+", 
       SuperscriptBox["t", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", "t", " ", "u"}], "-", "1"}], ")"}]}], 
   RowBox[{"s", " ", "t", " ", "u"}]], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604829318539173*^9, 3.604829322674415*^9}, 
   3.604829367039171*^9, {3.604829595373789*^9, 3.604829624693849*^9}, 
   3.6048296851109247`*^9, 3.604901627843294*^9, 3.604997507959589*^9, 
   3.60499783780888*^9, 3.6049979976144667`*^9, 3.60499826128228*^9, 
   3.604998678545773*^9, 3.604999022192058*^9, 3.6049995661482897`*^9, 
   3.605322219108098*^9, 3.605329247349904*^9, 3.605344878125188*^9, 
   3.605499359935672*^9, 3.605499758716442*^9, 3.605500270218598*^9, 
   3.605500978705776*^9, 3.605517526607051*^9, 3.6055185892700453`*^9, 
   3.606019706819116*^9, 3.6066245062452097`*^9, 3.607254798459593*^9, 
   3.607746834630604*^9, 3.608458667766111*^9, 3.608461046543062*^9, 
   3.608611355807652*^9, 3.608972244650546*^9, 3.609039059517395*^9, 
   3.6090655107250957`*^9, 3.609130529211176*^9, 3.610078786212476*^9, 
   3.610183010766032*^9, 3.6107687402591763`*^9, 3.614321215702792*^9, 
   3.6144885938465843`*^9, 3.6144948979788017`*^9, 3.614495198392075*^9, 
   3.614500563159007*^9, 3.614500787914826*^9, 3.614500929409152*^9, 
   3.614501054276366*^9}]
}, Open  ]],

Cell["\<\
Hence, the result is -32i (su/t + st/u + tu/s). This is a priori non-zero.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.6044041482973137`*^9, 3.604404157841824*^9}, {3.604648554310869*^9, 
   3.6046486678278627`*^9}, {3.604648710643353*^9, 3.60464871601261*^9}, {
   3.604649065823064*^9, 3.604649092507543*^9}, {3.6048297524374857`*^9, 
   3.604829768550879*^9}, {3.6048299258436213`*^9, 3.604829931687984*^9}, 
   3.61449489797946*^9, {3.614500667222034*^9, 3.614500673188508*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "e\[CurlyPhi]\[CurlyPhi]",
 "\[CurlyPhi]",
 " \[OpenCurlyDoubleQuote]amplitude\[CloseCurlyDoubleQuote] (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"]}], TraditionalForm]]],
 "] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "2"]}], TraditionalForm]]],
 "] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "3"]}], TraditionalForm]]],
 "] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CurlyPhi]", "[", 
    SubscriptBox["k", "4"]}], TraditionalForm]]],
 "]):"
}], "Subsection",
 CellChangeTimes->{{3.60480638059011*^9, 3.60480645410249*^9}, {
   3.604810122854487*^9, 3.604810125021324*^9}, {3.6048284433576717`*^9, 
   3.604828470417059*^9}, {3.6048299366338663`*^9, 3.60482996071869*^9}, 
   3.614494897980048*^9, {3.614495419381094*^9, 3.614495424455171*^9}, {
   3.616221630724696*^9, 3.616221649389793*^9}}],

Cell[CellGroupData[{

Cell[BoxData["verEEVarphi"], "Input",
 CellChangeTimes->{3.6144948979802237`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVz1sow2EcxvH/JLmQiyWrobXdiIYybmyLF1EyoYWLKZscaluisKQVZS5I
kVNTElqtbfgLkxY3NGKtlDZz2pziZc6HtRl+78XT5/Lpy1W0VDYwKIrKhjF7
/xizJxgVbdomDKCm1bFADFAJnUYwMc9CmUCDsvfCAXbIe5Z+QOO97ZjYz1r3
E1PizLFhMFNymE+cc9vVRE2BnSYunjWKp04xEgz4TdOg++VAYgC5zEjbK/gR
cvuJqsG9tDfQq6jVETX0kT4IXrtMnBD4KZY5n88wir0p57AuMHqad/pKvBg9
tlTzhD6MlDndq+OXGOnWXOcT4GiztsAHSqnJruErjGYcbexlkF/lidwClW2p
2+dgBLd013ID/x0ysxdkNQyZf28xiqkJFO/4MRoOCyNYTxjx1LnxbLDsyi0k
7o80eRJBX532izifnB6dBI6Hs6o54J3IKs4HpYU/UW+gtdCZXPSCkX6/xy5/
xYheYdb3vYMPPJUOrFhspwWfGAXHMjak39BFB0X8AEb/aF38nw==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzVsog2EcgPFvWnIhF0tWDq3tZpFDmSuzeE1TMqGFC8qhoTaJwpJWlLkg
RU5NSazV2hw+YdLihkasldI+5w0TLxvmtMbwfy+efpcPv761XMmiKCoL4vT9
sebOMJJt2SaNoKbNsUgMUgldJjAxb4Eyg0ZV35UD7KzrXf4BTQ+2E+IAd8NH
TI61xITBTPlRPnGesbcQNVI7TVy6aJRMn2MkGvSZZ0Dm5VBuBPkctu0VfP9m
fET10H5aAHTX1+iIGvpYHwJvXWbeN/ghqXY+X2AU4y3lca8w8hucniI3Rk+t
lQKxByNVds/axDVGunXX5SQ41qyVekAFNdU9coPRrKM9fgVMrThlb4Oq9pSd
SzCCX7y34IV/Z7XFDXKVw5bfO4yiq4KFuz6MRsLiCK4fI0FLblw8WHLDiIkH
o02niaCnVvtJNAjTo5LAiXBWJQ+8z7FK8kFFwU9kALQWOIWyF4z0B732uleM
6FVOQ/8b+ChQ68CypQ5a9IFRaDxjU/GF0T+Rbfd8
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzU0ow2EcwPH/tOQghyWrobVdRDiYk1k8myiZkMxhislLjWRllrSaMgdS
pE1TEmulbZgwh8WFRqyVkr+X2YaJh3mZl5Zt+D2Hb5/jl6foa+hgUBQlgFgj
f4zFS4wqd1xGC6jp96wQo1Tm4DKYVW6nrKBFOeL3gOo23VocXH50nRPH2Nth
Ym66LS0BFklPxMQl2t1L1EjcDuKqr1M0d4WRYDxsnQfpt2OpBeSxmK538DNG
h4k9E4cFETCgaNETNY5T0w94d2blxsAvkdz76sMoLVTHZfsxejF7g9UBjJ77
ZHxhECNlyfCm4QYj/dbZtRGc6dZKgmAjNTs0dYvRgkfFWQfzmy6Yu6BSlbd3
DSbxag7sIfir5bYAyO6YtP3eY5TaHK3aD2M0lRAmsV8w4veWZXDA2ltaSDya
7rrIAoOt2m+iOacwJRs0JIplXPCh1CkSg40V8eQI6Kzw5lS+YWQ60rnb3jFy
bLDaRz/AJ36PHqxfHXAIvjD6B+QA8o0=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzU0ow2EcwPE/SQ7aYclqaG2XRTiMk1k8oymZpIUDZdNQI3GYJa22MgdS
kzZRElqtzcuEOSwuNJq1UvL3sjdv8TC2eWmx4fccvn2OX65ioFmZRlGUAGLq
/9KWrjCS7LnMFlAz6F0jJqi8YSuYX71K2UCLSh/0gmq5biMJWp9cF8Rx1m6E
WJhjZ6RAgfRUTFym3f1ETY3bQVz3d4vmrzEqm4jYFkA6eiK1gFxmhisGfvzQ
EWLf5HFJHAwpOgxEjeNs7hu8O7dxfsBPUbvvzY8R476Jwwpi9LriC9eHMHoZ
aOUJwxipKka3TTcYGXbOA2ZwpldbEwZl1OyI8RajRe8QexMsbrnM2AdVQ0UH
ATCd23C0eg9/dbs9BLKUU/bfB4yy2xJ1hxGMjClhOusVI15/VS4bbLylhUTP
dM9lPhju1H4RV/ilWQWgKVXeygEfK50iMSirTWbGQWetjy+JYjTn0bnlMYwc
W8yusXfwmddnAP8BXh/uEw==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzU0ow2EcwPE/SQ5yWLIaWnMRobyczOKZNSWTJHOYsmmoWYvDLGm1lTmQ
mrRpSkIrbV4mzGFxodGsldJmmA0TTzbbvCTb8HsO3z7HL0ui6JRmUBRVDdG0
fxkr1xjxDx1GM6gacW8Sv6nCsXWwqGmDsoBmmfbODSrFmu0UuP7iuCJO0Q8i
xLJ8a14arBFccImrPqecqGp22ohbtwOcxRuMaqcjliXQFzsXmEEWLcsRBz+S
vghxeOasMgEGJb06osp2afoBH70WZhL85Ig8b7cY5YU7mPQ7jKJrnlBrEKNX
hbCEHcJIVj+xZ7jHSLfvDRjB+SF1cwjsohbG9Q8YLbtHGTtgRbc/6wiUjZYf
B8BMVtvpRhj+SpE1CNKls9bfJ4xye75bTiIY6dPsTHoUoxJ5YwEDbH/wsYmu
uUF/ERjqU38R10qrcopBQ7pOyASfG+wcLtjFS2UnQDvPU8qPYWRyaZziOEa2
XVr/5DtG//wQ6UQ=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAGKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkH6YUPcNRC9R
1+OQBdLT/pqEywPpFzbbbZ2AdIjLH7ZPQHq7y3l1tw+vHGedbjye+PGVIwDA
GuTG
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB2Khpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkH6YUPcNRC9R
1+OQBdLT/pqEywPpFzbbbZ2AdIjLH7ZPQHq7y3l1tw+vHAGpo9+b
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA2Khpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkH6YUPcNRC9R
1+OQBdLT/pqEywPpFzbbbZ2AdIjLH7ZPQBoAulDbSA==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBWKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkH6YUPcNRC9R
1+OQBdLT/pqEywPpFzbbbZ2ANADwOtai
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAWKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkH6YUPcNRC9R
1+OQBdLT/pqEywNpAEi+0i4=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBmKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkH6YUPcNRC9R
1+OQBdIAxFjN1w==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAmKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkH6YUPcNRAMA
YOrKnw==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBGKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIPj0p/ZYMkAYAGuPFtA==

  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAGKhpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkg7ff4hjWIBgD73cDg
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    RowBox[{
     FormBox[
      SubscriptBox["k", "1"],
      TraditionalForm], "\[CenterDot]", 
     FormBox[
      SubscriptBox["k", "2"],
      TraditionalForm]}], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB2Khpv+Mi26/cnTbt2f6MiBdUXh2HYj+wSBdvhJIyzis
ZVgNpJdlN90/C6TLEhs3/AHSK1/uuQmi28V3vAXRmiJr+P4CaSPfS04gevGN
47kgusL5+EYQvf5umu3sO68cjbvfrp4HpG98OOO7DEgrCrHs+Qikv/y+8RZE
5/Sc1P0EpB8kxbaB6IqNV2f9AtJPrq+W/w2kv9rGnH9/95Uj39MAefH7rxzf
LTn/0OvBK8c3+eFK1g9fOWZb1Wyd9uiVY9u26/emA+kpGXXOD4F0CMOMqomP
XzkuOFsktQlI64TdYtkPpLOLtI7cA9JMij4n1j4F2l8Ws+YBkBZP7Vvz79kr
R56IH+5H375ynPjXmkn83StHpVx7MSkgDQAC67xo
  "]]
}, Open  ]],

Cell["\<\
Modify verEEVarphi by eliminating k2 = -k1-k2 because it is now an internal \
momentum. Moreover, substitute (cd) -> (ij)\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048175877526617`*^9, 3.6048176227157993`*^9}, {3.6048176757364683`*^9, 
   3.604817678723796*^9}, {3.604817764591837*^9, 3.6048177920344276`*^9}, 
   3.604830288380419*^9, 3.614494897982704*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEVarphimod", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"verEEVarphi", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "b_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "b"}], "]"}]}], "-", 
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "b"}], "]"}]}]}], ",", 
        RowBox[{
         RowBox[{"kdotk", "[", 
          RowBox[{"i_", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"kdotk", "[", 
            RowBox[{"i", ",", "1"}], "]"}]}], "-", 
          RowBox[{"kdotk", "[", 
           RowBox[{"i", ",", "2"}], "]"}]}]}]}], "}"}]}], "//", "Expand"}], 
    ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{"c", "\[Rule]", "i"}], ",", 
     RowBox[{"d", "\[Rule]", "j"}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.6048118019554462`*^9, {3.604811860128257*^9, 3.604811867862918*^9}, {
   3.604811928271016*^9, 3.6048119292450438`*^9}, {3.6048119912125273`*^9, 
   3.604812139141265*^9}, {3.6048122480315733`*^9, 3.604812267208663*^9}, {
   3.6048124103533287`*^9, 3.6048124104906178`*^9}, {3.604812672116448*^9, 
   3.60481267525301*^9}, {3.60481806149019*^9, 3.6048180616894093`*^9}, {
   3.604830324227413*^9, 3.604830362351947*^9}, {3.604830423288822*^9, 
   3.6048304283661346`*^9}, {3.614494344669455*^9, 3.6144944937962427`*^9}, 
   3.6144948979842978`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9, 3.615633726512533*^9, 
   3.616214588107012*^9, 3.6173360886166887`*^9, 3.61733820914095*^9, 
   3.618217355717038*^9, 3.619333585532908*^9, 3.6197749518720093`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9, 3.615633726512533*^9, 
   3.616214588107012*^9, 3.6173360886166887`*^9, 3.61733820914095*^9, 
   3.618217355717038*^9, 3.619333585532908*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9, 3.615633726512533*^9, 
   3.616214588107012*^9, 3.6173360886166887`*^9, 3.61733820914095*^9, 
   3.618217355717038*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9, 3.615633726512533*^9, 
   3.616214588107012*^9, 3.6173360886166887`*^9, 3.61733820914095*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9, 3.615633726512533*^9, 
   3.616214588107012*^9, 3.6173360886166887`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9, 3.615633726512533*^9, 
   3.616214588107012*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9, 3.615633726512533*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9, 3.614937143915584*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9, 
   3.614577133769987*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9, 3.6145056576966476`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9, 3.61450092947578*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9, 
   3.614500787987228*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9, 3.614500563288045*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9, 3.61449519881429*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "+", 
   RowBox[{"\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "s", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604811873070668*^9, 3.604811929589794*^9, {3.6048119932709513`*^9, 
   3.604812013466433*^9}, 3.6048120605214787`*^9, 3.6048120977965612`*^9, 
   3.6048121402220182`*^9, 3.604812268028009*^9, 3.604812411385325*^9, 
   3.604812676211452*^9, 3.604818066684366*^9, 3.6048211819827538`*^9, 
   3.604821366546591*^9, 3.604827064951501*^9, 3.6048303633724194`*^9, {
   3.6048304237816257`*^9, 3.6048304419566383`*^9}, 3.604901628190333*^9, 
   3.604997508299562*^9, 3.604997838027936*^9, 3.604997997866541*^9, 
   3.604998261474526*^9, 3.604998678605166*^9, 3.6049990223383408`*^9, 
   3.604999566304405*^9, 3.605322219381824*^9, 3.605329247509688*^9, 
   3.605344878534625*^9, 3.605499360204999*^9, 3.6054997589682417`*^9, 
   3.605500270403306*^9, 3.605500978978117*^9, 3.605517526769414*^9, 
   3.605518589465114*^9, 3.60601970695613*^9, 3.6066245066482353`*^9, 
   3.6072547985283327`*^9, 3.607746834832563*^9, 3.6084586681111794`*^9, 
   3.608461046888167*^9, 3.6086113560895853`*^9, 3.608972244867647*^9, 
   3.609039059677928*^9, 3.609065510919427*^9, 3.6091305296128893`*^9, 
   3.610078786543741*^9, 3.6101830110069523`*^9, 3.610768740775035*^9, 
   3.61432121584839*^9, 3.614488593950396*^9, 3.61449449489361*^9, 
   3.614494897986227*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diaggs", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"verEEVarphimod", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], 
         RowBox[{"I", "/", "s"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "I", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"3", ",", "i"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "i"}], "]"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"3", ",", "j"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "j"}], "]"}]}], ")"}]}], "+", 
         RowBox[{"4", "I", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"3", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"4", ",", "j"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"4", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"3", ",", "j"}], "]"}]}]}], ")"}]}]}], ")"}]}], "//", 
      "Expand"}], "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.604830456735118*^9, 3.604830482581274*^9}, {
   3.604830543213916*^9, 3.6048306970149612`*^9}, {3.614494503705185*^9, 
   3.6144946069309053`*^9}, 3.6144948979895906`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9, 
   3.615633726671646*^9, 3.616214588278028*^9, 3.6173360887606*^9, 
   3.617338209312393*^9, 3.618217355860573*^9, 3.619333585714737*^9, 
   3.61977495203362*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9, 
   3.615633726671646*^9, 3.616214588278028*^9, 3.6173360887606*^9, 
   3.617338209312393*^9, 3.618217355860573*^9, 3.619333585714737*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9, 
   3.615633726671646*^9, 3.616214588278028*^9, 3.6173360887606*^9, 
   3.617338209312393*^9, 3.618217355860573*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9, 
   3.615633726671646*^9, 3.616214588278028*^9, 3.6173360887606*^9, 
   3.617338209312393*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9, 
   3.615633726671646*^9, 3.616214588278028*^9, 3.6173360887606*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9, 
   3.615633726671646*^9, 3.616214588278028*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9, 
   3.615633726671646*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9, 3.614937144075508*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9, 3.614577133939794*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9, 
   3.61450565785828*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9, 3.614500929631722*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9, 3.6145007881472197`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9, 
   3.614500563468459*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9, 3.614495198971837*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830598516017*^9, 3.6048306976372137`*^9}, 
   3.604901628464443*^9, 3.604997508468433*^9, 3.604997838202011*^9, 
   3.604997998069332*^9, 3.604998261685192*^9, 3.604998678780203*^9, 
   3.6049990225174837`*^9, 3.604999566514167*^9, 3.605322219748541*^9, 
   3.605329247668223*^9, 3.605344878828897*^9, 3.605499360363853*^9, 
   3.6054997591658993`*^9, 3.605500270623823*^9, 3.60550097917948*^9, 
   3.605517526981292*^9, 3.6055185896941833`*^9, 3.606019707120655*^9, 
   3.606624506893181*^9, 3.607254798692885*^9, 3.607746834999915*^9, 
   3.6084586683551617`*^9, 3.6084610472036057`*^9, 3.608611356367715*^9, 
   3.608972245044281*^9, 3.6090390598945093`*^9, 3.609065511077799*^9, 
   3.6091305298519382`*^9, 3.610078786836887*^9, 3.610183011327964*^9, 
   3.610768741107706*^9, 3.6143212162321653`*^9, 3.614488594109865*^9, 
   3.614494608059971*^9, 3.6144948979909763`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diaggt", "=", 
  RowBox[{"Diaggs", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "t"}], ",", 
     RowBox[{"t", "\[Rule]", "s"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "a"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a"}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6048307541455393`*^9, 3.604830791835392*^9}, {
   3.614494625918297*^9, 3.614494685333457*^9}, 3.61449489799244*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAmLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQDva5pu724ZXjBcau44kfgbSsZHLr51eOit7aOW1A2qq5ZqPx11eO
e05a7Ar5/srxzmdGW50frxwBGS/tXA==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBGLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQDva5pu724ZXjBcau44kfgbSsZHLr51eOit7aOW1A2qq5ZqPx11eO
e05a7Ar5/soRALrC6P8=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAGLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQDva5pu724ZXjBcau44kfgbSsZHLr51eOit7aOW1A2qq5ZqPx11eO
AIGq5BE=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB2LF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQDva5pu724ZXjBcau44kfgbSsZHLr51eOit7aOW1AGgBvo9/T
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA2LF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQDva5pu724ZXjBcau44kfgbSsZHLr51eOAH8t3Cs=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBWLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQDva5pu724ZXjBcau44kfXzkCAKuO2B4=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAWLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQDva5pu724ZUjAPm3034=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBmLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyDd
+JqJ/ROQBgBric+A
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAmLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQLrgzz5bJyAN
AP6Byv8=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBGLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSB9N6V7uHyQBoAtQPGPA==

  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAGLF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRDgdMOGSBNACQJsH/
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB2LF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSDFenfwPRAIw1vow=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA2LF7888V99+5VjyZuL9s0A6onfShj9AesGT0zdB9C6f
w29BdHLtTr6/QJpj/n0nED1v4eVcEP3i1OWNIHpOUqXt7DuvHNfM/r56HpD+
UXTHdxmQnnKJb89HIC2k//wtiO6acE33E5DO2ZveBqIZdj+c9QtIh1bslP8N
pOM3p55/f/eV44e2WHnx+68clXhuPfR68MpRji1ZyfrhK8fOB31bpz165RiX
9vredCCdtrPf+SGQbs1dUTXx8StHi7QmqU1A2rTnGct+IB1naXfkHpAOmR9/
Yu3TV45M/3LXPADSE6pXrPn3DKj/OqfH0bevHGNu+TCJv3vlmDfx2m9JIG1y
1l5MCkgfY31gDaLX6RTckgHSAKeFufQ=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604830799217667*^9, 3.604901628560114*^9, 
  3.604997508579754*^9, 3.6049978383716583`*^9, 3.604997998103116*^9, 
  3.604998261796556*^9, 3.604998678988163*^9, 3.6049990226134787`*^9, 
  3.604999566618519*^9, 3.6053222197932873`*^9, 3.605329247737753*^9, 
  3.6053448788890343`*^9, 3.6054993604632053`*^9, 3.605499759224496*^9, 
  3.605500270705144*^9, 3.605500979241873*^9, 3.605517527054077*^9, 
  3.605518589795939*^9, 3.606019707178146*^9, 3.606624506922722*^9, 
  3.607254798813981*^9, 3.6077468350944967`*^9, 3.608458668464909*^9, 
  3.608461047356246*^9, 3.6086113564913816`*^9, 3.608972245263369*^9, 
  3.609039060074978*^9, 3.609065511204615*^9, 3.609130529944503*^9, 
  3.610078786988199*^9, 3.610183011437257*^9, 3.6107687412650833`*^9, 
  3.6143212163075438`*^9, 3.614488594401655*^9, 3.6144946867052526`*^9, 
  3.614494897993799*^9, 3.614495199000705*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604830799217667*^9, 3.604901628560114*^9, 
  3.604997508579754*^9, 3.6049978383716583`*^9, 3.604997998103116*^9, 
  3.604998261796556*^9, 3.604998678988163*^9, 3.6049990226134787`*^9, 
  3.604999566618519*^9, 3.6053222197932873`*^9, 3.605329247737753*^9, 
  3.6053448788890343`*^9, 3.6054993604632053`*^9, 3.605499759224496*^9, 
  3.605500270705144*^9, 3.605500979241873*^9, 3.605517527054077*^9, 
  3.605518589795939*^9, 3.606019707178146*^9, 3.606624506922722*^9, 
  3.607254798813981*^9, 3.6077468350944967`*^9, 3.608458668464909*^9, 
  3.608461047356246*^9, 3.6086113564913816`*^9, 3.608972245263369*^9, 
  3.609039060074978*^9, 3.609065511204615*^9, 3.609130529944503*^9, 
  3.610078786988199*^9, 3.610183011437257*^9, 3.6107687412650833`*^9, 
  3.6143212163075438`*^9, 3.614488594401655*^9, 3.6144946867052526`*^9, 
  3.614494897993799*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Diaggu", "=", 
  RowBox[{"Diaggs", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", "u"}], ",", 
     RowBox[{"u", "\[Rule]", "s"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "a"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "a_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a"}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.60483082005287*^9, 3.604830820967239*^9}, {
   3.614494699397416*^9, 3.614494752293949*^9}, 3.614494897995343*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzE0ow3EcBvC/URwwSZa3Zi7ElLyUYuk3JayVpFZOTLPSEGlpzUHZdsCB
afIaFweb8l60Ik1z8FJiNZv/zEb6Zhgbi5Hv7/D06Tk8j0De26yIYRimFFNX
qJGaXUDya0yeM5Sza1yPopG/UydVP2wLUC9Xrcm/aK7BJ6beX113U60SxwbV
H9KK5txAdsM/5kV0PspKV1DdUYo1iDrdTwFqdNxZ/I4uS7r0VKbZP/uNahSH
/B9UNaa8eL0Fss5p5/M8+JPq8jbe4a6oM6/KC+TofHLHdA+kPCnMTqOtJVO1
XtTTY9ZM+IAswUjmJmowQdwB2jZAbCyabVeerD0Agck+yx3aMrJn+XsEoixI
rD8OAFEvSDm8FyBjaYK4TLTWV5NOHQz6qqhZ3P6bbNRqnPmkCrUVCTlo8Xa9
jE8791AkRiunY+Pf0aZXR37dGxC5bNTeHgSyxWZ06D5wbxKq9GiDemijLAwk
xFbvt3wBeXZzRMIIkH9Hv+5Y
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwBGI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUhbTGdm
/wSkA95fU3f78MoxKbz7eOLHV46b70kmt34G6p+mk9MGpD3Lajcaf33l+OWe
za6Q768cAeFd6gE=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAGI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUhbTGdm
/wSkA95fU3f78MoxKbz7eOLHV46b70kmt34G6p+mk9MGpD3Lajcaf33lCACg
UuTC
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB2I3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUhbTGdm
/wSkA95fU3f78MoxKbz7eOLHV46b70kmt34G6p+mk9MGpAGIuOCB
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA2I3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUhbTGdm
/wSkA95fU3f78MoxKbz7eOLHV46b70kmt35+5QgAkx/b8g==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBWI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUhbTGdm
/wSkA95fU3f78MoxKbz7eOLHV44AwgnXQQ==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAWI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUhbTGdm
/wSkA95fU3f78MoRABeB0rg=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBmI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUhbTGdm
/wSkAZAXzho=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAmI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PIjPf8DWCUgDAC38
yjU=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBGI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQFp3i0e4PJAGAOnWxqE=
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAGI3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0To1phyyQBoAwd7C6A==
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB2I3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskA6T2TZ34D0QC2Y7/M
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA2I3rSrf1bdfOarbT7t/FkgzbZu84Q+Q/vHvzE0Q3dZ4
5C2IvrRqD99fIK3Q/tgJRD+6cjUXRO/xvrYRRD/5UmM7+84rx21ff6+eB6Tn
/LnnuwxItx4S2PMRSN+88+ItiP7Te1P3E5Be6J3VBqIZgp7M+gWkq1IPyP8G
0jk96eff333luIEpUV78PtAcodsPvR4A9WmnKVk/fOV46NykrdMevXI04f16
bzqQjjKY4vwQSN/PW1018fErxwWvWqQ2Aen2aa9Y9gPphBLHI/eAtMzx9BNr
n75yfDWpcM0DIB3SsnPNv2evHNM1eDyOvn3lWDbXl0n83SvHHhFFFikg7fzY
XgxEV3x8bA2ipfmLbskAaQDHdbq4
  "]],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6048308278176603`*^9, 3.604901628695209*^9, 
  3.6049975086159678`*^9, 3.604997838406124*^9, 3.604997998140811*^9, 
  3.604998261895852*^9, 3.6049986791102448`*^9, 3.6049990226822367`*^9, 
  3.604999566696745*^9, 3.605322219904894*^9, 3.605329247873744*^9, 
  3.605344878968336*^9, 3.605499360523745*^9, 3.605499759276959*^9, 
  3.605500270798582*^9, 3.605500979321732*^9, 3.60551752713501*^9, 
  3.6055185900123873`*^9, 3.6060197072358913`*^9, 3.606624507031578*^9, 
  3.6072547988460217`*^9, 3.607746835192869*^9, 3.608458668587739*^9, 
  3.6084610476578617`*^9, 3.6086113566309023`*^9, 3.608972245357284*^9, 
  3.6090390601536407`*^9, 3.609065511330875*^9, 3.609130530045456*^9, 
  3.6100787872430553`*^9, 3.610183011549184*^9, 3.6107687417974033`*^9, 
  3.614321216379932*^9, 3.6144885944254713`*^9, 3.614494753033758*^9, 
  3.614494897996492*^9, 3.614495199123226*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.6048308278176603`*^9, 3.604901628695209*^9, 
  3.6049975086159678`*^9, 3.604997838406124*^9, 3.604997998140811*^9, 
  3.604998261895852*^9, 3.6049986791102448`*^9, 3.6049990226822367`*^9, 
  3.604999566696745*^9, 3.605322219904894*^9, 3.605329247873744*^9, 
  3.605344878968336*^9, 3.605499360523745*^9, 3.605499759276959*^9, 
  3.605500270798582*^9, 3.605500979321732*^9, 3.60551752713501*^9, 
  3.6055185900123873`*^9, 3.6060197072358913`*^9, 3.606624507031578*^9, 
  3.6072547988460217`*^9, 3.607746835192869*^9, 3.608458668587739*^9, 
  3.6084610476578617`*^9, 3.6086113566309023`*^9, 3.608972245357284*^9, 
  3.6090390601536407`*^9, 3.609065511330875*^9, 3.609130530045456*^9, 
  3.6100787872430553`*^9, 3.610183011549184*^9, 3.6107687417974033`*^9, 
  3.614321216379932*^9, 3.6144885944254713`*^9, 3.614494753033758*^9, 
  3.614494897996492*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ampE3varphis", "=", 
  RowBox[{
   RowBox[{"Diaggs", "+", "Diaggt", "+", "Diaggu"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.604830833818068*^9, 3.604830847331704*^9}, {
   3.604830892289398*^9, 3.604830901484098*^9}, 3.614494897997006*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9, 
   3.6156337267559547`*^9, 3.616214588408289*^9, 3.617336088847303*^9, 
   3.61733820944897*^9, 3.6182173559653883`*^9, 3.619333585966237*^9, 
   3.619774952115795*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9, 
   3.6156337267559547`*^9, 3.616214588408289*^9, 3.617336088847303*^9, 
   3.61733820944897*^9, 3.6182173559653883`*^9, 3.619333585966237*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9, 
   3.6156337267559547`*^9, 3.616214588408289*^9, 3.617336088847303*^9, 
   3.61733820944897*^9, 3.6182173559653883`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9, 
   3.6156337267559547`*^9, 3.616214588408289*^9, 3.617336088847303*^9, 
   3.61733820944897*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9, 
   3.6156337267559547`*^9, 3.616214588408289*^9, 3.617336088847303*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9, 
   3.6156337267559547`*^9, 3.616214588408289*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9, 
   3.6156337267559547`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9, 3.6149371441473637`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9, 3.614577134049376*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9, 
   3.614505658317532*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9, 3.61450092970854*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9, 3.614500788870636*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9, 
   3.61450056360767*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9, 3.614495199149851*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["b",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "-", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["b",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]]}], ")"}]}]}], ")"}]}], TraditionalForm]], "Output",\

 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830837122744*^9, 3.6048308477729816`*^9}, 
   3.604830902102124*^9, 3.604901628865232*^9, 3.604997508689547*^9, 
   3.604997838511408*^9, 3.6049979982625437`*^9, 3.604998262016032*^9, 
   3.604998679202285*^9, 3.60499902283349*^9, 3.604999566805058*^9, 
   3.605322220054351*^9, 3.6053292479671793`*^9, 3.605344879052167*^9, 
   3.6054993606050253`*^9, 3.6054997593477087`*^9, 3.6055002708985233`*^9, 
   3.6055009794497547`*^9, 3.60551752722585*^9, 3.6055185901209097`*^9, 
   3.6060197072842493`*^9, 3.606624507152643*^9, 3.60725479888783*^9, 
   3.607746835474428*^9, 3.6084586687124577`*^9, 3.608461047920175*^9, 
   3.608611356825832*^9, 3.608972245484674*^9, 3.60903906022305*^9, 
   3.6090655114587193`*^9, 3.609130530155184*^9, 3.610078787417819*^9, 
   3.610183011660204*^9, 3.610768742179309*^9, 3.614321216433625*^9, 
   3.614488594470209*^9, 3.614494897998561*^9}]
}, Open  ]],

Cell["This is non-zero!", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048175877526617`*^9, 3.6048176227157993`*^9}, {3.6048176757364683`*^9, 
   3.604817678723796*^9}, {3.604817764591837*^9, 3.6048177920344276`*^9}, 
   3.604830288380419*^9, {3.604830880192257*^9, 3.604830884582342*^9}, {
   3.604830984857476*^9, 3.604830988493466*^9}, 3.6144948979992113`*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res", "=", 
  RowBox[{
   RowBox[{"ampE3varphis", " ", 
    RowBox[{"xi", "[", 
     RowBox[{"1", ",", "a"}], "]"}], 
    RowBox[{"xibar", "[", 
     RowBox[{"1", ",", "b"}], "]"}]}], "//", "Contract"}]}]], "Input",
 CellChangeTimes->{{3.6048310025962677`*^9, 3.6048310274864388`*^9}, 
   3.614494897999934*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9, 3.6156337267931967`*^9, 
   3.616214588462285*^9, 3.617336088884762*^9, 3.6173382094837713`*^9, 
   3.618217356006795*^9, 3.6193335860291862`*^9, 3.6197749521571836`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9, 3.6156337267931967`*^9, 
   3.616214588462285*^9, 3.617336088884762*^9, 3.6173382094837713`*^9, 
   3.618217356006795*^9, 3.6193335860291862`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9, 3.6156337267931967`*^9, 
   3.616214588462285*^9, 3.617336088884762*^9, 3.6173382094837713`*^9, 
   3.618217356006795*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9, 3.6156337267931967`*^9, 
   3.616214588462285*^9, 3.617336088884762*^9, 3.6173382094837713`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9, 3.6156337267931967`*^9, 
   3.616214588462285*^9, 3.617336088884762*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9, 3.6156337267931967`*^9, 
   3.616214588462285*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9, 3.6156337267931967`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9, 3.614937144180772*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9, 
   3.6145771340956717`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9, 3.614505658360367*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9, 3.614500929744562*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9, 
   3.614500788925968*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9, 3.614500563648162*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9, 3.61449519918851*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "2"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "4"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["\[Eta]", "1"],
          TraditionalForm]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["\[Eta]", "1"],
           TraditionalForm]}]}]}], ")"}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Xi]", "1"],
        TraditionalForm]}]}]}], ")"}]}], TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.6048310076228647`*^9, 3.6048310291696863`*^9}, 
   3.604901629122834*^9, 3.604997508790143*^9, 3.604997838628757*^9, 
   3.604997998468191*^9, 3.604998262078267*^9, 3.604998679311318*^9, 
   3.604999022905306*^9, 3.6049995668870783`*^9, 3.6053222201681957`*^9, 
   3.60532924816975*^9, 3.605344879129242*^9, 3.605499360681896*^9, 
   3.605499759415371*^9, 3.6055002710900173`*^9, 3.605500979507086*^9, 
   3.6055175273141003`*^9, 3.6055185902300577`*^9, 3.6060197073517437`*^9, 
   3.606624507213619*^9, 3.6072547989262114`*^9, 3.607746835577018*^9, 
   3.6084586688131*^9, 3.608461048070719*^9, 3.608611356956913*^9, 
   3.608972245575416*^9, 3.609039060310924*^9, 3.609065511652372*^9, 
   3.6091305302451468`*^9, 3.61007878756499*^9, 3.610183011771109*^9, 
   3.610768742575428*^9, 3.614321216515253*^9, 3.614488594503304*^9, 
   3.614494898001616*^9}]
}, Open  ]],

Cell["And it doesn\[CloseCurlyQuote]t satisfy the Ward identity.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.601897669869924*^9, 3.601897688474907*^9}, {
   3.602226951402175*^9, 3.602226958496961*^9}, {3.602227029249427*^9, 
   3.602227035960477*^9}, {3.602227578471747*^9, 3.602227591055292*^9}, {
   3.604807370949923*^9, 3.6048074026420717`*^9}, {3.604810148093953*^9, 
   3.6048101510798817`*^9}, {3.6048118939953747`*^9, 3.604811894919134*^9}, {
   3.6048175877526617`*^9, 3.6048176227157993`*^9}, {3.6048176757364683`*^9, 
   3.604817678723796*^9}, {3.604817764591837*^9, 3.6048177920344276`*^9}, 
   3.604830288380419*^9, {3.604830880192257*^9, 3.604830884582342*^9}, {
   3.604831132434949*^9, 3.604831139143705*^9}, 3.614494898002263*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resWard", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"ampE3varphis", " ", 
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "a"}], "]"}], 
       RowBox[{"xibar", "[", 
        RowBox[{"1", ",", "b"}], "]"}]}], "//", "Contract"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
       RowBox[{"s", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
       RowBox[{"t", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
       RowBox[{"u", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
       RowBox[{"u", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
       RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
       RowBox[{"s", "/", "2"}]}]}], "}"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.604830916363379*^9, 3.604830953956727*^9}, {
   3.604831030475566*^9, 3.6048310325496397`*^9}, {3.6048311051901608`*^9, 
   3.6048311069644327`*^9}, {3.6144947654134502`*^9, 3.614494857349168*^9}, 
   3.614494898003551*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9, 3.615633726839102*^9, 
   3.616214588581485*^9, 3.6173360889187937`*^9, 3.617338209543501*^9, 
   3.618217356041404*^9, 3.619333586100891*^9, 3.619774952205497*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9, 3.615633726839102*^9, 
   3.616214588581485*^9, 3.6173360889187937`*^9, 3.617338209543501*^9, 
   3.618217356041404*^9, 3.619333586100891*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9, 3.615633726839102*^9, 
   3.616214588581485*^9, 3.6173360889187937`*^9, 3.617338209543501*^9, 
   3.618217356041404*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9, 3.615633726839102*^9, 
   3.616214588581485*^9, 3.6173360889187937`*^9, 3.617338209543501*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9, 3.615633726839102*^9, 
   3.616214588581485*^9, 3.6173360889187937`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9, 3.615633726839102*^9, 
   3.616214588581485*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9, 3.615633726839102*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9, 3.614937144222875*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9, 
   3.614577134145998*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9, 3.6145056584105997`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9, 3.614500929786788*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9, 
   3.614500789106368*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9, 3.614500563692964*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9, 3.614495199234962*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"2", " ", "s"}]}], "+", "t", "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "3"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "-", 
        RowBox[{"2", " ", "t"}], "+", "u"}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{"s", "+", "t", "-", 
        RowBox[{"2", " ", "u"}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.604830919754204*^9, 3.604830954448965*^9}, 
   3.604831033408429*^9, 3.604831108237795*^9, 3.604901629254023*^9, 
   3.6049975088752413`*^9, 3.604997838734462*^9, 3.604997998605283*^9, 
   3.604998262179002*^9, 3.604998679429525*^9, 3.6049990229776077`*^9, 
   3.6049995670021467`*^9, 3.605322220333577*^9, 3.6053292482882566`*^9, 
   3.605344879287614*^9, 3.605499360772788*^9, 3.605499759498363*^9, 
   3.6055002711986227`*^9, 3.605500979593771*^9, 3.6055175274908123`*^9, 
   3.605518590346552*^9, 3.6060197074726677`*^9, 3.6066245073094597`*^9, 
   3.6072547989779863`*^9, 3.607746835719624*^9, 3.6084586689428873`*^9, 
   3.608461048248185*^9, 3.608611357079357*^9, 3.6089722456992893`*^9, 
   3.609039060412743*^9, 3.609065511760639*^9, 3.6091305303672523`*^9, 
   3.610078787746703*^9, 3.61018301213076*^9, 3.61076874295704*^9, 
   3.61432121660159*^9, 3.6144885945446053`*^9, 3.614494858446949*^9, 
   3.614494898004574*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Binomial", "[", 
  RowBox[{"5", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.6048340029353333`*^9, 3.60483400589157*^9}, {
   3.6048340385452547`*^9, 3.604834057119026*^9}, {3.6048341149618187`*^9, 
   3.604834116803843*^9}, {3.604834190878729*^9, 3.604834220640279*^9}, {
   3.604834561636445*^9, 3.604834562052318*^9}, {3.60483503797243*^9, 
   3.604835051503582*^9}, {3.604835292942933*^9, 3.604835298683566*^9}, 
   3.614494898005232*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9, 3.615633726857954*^9, 3.61621458861567*^9, 
   3.617336088936483*^9, 3.617338209577347*^9, 3.618217356064684*^9, 
   3.6193335861455393`*^9, 3.619774952281006*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9, 3.615633726857954*^9, 3.61621458861567*^9, 
   3.617336088936483*^9, 3.617338209577347*^9, 3.618217356064684*^9, 
   3.6193335861455393`*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9, 3.615633726857954*^9, 3.61621458861567*^9, 
   3.617336088936483*^9, 3.617338209577347*^9, 3.618217356064684*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9, 3.615633726857954*^9, 3.61621458861567*^9, 
   3.617336088936483*^9, 3.617338209577347*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9, 3.615633726857954*^9, 3.61621458861567*^9, 
   3.617336088936483*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9, 3.615633726857954*^9, 3.61621458861567*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9, 3.615633726857954*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9, 
   3.614937144335002*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9, 3.6145771341730213`*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9, 3.614505658436604*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9, 
   3.614500930055176*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9, 3.614500789148596*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9, 3.6145005637141533`*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9, 
   3.6144951992559566`*^9}],

Cell[BoxData[
 FormBox["10", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.604834006135477*^9, {3.60483403889467*^9, 3.6048340573604107`*^9}, 
   3.6048341171113253`*^9, {3.6048341911103354`*^9, 3.604834220855476*^9}, 
   3.60483456228478*^9, {3.604835038188341*^9, 3.604835051821039*^9}, {
   3.6048352956603928`*^9, 3.604835298831065*^9}, 3.604901629278191*^9, 
   3.604997508957581*^9, 3.60499783882937*^9, 3.604997998729776*^9, 
   3.6049982622830563`*^9, 3.604998679463503*^9, 3.60499902298676*^9, 
   3.604999567037784*^9, 3.605322220371346*^9, 3.6053292483450336`*^9, 
   3.6053448793459587`*^9, 3.60549936077777*^9, 3.6054997595035152`*^9, 
   3.6055002712029448`*^9, 3.6055009796507263`*^9, 3.605517527565255*^9, 
   3.6055185903508663`*^9, 3.6060197075245028`*^9, 3.606624507435307*^9, 
   3.6072547989827633`*^9, 3.6077468357241488`*^9, 3.608458669078726*^9, 
   3.608461048262539*^9, 3.608611357206273*^9, 3.608972245802683*^9, 
   3.6090390604177437`*^9, 3.60906551176591*^9, 3.609130530562516*^9, 
   3.610078787753937*^9, 3.610183012439724*^9, 3.610768743106331*^9, 
   3.614321216653284*^9, 3.6144885945571327`*^9, 3.614494898005814*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"6", "*", "6", "*", "6", "*", "5"}], "+", "240", "+", "40", "+", 
  "30", "+", "1", "+", "270"}]], "Input",
 CellChangeTimes->{{3.6048345687559767`*^9, 3.6048345714186296`*^9}, {
   3.604834604959248*^9, 3.6048346131870728`*^9}, {3.604835144071001*^9, 
   3.604835144790674*^9}, 3.6144948980062637`*^9}],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzVsog3EYgPGRMhIXTln4jLKSSUhY016WRKSlXHDhXOSUnONG4WpDtDlF
XBCmTBFSUk5NuJGc5yNLL8PmtJzy/i+efpePuLBaVeIgEAiiqVb3FvHcOYLj
8mIoM6xBWsZ81E6b9klt3tj8D1kbd3HK3G47sTAjPI3uv6Sg7zmJOdPDVzK9
Km4MzOBitXz4AuHrwE0/SqYoHzImyTeh35qVTIQXCzNu3Cy1kUZrXSdzJ8E2
9EWac/e4b3Ltrebw+RKh0qOK8zUhdOlMfNo1QnZ6Y7CMR8jamFjU3iCUrghN
OjJHMZXMk0Mxqy29twgn7WrRAqmZtTutkwNS1eYV2Z/XtDt3h2DP1+ivyZDI
B/2fGaGa807dstA/XuXo+4TwE6vwEZGl5fcy5plb45k/6VM/+cH8s4AwgGwW
Z+ZwZM3SljyJbOBdnW2kcfBckvKCcHTat1NgRUjgAos6XhH0I1EVnWS+rN0Q
/Y4QdKxczf5E6Ja4yMPtCP+3bu5y
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzVsog2EYwPFZypK4cIrwGUWpSSNhkYclEWmtdsGF44rMlpzjZoWriaY5
RlxM2Ao1ISVlaMKN5DDmI0svY5tjM8vzXvz7Xf75tUpJgx+HwxFivcE9fOM1
Ae6GKYma0iFopL7oFm3HqK5qdsWLtmZZL6n7fRcOamqoJfgP5WjfCqhLw6yC
GtZ8v0pNqNfkTlkJeE6CDDNokfi5TI9+8KK2XWgeOB3UrDm7wI1aXG0D1IMc
96QHtVceMb/o9ofq9O2GgCKkhYm0ERgcs7EldwSkpZ0JIpZAxe68SXdPQL7J
s42hsvyFQhadzNjqGXkgcKHWRK+hQ8s//jvouECyd4uOVnUdGh8J/FQPGe7Q
xLRng89OQMmEF5sd+M+WcCNfCXgz8yOiUXnTk4h6FdR5FYNGtOu/qD4H8GLR
bn65jEFV6+bcArSDDQxwo5aJ6+QiJ4GzS+1BjYtADhNX1/9OwDAtbB5Aq0Xq
1fRPAvHn4i3pN4F/T5zrJg==
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVzU0ow3EYwPFZypI4YMvCv01RavKWsGjPaIlIS+3AwXvRmOQ9LsqcJpo2
bxEHwhRqQispb024OGzetv9k6ceweUkz8vwO3z7Hr6hWo2wI4nA4aVh/eJ9o
7ZoAd9ucSE3ukjRRnw3LjjPUUDW3HkDbs2/s1KMBm4eaEmkN/0U5+lc5dWWU
baFGqV0bVHG9Lm/6hoD/PMw0iyoKn0oX0Q9ejMWL5sObh5o975b4UKu3Q0s9
zvVN+VF35Snzg1o+2i5ebwm0RLQyAgeBYaODLXYSqCjpFktZAuX7C2aDi0Dj
Ds9hRFWypQIWncrc7Ru7J2Ab1Ak30ZHV7+A9dEKiPLhDx6t6TtYeCHxXj5ic
aELqk+nPTUDDRBcdevCfo+QKXggEsmR8IdrY/CilXoV1X8Wi/M7FL+qfB3hx
aK+oTMWgbVuHeXK0iw0N8aHWyeskxRuBS7v+uMZLIJeJrxt6J2CaSVdr0Wrp
4EbGJ4F/BWnmuw==
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOIavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAulKRb9weSBdsO2o
rROQLnvIxf4JSJ+aeVvd7cMrxys3Jx9P/PjK0UpeLrn18yvHNXOMctqANADd
v+KZ
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+IavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAulKRb9weSBdsO2o
rROQLnvIxf4JSJ+aeVvd7cMrxys3Jx9P/PjK0UpeLrn18ytHANdw3g4=
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+IavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAulKRb9weSBdsO2o
rROQLnvIxf4JSJ+aeVvd7cMrxys3Jx9P/PjKEQD0vdqQ
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeIavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAulKRb9weSBdsO2o
rROQLnvIxf4JSJ+aeVvd7cMrRwAwR9UL
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAeIavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAulKRb9weSBdsO2o
rROQLnvIxf4JSAMAlfHQRA==
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuIavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAulKRb9weSBdsO2o
rROQBgAi1svQ
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuIavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAulKRb9weSANANKB
x0w=
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBOIavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0f/eOnLIAmkApKLD1A==
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAOIavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpMVKl30D0QCSSL9p
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+IavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpE3+IpvyUDpAGmZrsM
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+IavirFtbdfOTLt2KoGorXKdDNB9JtpK++fBdLTYuZv
+AOkiyzu3ATRx2pvvAXResKn+P4CaYbJ751A9KoJD3NBtEjOo40gWiml13b2
nVeOv87xrJkHpN1cXvsuA9JfOCT3fATSdo4f3oJoi4XPdD8B6VMfS9pA9HGr
T7N+Aeln0aflfwPpPV8Kzr+/+8oxlz9PXvz+K8f26fcfej145RjiXa5k/fCV
Y8DBRVunPXrlmLaT4/50IB3usNz5IZCeZbKrauLjV443mnqlNgHpvtU/WPYD
6Rm6QUfuAekpMRUn1j595fgjoW/NAyCtbPB6zb9nrxzz5UU9jr4F2m8ZxCT+
7pXjHzMHMSkgnZb1whpEAwDcWbaf
  "]],

Cell[BoxData[
 FormBox["1661", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604834571814268*^9, 3.604834613678712*^9, 
  3.6048351454206743`*^9, 3.604901629299673*^9, 3.604997508980052*^9, 
  3.6049978388818903`*^9, 3.604997998765353*^9, 3.6049982623148413`*^9, 
  3.6049986794866943`*^9, 3.604999023048909*^9, 3.604999567075693*^9, 
  3.6053222204184732`*^9, 3.6053292484002657`*^9, 3.605344879352084*^9, 
  3.605499360782343*^9, 3.605499759507964*^9, 3.60550027120718*^9, 
  3.6055009796545153`*^9, 3.605517527569675*^9, 3.605518590354968*^9, 
  3.606019707529875*^9, 3.606624507439383*^9, 3.607254798987247*^9, 
  3.6077468357279453`*^9, 3.6084586690860977`*^9, 3.6084610482726316`*^9, 
  3.608611357226604*^9, 3.608972245818921*^9, 3.609039060422222*^9, 
  3.6090655117709417`*^9, 3.6091305305680656`*^9, 3.610078787761301*^9, 
  3.610183012449337*^9, 3.610768743349626*^9, 3.614321216660087*^9, 
  3.6144885945695677`*^9, 3.614494898006712*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"3", "*", "15", "*", "6"}]], "Input",
 CellChangeTimes->{{3.604835082609826*^9, 3.6048350861931677`*^9}, 
   3.61449489800716*^9}],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVyk0sAmAcgPGYTS0fmy3REA5sJhPmksYb89HIhDk5RGw2sg6WOTjYmAMH
W9gwM5u0FLI5+BgHjCm6uCiVkuRtpTK0vub/Hp79Lk/RwLh4KIlCoXChkkaT
RGfBqLZNY38AY6ytwxhYk2F9Jl7QrD6imW/IiIP6zoCAKJc6x4iGA5eeGJlX
8tdfMHpMpGk3wZENb4cKLKvIPQ+C99KAjzh95eaEQGH6xByR2x9ai4C8aQM7
Csaz5KYvK0bzHBmbacdIdGJ3CF8xMsoUxTwHRp6P7eMVJ0Z1TJp9FaTu7zY6
wG7v6dTSG0Z01SLrCDQ/hVMuwZ5e8bUN7FqevNO9w/+5pH0F3SqvNuEGhxmt
Nz6M+nfEyUw/RlX1Ddks0Ljg4RH3KhXmPNAfVf8SqQwBNR8sbBH1sUG17YYv
AD2Z9NQQyD6zlDYHMJqhKG8lQYw0zQWDs98Yuc6qRufAbMmMvvoHo+R402nP
H0Y57TR+eRijf8Rj5hI=
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAGI15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgHpF/zc7J+AtPzu
2+puH145NjFMOZ748ZXjKje55NbPrxyf7DbKaQPSYolNG42/vnJk+uuyK+T7
K0cAn8bjGA==
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB2I15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgHpF/zc7J+AtPzu
2+puH145NjFMOZ748ZXjKje55NbPrxyf7DbKaQPSYolNG42/vnIEAJY63qQ=

  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA2I15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgHpF/zc7J+AtPzu
2+puH145NjFMOZ748ZXjKje55NbPrxyf7DbKaQPSAK+N2qY=
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBWI15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgHpF/zc7J+AtPzu
2+puH145NjFMOZ748ZXjKje55NbPrxwB6QXVxA==
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAWI15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgHpF/zc7J+AtPzu
2+puH145NjFMOZ748ZUjAEjo0a8=
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBmI15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgHpF/zc7J+AtPzu
2+puH145AgDKpM1U
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAmI15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgHpF/zc7J+ANABu
R8kW
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBGI15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA+kV947aOgFpADPcxQE=
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAGI15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSCu4+4XLA2kAGkbAHQ==
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB2I15/OJa2+/cjTzXHX/LJD+I7Vgwx8gbcJ39yaI3sd5
9y2IvmV7mu8vkN7o/8EJRBemPMoF0afXP9kIon91TLGdfeeV47l/PGvmAenM
Oa99lwFpLT3JPR+B9KmUD29BdN3hZ7qfgLQXb2kbiDaM/TTrF5C2rjst/xtI
/xUqPP/+7ivHDt08efH7rxz9dt5/6PXgleOZvHIl64evHF88X7R12qNXjjbi
nPenA2mOdcudHwLp4Ne7qiY+fuXIvaxXahOQvnXlB8t+IB0SGnTkHpAOnFpx
Yu1ToPqXE9c8ANLPlr1e8+8ZkE4T9Tj69pVj7NIgJvF3rxyN7B3EpID0mZ4X
1iB6tUH5LRkg/e73im8gmkPUiUMWSAMAJhW82A==
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA2Hn84lrb79yNPNcdf8skP4jtWDDHyBtwnf3Jojex3n3
LYi+ZXua7y+Q3uj/wQlEF6Y8ygXRp9c/2Qiif3VMsZ1955XjuX88a+YB6cw5
r32XAWktPck9H4H0qZQPb0F03eFnup+AtBdvaRuINoz9NOsXkLauOy3/G0j/
FSo8//7uK8cO3Tx58fuvHP123n/o9eCV45m8ciXrh68cXzxftHXao1eONuKc
96cDaY51y50fAung17uqJj5+5ci9rFdqE5C+deUHy34gHRIadOQekA6cWnFi
7VOg+pcT1zwA0s+WvV7z7xmQThP1OPr2lWPs0iAm8XevHI3sHcSkgPSZnhfW
IHq1QfktGSD97veKbyAaAErVujo=
  "]],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604835086476947*^9, 3.604901629321437*^9, 
  3.604997509003294*^9, 3.604997838907984*^9, 3.604997998907439*^9, 
  3.6049982623513002`*^9, 3.604998679509728*^9, 3.604999023074761*^9, 
  3.604999567146459*^9, 3.605322220641721*^9, 3.605329248406104*^9, 
  3.605344879362843*^9, 3.6054993607868853`*^9, 3.6054997595123034`*^9, 
  3.605500271211364*^9, 3.605500979657872*^9, 3.605517527573876*^9, 
  3.605518590359159*^9, 3.606019707533568*^9, 3.606624507443058*^9, 
  3.60725479899137*^9, 3.607746835732275*^9, 3.608458669090809*^9, 
  3.608461048284086*^9, 3.608611357239994*^9, 3.608972245841226*^9, 
  3.609039060426519*^9, 3.609065511775983*^9, 3.609130530572916*^9, 
  3.610078787768227*^9, 3.610183012559696*^9, 3.6107687433641233`*^9, 
  3.614321216668811*^9, 3.614488594582686*^9, 3.6144948980077143`*^9, 
  3.614495199267187*^9, 3.614500563724691*^9}],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604835086476947*^9, 3.604901629321437*^9, 
  3.604997509003294*^9, 3.604997838907984*^9, 3.604997998907439*^9, 
  3.6049982623513002`*^9, 3.604998679509728*^9, 3.604999023074761*^9, 
  3.604999567146459*^9, 3.605322220641721*^9, 3.605329248406104*^9, 
  3.605344879362843*^9, 3.6054993607868853`*^9, 3.6054997595123034`*^9, 
  3.605500271211364*^9, 3.605500979657872*^9, 3.605517527573876*^9, 
  3.605518590359159*^9, 3.606019707533568*^9, 3.606624507443058*^9, 
  3.60725479899137*^9, 3.607746835732275*^9, 3.608458669090809*^9, 
  3.608461048284086*^9, 3.608611357239994*^9, 3.608972245841226*^9, 
  3.609039060426519*^9, 3.609065511775983*^9, 3.609130530572916*^9, 
  3.610078787768227*^9, 3.610183012559696*^9, 3.6107687433641233`*^9, 
  3.614321216668811*^9, 3.614488594582686*^9, 3.6144948980077143`*^9, 
  3.614495199267187*^9}],

Cell[BoxData[
 FormBox["270", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604835086476947*^9, 3.604901629321437*^9, 
  3.604997509003294*^9, 3.604997838907984*^9, 3.604997998907439*^9, 
  3.6049982623513002`*^9, 3.604998679509728*^9, 3.604999023074761*^9, 
  3.604999567146459*^9, 3.605322220641721*^9, 3.605329248406104*^9, 
  3.605344879362843*^9, 3.6054993607868853`*^9, 3.6054997595123034`*^9, 
  3.605500271211364*^9, 3.605500979657872*^9, 3.605517527573876*^9, 
  3.605518590359159*^9, 3.606019707533568*^9, 3.606624507443058*^9, 
  3.60725479899137*^9, 3.607746835732275*^9, 3.608458669090809*^9, 
  3.608461048284086*^9, 3.608611357239994*^9, 3.608972245841226*^9, 
  3.609039060426519*^9, 3.609065511775983*^9, 3.609130530572916*^9, 
  3.610078787768227*^9, 3.610183012559696*^9, 3.6107687433641233`*^9, 
  3.614321216668811*^9, 3.614488594582686*^9, 3.6144948980077143`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"3", "*", "5", "*", "6"}]], "Input",
 CellChangeTimes->{{3.6048354058179617`*^9, 3.6048354079691057`*^9}, 
   3.6144948980081673`*^9}],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVx2kow3EYwPGRcsUbzbIwxwsJLxwv1Ex75lrOQnmNxIs5WuQqSvFiMZF7
5Si3rVBqIV5srtDKG23zt40mPQybHLny/F58+/SNrmosrfHi8XjJ1FiJr0pn
RZhuWrWdk2c3s+s/pCCdMzM5A+diblecBf+S+kK3jHmxelvP3Lt0bjDV3KhE
c0UfFaSdJg+ND0WLJJSH7bpJqerFxcx03iV5yM34lj7mfpdn6oucmzkVfZPq
BaXpmUOYlzeIBDaEbLPNkW9HeBhsjRE7ECrTFrfGbhB4k/62cVJ9uZTlIPdC
djqGbhHsJwPCTXLi7dNnnxxuLzVekzv6tmOdEyFIM6y1k8XiR+3fHcJyP19+
4EIw88u8BU8IhjxpqJC8WLsXMwMKWi3hZF7tyjvTkiHziyCVDcUVIvLa51Ai
I4M7A309ZMKVNS73BaE7duSo0o3QrIis7n1FUFhSFH1knapnI/UNwRSTs13+
gRDV6C9J/ET4B8Lh6ek=
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJwVx2kow3EYwPHRypW90SzCHC8kKeGFmmnPHJOzRnk9Ei/mSOQqSvFiMZF7
NZRztkKptYkX7pDyZm3232Ft6TfDpiFXnt+Lb5++KQ3t0qYQFouVjc3WhCl0
9wTUHRr7DXr9sLzzg/LyGTOVOWZ8VEP9NecX1Vf6xdQ7jauVemhy71KVzIxQ
ZcVPjtaq0bMTb9U6CnVxB35UpHj1UQvdnqwAupfRPUo9GgwsfqErS1f8b1S5
1nn7whBYLWvj8+wEis12Z7mDgHeiJ1XgJCDLW9+ffSDAWoiwz6FK00aREz2M
MfZPugg4Lsfj99D54Cf7CJ3qk57YUKO+90LnJhCtmtI60GrBk/bPQ2BzjFt2
6iNg5taG8p4JHEtEsfHo3fajgBpZ0WNJQCXNW+9US4E4PBHtbKuu56M29plQ
jHIGosICaKb1Pr30lcBQ2vS5zE+gS57UOPJGQG7JkY+iLYrh3dwggdvUEkPd
B4F/f6/mxA==
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQB+Jp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSN9jOWbrBKT5qrnZPwFp
7Tu31d0+vHKsV55yPPHjK8eSHLnk1s+vHHNuGeW0AemMrqaNxl9fOQIAV+ri
XQ==
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+Jp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSN9jOWbrBKT5qrnZPwFp
7Tu31d0+vHKsV55yPPHjK8eSHLnk1s+vHHNuGeW0AWkAU57d5A==
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeJp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSN9jOWbrBKT5qrnZPwFp
7Tu31d0+vHKsV55yPPHjK8eSHLnk1s+vHAFzRdlb
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAeJp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSN9jOWbrBKT5qrnZPwFp
7Tu31d0+vHKsV55yPPHjK0cAtofVVg==
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBuJp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSN9jOWbrBKT5qrnZPwFp
7Tu31d0+vHIEABs90Ns=
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAuJp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSN9jOWbrBKT5qrnZPwFp
AKK6zHA=
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBOJp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSN9jOWbrBKQBTevIyQ==

  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQAOJp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAuijPL1weSAMAFT3EiA==
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQB+Jp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4HoWzZOHLJAGgD9zMDK
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+Jp/uxda2+/cpxXsOr+WSB95tGCDX+AtLjF3Zsg+u7h
u29B9K7wM3x/gfQOn49OIPrSqse5IHrf9acbQXTf3am2s+8A+Qq8a+YB6WNH
XvsuA9KOIZJ7PgJph64Pb0G03dNnup+A9CbN0jYQvb/u06xfQHrh/NPyv4F0
39Ki8+/vvnJc4pEnL37/laPLzfsPvR68cnzdX65k/fCVY6LJsq3THr1yZJjJ
eX86kO67vtz5IZDeJ7y7auLjV44PTvZKbQLSM77+YNkPpCdVBh25B6R376g4
sfbpK0fe2ZPWPADSftZv1vx79spxRY+ox9G3rxxvigYzib975XjY3UFMCkhf
Wv3CGkRzeZffkgHS7ukrv4FoAAMyvTM=
  "]],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604835408228465*^9, 3.604901629326247*^9, 
  3.604997509027685*^9, 3.604997838913097*^9, 3.604997998930159*^9, 
  3.604998262385709*^9, 3.604998679540615*^9, 3.604999023114602*^9, 
  3.6049995671825857`*^9, 3.6053222206832952`*^9, 3.605329248410247*^9, 
  3.60534487936777*^9, 3.605499360791535*^9, 3.605499759516876*^9, 
  3.6055002712154837`*^9, 3.6055009796613398`*^9, 3.605517527577972*^9, 
  3.605518590363236*^9, 3.6060197075827093`*^9, 3.6066245074463673`*^9, 
  3.6072547989952717`*^9, 3.607746835736318*^9, 3.608458669193894*^9, 
  3.6084610482999268`*^9, 3.608611357245063*^9, 3.60897224584616*^9, 
  3.609039060430893*^9, 3.6090655117799797`*^9, 3.60913053057734*^9, 
  3.61007878777255*^9, 3.610183012581427*^9, 3.6107687433822393`*^9, 
  3.61432121667342*^9, 3.614488594596417*^9, 3.61449489800876*^9, 
  3.614495199270974*^9, 3.61450056372791*^9}],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604835408228465*^9, 3.604901629326247*^9, 
  3.604997509027685*^9, 3.604997838913097*^9, 3.604997998930159*^9, 
  3.604998262385709*^9, 3.604998679540615*^9, 3.604999023114602*^9, 
  3.6049995671825857`*^9, 3.6053222206832952`*^9, 3.605329248410247*^9, 
  3.60534487936777*^9, 3.605499360791535*^9, 3.605499759516876*^9, 
  3.6055002712154837`*^9, 3.6055009796613398`*^9, 3.605517527577972*^9, 
  3.605518590363236*^9, 3.6060197075827093`*^9, 3.6066245074463673`*^9, 
  3.6072547989952717`*^9, 3.607746835736318*^9, 3.608458669193894*^9, 
  3.6084610482999268`*^9, 3.608611357245063*^9, 3.60897224584616*^9, 
  3.609039060430893*^9, 3.6090655117799797`*^9, 3.60913053057734*^9, 
  3.61007878777255*^9, 3.610183012581427*^9, 3.6107687433822393`*^9, 
  3.61432121667342*^9, 3.614488594596417*^9, 3.61449489800876*^9, 
  3.614495199270974*^9}],

Cell[BoxData[
 FormBox["90", TraditionalForm]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.604835408228465*^9, 3.604901629326247*^9, 
  3.604997509027685*^9, 3.604997838913097*^9, 3.604997998930159*^9, 
  3.604998262385709*^9, 3.604998679540615*^9, 3.604999023114602*^9, 
  3.6049995671825857`*^9, 3.6053222206832952`*^9, 3.605329248410247*^9, 
  3.60534487936777*^9, 3.605499360791535*^9, 3.605499759516876*^9, 
  3.6055002712154837`*^9, 3.6055009796613398`*^9, 3.605517527577972*^9, 
  3.605518590363236*^9, 3.6060197075827093`*^9, 3.6066245074463673`*^9, 
  3.6072547989952717`*^9, 3.607746835736318*^9, 3.608458669193894*^9, 
  3.6084610482999268`*^9, 3.608611357245063*^9, 3.60897224584616*^9, 
  3.609039060430893*^9, 3.6090655117799797`*^9, 3.60913053057734*^9, 
  3.61007878777255*^9, 3.610183012581427*^9, 3.6107687433822393`*^9, 
  3.61432121667342*^9, 3.614488594596417*^9, 3.61449489800876*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eee scattering amplitude (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ef"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 ")"
}], "Section",
 CellChangeTimes->{{3.602500218571827*^9, 3.602500231014485*^9}, {
  3.614495334056213*^9, 3.614495334357644*^9}, {3.614587354336177*^9, 
  3.614587364202553*^9}}],

Cell["The eee amplitude with 3 onshell legs:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
  3.601895022880265*^9}, {3.602331368630467*^9, 3.602331382508975*^9}, {
  3.614495338911874*^9, 3.6144953391965723`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"verEEEonshell123", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"verEEE", "//", "Contract"}], ")"}], "/.", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "j"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"i", "\[Rule]", "e"}], ",", 
     RowBox[{"j", "\[Rule]", "f"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.602331392459587*^9, 3.602331419828217*^9}, {
  3.602331481053072*^9, 3.602331483499743*^9}, {3.602396894714862*^9, 
  3.6023969065846863`*^9}, {3.6144895305389*^9, 3.614489583335857*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.602331401995409*^9, 3.6023314206558313`*^9}, 
   3.602396907329153*^9, 3.602499810747608*^9, 3.602831990408771*^9, 
   3.602832388854732*^9, 3.6030881669871264`*^9, 3.603094307551989*^9, 
   3.604037078716859*^9, 3.6040449594740677`*^9, 3.6040526754550543`*^9, 
   3.604055883682981*^9, 3.604056040372099*^9, 3.604397626578864*^9, 
   3.604397860577434*^9, 3.604398246714408*^9, 3.604398492019617*^9, 
   3.6043985842953176`*^9, 3.604400983315955*^9, 3.6044019666464787`*^9, 
   3.6044021087530327`*^9, 3.604403315221642*^9, 3.604405714765356*^9, 
   3.604649257580556*^9, 3.604653205280054*^9, 3.604821175691725*^9, 
   3.604821358918969*^9, 3.604827057941599*^9, 3.604901613854699*^9, 
   3.604997493737465*^9, 3.604997823526428*^9, 3.604997982933484*^9, 
   3.604998246133398*^9, 3.604998664413342*^9, 3.604999009208597*^9, 
   3.604999552453579*^9, 3.6053222022188883`*^9, 3.605329234525961*^9, 
   3.6053448655736856`*^9, 3.605499347787444*^9, 3.605499746642235*^9, 
   3.605500256770092*^9, 3.6055009662439337`*^9, 3.605517512992713*^9, 
   3.605518574438402*^9, 3.606019694351389*^9, 3.606624493568824*^9, 
   3.607254788076982*^9, 3.607746820718091*^9, 3.6084586536475763`*^9, 
   3.608461029772558*^9, 3.608611340586561*^9, 3.608972230610519*^9, 
   3.609039044993692*^9, 3.6090654967283373`*^9, 3.609130513342875*^9, 
   3.610078769272253*^9, 3.6101829973212147`*^9, 3.610183040413521*^9, 
   3.610768723268023*^9, 3.614321201145203*^9, 3.614488581300045*^9, 
   3.614489584134202*^9, 3.614495193378955*^9, 3.614500558430891*^9, 
   3.614500783086699*^9, 3.6145009248279543`*^9, 3.614505652893125*^9, 
   3.6145771299018793`*^9, 3.61493714463776*^9, 3.615633727160007*^9, 
   3.6162145888945913`*^9, 3.617336089230506*^9, 3.617338209876212*^9, 
   3.618217356364726*^9, 3.6193335864253674`*^9, 3.619774952575275*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "verEEEonshell123", "]"}]], "Input",
 CellChangeTimes->{{3.602332132168213*^9, 3.602332135145669*^9}}],

Cell[BoxData[
 FormBox["14", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVz1toEmAYxnEj2NaQVcMxCyUjQmwLS9tFOFffbBbDTuKGbBRlW0UIIyKx
KBitclRIKu3QwejCgcLMbRHhgpi0jEJvMt10msdV7+Y2lbVR2Xq/i4ff7fPf
rulSdq5jMBjNOPmN+frvQSADF9Wc/SEgcoXvWAQV+q3d1MObZzvUU0Dikcsd
7ei+ypCbHwZSOL9oqUFvKq6qhaiIofu5B117tKlITTqV3hD6ymVOU636MGsK
HTnRI6Za7BsOUJ+1wqVpVLwQyFDZxwdWqMmWC8YwWmM47Y6gZQWRTRkBUm+w
m1Uo0/urbwgtNyWGqeZCg86OZiveRn2o0f/G+RcNeHIhKm8iNkdNdk4yi2j6
VgWh3nPztdTYi40uanuvQvJkBki07qTDilpTIsUQqn94zZ1DG0ta5ql52Zba
PJoVfLxN/XGEN/gbfW/4yv2DBk2ffYtRIE7dKLf6GxB43hNvjgPRPujnSRJA
ejWvx/qSQFhdEzP96KrNQhJoU3dAb0oB8a/Z2KPolxL2+ncoJ7HXE0MPCgUf
hjNAVIMORxz1sGQu6tKpK45/s0AUh3bKJ7P4r+hiVC8AuZ/YLdlKlfmnOaim
LLVMbRh/XMpFm0K21m1osFwqbUSZ6arSPFp3JsOXL2EvPPWezQFpeyk4d6cA
RHddqr2L7mozjoiXgXyaO+pWrQDZYaqU1q4C+Q9usl6n
  "]]
}, Open  ]],

Cell["We check that the eee amplitude satisfies the Ward identity.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
  3.601895022880265*^9}, {3.6023313741357803`*^9, 3.602331374357727*^9}, {
  3.6144953456320953`*^9, 3.614495345925658*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"k", "[", 
            RowBox[{"1", ",", "a"}], "]"}], "verEEEonshell123", " ", 
           RowBox[{"xibar", "[", 
            RowBox[{"1", ",", "b"}], "]"}], " ", 
           RowBox[{"xi", "[", 
            RowBox[{"2", ",", "c"}], "]"}], 
           RowBox[{"xibar", "[", 
            RowBox[{"2", ",", "d"}], "]"}], 
           RowBox[{"xi", "[", 
            RowBox[{"3", ",", "e"}], "]"}], 
           RowBox[{"xibar", "[", 
            RowBox[{"3", ",", "f"}], "]"}]}], "//", "Expand"}], "//", 
         "Contract"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}],
      "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"kdotk", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.601724328652483*^9, 3.601724878867429*^9}, {
  3.601724973478969*^9, 3.601724975593553*^9}, {3.601895070134055*^9, 
  3.601895135135469*^9}, {3.60223801458788*^9, 3.6022381120776453`*^9}, {
  3.602331338670867*^9, 3.602331347413097*^9}, {3.61018302907267*^9, 
  3.6101830497498407`*^9}, {3.61018316226029*^9, 3.610183165158978*^9}, {
  3.6101836104368343`*^9, 3.610183611582963*^9}, {3.6144896036595592`*^9, 
  3.6144896607175922`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "2"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "3"],
        TraditionalForm]}]}], "-", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "2"],
        TraditionalForm]}]}], "+", 
     RowBox[{
      RowBox[{
       FormBox[
        SubscriptBox["\[Eta]", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "3"],
        TraditionalForm]}], " ", 
      RowBox[{
       FormBox[
        SubscriptBox["k", "2"],
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["\[Eta]", "1"],
        TraditionalForm]}]}]}], ")"}], " ", 
   RowBox[{
    FormBox[
     SubscriptBox["k", "1"],
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["\[Xi]", "2"],
     TraditionalForm]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["\[Xi]", "3"],
       TraditionalForm]}], "+", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["\[Xi]", "3"],
       TraditionalForm]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.601895135793324*^9, 3.6018977166808023`*^9, 3.601973965749297*^9, 
   3.601975002166479*^9, 3.6022258193901978`*^9, 3.602227120847394*^9, 
   3.6022272626548653`*^9, 3.602227471715334*^9, {3.602238050030649*^9, 
   3.60223811272069*^9}, 3.602240450318458*^9, 3.602331347856646*^9, 
   3.6024998108200893`*^9, 3.60283199051431*^9, 3.602832389081932*^9, 
   3.603088167499701*^9, 3.603094307657754*^9, 3.6040370788049994`*^9, 
   3.604044959631425*^9, 3.604052675857366*^9, 3.604055883762645*^9, 
   3.6040560405842648`*^9, 3.604397626802581*^9, 3.604397860653058*^9, 
   3.604398246886388*^9, 3.604398492239558*^9, 3.604398584392085*^9, 
   3.604400983420231*^9, 3.604401966747013*^9, 3.604402108845818*^9, 
   3.604403315334837*^9, 3.604405715152938*^9, 3.604649257679328*^9, 
   3.604653205364641*^9, 3.6048211759235773`*^9, 3.6048213593120003`*^9, 
   3.604827058078806*^9, 3.604901613981414*^9, 3.604997493906233*^9, 
   3.604997823661868*^9, 3.604997983075025*^9, 3.604998246273479*^9, 
   3.604998664562941*^9, 3.604999009320043*^9, 3.604999552577344*^9, 
   3.605322202535152*^9, 3.6053292346027193`*^9, 3.605344865662486*^9, 
   3.6054993479112797`*^9, 3.6054997467276917`*^9, 3.605500256882934*^9, 
   3.6055009663242683`*^9, 3.605517513088645*^9, 3.605518574776104*^9, 
   3.606019694456184*^9, 3.606624493655525*^9, 3.607254788178154*^9, 
   3.6077468208190517`*^9, 3.608458653809518*^9, 3.6084610302036533`*^9, 
   3.6086113407393208`*^9, 3.608972230797789*^9, 3.6090390453324738`*^9, 
   3.609065496853819*^9, 3.609130513656281*^9, 3.6100787694426813`*^9, 
   3.610182997446083*^9, {3.6101830296421824`*^9, 3.610183050387488*^9}, 
   3.6101831658658257`*^9, 3.610183612345847*^9, 3.610768723726372*^9, 
   3.614321201274169*^9, 3.6144885816164513`*^9, 3.6144896618946342`*^9, 
   3.6144951936789503`*^9, 3.614500558530961*^9, 3.614500783176564*^9, 
   3.6145009249246492`*^9, 3.6145056532648563`*^9, 3.614577129991947*^9, 
   3.6149371447679777`*^9, 3.615633727250127*^9, 3.616214588996344*^9, 
   3.617336089387416*^9, 3.617338210007258*^9, 3.6182173565321302`*^9, 
   3.619333586527767*^9, 3.6197749526663313`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"k", "[", 
            RowBox[{"1", ",", "a"}], "]"}], "verEEEonshell123"}], " ", "//", 
          "Expand"}], "//", "Contract"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}],
      "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"kdotk", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{
  3.610183505403319*^9, {3.610183615089226*^9, 3.610183616416986*^9}, {
   3.61018424707718*^9, 3.610184248022201*^9}, {3.6101843931848927`*^9, 
   3.6101843944644337`*^9}, {3.614489685235763*^9, 3.6144897574525146`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "4"]}], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["1",
     TraditionalForm], 
    FormBox[
     FormBox["c",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], "+", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.610183506231072*^9, 3.610183618814723*^9, 
  3.610184252299098*^9, 3.6101843953828907`*^9, 3.610768724096281*^9, 
  3.614321201778452*^9, 3.614488581820071*^9, 3.614489758403143*^9, 
  3.61449519387679*^9, 3.6145005587810507`*^9, 3.614500783654726*^9, 
  3.614500925383739*^9, 3.6145056534920597`*^9, 3.6145771302233458`*^9, 
  3.6149371449748096`*^9, 3.6156337274738007`*^9, 3.616214589237318*^9, 
  3.6173360896042013`*^9, 3.617338210236261*^9, 3.618217356755795*^9, 
  3.619333586769953*^9, 3.619774952889997*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"k", "[", 
            RowBox[{"2", ",", "c"}], "]"}], "verEEEonshell123"}], " ", "//", 
          "Expand"}], "//", "Contract"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}],
      "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"kdotk", "[", 
      RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{
  3.610183505403319*^9, {3.610183615089226*^9, 3.610183616416986*^9}, {
   3.61018424707718*^9, 3.610184248022201*^9}, {3.6144897890792*^9, 
   3.6144898580928164`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
   SubsuperscriptBox["k", 
    FormBox["2",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], "+", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.610183506231072*^9, 3.610183618814723*^9, 
  3.610184252299098*^9, 3.610768724424683*^9, 3.614321202007266*^9, 
  3.614488582049608*^9, 3.614489859306787*^9, 3.6144951941014147`*^9, 
  3.614500559038642*^9, 3.614500783872633*^9, 3.614500925597464*^9, 
  3.614505653697897*^9, 3.61457713046074*^9, 3.61493714517941*^9, 
  3.6156337277345*^9, 3.616214589439148*^9, 3.617336089804656*^9, 
  3.617338210444778*^9, 3.618217356956933*^9, 3.6193335869776*^9, 
  3.6197749530914516`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "e"}], "]"}]}], "-", 
             RowBox[{"k", "[", 
              RowBox[{"2", ",", "e"}], "]"}]}], ")"}], "verEEEonshell123"}], 
          " ", "//", "Expand"}], "//", "Contract"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}],
      "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.610184050059238*^9, 3.610184068497746*^9}, {
  3.610184118742997*^9, 3.6101841475342503`*^9}, {3.614489883130808*^9, 
  3.614489918005965*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610184069609519*^9, {3.610184122575292*^9, 3.6101841482835817`*^9}, 
   3.6107687248077927`*^9, 3.614321202311083*^9, 3.614488582306925*^9, 
   3.614489885878162*^9, 3.6144899191629467`*^9, 3.614495194350775*^9, 
   3.6145005593001633`*^9, 3.6145007841295443`*^9, 3.6145009258411703`*^9, 
   3.61450565396968*^9, 3.614577130752578*^9, 3.6149371454427233`*^9, 
   3.615633727987637*^9, 3.616214589718526*^9, 3.617336090072999*^9, 
   3.617338210729731*^9, 3.618217357240663*^9, 3.619333587340375*^9, 
   3.61977495335955*^9}]
}, Open  ]],

Cell["\<\
This indeed vanishes using momentum conservation and transversality.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
  3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
  3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
  3.601893558350622*^9, 3.6018935809869204`*^9}, {3.6018951408582497`*^9, 
  3.601895143895219*^9}, {3.601895389098605*^9, 3.601895399879635*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eeee scattering amplitude (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ef"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SuperscriptBox["e", "gh"], "[", 
     SubscriptBox["k", "4"], "]"}]}], TraditionalForm]]],
 ")"
}], "Section",
 CellChangeTimes->{{3.601882668497199*^9, 3.601882684555799*^9}, {
   3.601896514920569*^9, 3.6018965349801273`*^9}, 3.602226132317813*^9, {
   3.614502448121525*^9, 3.614502448594343*^9}}],

Cell[CellGroupData[{

Cell["e exchange diagrams", "Subsection",
 CellChangeTimes->{{3.6018979640354147`*^9, 3.601897972582534*^9}}],

Cell["\<\
Unlike in previous computations the propagators need a sign flip because now \
we have the \[OpenCurlyDoubleQuote]mostly plus\[CloseCurlyDoubleQuote] \
convention.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.6044041482973137`*^9, 3.604404157841824*^9}, {3.604648554310869*^9, 
   3.6046486678278627`*^9}, {3.604648710643353*^9, 3.60464871601261*^9}, {
   3.604649065823064*^9, 3.604649092507543*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4Eexchange", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", 
         "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], 
       RowBox[{"I", "/", "s"}], " ", 
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", ",", "i", ",", 
         "j"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "1", ",", "3", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
         "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], 
       RowBox[{"I", "/", "t"}], " ", 
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "2", ",", "4", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
         "j"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "1", ",", "4", ",", "a", ",", "b", ",", "g", ",", "h", ",", "i", ",", 
         "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], 
       RowBox[{"I", "/", "u"}], " ", 
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "2", ",", "3", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", 
         "j"}], "]"}]}]}], "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.601800889062563*^9, 3.6018008913845377`*^9}, {
   3.6018009237073927`*^9, 3.6018009602333384`*^9}, 3.60180103902945*^9, {
   3.601801123240301*^9, 3.601801153453907*^9}, {3.6018011842143106`*^9, 
   3.601801208717125*^9}, {3.6018013583620577`*^9, 3.6018014101449547`*^9}, {
   3.601801464114931*^9, 3.601801473851925*^9}, {3.6018015110242662`*^9, 
   3.601801512229225*^9}, 3.601801558753707*^9, {3.601801736452009*^9, 
   3.6018018372304688`*^9}, {3.601801879936207*^9, 3.601801882884056*^9}, 
   3.601801942996451*^9, {3.601802002385048*^9, 3.601802003709889*^9}, 
   3.6018029749158087`*^9, {3.6018977390495768`*^9, 3.601897777922901*^9}, {
   3.602229998924395*^9, 3.602230028260083*^9}, {3.604649036054744*^9, 
   3.604649050089335*^9}, {3.614501283440854*^9, 3.614501362636174*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"16", " ", "u"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"16", " ", "t"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", "s"}], 
            RowBox[{"8", " ", "u"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", "s"}], 
            RowBox[{"8", " ", "t"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "791", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 185, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 185, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 185, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[185]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6055009812918386`*^9, 3.605517529206732*^9, 
  3.60551837522686*^9, 3.6055185921057663`*^9, 3.6060197093414803`*^9, 
  3.60662450906264*^9, 3.60725480054669*^9, 3.607746837402122*^9, 
  3.608458670775622*^9, 3.608461050090526*^9, 3.6086113589668303`*^9, 
  3.6089722475135593`*^9, 3.609039062042251*^9, 3.609065513506118*^9, 
  3.60913053508959*^9, 3.610078789536079*^9, 3.610183014197352*^9, 
  3.610768745128727*^9, 3.614321218322115*^9, 3.614501127127256*^9, 
  3.614501366814309*^9, 3.614505660042061*^9, 3.61457713578751*^9, 
  3.614937147011366*^9, 3.615633729560418*^9, 3.6162145913515263`*^9, 
  3.617336091637947*^9, 3.617338212289618*^9, 3.618217358827825*^9, 
  3.619333588887542*^9, 3.619774955022221*^9}]
}, Open  ]],

Cell["\<\
A few inspections of the sum of e exchange tree-level diagrams:\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896420776207*^9, 3.60189643156511*^9}, {3.601897836669272*^9, 
  3.601897855418285*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4Eexchange", "//", "Length"}]], "Input",
 CellChangeTimes->{{3.601801294205007*^9, 3.601801295967149*^9}, 
   3.6018014198565702`*^9, 3.601802011039729*^9, 3.601802979290784*^9, 
   3.6018978187938538`*^9}],

Cell[BoxData[
 FormBox["534", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0WtI02EUBvAZWRaSlYVo2tRqTl3OUMmsoW+CSoXCkMxLkbOZNakICxsS
rssyhbyESimWYYPR5mw1MDcqSGvBQhBK3f65aTrG67ZyS5u30TkfDj8OPB8O
z4kRXRWKA1gs1mmY4MVtW2e/U9LplYej0vUdHHSs8U4iOhIyU4DmZ9VUoJWO
egZt7Dflz4GeWkli6A9K+A9KStJBf5rNgvbe3Vj4BpTqJEvosYZDQW9BhSc3
Fu0qcl7QYf6hs3YIlIuWI4+MU9IyJS2wgKa+YhlaH6wWn5mghOs/KC4FHZot
hjgzJd6vZ9sTwZsvh4v54L3mDpoMtsXw/GjSU61xHHTq1XNoncy7ewJc0SlT
Uc6e+CzUeSu8ehK07HfZ0epejQ/NkLU3m0HX4Hu9BVzW8xVCCyWBa5rHhWDH
gYAnCpAzzx5Atz+vrFWCTOi89RvocDEDa6AvPsKMJtvD3Cjnc1DIOtiQyctG
L6dFXUGZhBgtmlE2IehioG9/jqoH3NS9L18B7iotMCyAGblcN1pWyU7ygKoq
jRytu8brWgEvRgZHr4IJrzSjv3/C3acU7DArJf2anTMnbNDnrDb26DT08M6q
65ihpO/TSWsn+HHSkT0Nstp80tZflFQlGyO04CNJeuAH0BRHh6dwnx00quco
qbk+qrKB4tuH1X47JUsiYd6Ii5K8c+7oKDclBkFrJtrkbipig37lquA4urd8
swc8fymFm/OHEtri+lK+QMkz1Y2K+15K/jKN1XLwxRjzOmWRklR7z1DhP/jv
BpGA56PkP54smgY=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Count", "[", 
    RowBox[{"amp4Eexchange", ",", 
     RowBox[{"Power", "[", 
      RowBox[{"s", ",", 
       RowBox[{"-", "1"}]}], "]"}], ",", "10"}], "]"}], ",", 
   RowBox[{"Count", "[", 
    RowBox[{"amp4Eexchange", ",", 
     RowBox[{"Power", "[", 
      RowBox[{"t", ",", 
       RowBox[{"-", "1"}]}], "]"}], ",", "10"}], "]"}], ",", 
   RowBox[{"Count", "[", 
    RowBox[{"amp4Eexchange", ",", 
     RowBox[{"Power", "[", 
      RowBox[{"u", ",", 
       RowBox[{"-", "1"}]}], "]"}], ",", "10"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.601969151181973*^9, 3.601969154783752*^9}, {
  3.601969198751771*^9, 3.601969217162133*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"178", ",", "178", ",", "178"}], "}"}], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.601969204106668*^9, 3.601969217403453*^9}, 
   3.601973970847468*^9, 3.601975007033469*^9, 3.602225824173141*^9, 
   3.602227123370853*^9, 3.602227265551412*^9, 3.602227474292984*^9, 
   3.602230071904911*^9, 3.602240455437624*^9, 3.6024998158168983`*^9, 
   3.602831995923073*^9, 3.602832394931923*^9, 3.603088173479629*^9, 
   3.603094313518161*^9, 3.604037088383164*^9, 3.6040449710734243`*^9, 
   3.6040526862568817`*^9, 3.604055892788817*^9, 3.604056049441874*^9, 
   3.604397637800314*^9, 3.6043978694754133`*^9, 3.604398255664218*^9, 
   3.6043985013828897`*^9, 3.604398593367456*^9, 3.6044009928855257`*^9, 
   3.6044019754913177`*^9, 3.604402117567876*^9, 3.604403324762295*^9, 
   3.6044057261515923`*^9, 3.604649265505536*^9, 3.604653213513727*^9, 
   3.6048211920573*^9, 3.604821377012199*^9, 3.604827075222307*^9, 
   3.604901631365793*^9, 3.604997510926653*^9, 3.604997840853804*^9, 
   3.604998000776059*^9, 3.604998264372046*^9, 3.604998681418985*^9, 
   3.604999024948572*^9, 3.6049995691047993`*^9, 3.605322222811421*^9, 
   3.605329250375411*^9, 3.605344881178892*^9, 3.6054993625364227`*^9, 
   3.605499761324773*^9, 3.605500273059298*^9, 3.6055009815495253`*^9, 
   3.605517529467469*^9, 3.60551859247812*^9, 3.6060197095453253`*^9, 
   3.606624509257943*^9, 3.607254800607139*^9, 3.6077468376689*^9, 
   3.608458671100116*^9, 3.608461050511073*^9, 3.608611359296283*^9, 
   3.6089722477934427`*^9, 3.6090390623304367`*^9, 3.609065513888152*^9, 
   3.609130535418062*^9, 3.6100787899304523`*^9, 3.6101830145989447`*^9, 
   3.610768745863718*^9, 3.61432121862528*^9, 3.6145011274804153`*^9, 
   3.614501375249572*^9, 3.6145056604013767`*^9, 3.614577135915687*^9, 
   3.614937147051441*^9, 3.615633729636219*^9, 3.616214591473399*^9, 
   3.617336091705567*^9, 3.617338212388114*^9, 3.618217358938933*^9, 
   3.6193335890238333`*^9, 3.619774955094418*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"I", "  ", "16", "amp4Eexchange"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"a_", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "m_"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], "}"}]}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.601802033166669*^9, 3.601802077769244*^9}, 
   3.601802495296027*^9, 3.60180298204675*^9, 3.601897821606214*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["s", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "f"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "t"]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["s", "2"], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "h"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "u"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"f", "h"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"f", "h"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["t", "2"], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "h"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}], "u"], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["u", "2"], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "h"}]]}], "t"]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.60180205661154*^9, 3.601802078074072*^9}, 
   3.601802495702676*^9, 3.60180298247821*^9, 3.601803896678791*^9, 
   3.601897823037836*^9, 3.601973970948772*^9, 3.6019750070762577`*^9, 
   3.602225824226728*^9, 3.602227123440658*^9, 3.602227265600216*^9, 
   3.6022274743526087`*^9, 3.6022300778267527`*^9, 3.602240455491954*^9, 
   3.602499815864408*^9, 3.602831996016409*^9, 3.602832395029786*^9, 
   3.603088173583765*^9, 3.603094313615267*^9, 3.60403708846211*^9, 
   3.604044971322956*^9, 3.6040526863694353`*^9, 3.604055892884636*^9, 
   3.604056049521731*^9, 3.604397638013227*^9, 3.604397869540176*^9, 
   3.604398255732327*^9, 3.604398501479308*^9, 3.604398593458544*^9, 
   3.604400992990543*^9, 3.6044019755968227`*^9, 3.604402117671092*^9, 
   3.6044033248804407`*^9, 3.604405726337201*^9, 3.604649265599431*^9, 
   3.604653213577956*^9, 3.604821192131707*^9, 3.604821377106516*^9, 
   3.604827075328055*^9, 3.604901631477242*^9, 3.604997511018939*^9, 
   3.604997840904525*^9, 3.6049980008821163`*^9, 3.604998264457584*^9, 
   3.6049986815197763`*^9, 3.604999025021248*^9, 3.60499956920435*^9, 
   3.6053222228646383`*^9, 3.60532925043279*^9, 3.605344881279055*^9, 
   3.605499362622122*^9, 3.605499761395574*^9, 3.605500273145026*^9, 
   3.605500981608927*^9, 3.605517529539543*^9, 3.605518592594804*^9, 
   3.606019709618334*^9, 3.606624509337502*^9, 3.607254800655484*^9, 
   3.607746837740788*^9, 3.608458671202366*^9, 3.608461050680316*^9, 
   3.608611359417759*^9, 3.608972247912559*^9, 3.609039062399925*^9, 
   3.6090655140162992`*^9, 3.609130535507642*^9, 3.610078790081793*^9, 
   3.610183014705792*^9, 3.610768746136471*^9, 3.614321218710779*^9, 
   3.614501127531507*^9, 3.614501378122355*^9, 3.614505660447694*^9, 
   3.614577136010024*^9, 3.614937147088153*^9, 3.6156337296783333`*^9, 
   3.616214591539768*^9, 3.6173360917449007`*^9, 3.617338212447405*^9, 
   3.61821735898748*^9, 3.619333589097558*^9, 3.6197749551450377`*^9}]
}, Open  ]],

Cell["Checking Bose symmetry:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896420776207*^9, 3.60189643156511*^9}, {3.601897836669272*^9, 
  3.601897855418285*^9}, {3.602230605273546*^9, 3.602230612872519*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"amp4Eexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4Eexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "b"}], ",", 
        RowBox[{"t", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "t"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4Eexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4Eexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "b"}], ",", 
        RowBox[{"s", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4Eexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4Eexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "b"}], ",", 
        RowBox[{"t", "\[Rule]", "s"}], ",", 
        RowBox[{"s", "\[Rule]", "t"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4Eexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4Eexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "c"}], ",", 
        RowBox[{"d", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "d"}], ",", 
        RowBox[{"s", "\[Rule]", "t"}], ",", 
        RowBox[{"t", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4Eexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4Eexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "c"}], ",", 
        RowBox[{"d", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "d"}], ",", 
        RowBox[{"u", "\[Rule]", "s"}], ",", 
        RowBox[{"s", "\[Rule]", "u"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4Eexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4Eexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"e", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "e"}], ",", 
        RowBox[{"f", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "f"}], ",", 
        RowBox[{"u", "\[Rule]", "t"}], ",", 
        RowBox[{"t", "\[Rule]", "u"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.60222962884649*^9, 3.6022297444944696`*^9}, {
  3.602230647592573*^9, 3.602230656683042*^9}, {3.6022307986244698`*^9, 
  3.602230824535781*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.602229731594522*^9, 3.602229744760645*^9}, 
   3.602230657569434*^9, 3.60223082490466*^9, 3.602240455662315*^9, 
   3.602499816015953*^9, 3.6028319961737223`*^9, 3.602832395236207*^9, 
   3.603088173802578*^9, 3.603094313826912*^9, 3.604037088671769*^9, 
   3.60404497147684*^9, 3.604052686499177*^9, 3.604055893027898*^9, 
   3.604056049646954*^9, 3.604397638346887*^9, 3.604397869706168*^9, 
   3.604398255913599*^9, 3.604398501608383*^9, 3.604398593588649*^9, 
   3.604400993120542*^9, 3.604401975728266*^9, 3.604402117800764*^9, 
   3.604403325011406*^9, 3.604405726648036*^9, 3.604649265736126*^9, 
   3.604653213750296*^9, 3.604821192266993*^9, 3.604821377331997*^9, 
   3.604827075563833*^9, 3.604901631727852*^9, 3.604997511194272*^9, 
   3.6049978410482807`*^9, 3.604998001139391*^9, 3.60499826468399*^9, 
   3.6049986817623787`*^9, 3.604999025162129*^9, 3.6049995693788433`*^9, 
   3.6053222230690002`*^9, 3.605329250625701*^9, 3.605344881455845*^9, 
   3.60549936276523*^9, 3.605499761538311*^9, 3.605500273336061*^9, 
   3.605500981790032*^9, 3.605517529729464*^9, 3.605518592815752*^9, 
   3.606019709766816*^9, 3.606624509477845*^9, 3.607254800807033*^9, 
   3.6077468379570312`*^9, 3.608458671423787*^9, 3.608461050833544*^9, 
   3.608611359685526*^9, 3.608972248066814*^9, 3.6090390626070147`*^9, 
   3.609065514254149*^9, 3.609130535718382*^9, 3.610078790249094*^9, 
   3.610183014936796*^9, 3.61076874640657*^9, 3.6143212189014597`*^9, 
   3.614501127670879*^9, 3.614505660591868*^9, 3.614577136190042*^9, 
   3.6149371472440166`*^9, 3.615633729830331*^9, 3.616214591714773*^9, 
   3.6173360918956423`*^9, 3.617338212604204*^9, 3.61821735919552*^9, 
   3.6193335892608013`*^9, 3.619774955305772*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[CurlyPhi] exchange diagrams", "Subsection",
 CellChangeTimes->{{3.601897982528846*^9, 3.601897989793633*^9}, 
   3.6162217730420933`*^9}],

Cell["\<\
Again, unlike in previous computations the propagators need a sign flip \
because now we have the \[OpenCurlyDoubleQuote]mostly plus\
\[CloseCurlyDoubleQuote] convention.\
\>", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.6018825996986227`*^9, 3.601882618496421*^9}, {
   3.601893558350622*^9, 3.601893558659031*^9}, {3.60189502199518*^9, 
   3.601895022880265*^9}, {3.6018963529258337`*^9, 3.60189636857299*^9}, {
   3.601897138351499*^9, 3.6018972411491413`*^9}, 3.602229254349514*^9, {
   3.6044041482973137`*^9, 3.604404157841824*^9}, {3.604648554310869*^9, 
   3.6046486678278627`*^9}, {3.604648710643353*^9, 3.60464871601261*^9}, {
   3.604649065823064*^9, 3.604649092507543*^9}, {3.604649147340787*^9, 
   3.6046491488757668`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4VARPHIexchange", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "I"}], "/", "16"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"s", " ", 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"e", ",", "g"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"f", ",", "h"}], "]"}]}], "+", 
      RowBox[{"t", " ", 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "e"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "f"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "g"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "h"}], "]"}]}], "+", 
      RowBox[{"u", " ", 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "g"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "h"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"c", ",", "e"}], "]"}], 
       RowBox[{"d", "[", 
        RowBox[{"d", ",", "f"}], "]"}]}]}], ")"}]}], "//", 
   "Contract"}]}]], "Input",
 CellChangeTimes->{{3.601802403820528*^9, 3.6018024091103907`*^9}, {
   3.60180283621449*^9, 3.601802901958374*^9}, 3.601802985030754*^9, {
   3.601897878760676*^9, 3.601897880151854*^9}, 3.604649136937821*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"f", "h"}]]}]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "t", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.601802897747238*^9, 3.601802902207399*^9}, 
   3.601802985683408*^9, 3.601803898853541*^9, 3.6018978817074223`*^9, 
   3.6019739710958767`*^9, 3.601975007145294*^9, 3.602225824295103*^9, 
   3.602227123558938*^9, 3.602227265697549*^9, 3.6022274745124483`*^9, 
   3.6022404557185173`*^9, 3.60249981607014*^9, 3.6028319962951183`*^9, 
   3.602832395327263*^9, 3.603088173887623*^9, 3.60309431390968*^9, 
   3.604037088752734*^9, 3.6040449716887293`*^9, 3.604052686616384*^9, 
   3.60405589314832*^9, 3.604056049752346*^9, 3.604397638559697*^9, 
   3.6043978697602777`*^9, 3.604398255965949*^9, 3.604398501729289*^9, 
   3.604398593706819*^9, 3.604400993240366*^9, 3.604401975846863*^9, 
   3.604402117919959*^9, 3.604403325145337*^9, 3.6044057268462067`*^9, 
   3.604649265873372*^9, 3.6046532138668327`*^9, 3.604821192389307*^9, 
   3.6048213774383793`*^9, 3.604827075708973*^9, 3.604901631868229*^9, 
   3.6049975112746563`*^9, 3.60499784121813*^9, 3.60499800123897*^9, 
   3.604998264762336*^9, 3.604998681852621*^9, 3.604999025285984*^9, 
   3.604999569464553*^9, 3.605322223196911*^9, 3.605329250688382*^9, 
   3.6053448815606613`*^9, 3.6054993628758287`*^9, 3.60549976163361*^9, 
   3.605500174311768*^9, 3.605500273416656*^9, 3.605500981890277*^9, 
   3.60551752980585*^9, 3.605518592915245*^9, 3.6060197098633413`*^9, 
   3.6066245095834084`*^9, 3.607254800858531*^9, 3.607746838038249*^9, 
   3.608458671527315*^9, 3.608461051033669*^9, 3.608611359813539*^9, 
   3.608972248170755*^9, 3.609039062682053*^9, 3.609065514393374*^9, 
   3.609130535819168*^9, 3.610078790446144*^9, 3.610183015048562*^9, 
   3.610768746575851*^9, 3.61432121896213*^9, 3.6145011277462254`*^9, 
   3.614505660714686*^9, 3.614577136275625*^9, 3.614937147306197*^9, 
   3.615633729882002*^9, 3.616214591769144*^9, 3.61733609194786*^9, 
   3.6173382126576777`*^9, 3.618217359249951*^9, 3.61933358932248*^9, 
   3.6197749553678837`*^9}]
}, Open  ]],

Cell["Checking Bose symmetry:", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896420776207*^9, 3.60189643156511*^9}, {3.601897836669272*^9, 
  3.601897855418285*^9}, {3.602230605273546*^9, 3.602230612872519*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"amp4VARPHIexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4VARPHIexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "c"}], ",", 
        RowBox[{"c", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "d"}], ",", 
        RowBox[{"d", "\[Rule]", "b"}], ",", 
        RowBox[{"t", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "t"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4VARPHIexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4VARPHIexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "b"}], ",", 
        RowBox[{"s", "\[Rule]", "u"}], ",", 
        RowBox[{"u", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4VARPHIexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4VARPHIexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "a"}], ",", 
        RowBox[{"b", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "b"}], ",", 
        RowBox[{"t", "\[Rule]", "s"}], ",", 
        RowBox[{"s", "\[Rule]", "t"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4VARPHIexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4VARPHIexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "e"}], ",", 
        RowBox[{"e", "\[Rule]", "c"}], ",", 
        RowBox[{"d", "\[Rule]", "f"}], ",", 
        RowBox[{"f", "\[Rule]", "d"}], ",", 
        RowBox[{"s", "\[Rule]", "t"}], ",", 
        RowBox[{"t", "\[Rule]", "s"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4VARPHIexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4VARPHIexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "c"}], ",", 
        RowBox[{"d", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "d"}], ",", 
        RowBox[{"u", "\[Rule]", "s"}], ",", 
        RowBox[{"s", "\[Rule]", "u"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"amp4VARPHIexchange", "-", 
    RowBox[{"(", 
     RowBox[{"amp4VARPHIexchange", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"e", "\[Rule]", "g"}], ",", 
        RowBox[{"g", "\[Rule]", "e"}], ",", 
        RowBox[{"f", "\[Rule]", "h"}], ",", 
        RowBox[{"h", "\[Rule]", "f"}], ",", 
        RowBox[{"u", "\[Rule]", "t"}], ",", 
        RowBox[{"t", "\[Rule]", "u"}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}]}], "}"}]}], 
     ")"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.60222962884649*^9, 3.6022297444944696`*^9}, {
  3.602230647592573*^9, 3.602230656683042*^9}, {3.602230698239215*^9, 
  3.60223069890628*^9}, {3.602230733574572*^9, 3.6022307813232727`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.602229731594522*^9, 3.602229744760645*^9}, 
   3.602230657569434*^9, 3.60223069957679*^9, {3.6022307704495068`*^9, 
   3.602230781973811*^9}, 3.602240455842906*^9, 3.602499816111114*^9, 
   3.602831996399044*^9, 3.602832395510873*^9, 3.603088174011286*^9, 
   3.603094314028883*^9, 3.604037088863649*^9, 3.6040449719078827`*^9, 
   3.604052686745028*^9, 3.604055893227531*^9, 3.604056049829018*^9, 
   3.6043976388042583`*^9, 3.60439786983494*^9, 3.6043982560466146`*^9, 
   3.604398501822179*^9, 3.6043985937961073`*^9, 3.604400993336589*^9, 
   3.604401975940716*^9, 3.6044021180106707`*^9, 3.604403325246726*^9, 
   3.6044057270639*^9, 3.604649265951364*^9, 3.604653213888218*^9, 
   3.604821192459861*^9, 3.6048213775459642`*^9, 3.604827075830811*^9, 
   3.604901631984151*^9, 3.604997511356885*^9, 3.6049978412673817`*^9, 
   3.60499800134933*^9, 3.604998264861248*^9, 3.604998681965273*^9, 
   3.604999025325629*^9, 3.6049995695458727`*^9, 3.6053222233973083`*^9, 
   3.605329250783442*^9, 3.6053448816320066`*^9, 3.6054993629687777`*^9, 
   3.605499761716919*^9, 3.605500273518805*^9, 3.605500981950307*^9, 
   3.605517529897814*^9, 3.605518593040003*^9, 3.6060197099495363`*^9, 
   3.606624509677267*^9, 3.607254800911332*^9, 3.607746838157436*^9, 
   3.608458671658081*^9, 3.608461051206996*^9, 3.608611359950143*^9, 
   3.608972248278512*^9, 3.609039062785715*^9, 3.609065514520702*^9, 
   3.609130535938151*^9, 3.6100787906126957`*^9, 3.610183015177088*^9, 
   3.610768746702552*^9, 3.6143212190638742`*^9, 3.614501127792109*^9, 
   3.614505660766827*^9, 3.614577136410673*^9, 3.61493714735249*^9, 
   3.615633729934709*^9, 3.616214591850758*^9, 3.6173360919994497`*^9, 
   3.617338212715034*^9, 3.618217359324236*^9, 3.6193335893973503`*^9, 
   3.619774955433215*^9}]
}, Open  ]],

Cell["Hence, the full 4e amplitude has Bose symmetry.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896420776207*^9, 3.60189643156511*^9}, {3.601897836669272*^9, 
  3.601897855418285*^9}, {3.602230605273546*^9, 3.602230612872519*^9}, {
  3.6022309040486317`*^9, 3.6022309180240498`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4e amplitude", "Subsection",
 CellChangeTimes->{{3.601897982528846*^9, 3.601897989793633*^9}, {
  3.601968328519759*^9, 3.601968331076151*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
    "amp4Eexchange", "+", "amp4VARPHIexchange", "+", "verEEEEonshell"}], 
    ")"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.601802988136907*^9, 3.601803027069841*^9}, {
   3.601803078464552*^9, 3.601803083416788*^9}, {3.601803118961344*^9, 
   3.60180313347232*^9}, {3.6018757813423758`*^9, 3.601875781825548*^9}, 
   3.6018760182012978`*^9, {3.6018776527885923`*^9, 3.60187765291535*^9}, 
   3.601877837907439*^9, {3.6018778921077023`*^9, 3.601877892372789*^9}, 
   3.601877977829279*^9, {3.601897927244547*^9, 3.601897950109571*^9}, 
   3.601968371694697*^9, 3.6040525953772182`*^9, 3.604052656528199*^9, {
   3.604055690074335*^9, 3.604055691949005*^9}, 3.6040558679965267`*^9, 
   3.6040559593816853`*^9, {3.604397516128151*^9, 3.604397517974156*^9}, {
   3.6043978423509827`*^9, 3.604397844661191*^9}, 3.604398480621339*^9, 
   3.604398571803533*^9, {3.6044009581519833`*^9, 3.604400963551817*^9}, 
   3.6044019565027514`*^9, 3.6044020964061003`*^9, {3.604649169058374*^9, 
   3.604649170985036*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"16", " ", "u"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"16", " ", "t"}]], "+", 
           RowBox[{
            FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "f"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", "s"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", "s"}], 
            RowBox[{"8", " ", "u"}]], "+", 
           RowBox[{
            FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "f"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", "s"}], "+", 
           RowBox[{"\[LeftSkeleton]", "1024", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 192, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 192, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 192, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[192]], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0VtI03EYxvGtWKOLmhfhoQM2G8sy1HJdDJv0lnNrFxKytFAiHfPC7EB0
kAw6iH+dXViERY6sq0mlsaldWMPAbTiDigpyTW0Hd9AXmvM/Mlvb6v1dPHzg
uf1Kmy7UGIUCgUBDKy633g3NIOxdnDae9CBc3KYz1pMLyzL7bi/C5lumviKS
N9+rLiFl232nmA2c83Mp+aXfhszOScgwO5KR8RlSkhd1Mxt6nWGmN70x20Me
H3comEsCOMw0Nytav5P6DlGUOdg3tcaUBGy9XrLnZuztLOkxaC01swipiOOB
nrwWzXlsIc+cUFqZfPJ223NydH6D/wMZTiesKVL1otTLzM1TxJj9u2SSNHns
leYoc5A7cJ75NKEcYWbLV1XmOYSM0DA0QNaGD1VbSLmk2b5CKs6avjI96yti
TF37pJQnY93KYmZW7RTHDD1Rm5NkSW7Rzr9k2zfXp+V5hKtJe36OD8HZJQvq
/AiVix8LygMIlpep1w+DCBOjl32PyD+rosoAuWcpq/3+AsKNTcGtI6TWUSd6
Rzp7xK4f5PXGkHs4jHBHEx/yk93q08OZCAIXatG6fiI0iYXSHTGEAu2zunxS
8G9LxRGy0HFJzJP7y9SFVXHqH1/nblyhv6rL0JlAODc90MqRLXLeVvYL4f3c
2Bv9b4SDpiuqfWsI/wE6p0+X
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4", "//", "Length"}]], "Input",
 CellChangeTimes->{{3.60180308861264*^9, 3.6018030909952497`*^9}}],

Cell[BoxData[
 FormBox["669", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0mtIE1AYxvGl1maJlpaGOJeCGixSW6XpHB4XMlaaDctLLWyxmuIltUKT
aH3QhIyIqFlesIhRpLDUrJYohZpFUY1ytnnXlR1yprO8W8/pw8vv63v+5w1Q
5SnUqzgcjhKjSMqhY18oyeTn25nakuEkGzyfJ8/k9VByZ+lpGVPG6Ve4Qp1W
nsWUFYfmMz0TnpUwZwVSsRe8pwys3gVXPhWkR8KeuAkr067ckNwEj3GL/jAX
RqN4zXD3y0OBzFfcNVlPYO7GYhNzZNSl2AjTRG78PWZKdrRXHrDCiqaLl5gZ
WnXFGOwKMqlTeymp5B1UH4EZPcLWEAv2sl29KYTieXNiKBz/OZn2X6u3KQym
+DRTJs8gXWH2rVEZzbCI2LuZveMdNmadbp13L+QGd+1kygalsczUqIjsrzDy
DO87s0Pzdo4p9mi5ZoHVP2ZeWGGIRaZXWCnxzem6kQxDGjff1kO+s9jA/Hjh
ctFDWKpzH3oP620zhiV4JSfcwrwvjbAzZa5Cj2VYUyOXMjX7RblMv/CYRqZB
shhT1Yeuy5r6WphqlCTqof6BpnUK5pu1JubJ2lg786hDsn0alie+KWMqnsuq
FuBagWjLIvSee/1hsp+S03/bBD6DlFD/oBH5EPq9+xwYPUxJsMq55dYIJW3r
zw7qoF+A+95h2GreVHJ9lBJV4bhvI4zuVK5uhwmZ7p0D0MnT1t1go2Rsn6N+
CDY/UjWsfMNdzBfIOifQW+8UwLfjHg/fTRHAuAwfSRx0ExZyp2E6J35r/C9K
Bvxduo9P4Z+8yk+UOvD+sLrsMmg85Xgs+o1uFS3G5Fl0DzsXs22Okn8EN6dQ

  "]]
}, Open  ]],

Cell["That is expression for the 4e tree-level amplitude!", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896664745449*^9, 3.601896674004702*^9}, {3.601898021052835*^9, 
  3.601898031801317*^9}, {3.601974031021276*^9, 3.601974034273855*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Length", "[", 
    RowBox[{"Filter", "[", 
     RowBox[{"amp4", ",", 
      RowBox[{"1", "/", "s"}]}], "]"}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"Filter", "[", 
     RowBox[{"amp4", ",", 
      RowBox[{"1", "/", "t"}]}], "]"}], "]"}], ",", 
   RowBox[{"Length", "[", 
    RowBox[{"Filter", "[", 
     RowBox[{"amp4", ",", 
      RowBox[{"1", "/", "u"}]}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.6028332270229807`*^9, 3.602833264270605*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"178", ",", "178", ",", "178"}], "}"}], TraditionalForm]], "Output",\

 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOLdf3z0Qm6/cjQIOTkZTH+TmrkMSGfNtN8Aouum91as
BNJWUUIPzgLpHw3fN/wB0i2zTG6BaKcFVu9A9Bc7I/6/QJpvsq8ziC72Ns0D
0f/O228C0bu+/bedfeeVIxdj3pp5QLrqnqPfMiD9pCFrz0cgvSLB+R2Ibsty
0vsE4u850wai7xj4z/4FpMWLzBV+A2mX3pPn39995ajFfFBe/P4rxy3f1R55
PXjlKFN+U8n64SvHmmPs26Y9euU4o63q/nQgvUBbyOUhkBYwkK6e+PiVo9uV
11KbgHRpeiLrfiB9o0bo6D2Q+LuXJ9Y+feUYZvNjzQMg3XooY+2/Z68cY5eX
eBx9C/SfMaui7LtXjre2Lw6XB9KT/0vaOQFpsfMl7J+ANBOLh4bbh1eOZUvZ
TiR+fOXY59+V3Pr5lSPL2kU5bUDade3XjcZfXzmeSti5K+T7K8eoqApbnR+v
HAGh1t/I
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"669", "-", 
  RowBox[{"178", "*", "3"}]}]], "Input",
 CellChangeTimes->{{3.602833949529834*^9, 3.602833953150524*^9}}],

Cell[BoxData[
 FormBox["135", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBwAeKeO7oud66/coydeT014sYrR7nzwanRQFqhUm+P+q1X
jmcXTJqqDaT9OMP99YE0m8+fSBAd5LzrlQGQ9mRy+QeinRuP7roOpM1Y/p4A
0VWmp5+C6B29vGI3gLTK0TMmIFpgg4cDiJ4uY5dzE2TuW97nIHpG9/kfIHrd
rd39t4D0NlumPbeBdNNhz2VBt185xjSfnhwCpP8wyc5cBqTXfXfaAKLzFPsr
VgLp3m7RB2dB4kx/N/wB0rf6LW+B6Adt1u9A9NPZ1vx/gXTCywBnEN1gY54H
omW2OmwC0Tz6jHaz77xyPKOZt2YekP4m4eK3DEizZOTs+Qji97q+A9ExU5z0
PgHpRTkX20D0rZrA2b+AtMBcc4XfQHoOz+nz7+++cixROSwvfv+Vo9Ms9Ude
D4DuvHVTyfoh0P3cHNumPQKGD2/D/elAOnOOkMtDIP33uWz1xMdA+X+vpTYB
6Ql3kln3A+mT64SO3gPSXovenVj79JVjl/WfNQ+AtFZJwdp/z145Mu0o8zj6
9pWj1BE+Rdl3wHB7sSRcHkifkJS2cwLSGU6l7J+AtNxFDw23D68cwy+wn0j8
CORLdye3fn7lWPd4cU4bkO7Y/W2j8VegvUy7d4V8f+UYpldpq/PjlSMAWUI6
wg==
  "]]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.588299680584828*^9}, {
   3.588395611875143*^9, 3.588395613168173*^9}, {3.601882525426063*^9, 
   3.601882542744773*^9}, {3.601892101592599*^9, 3.601892122061247*^9}, {
   3.6018921859627113`*^9, 3.6018922197607737`*^9}, {3.601892296031958*^9, 
   3.601892326949563*^9}, {3.601893037102207*^9, 3.6018930510517807`*^9}, 
   3.6018932060464363`*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ward identity", "Subsection",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896664745449*^9, 3.601896674004702*^9}, {3.604649177143317*^9, 
  3.60464917757987*^9}, {3.6066222889427643`*^9, 3.6066222986086063`*^9}}],

Cell["In what follows we show that the Ward identity is satisfied.", "Text",
 CellChangeTimes->{{3.588299663441812*^9, 3.5882997038609037`*^9}, {
  3.588304757783607*^9, 3.588304763310542*^9}, {3.601795426429627*^9, 
  3.601795441412965*^9}, {3.601800531688353*^9, 3.601800545541029*^9}, {
  3.601896664745449*^9, 3.601896674004702*^9}, {3.601898021052835*^9, 
  3.601898031801317*^9}, {3.601974031021276*^9, 3.601974034273855*^9}, {
  3.606622304494486*^9, 3.60662231484097*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "a"}], "]"}], "amp4"}], " ", "//", "Contract"}], 
      ")"}], "/.", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
        RowBox[{"s", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"t", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"u", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"u", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"s", "/", "2"}]}]}], "}"}]}], ")"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.601803174142367*^9, 3.601803188548613*^9}, {
   3.601803231489276*^9, 3.6018032367367697`*^9}, 3.6018032822826033`*^9, {
   3.601803395966791*^9, 3.60180341105964*^9}, {3.6018112639952717`*^9, 
   3.6018112656528177`*^9}, 3.601874931956284*^9, {3.60187503637879*^9, 
   3.601875097542708*^9}, 3.60187522262046*^9, {3.601878214231585*^9, 
   3.601878239267827*^9}, {3.60187833318561*^9, 3.6018783364091177`*^9}, 
   3.601878625657806*^9, {3.60189848382277*^9, 3.601898490950287*^9}, 
   3.6019645153746147`*^9, {3.6019646695710287`*^9, 3.601964676650507*^9}, 
   3.601964769691595*^9, 3.601964863449747*^9, {3.601982075041329*^9, 
   3.6019820751904297`*^9}, {3.6022309986477423`*^9, 3.602231013788692*^9}, 
   3.6022310655872917`*^9, {3.614501404611624*^9, 3.614501474247117*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"32", " ", "t"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"32", " ", "u"}]], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "h"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["c",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "f"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", "s"}], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "f"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["c",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", "s"}], "+", 
           RowBox[{"\[LeftSkeleton]", "648", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 196, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 196, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 196, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[196]], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0n0sFHAYB3Cn0t2oP8jlNu9EhSIsxlo/E9KxuyPXwhVF00ZKZIVGmJel
SPTiJTQLMe9bGNdoS4iVHC455/3nJXfemrf1PH88++zZnu15tudrFHxHEMJQ
UVEJh+r65r419YuSrYFEtWnQNPQmG621172MWuWXLMyBiwK+KnOIkj3WsAH6
XNhvhoq6ZTFobo1FJpo9aCdkgRrzZyPQh3KdaFSndPQxqslhlKHXeNrVqLdc
fQBlnNlO0gLntKLFtqBla+wgyryhL0O73rQtoFnKcyIH8JVL5Tja+8PVxxls
EMmEDWCcsGoDbeFGMRtBp+Z0Y9SxyT6qCax/cnAYjeCUjKGZEW5ylDnInEUD
YjriWsCt4GVDRwklU30JPlKwLNk3Bc2JaQm7MkzJcXtOmD/4vYohNh+lpNjK
67UFGFPu53Ma9F4cC0QfceOHrLG3qlhGTRVKhg2Ypylpl4AepK0XdWNnzKMF
fDlnGAyJL3JA/TQMXNGLl5iRI6DQRkzR/XpPd9DOwmcvRsGse60dUjC09ECl
QErJx4LcfF9Q9cS+wnJQYqPSiI5n8uIqQOfyvck+UG1d1rgDGos2x9ARNluJ
egRpa+2CPfcPuaMKxtpdVD6j1oy+d1kib39Tcj75VG0RWCHd5JeDDnrHxArw
QTJLiSZdX7VR4lxafgYqCNUp3gI5F1dNtkHrgPSff8co8cxb02GPw17dRJOj
4J5SMe0po2RIUmXmNEHJ4Gfxpzw5JbobgZP5ctzX4z4Btsf1J2RPUrJwuEu/
HpT3WLE6QMMPXV//gHV8PsdumpJ3Di291WDayavVMnDIntTtzVCy68XlflmC
f/L6TPWW4c6X5jw0tSrU3wBsY60QFzDWjKuuBI8YaVi6rVBywb2zJ0hBidSO
eytllZLZ5tuRqWCNa3eT7TrkPDyh3XcTcp/DI5b/KPkPH9PuDw==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "res", "]"}]], "Input",
 CellChangeTimes->{{3.601898501987535*^9, 3.601898503521942*^9}, {
  3.601982081188013*^9, 3.601982081363924*^9}}],

Cell[BoxData[
 FormBox["426", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0ltI02EYBnDNwlORYZBDzHShF1nNU5gV8Q1LWZq5aaYjKdGZkKbEZhfr
wN9WpiUeQhHTSkI6KZqbUYmbW+agFVFLt9myaTP9Vtr+kiun1ftevPzunovn
ecPyzwgLPT08PMRw0wUrTOAoJVypTh8LSqVyI1qz66IZTZe12ND1/wYdaEQ1
yUsAP4oTC9Cb3K4JlG9OEe0Fm7bbsvtA7f2uRTSvTeajBP2GasPRoOWrUhVY
Ud9hRYXlNZOoV5//N1TNauTPwcf6+S27xyiZCWdE4+C5kRwF6jyrLT5mokRR
ElIsBpWHfDSRFkp6Ak60bAOd9hzRTtC44DiOdtBLozyw3/RoDhVQl2c0aDgf
rx4DU7Q6A6qtuD6L8tbNcEygMutuAroyG5aESur8y8xg7hodRUs5dctozI3G
Rgt4h6dVj4NxjPdD4TglqQXNzZlgrs27rRN9sVqJJsVkyR+A31O9vr5BS+zK
ZdA65LainYXBLKpScQJXwLLSDcmoKcxVjoqoXz/KGWNJ6ydKHCyvpx3kX1vK
6ASLkiM1TvBp0FoWZQ4sRrPggPtWNdrwJ/j2EtikcnHdYL+l9sO8FXYWV3I3
TVByL3/BLvhCiSa3O2KPDfqvfPmsaZKSySzJVDPYLXyXbANbQ40X6qcoMVeN
bH4C7k+M9lWDRoFe/xmc1hzlxNkp2fh+wNAFXt4n6P07DXm+6anDPyjprXq7
NWSOkswdr46gwdmnxKFgg9lJ+KCcSfNnQWF8QNTBn5Ss0g2/PumEv1OkFSkW
KPGuOV12BZQcNqhif1EiS2MGM12UDOszSNRvSv4DB86ujg==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Count", "[", 
  RowBox[{
   RowBox[{"Expand", "[", "res", "]"}], ",", 
   RowBox[{"Momentum", "[", 
    RowBox[{
     RowBox[{"Subscript", "[", 
      RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", "12"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.602237823092431*^9, 3.602237831286381*^9}}],

Cell[BoxData[
 FormBox["528", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGCwBmJ1e+0D12+9cvyw+dQZEP3cpe8liG4991LyBpB241pi
AaJPHFJxAdFplnwFN4H0uwNHX4Ho4MWT/oDopPRpk28B6X+aJ/bfBtI7ZLlX
Bd1+5Xi8ZNb0ECAtpMczdxmQ3hbBugVE7/kZWrMSSK+6z/zkLJAuUHm25Q+Q
nj3/z10Qvb1b/hOILvshJfwXSF8KE3IH0QnsPwtBtPl97m0gWqLyi+PsO68c
31sbb5gHpM9t/xO4DEhfz9I88BFI7y7k+wSi2/b9MPwEpD8KzO8C0UHv5eb/
AtLzP/9S/g2kJ82YcPn93VeOcq6tyuL3Xzlyvvn81OvBK8ddCzaoWT985Xj+
25Gd0x4BzVuZ9ng6kC74f8H9IZDW+3qlbuLjV47znE/JbQLSM9Ybc+4H0cGn
T9wD0tJMglImT4H+vXfwzFogHVGXuPHfs1eOkpZBPkffvnJ0iTuvIvvulSNj
Vma0PJCe/PeToxOQXhTtx/0JSO8QEtRx+/DKserPsdOJH185xpT4pbd+fuXY
wZxX0AakX0w6u9X46yvH3nfN+0K+v3I8dSTIUefHK0cAXxAeoQ==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s", " ", "t", " ", "u", " ", "res"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "a_"}], "]"}], "\[Rule]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"kc", "[", 
               RowBox[{"2", ",", "a"}], "]"}]}], "-", 
             RowBox[{"kc", "[", 
              RowBox[{"3", ",", "a"}], "]"}], "-", 
             RowBox[{"kc", "[", 
              RowBox[{"4", ",", "a"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{"u", "\[Rule]", 
           RowBox[{
            RowBox[{"-", "s"}], "-", "t"}]}]}], "}"}]}], "//", "Expand"}], 
      ")"}], "//", "Simplify"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a_"}], "]"}], "+", 
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "a_"}], "]"}], "+", 
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "a_"}], "]"}]}], "\[Rule]", 
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "a"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6098296038437977`*^9, 3.6098296048005667`*^9}, {
  3.609829669815115*^9, 3.6098296854785023`*^9}, {3.609835079454357*^9, 
  3.6098351365984707`*^9}, {3.614501519375511*^9, 3.614501752965406*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "s", " ", "t", " ", 
   SubsuperscriptBox["k", 
    FormBox["1",
     TraditionalForm], 
    FormBox[
     FormBox["b",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"s", "+", "t"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "-", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "f"}]]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["3",
            TraditionalForm], 
           FormBox[
            FormBox["d",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"f", "h"}]]}]}], "+", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "f"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.609829590463882*^9, 3.609829606473372*^9}, {
   3.609829672182968*^9, 3.609829686477508*^9}, {3.609835125706184*^9, 
   3.609835137127617*^9}, 3.610078822548143*^9, 3.6107687801850853`*^9, 
   3.614321251111423*^9, 3.6145011589813223`*^9, 3.614501754092407*^9, 
   3.614505691771487*^9, 3.6145771678412333`*^9, 3.614937178963969*^9, 
   3.615633761005327*^9, 3.616214622690035*^9, 3.6173361229385643`*^9, 
   3.61733824394062*^9, 3.618217390909622*^9, 3.6193336206047297`*^9, 
   3.6197749870858727`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"kc", "[", 
     RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.609835139218946*^9, 3.609835158439732*^9}, {
  3.614501776783717*^9, 3.61450178224183*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.6098351588161793`*^9, 3.610078822571343*^9, 
  3.610768780315384*^9, 3.61432125117699*^9, 3.614501159022138*^9, 
  3.614501782970748*^9, 3.6145056917893143`*^9, 3.614577167858802*^9, 
  3.61493717898633*^9, 3.615633761015663*^9, 3.6162146226969643`*^9, 
  3.61733612294945*^9, 3.617338243949996*^9, 3.618217390935934*^9, 
  3.619333620619837*^9, 3.619774987092374*^9}]
}, Open  ]],

Cell[TextData[{
 "As a result, the Ward identity is indeed satisfied due to transversality \
and momentum conservation. Note, however, that while replacing ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Xi]", "1"], "\[Rule]", " ", 
    SubscriptBox["k", "1"]}], TraditionalForm]]],
 ", one really needs to keep the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Eta]", "1"], TraditionalForm]]],
 " transversal to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
  3.604652950305522*^9}, {3.6098352420152082`*^9, 3.6098353424865217`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
   3.604652950305522*^9}, 3.604653026772519*^9},
 Background->RGBColor[1, 0.9, 0.8]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$wardremainder", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"s", " ", "t", " ", "u"}], ")"}]}], "res2"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "1"}], "}"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "+", "t"}], "\[Rule]", 
      RowBox[{"-", "u"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.615007925259079*^9, 3.6150079757104473`*^9}, {
  3.615008179054668*^9, 3.615008180696786*^9}, {3.6150082107061977`*^9, 
  3.615008216117405*^9}, {3.6150082590060167`*^9, 3.615008262275466*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.61500797712674*^9, 3.615008181545429*^9, 
  3.615008216934621*^9, 3.615008262628854*^9, 3.615633761045782*^9, 
  3.616214622735733*^9, 3.617336122980842*^9, 3.6173382439977417`*^9, 
  3.6182173909911413`*^9, 3.619333620673893*^9, 3.6197749871206303`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp4$wardremainder", ",", 
   RowBox[{"Subscript", "[", 
    RowBox[{"k", ",", "1"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6150083948856277`*^9, 3.615008408778473*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.615008409102399*^9, 3.6156337610730333`*^9, 
  3.616214622793324*^9, 3.6173361230058613`*^9, 3.617338244041319*^9, 
  3.618217391068655*^9, 3.6193336207298517`*^9, 3.619774987145895*^9}]
}, Open  ]],

Cell[TextData[{
 "Note that in the remainder the poles have disappeared! Furthermore, it no \
longer depends on ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
  3.604652950305522*^9}, {3.6098352420152082`*^9, 3.6098353424865217`*^9}, {
  3.6150083017910433`*^9, 3.6150083099581833`*^9}, {3.6150083712950583`*^9, 
  3.615008381655923*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["\<\
Investigate how the remainder looks like upon checking the Ward identity with \
k[1,b]\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.602242211209177*^9, 
  3.6022422410722857`*^9}, {3.6098379559760437`*^9, 3.609837984412796*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "b"}], "]"}], "amp4"}], " ", "//", "Contract"}], 
      ")"}], "/.", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
        RowBox[{"s", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"t", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"u", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
        RowBox[{"u", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
        RowBox[{"s", "/", "2"}]}]}], "}"}]}], ")"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.601803174142367*^9, 3.601803188548613*^9}, {
   3.601803231489276*^9, 3.6018032367367697`*^9}, 3.6018032822826033`*^9, {
   3.601803395966791*^9, 3.60180341105964*^9}, {3.6018112639952717`*^9, 
   3.6018112656528177`*^9}, 3.601874931956284*^9, {3.60187503637879*^9, 
   3.601875097542708*^9}, 3.60187522262046*^9, {3.601878214231585*^9, 
   3.601878239267827*^9}, {3.60187833318561*^9, 3.6018783364091177`*^9}, 
   3.601878625657806*^9, {3.60189848382277*^9, 3.601898490950287*^9}, 
   3.6019645153746147`*^9, {3.6019646695710287`*^9, 3.601964676650507*^9}, 
   3.601964769691595*^9, 3.601964863449747*^9, {3.601982075041329*^9, 
   3.6019820751904297`*^9}, {3.6022309986477423`*^9, 3.602231013788692*^9}, 
   3.6022310655872917`*^9, 3.6098379970630074`*^9, {3.614501867537305*^9, 
   3.6145019271092176`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"32", " ", "t"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"32", " ", "u"}]], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "e"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["d",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", "s"}], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "e"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "g"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["d",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", "s"}], "-", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["d",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", "s"}], "+", 
           RowBox[{"\[LeftSkeleton]", "648", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", "s"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 203, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 203, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 203, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[203]], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0n0sFHAYB3Cn4izVxhy3eSdp3t/WGWv9zHsyd+TavEWxWUsvXmqFRjQv
S5G5XrzMyyykiWPzMq6wCDHJeek4J+Lnpe68Dqnn+ePZZ8/2bN9nzx6jqFu8
aIaSktJNqJ4vXns/v1OyN5KmsgCaxlxnoQ1OupdRK0H5yhK4yuMqM8cpOVSb
MECf84fN0PB+aRJa+N4iF80fc+SrgerL5+LQBzKdRFSnYuoRqsFmVKIRAVr1
qL/s+AjKsN9P1wSXNBNFDqBl+/0xlHlNX4r2vO5YQfMU58M54Eu32ll0cNQ9
0BVsCpfym8Bkft022uYXzxSCLi3Zxqhzs1N8M9j4WHUCjWOXS9DcOE8Zyhxj
/kJDk7qS28C9qHVDZzElP4dSA6fByoygTLQgqS32ygQl5k7s2BDwax1DdGaK
kjKrS68swKTq4EAb0H9VEoY+9EsZt8XeqmYdNZUrGHZgkYa4Uwx6k45B1JOV
s4wWc2XsCTA6pZSDBqsbuKM+F5m3J0G+nYiiR/WeHqDdJc9eTIF5d9u7psGY
imO1vGlK3hUXCoJA5bNHSqpBsZ2SEJ3NDUiuAV2rD+eHQJUtqfAANA7fkaCT
LJYC9Y7U0vwLDiSc8ELljM07qGxRpQWtclsjb35QciHDuqEUrJne4VaDHL3T
Ijl4L0NNgaZf3bBT4FyWIAflxeiU7YFsnw2TfdA2NPvbbwklvkWbOqxZyNVN
M9EGDxXyBV8pJePiOjOXOUrGPopai2SU6G6HzQtkmDfgNQd2Jg+n5s9TsnKy
R78RlA1YqXWBhm97+mbAD1wu23GBEu2+XmcOOFNQMFIPCm28mg8XYa9u34De
NUp2hwXmeuuUhAhHs1BrPccIAzBN0u/hBu4P2J9SgPL8BRvPP3DXf1XDkXLY
P9foRuYG/K2rf8ITsEn7c6vDFiXbqrxPQTuUTMk5Hpa7lPwHMIvy/g==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "res", "]"}]], "Input",
 CellChangeTimes->{{3.601898501987535*^9, 3.601898503521942*^9}, {
  3.601982081188013*^9, 3.601982081363924*^9}}],

Cell[BoxData[
 FormBox["426", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0ltI02EYBvCJhaaFhRc5xEwHGlS4qYmaEJ94ylbWNktdWck0JDSlpl2Y
1mQd1EQzpmJ2kBDLJpLbwpI2Z+UkI6HlNm3ZtHn4Vtr+kitP9b4XL7+b5+p5
3qCcC4JcNxaLJYablqzJfEcp4UgHDBGgVFpmRKujKixoWkmzDfX599qBhlSR
7GjwszhWgt7lKCfQeEuKMA5U7LWd6AH1HcolNLu1xFMFevXXBqN+qzekarC0
vs2KCoqrJ1H3Hu8ZVMvoyl6CzwwLO2NMlMwGy4Tj4OXBTDnqvKjPzzBTIi8I
yBeDqkOeutAxSrq3nmneDTrtmcIw0LjoOIW20aujXFBj7pxHU6nLjQcOX9mn
NYEp+oFhVF9aM4dyt8yyzaAq/VE0ujYXlIDm1XkXWcCsjQMULWTXraLhtxsa
xsCHXL12HIyUeTwVjFPClzQ2isAsm0drO/pqgwpNCE8vewL+4Lt//4AW2FWr
oLV/xYq25/ozqFrN9l0Diwq3JaPmIFcxKqReGpRtYkjLF0ocDLf7Phh/a/lY
O3guOVTnBF/4bWZQWeISjwH7Vu5VoXf++j9YBhVqF2cF1IzVflqwws7iSs72
CUoe5yzaU79RosvqCtlvg/4r3/QqJimZTM+bagS7BCPJNrAl0FheP0WJ5ebg
jufggVjeJi1oTDUYvoLTuuPsSDslnYeHYqJBVlLTiBL08Oar16chf+3I0bc/
KZGcbN4VME9JzcGo04HgesX7xHiwTxnhw4BN5TNhSb8oyXDr+HjWCf/0Lvi8
fJESMpV26TqoyBvqjfhNSUe1SC9yUTK/FJe45w8l/wGjYq8Q
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res3", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"s", " ", "t", " ", "u", " ", "res"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "a_"}], "]"}], "\[Rule]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"kc", "[", 
               RowBox[{"2", ",", "a"}], "]"}]}], "-", 
             RowBox[{"kc", "[", 
              RowBox[{"3", ",", "a"}], "]"}], "-", 
             RowBox[{"kc", "[", 
              RowBox[{"4", ",", "a"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{"u", "\[Rule]", 
           RowBox[{
            RowBox[{"-", "s"}], "-", "t"}]}]}], "}"}]}], "//", "Expand"}], 
      ")"}], "//", "Simplify"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a_"}], "]"}], "+", 
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "a_"}], "]"}], "+", 
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "a_"}], "]"}]}], "\[Rule]", 
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "a"}], "]"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6098296038437977`*^9, 3.6098296048005667`*^9}, {
   3.609829669815115*^9, 3.6098296854785023`*^9}, {3.609835079454357*^9, 
   3.6098351365984707`*^9}, 3.609838018830977*^9, {3.614501950606471*^9, 
   3.614502184737015*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "s", " ", "t", " ", 
   SubsuperscriptBox["k", 
    FormBox["1",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"s", "+", "t"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "-", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "f"}]]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["3",
            TraditionalForm], 
           FormBox[
            FormBox["d",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"f", "h"}]]}]}], "+", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "f"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.609829590463882*^9, 3.609829606473372*^9}, {
   3.609829672182968*^9, 3.609829686477508*^9}, {3.609835125706184*^9, 
   3.609835137127617*^9}, 3.6098380307590322`*^9, 3.610078853149618*^9, 
   3.610768810761674*^9, 3.614321282895509*^9, 3.61450118915196*^9, 
   3.614502185549224*^9, 3.6145057221503067`*^9, 3.614577198522447*^9, 
   3.614937209981224*^9, 3.615633791608614*^9, 3.6162146536392*^9, 
   3.617336153464033*^9, 3.617338274887986*^9, 3.618217422663855*^9, 
   3.619333651039747*^9, 3.6197750182981586`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res3", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"kc", "[", 
     RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.609835139218946*^9, 3.609835158439732*^9}, 
   3.609838023812129*^9, {3.6145022108066263`*^9, 3.614502216554472*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "s", " ", "t", " ", 
   SubsuperscriptBox["k", 
    FormBox["1",
     TraditionalForm], 
    FormBox[
     FormBox["a",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"s", "+", "t"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["d",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"f", "h"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["f",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "h"}]]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "-", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "f"}]]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "g"}]], " ", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["e",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "-", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["g",
         TraditionalForm],
        TraditionalForm]], " ", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["h",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"d", "f"}]]}], "+", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"e", "g"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["3",
            TraditionalForm], 
           FormBox[
            FormBox["d",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["g", 
           RowBox[{"f", "h"}]]}]}], "+", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["d",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"f", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "h"}]]}], "+", 
        RowBox[{"2", " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["g", 
          RowBox[{"d", "f"}]]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6098351588161793`*^9, 3.6098380309263372`*^9, 
  3.610078853310514*^9, 3.610768810877286*^9, 3.614321282973634*^9, 
  3.614501189245878*^9, 3.614502217340693*^9, 3.614505722217699*^9, 
  3.61457719860949*^9, 3.614937210046896*^9, 3.6156337916731367`*^9, 
  3.6162146537010717`*^9, 3.61733615352983*^9, 3.617338274954351*^9, 
  3.61821742273734*^9, 3.619333651118099*^9, 3.619775018386907*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res2", "-", 
  RowBox[{"(", 
   RowBox[{"res3", "/.", 
    RowBox[{"{", 
     RowBox[{"a", "\[Rule]", "b"}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.609838049093958*^9, 3.609838062644072*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.6098380639971046`*^9, 3.6100788534749813`*^9, 
  3.6107688109953117`*^9, 3.614321283045232*^9, 3.6145011893060904`*^9, 
  3.614505722319289*^9, 3.614577198632411*^9, 3.614937210070198*^9, 
  3.615633791704122*^9, 3.616214653739181*^9, 3.617336153551861*^9, 
  3.617338275004884*^9, 3.6182174227786417`*^9, 3.619333651183138*^9, 
  3.6197750184390306`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "eeeee scattering amplitude (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ab"], "[", 
    SubscriptBox["k", "1"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "cd"], "[", 
    SubscriptBox["k", "2"], "]"}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "ef"], "[", 
    SubscriptBox["k", "3"], "]"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SuperscriptBox["e", "gh"], "[", 
     SubscriptBox["k", "4"], "]"}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SuperscriptBox["e", "ij"], "[", 
     SubscriptBox["k", "5"], "]"}]}], TraditionalForm]]],
 ")"
}], "Section",
 CellChangeTimes->{{3.6145025136340237`*^9, 3.614502549256619*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules$sij", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"a", ",", "b"}], "]"}], "\[Rule]", 
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"1", "/", "2"}], 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<s\>\"", "<>", 
            RowBox[{"ToString", "[", "b", "]"}], "<>", 
            RowBox[{"ToString", "[", "a", "]"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", 
         RowBox[{"b", "+", "1"}], ",", "5"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.611050561621358*^9, 3.611050569997024*^9}, {
  3.611050680201893*^9, 3.611050716923559*^9}, {3.6110507470283327`*^9, 
  3.611050802146605*^9}, {3.611050943470523*^9, 3.6110510091312943`*^9}, {
  3.614502678070238*^9, 3.614502693138921*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s12", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s13", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s14", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s15", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s23", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s24", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s25", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s34", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s35", "2"]}], ",", 
    RowBox[{
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], "\[Rule]", 
     FractionBox["s45", "2"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.611050730153778*^9, 3.6110507910770693`*^9}, {
   3.611050951115443*^9, 3.6110510096807327`*^9}, 3.61225659821879*^9, 
   3.614414080577429*^9, 3.6144155145750713`*^9, 3.6145026944500628`*^9, 
   3.614505722340404*^9, 3.614577198668627*^9, 3.6149372101422577`*^9, 
   3.6156337917851152`*^9, 3.616214653777297*^9, 3.617336153577306*^9, 
   3.617338275041349*^9, 3.618217422823596*^9, 3.619333651240316*^9, 
   3.619775018494647*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules$transversality", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"5", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"5", ",", "j"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.612670718931587*^9, 3.612670723943194*^9}, 
   3.612688128640332*^9, {3.614502701186989*^9, 3.614502775274876*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["h",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["5",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["5",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", "0"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.612671391880723*^9, 3.612688130608539*^9, 
  3.6144140806752777`*^9, 3.6144155146651573`*^9, 3.614502776205373*^9, 
  3.614505722420726*^9, 3.614577198709752*^9, 3.614937210160973*^9, 
  3.615633791821088*^9, 3.6162146538218393`*^9, 3.617336153607349*^9, 
  3.6173382750943737`*^9, 3.618217422865366*^9, 3.619333651290819*^9, 
  3.61977501854604*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules$massless", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"kdotk", "[", 
      RowBox[{"i", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612670924537416*^9, 3.612670927567191*^9}, {
  3.614502783334776*^9, 3.614502820776779*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["k", "1", "2"], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", "2", "2"], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", "3", "2"], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", "4", "2"], "\[Rule]", "0"}], ",", 
    RowBox[{
     SubsuperscriptBox["k", "5", "2"], "\[Rule]", "0"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.612671393068544*^9, 3.614414080759262*^9, 
  3.614415514740991*^9, 3.6145028220169287`*^9, 3.614505722447112*^9, 
  3.614577198752536*^9, 3.614937210183206*^9, 3.615633791842739*^9, 
  3.616214653858276*^9, 3.617336153631091*^9, 3.617338275122683*^9, 
  3.6182174228927917`*^9, 3.619333651336574*^9, 3.6197750185937757`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Some permutation tools", "Subsection",
 CellChangeTimes->{{3.604991435802387*^9, 3.604991459471311*^9}, {
  3.60499152890079*^9, 3.604991531351738*^9}}],

Cell["\<\
Some technicalities in order to conveniently reproduce diagrams related by \
permutation of certain external legs.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.6049014132904787`*^9, 3.604901422302884*^9}, {3.604905975714284*^9, 
  3.604905980453814*^9}, {3.604921263027215*^9, 3.604921286356237*^9}, {
  3.604991547764576*^9, 3.6049915702716217`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ss", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "s12", ",", "s13", ",", "s14", ",", "s15"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "s23", ",", "s24", ",", "s25"}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "s34", ",", "s35"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "s45"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.604918285354271*^9, 3.6049183989663773`*^9}, {
  3.604918903025673*^9, 3.604918944755612*^9}, {3.6110536075597067`*^9, 
  3.611053632312888*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "s12", "s13", "s14", "s15"},
     {"0", "0", "s23", "s24", "s25"},
     {"0", "0", "0", "s34", "s35"},
     {"0", "0", "0", "0", "s45"},
     {"0", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604918286315037*^9, 3.6049183994357023`*^9, {3.604918910146989*^9, 
   3.6049189452306433`*^9}, 3.604979947919818*^9, 3.604991575154098*^9, 
   3.604997559126388*^9, 3.604998048259873*^9, 3.604998311386902*^9, 
   3.604998727819045*^9, 3.604999068121663*^9, 3.604999616503703*^9, 
   3.605322274377655*^9, 3.6053293008642282`*^9, 3.605344923197794*^9, 
   3.605499405388812*^9, 3.605499805098523*^9, 3.6055003169070873`*^9, 
   3.605517574818564*^9, 3.605518639692595*^9, 3.606019753169056*^9, 
   3.6066245534164333`*^9, 3.607254870250371*^9, 3.607746883146125*^9, 
   3.608458716458954*^9, 3.608461098773971*^9, 3.60861140672165*^9, 
   3.608972293290337*^9, 3.609039108584689*^9, 3.609065559459676*^9, 
   3.609130582825893*^9, 3.6100788640714893`*^9, 3.6107688195234222`*^9, 
   3.61105363349965*^9, 3.612073946668751*^9, 3.612256598425859*^9, 
   3.61441408083566*^9, 3.6144155148169823`*^9, 3.614505722463806*^9, 
   3.614577198791009*^9, 3.614937210197414*^9, 3.615633791862483*^9, 
   3.616214653895423*^9, 3.617336153650529*^9, 3.6173382751944437`*^9, 
   3.618217422920266*^9, 3.61933365138113*^9, 3.619775018641749*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sss", "=", 
  RowBox[{"ss", "+", 
   RowBox[{"Transpose", "[", "ss", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6049189470820513`*^9, 3.604918951623597*^9}, {
  3.605518427570167*^9, 3.605518430360942*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "s12", "s13", "s14", "s15"},
     {"s12", "0", "s23", "s24", "s25"},
     {"s13", "s23", "0", "s34", "s35"},
     {"s14", "s24", "s34", "0", "s45"},
     {"s15", "s25", "s35", "s45", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQA+IaTqHQa7dfOZ73WSH7BUhn7NM4/RNIS5x+uu0PkI7O
5fwCopk+vxX5C6TVHX57gOgtz1uKQfSPywI7QPSl3QEus++8cvypO2/TPCA9
YUla8DIgLWS77uBHIL3IZOlnEM1iNd/4E5Cu6L+z4BeQ7rKZwPsbSOsa/VQF
0W7i6lff333l+N5KX1X8/itHjoITr7wevHI8xpuuYf3wlaPg/77d0x69ckzR
jn46HUibTLvu+RBIhzxY2TDx8SvHeX+nKGwC0rLeH7n2A+mYxbdO3QPSZt/Y
Lq19+srxnkfhtn/PXjnqO0w60fn8lWObXffv6pevHG2mXdS6CqTPGMgu+PT2
laNMe0zwZyDdGe8fL//ulePplpuuTkD6y383/k9A+pPFH323D68cN1zaez7x
4ytHgyTT7NbPrxy3/00raQPSx2Lv7TT+CrR/Ze6hkO9Af8uGuer8eOUIAOX4
2vo=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ind", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "c", ",", "e", ",", "g", ",", "i"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"b", ",", "d", ",", "f", ",", "h", ",", "j"}], "}"}]}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.604919106873252*^9, 3.60491912143011*^9}, {
  3.6049192447226667`*^9, 3.604919257243636*^9}, {3.6110536484418983`*^9, 
  3.611053649866706*^9}, {3.611053748225556*^9, 3.61105375553585*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"a", "c", "e", "g", "i"},
     {"b", "d", "f", "h", "j"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGAwAOLNb/2zrt1+5RjtYFcKovmu2VSDaK/6r7JfgPS0+ctP
/wTSGrIvt/0B0rdO8X0B0QbXP4r8BdLLVP95gGiNE23FIHrSd8EdIHrd0UCX
2XdeOeaVzds0D0in9GUELwPSMUkbDn4E0hZWyz+D6NilC40/AentXPcX/ALS
YjF/VH8D6adbNa6+v/vK0cbYUFX8/ivHWQ9OvPJ68MqxqjFTw/rhK0eTqP7d
0x69crTVSHo6HUif6r3t+RBIN3CvbZj4+JXjqiuzFDYBaaOnn7n2A+lzs+6e
ugek9xayX1r79JUj1//Cbf+evXJcYe1/qvP5K8dr2+qug2iTfTt+V78E+tvp
itZVIC22QH7Bp7evHPVuxwV/BtJmTwLj5d+9cpS5fNPVCUgrzXDn/wSkZ/z+
o+/24ZWjj/3+84kfXzlu/WWa3fr5leN328ySNiBdveD+TuOvQHXy+YdCvgP9
sTLcVefHK0cAfQXokg==
  "]]
}, Open  ]],

Cell[TextData[{
 "Permuting external legs (ij), i.e. their labelling, their indices and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "mn"], TraditionalForm]]],
 "variables."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"PermS$ij$", "[", 
   RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"sss", "[", 
          RowBox[{"[", "ii", "]"}], "]"}], "[", 
         RowBox[{"[", "jj", "]"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"sss", "[", 
          RowBox[{"[", 
           RowBox[{
            RowBox[{"Permute", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], 
              ",", 
              RowBox[{"Cycles", "[", 
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{"i", ",", "j"}], "}"}], "}"}], "]"}]}], "]"}], "[", 
            RowBox[{"[", "ii", "]"}], "]"}], "]"}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"Permute", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], 
             ",", 
             RowBox[{"Cycles", "[", 
              RowBox[{"{", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], "}"}], "]"}]}], "]"}], "[", 
           RowBox[{"[", "jj", "]"}], "]"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"jj", ",", 
         RowBox[{"ii", "+", "1"}], ",", "5"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.605326688518827*^9, 3.605326694419714*^9}, {
  3.605326730277635*^9, 3.6053267554040318`*^9}, {3.6053267933071327`*^9, 
  3.605326793855322*^9}, {3.6055184887097063`*^9, 3.6055184902561407`*^9}, {
  3.611053676176319*^9, 3.611053685913786*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PermS$ij$", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.605326760581832*^9, 3.605326761298853*^9}, {
  3.605326797965207*^9, 3.605326843780952*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s12", "\[Rule]", "s12"}], ",", 
    RowBox[{"s13", "\[Rule]", "s23"}], ",", 
    RowBox[{"s14", "\[Rule]", "s24"}], ",", 
    RowBox[{"s15", "\[Rule]", "s25"}], ",", 
    RowBox[{"s23", "\[Rule]", "s13"}], ",", 
    RowBox[{"s24", "\[Rule]", "s14"}], ",", 
    RowBox[{"s25", "\[Rule]", "s15"}], ",", 
    RowBox[{"s34", "\[Rule]", "s34"}], ",", 
    RowBox[{"s35", "\[Rule]", "s35"}], ",", 
    RowBox[{"s45", "\[Rule]", "s45"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.60532676172122*^9, {3.6053267986015167`*^9, 3.605326844087324*^9}, 
   3.6053293010421553`*^9, 3.6053449233582706`*^9, 3.6054994057035007`*^9, 
   3.6054998053036337`*^9, 3.60550031725254*^9, 3.605517575067068*^9, 
   3.6055186399969263`*^9, 3.6060197533541327`*^9, 3.606624553614525*^9, 
   3.60725487034026*^9, 3.607746883497209*^9, 3.608458716588009*^9, 
   3.608461099260252*^9, 3.6086114070908213`*^9, 3.6089722935287027`*^9, 
   3.6090391089460287`*^9, 3.609065559734489*^9, 3.609130583047821*^9, 
   3.610078864397092*^9, 3.610768819686644*^9, {3.611053662748652*^9, 
   3.611053690309883*^9}, 3.61207395381227*^9, 3.612256598769484*^9, 
   3.614414081082869*^9, 3.61441551504261*^9, 3.614505722688422*^9, 
   3.61457719884129*^9, 3.614937210279106*^9, 3.615633791943685*^9, 
   3.6162146541259003`*^9, 3.6173361537220383`*^9, 3.617338275347249*^9, 
   3.6182174230642757`*^9, 3.619333651553266*^9, 3.6197750188047743`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Perm5$ij$", "[", 
   RowBox[{"term_", ",", "i_", ",", "j_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"term", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"i", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"j", ",", "e"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"j", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"i", ",", "e"}], "]"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "j", "]"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "j", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "j", "]"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"ind", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "[", 
         RowBox[{"[", "i", "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"PermS$ij$", "[", 
      RowBox[{"i", ",", "j"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.604921169096053*^9, 3.604921183753563*^9}, {
   3.6049916807922297`*^9, 3.604991697181696*^9}, {3.604991811712426*^9, 
   3.604991813229354*^9}, {3.6053268519447536`*^9, 3.60532685561228*^9}, 
   3.611053710658422*^9, {3.614502840208105*^9, 3.614502904155795*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two e propagators", "Subsection",
 CellChangeTimes->{{3.612080227452833*^9, 3.612080238252129*^9}, 
   3.6126704966121397`*^9}],

Cell[BoxData[
 RowBox[{"Pee$1old", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"I", "/", "s23"}]}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"I", "/", "s45"}]}], ")"}], 
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"verEEEonshellmn", "[", 
          RowBox[{
          "2", ",", "3", ",", "c", ",", "d", ",", "e", ",", "f", ",", "m", 
           ",", "n"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"verEEEonshellm", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "m", ",", "n", ",", "k", ",", "l"}],
             "]"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             SubscriptBox["k", "2"], "\[Rule]", 
             SubscriptBox["k", "23"]}], "}"}]}], ")"}]}], "]"}], "]"}], 
      RowBox[{"verEEEonshellmn", "[", 
       RowBox[{
       "4", ",", "5", ",", "g", ",", "h", ",", "i", ",", "j", ",", "k", ",", 
        "l"}], "]"}]}], "]"}], "]"}]}]}]], "Text",
 CellChangeTimes->{{3.611995146433002*^9, 3.6119951509784317`*^9}, {
  3.612670408174294*^9, 3.612670423828185*^9}}],

Cell["$Aborted", "Text",
 CellChangeTimes->{3.612257105565405*^9, 3.6126704082338037`*^9}],

Cell["\<\
In Pee$1old the middle three vertex is not symmetric which eventually \
complicates the proof of Bose symmetry for the sum of all Pee diagrams.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.612670329881069*^9, 3.61267038328027*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pee$1", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"I", "/", "s23"}]}], ")"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"I", "/", "s45"}]}], ")"}], 
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"verEEEonshellmn", "[", 
          RowBox[{
          "2", ",", "3", ",", "c", ",", "d", ",", "e", ",", "f", ",", "m", 
           ",", "n"}], "]"}], 
         RowBox[{"verEEEgenericmnl", "[", 
          RowBox[{
          "1", ",", "a", ",", "b", ",", "23", ",", "m", ",", "n", ",", "45", 
           ",", "k", ",", "l"}], "]"}]}], "]"}], "]"}], 
      RowBox[{"verEEEonshellmn", "[", 
       RowBox[{
       "4", ",", "5", ",", "g", ",", "h", ",", "i", ",", "j", ",", "k", ",", 
        "l"}], "]"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.611048254068303*^9, 3.611048255412181*^9}, {
   3.6110483254916983`*^9, 3.6110483866661158`*^9}, {3.611048583806142*^9, 
   3.6110486224208508`*^9}, {3.611048658247025*^9, 3.6110486880037727`*^9}, {
   3.611048959694137*^9, 3.6110490138951*^9}, {3.611051112977738*^9, 
   3.6110511653530893`*^9}, {3.6119950286737547`*^9, 3.611995065174799*^9}, {
   3.611995100352811*^9, 3.611995122046521*^9}, {3.611995180228094*^9, 
   3.6119951802995234`*^9}, 3.612074021438795*^9, {3.612670559567988*^9, 
   3.612670578689229*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{"-", 
           RowBox[{
            FractionBox["1", 
             RowBox[{"s23", " ", "s45"}]], 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "32"]}], " ", "\[ImaginaryI]", " ", 
                SubsuperscriptBox["k", 
                 FormBox["45",
                  TraditionalForm], 
                 FormBox[
                  FormBox["a",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["5",
                  TraditionalForm], 
                 FormBox[
                  FormBox["b",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["4",
                  TraditionalForm], 
                 FormBox[
                  FormBox["c",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["3",
                  TraditionalForm], 
                 FormBox[
                  FormBox["d",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["2",
                  TraditionalForm], 
                 FormBox[
                  FormBox["e",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["1",
                  TraditionalForm], 
                 FormBox[
                  FormBox["f",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"g", "i"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"h", "j"}]]}], "-", 
               RowBox[{
                FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
                SubsuperscriptBox["k", 
                 FormBox["45",
                  TraditionalForm], 
                 FormBox[
                  FormBox["a",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["4",
                  TraditionalForm], 
                 FormBox[
                  FormBox["b",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["5",
                  TraditionalForm], 
                 FormBox[
                  FormBox["c",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["3",
                  TraditionalForm], 
                 FormBox[
                  RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["2",
                  TraditionalForm], 
                 FormBox[
                  FormBox["e",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["1",
                  TraditionalForm], 
                 FormBox[
                  FormBox["f",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"g", "i"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"h", "j"}]]}], "+", 
               RowBox[{"\[LeftSkeleton]", "5213", "\[RightSkeleton]"}], "+", 
               RowBox[{
                FractionBox["1", "64"], " ", 
                RowBox[{"\[LeftSkeleton]", "8", "\[RightSkeleton]"}], " ", 
                RowBox[{
                 FormBox[
                  SubscriptBox["k", "5"],
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                  TraditionalForm]}]}], "-", 
               RowBox[{
                FractionBox["1", "64"], " ", "\[ImaginaryI]", " ", 
                SuperscriptBox["g", 
                 RowBox[{"a", "c"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"b", "h"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"d", "f"}]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["2",
                  TraditionalForm], 
                 FormBox[
                  FormBox["e",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"g", "i"}]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["4",
                  TraditionalForm], 
                 FormBox[
                  FormBox["j",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox[
                  SubscriptBox["k", "1"],
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}], " ", 
                RowBox[{
                 FormBox[
                  SubscriptBox["k", "5"],
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "23"],
                  TraditionalForm]}]}]}], ")"}]}]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 217, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 217, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 217, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[217]], TraditionalForm]], "Output",
 CellChangeTimes->{3.611048629534029*^9, 3.611048952669545*^9, 
  3.611049927201269*^9, 3.6110520890349007`*^9, 3.6120234430904617`*^9, 
  3.6120748136503067`*^9, 3.612671390803699*^9, 3.614414860906876*^9, 
  3.614416292989429*^9, 3.6145065009508877`*^9, 3.614577975939959*^9, 
  3.6149379910688753`*^9, 3.615634559013649*^9, 3.616215418734894*^9, 
  3.617336918137437*^9, 3.617339066896225*^9, 3.6182181934882393`*^9, 
  3.619334413500061*^9, 3.619775784748378*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Pee$1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.611049986940736*^9, 3.611049988236795*^9}, {
  3.61207380772281*^9, 3.6120738112587833`*^9}}],

Cell[BoxData[
 FormBox["3468", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.611049988577002*^9, 3.6110520892067013`*^9, 3.6120234433324738`*^9, {
   3.612073799899186*^9, 3.612073812377615*^9}, 3.612074813912752*^9, 
   3.6126713915718946`*^9, 3.614414861089316*^9, 3.614416293168528*^9, 
   3.614506501351144*^9, 3.614577976085125*^9, 3.6149379912981586`*^9, 
   3.615634559232951*^9, 3.616215418940557*^9, 3.6173369183313513`*^9, 
   3.617339067044128*^9, 3.618218193704583*^9, 3.61933441366744*^9, 
   3.6197757849288692`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{"Pee$1", "/.", "rules$transversality"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6110500489237823`*^9, 3.6110500653751097`*^9}, {
   3.6126706725196257`*^9, 3.6126706768009357`*^9}, {3.612670707243688*^9, 
   3.612670714355197*^9}, 3.612688136046502*^9}],

Cell[BoxData[
 FormBox["3468", TraditionalForm]], "Output",
 CellChangeTimes->{3.611050066816125*^9, 3.611052089484867*^9, 
  3.612075005740431*^9, 3.612671416132065*^9, 3.614414861310184*^9, 
  3.614416293385068*^9, 3.614506501524332*^9, 3.614577976266127*^9, 
  3.614937991482172*^9, 3.6156345594184427`*^9, 3.616215419115535*^9, 
  3.617336918528339*^9, 3.617339067229865*^9, 3.6182181938835497`*^9, 
  3.619334413858263*^9, 3.6197757851108503`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pee$1$elim", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Pee$1", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"23", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "b"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"b_", ",", "23"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "2"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "3"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"45", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "b"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"b_", ",", "45"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "4"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "5"}], "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.611050202742684*^9, 3.61105033061971*^9}, {
  3.6110503653852863`*^9, 3.611050388660204*^9}, {3.611050520744046*^9, 
  3.61105052361484*^9}, {3.612073839299294*^9, 3.61207386941566*^9}, {
  3.61450297366149*^9, 3.614503195537866*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SubsuperscriptBox["k", 
               FormBox["5",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["c",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["d",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["1",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"g", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"h", "j"}]]}], 
             RowBox[{"8", " ", "s23", " ", "s45"}]]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"g", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"h", "j"}]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"g", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"h", "j"}]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], " ", 
             SuperscriptBox["g", 
              RowBox[{"h", "j"}]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "10108", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "j"}]], " ", 
             RowBox[{"\[LeftSkeleton]", "4", "\[RightSkeleton]"}], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"g", "i"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"g", "i"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 220, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 220, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 220, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[220]], TraditionalForm]], "Output",
 CellChangeTimes->{3.611050391378804*^9, 3.611050526859393*^9, 
  3.6110520927130747`*^9, 3.612073908359929*^9, 3.6120750130925617`*^9, 
  3.612075043116304*^9, 3.612671424039341*^9, 3.6144148647104397`*^9, 
  3.614416296777401*^9, 3.6145031980021677`*^9, 3.614506504922263*^9, 
  3.6145779795447607`*^9, 3.6149379947739887`*^9, 3.61563456284074*^9, 
  3.616215422385974*^9, 3.617336921813781*^9, 3.617339070656316*^9, 
  3.618218197147481*^9, 3.619334417134934*^9, 3.619775788441124*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pee$1$elim", "]"}]], "Input",
 CellChangeTimes->{{3.611050415639818*^9, 3.611050416846714*^9}}],

Cell[BoxData[
 FormBox["6760", TraditionalForm]], "Output",
 CellChangeTimes->{3.611050417163341*^9, 3.611050526996475*^9, 
  3.6110520928133993`*^9, 3.6120739087549877`*^9, 3.612075043856636*^9, 
  3.6126714242208*^9, 3.61441486481558*^9, 3.61441629686804*^9, 
  3.6145065052631483`*^9, 3.6145779796193123`*^9, 3.614937994882921*^9, 
  3.6156345629372177`*^9, 3.6162154224857817`*^9, 3.6173369219062*^9, 
  3.6173390707266197`*^9, 3.618218197265478*^9, 3.619334417227261*^9, 
  3.61977578855721*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pee$1$elim$nice", "=", 
  RowBox[{"Pee$1$elim", "/.", 
   RowBox[{"Join", "[", 
    RowBox[{"rules$transversality", ",", "rules$massless", ",", "rules$sij"}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.611050399846109*^9, 3.611050408467682*^9}, {
  3.6110504394895277`*^9, 3.6110504889001513`*^9}, {3.611051020642345*^9, 
  3.611051033044385*^9}, {3.6126708879349957`*^9, 3.612670914897912*^9}, {
  3.6144140684745626`*^9, 3.614414069010936*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s15", " ", "s34", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"g", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"h", "j"}]]}], 
            RowBox[{"32", " ", "s23", " ", "s45"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "10117", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 222, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 222, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 222, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[222]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6110504127091208`*^9, 3.61105049109977*^9, 
  3.611050531984788*^9, 3.611051036048831*^9, 3.611052095188603*^9, 
  3.612073931887187*^9, 3.612075049191801*^9, 3.61267143565355*^9, 
  3.614414868082233*^9, 3.614416300001707*^9, 3.61450650851215*^9, 
  3.614577982626666*^9, 3.614937997865281*^9, 3.615634566192462*^9, 
  3.6162154254546556`*^9, 3.6173369249063807`*^9, 3.6173390738500147`*^9, 
  3.618218200250951*^9, 3.619334420233218*^9, 3.619775791615032*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pee$1$elim$nice", "]"}]], "Input",
 CellChangeTimes->{{3.611050421316581*^9, 3.611050422442265*^9}}],

Cell[BoxData[
 FormBox["6760", TraditionalForm]], "Output",
 CellChangeTimes->{3.6110504227690487`*^9, 3.611050493653646*^9, 
  3.611050533088585*^9, 3.611051043087055*^9, 3.611052095264797*^9, 
  3.6120739354418097`*^9, 3.612075051065585*^9, 3.612671497116987*^9, 
  3.6144148681726027`*^9, 3.614416300095481*^9, 3.614506508829427*^9, 
  3.614577982694072*^9, 3.6149379980312653`*^9, 3.615634566326622*^9, 
  3.616215425616681*^9, 3.6173369250018177`*^9, 3.617339073918516*^9, 
  3.618218200359131*^9, 3.6193344203176928`*^9, 3.61977579180602*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Perm5$ij$", "[", 
   RowBox[{
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$1$elim$nice", ",", "1", ",", "2"}], "]"}], ",", "1", ",", 
    "2"}], "]"}], "-", "Pee$1$elim$nice"}]], "Input",
 CellChangeTimes->{{3.6110538432852573`*^9, 3.611053882800156*^9}, {
  3.611650260504718*^9, 3.611650285624138*^9}, {3.611650342993946*^9, 
  3.61165035219079*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.611053855409369*^9, 3.611053869084359*^9}, {
   3.611650251054793*^9, 3.6116502884145308`*^9}, {3.611650349671072*^9, 
   3.611650353201021*^9}, 3.612073961561351*^9, 3.612671501326437*^9, 
   3.614414869147871*^9, 3.6144163010853977`*^9, 3.614506509726637*^9, 
   3.614577983599943*^9, 3.614937998923306*^9, 3.615634567286137*^9, 
   3.616215426559906*^9, 3.617336925908863*^9, 3.617339074858692*^9, 
   3.61821820124907*^9, 3.619334421219673*^9, 3.619775792741477*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pee$1$elim$nice", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6116503088539143`*^9, 3.6116503093793917`*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "s15", " ", "s34", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], 
   RowBox[{"32", " ", "s23", " ", "s45"}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6116503096671963`*^9, 3.6120739617032337`*^9, 
  3.612671501687639*^9, 3.614414869240911*^9, 3.614416301176855*^9, 
  3.614506509776335*^9, 3.614577983637292*^9, 3.614937998981595*^9, 
  3.615634567335548*^9, 3.616215426630924*^9, 3.6173369259587507`*^9, 
  3.617339074899765*^9, 3.6182182012993107`*^9, 3.6193344212692947`*^9, 
  3.619775792971171*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Perm5$ij$", "[", 
  RowBox[{
   RowBox[{"Pee$1$elim$nice", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", "4", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.611650319446707*^9, 3.611650320861855*^9}, {
  3.611650902122644*^9, 3.611650903966288*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "s14", " ", "s35", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], 
   RowBox[{"32", " ", "s23", " ", "s45"}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.61165032115287*^9, 3.6116509042657843`*^9, 
  3.61207396181168*^9, 3.612671504445352*^9, 3.614414869329274*^9, 
  3.6144163012585087`*^9, 3.614506509817266*^9, 3.6145779836906567`*^9, 
  3.61493799903576*^9, 3.615634567397863*^9, 3.616215426720543*^9, 
  3.617336926019339*^9, 3.617339074959791*^9, 3.618218201353774*^9, 
  3.619334421333087*^9, 3.619775793105564*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Perm5$ij$", "[", 
  RowBox[{
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"Pee$1$elim$nice", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", "4", ",", "5"}], "]"}], ",", "4", 
   ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.611650333776857*^9, 3.611650337320595*^9}, {
  3.611650919573715*^9, 3.6116509239832077`*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"\[ImaginaryI]", " ", "s15", " ", "s34", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], 
   RowBox[{"32", " ", "s23", " ", "s45"}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.611650337714924*^9, 3.611650924244465*^9, 
  3.612073961930176*^9, 3.6126715062281446`*^9, 3.614414869406608*^9, 
  3.614416301331492*^9, 3.6145065098595963`*^9, 3.6145779837405777`*^9, 
  3.6149379990871696`*^9, 3.6156345674490967`*^9, 3.616215426818563*^9, 
  3.61733692607836*^9, 3.617339075017078*^9, 3.618218201392009*^9, 
  3.6193344213825493`*^9, 3.619775793284562*^9}]
}, Open  ]],

Cell["The full amplitude part from two e propagators is:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pee$result", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pee$1$elim$nice", "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pee$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pee$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], ")"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pee$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "2"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pee$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "3"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pee$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pee$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pee$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "5"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.611054282546404*^9, 3.611054334601163*^9}, {
  3.6110543789911127`*^9, 3.611054407469212*^9}, {3.6110544423677807`*^9, 
  3.611054476523299*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s14", " ", "s35", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"16", " ", "s12", " ", "s34"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s24", " ", "s35", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"16", " ", "s12", " ", "s34"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s14", " ", "s35", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"32", " ", "s25", " ", "s34"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "151795", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 228, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 228, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 228, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[228]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6110543585259113`*^9, 3.611054514214246*^9, 
  3.612075113351514*^9, 3.6126719593474493`*^9, 3.614414924465575*^9, 
  3.614416353895754*^9, 3.614506565524984*^9, 3.614578035308875*^9, 
  3.61493805120236*^9, 3.615634619438531*^9, 3.616215478195455*^9, 
  3.6173369780686283`*^9, 3.617339127889275*^9, 3.6182182540864763`*^9, 
  3.6193344724004087`*^9, 3.619775845692194*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pee$result", "]"}]], "Input",
 CellChangeTimes->{{3.611054372311797*^9, 3.6110543734351263`*^9}}],

Cell[BoxData[
 FormBox["101400", TraditionalForm]], "Output",
 CellChangeTimes->{3.611054373722205*^9, 3.611054514610416*^9, 
  3.6120751138019533`*^9, 3.612671959852168*^9, 3.6144149248469954`*^9, 
  3.614416354283956*^9, 3.614506566102439*^9, 3.614578035621456*^9, 
  3.614938051561881*^9, 3.615634619785973*^9, 3.616215478546773*^9, 
  3.617336978417988*^9, 3.61733912822921*^9, 3.6182182544538107`*^9, 
  3.619334472715098*^9, 3.619775846024609*^9}]
}, Open  ]],

Cell["It is important to check Bose symmetry:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "1", ",", "2"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "1", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "1", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "1", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "2", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "2", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "2", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "3", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "3", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pee$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pee$result", ",", "4", ",", "5"}], "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.612075665681651*^9, 3.612075715637532*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6120756623050413`*^9, 3.612075795420464*^9, 
  3.612673798971095*^9, 3.614415005325341*^9, 3.614416434892152*^9, 
  3.6145066453007193`*^9, 3.614578113657073*^9, 3.614938129990974*^9, 
  3.615634698523273*^9, 3.616215556408228*^9, 3.617337059085425*^9, 
  3.617339213070846*^9, 3.6182183340397778`*^9, 3.61933455023258*^9, 
  3.619775923509241*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["One e propagator", "Subsection",
 CellChangeTimes->{{3.6120802603673077`*^9, 3.612080270864601*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pe$45", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"I", "/", "s45"}]}], ")"}], 
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"verEEEEonshell3legs$noMandel", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"g", "\[Rule]", "m"}], ",", 
          RowBox[{"h", "\[Rule]", "n"}], ",", 
          RowBox[{
           SubscriptBox["k", "4"], "\[Rule]", 
           SubscriptBox["k", "45"]}]}], "}"}]}], ")"}], 
      RowBox[{"verEEEonshellmn", "[", 
       RowBox[{
       "4", ",", "5", ",", "g", ",", "h", ",", "i", ",", "j", ",", "m", ",", 
        "n"}], "]"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.612080274833857*^9, 3.6120803419713907`*^9}, 
   3.612080375279212*^9, {3.612080473549474*^9, 3.612080481619767*^9}, {
   3.612080588061048*^9, 3.6120805892467833`*^9}, {3.612080623766941*^9, 
   3.612080635894451*^9}, {3.612080806001543*^9, 3.612080808149955*^9}, {
   3.6120809347735863`*^9, 3.612080964178095*^9}, {3.612674395204075*^9, 
   3.6126743996274548`*^9}, 3.612676843362678*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}]}], 
            "s45"]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 231, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 231, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 231, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[231]], TraditionalForm]], "Output",
 CellChangeTimes->{3.612080787420567*^9, 3.612081129527781*^9, 
  3.612673942480337*^9, 3.6126746961699753`*^9, 3.612677005983333*^9, 
  3.612677628659401*^9, 3.614415163887039*^9, 3.6144165947573957`*^9, 
  3.6145068029265957`*^9, 3.614578269119092*^9, 3.614938294947213*^9, 
  3.615634858243146*^9, 3.616215712716049*^9, 3.617337214665983*^9, 
  3.617339371252516*^9, 3.618218488139428*^9, 3.6193347051155376`*^9, 
  3.619776079842699*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Pe$45", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.612080810528059*^9, 3.612080819102273*^9}}],

Cell[BoxData[
 FormBox["2016", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612080813273724*^9, 3.612080819441649*^9}, 
   3.612081129737939*^9, 3.6126739427610607`*^9, 3.612674934306315*^9, 
   3.612677006233337*^9, 3.612677233916576*^9, 3.612677628903474*^9, 
   3.614415164017569*^9, 3.614416594890616*^9, 3.6145068032908163`*^9, 
   3.6145782692102003`*^9, 3.614938295103413*^9, 3.615634858361485*^9, 
   3.616215712830221*^9, 3.61733721478903*^9, 3.61733937136244*^9, 
   3.618218488272111*^9, 3.619334705226112*^9, 3.619776079987426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pe$45$elim", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Pe$45", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"45", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "b"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"b_", ",", "45"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"4", ",", "b"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"5", ",", "b"}], "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612080857867794*^9, 3.612080883227508*^9}, {
  3.614503266926838*^9, 3.614503356736154*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SubsuperscriptBox["k", 
               FormBox["5",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["c",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "f"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["1",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"g", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"h", "j"}]]}], 
             RowBox[{"16", " ", "s45"}]]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"g", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"h", "j"}]]}], 
            RowBox[{"16", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"g", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"h", "j"}]]}], 
            RowBox[{"16", " ", "s45"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "3569", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", "s45"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 233, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 233, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 233, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[233]], TraditionalForm]], "Output",
 CellChangeTimes->{3.612080884571021*^9, 3.612081130889483*^9, 
  3.61267496724619*^9, 3.612677245606977*^9, 3.612677629951088*^9, 
  3.614415165079521*^9, 3.6144165960316763`*^9, 3.6145033573745403`*^9, 
  3.614506804302372*^9, 3.614578270215783*^9, 3.6149382963049183`*^9, 
  3.615634859372613*^9, 3.616215713842301*^9, 3.617337215790399*^9, 
  3.617339372447742*^9, 3.618218489287839*^9, 3.619334706241622*^9, 
  3.619776081009103*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pe$45$elim", "]"}]], "Input",
 CellChangeTimes->{{3.612080888146202*^9, 3.612080889413281*^9}}],

Cell[BoxData[
 FormBox["2424", TraditionalForm]], "Output",
 CellChangeTimes->{3.612080889745392*^9, 3.612081130999447*^9, 
  3.612674969698736*^9, 3.612677248235428*^9, 3.612677630159237*^9, 
  3.6144151651617403`*^9, 3.614416596124517*^9, 3.6145068046045647`*^9, 
  3.614578270274115*^9, 3.614938296404656*^9, 3.615634859449984*^9, 
  3.616215713923195*^9, 3.6173372158773127`*^9, 3.617339372519741*^9, 
  3.618218489374325*^9, 3.6193347063151007`*^9, 3.619776081093688*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pe$45$elim$nice", "=", 
  RowBox[{"Pe$45$elim", "/.", 
   RowBox[{"Join", "[", 
    RowBox[{"rules$transversality", ",", "rules$massless", ",", "rules$sij"}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6120811261217623`*^9, 3.61208113235892*^9}, {
   3.6126780862983217`*^9, 3.6126781246872683`*^9}, 3.612688142795298*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 235, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 235, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 235, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[235]], TraditionalForm]], "Output",
 CellChangeTimes->{3.612081143832451*^9, 3.612674973578952*^9, 
  3.6126772543399153`*^9, 3.612677631194333*^9, 3.612678126964527*^9, 
  3.6144151661563797`*^9, 3.614416597202224*^9, 3.614506805540885*^9, 
  3.614578271240573*^9, 3.614938297543058*^9, 3.6156348604083767`*^9, 
  3.616215714880986*^9, 3.6173372168334837`*^9, 3.617339373491186*^9, 
  3.6182184903314657`*^9, 3.6193347072797127`*^9, 3.6197760820475473`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pe$45$elim$nice", "]"}]], "Input",
 CellChangeTimes->{{3.612081146632247*^9, 3.612081147964855*^9}}],

Cell[BoxData[
 FormBox["2424", TraditionalForm]], "Output",
 CellChangeTimes->{3.612081150712791*^9, 3.6126776313596888`*^9, 
  3.612678128756844*^9, 3.614415166248768*^9, 3.614416597377573*^9, 
  3.614506805858625*^9, 3.614578271294941*^9, 3.614938297637689*^9, 
  3.615634860497127*^9, 3.616215714974399*^9, 3.617337216931595*^9, 
  3.6173393735553417`*^9, 3.6182184904200974`*^9, 3.619334707357807*^9, 
  3.6197760821376534`*^9}]
}, Open  ]],

Cell["The full amplitude part from one e propagator is:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.612081243008892*^9, 
  3.61208124512131*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pe$result", "=", 
  RowBox[{"Pe$45$elim$nice", "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pe$45$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pe$45$elim$nice", ",", "3", ",", "5"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pe$45$elim$nice", ",", "2", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pe$45$elim$nice", ",", "2", ",", "5"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pe$45$elim$nice", ",", "2", ",", "4"}], "]"}], ",", "5", ",", 
     "3"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pe$45$elim$nice", ",", "1", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pe$45$elim$nice", ",", "1", ",", "5"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pe$45$elim$nice", ",", "1", ",", "4"}], "]"}], ",", "5", ",", 
     "3"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pe$45$elim$nice", ",", "1", ",", "4"}], "]"}], ",", "5", ",", 
     "2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.611054282546404*^9, 3.611054334601163*^9}, {
  3.6110543789911127`*^9, 3.611054407469212*^9}, {3.6110544423677807`*^9, 
  3.611054476523299*^9}, {3.612081247598879*^9, 3.6120812551409283`*^9}, {
  3.612081333657134*^9, 3.6120814850197153`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 237, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 237, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 237, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[237]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6110543585259113`*^9, 3.611054514214246*^9, 
  3.612075113351514*^9, 3.6120814972774353`*^9, 3.612677372459957*^9, 
  3.612677641506894*^9, 3.614415176630431*^9, 3.614416607822777*^9, 
  3.614506816041198*^9, 3.614578281395918*^9, 3.614938308962525*^9, 
  3.615634870791588*^9, 3.616215725071549*^9, 3.617337227071097*^9, 
  3.6173393838285017`*^9, 3.618218500495672*^9, 3.619334717437954*^9, 
  3.619776092189097*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pe$result", "]"}]], "Input",
 CellChangeTimes->{{3.611054372311797*^9, 3.6110543734351263`*^9}, 
   3.612081494200481*^9}],

Cell[BoxData[
 FormBox["24240", TraditionalForm]], "Output",
 CellChangeTimes->{3.611054373722205*^9, 3.611054514610416*^9, 
  3.6120751138019533`*^9, 3.6120814977047*^9, 3.612677376861699*^9, 
  3.6126776417622623`*^9, 3.6144151767787523`*^9, 3.6144166079696417`*^9, 
  3.614506816428401*^9, 3.614578281501564*^9, 3.614938309113996*^9, 
  3.615634870912002*^9, 3.6162157252033043`*^9, 3.6173372272083073`*^9, 
  3.6173393839417973`*^9, 3.618218500639841*^9, 3.619334717567483*^9, 
  3.619776092342058*^9}]
}, Open  ]],

Cell["It is important to check Bose symmetry:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "1", ",", "2"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "1", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "1", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "1", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "2", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "2", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "2", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "3", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "3", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pe$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pe$result", ",", "4", ",", "5"}], "]"}]}]}], "}"}]], "Input",
 CellChangeTimes->{{3.612075665681651*^9, 3.612075715637532*^9}, {
  3.612081499567829*^9, 3.612081517291541*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6120756623050413`*^9, 3.612075795420464*^9, 
  3.612081535280946*^9, 3.612677396536867*^9, 3.612677657943159*^9, 
  3.6144151935923347`*^9, 3.614416624158766*^9, 3.61450683308002*^9, 
  3.6145782975777187`*^9, 3.6149383262325*^9, 3.615634887243441*^9, 
  3.616215741372357*^9, 3.617337243489196*^9, 3.617339400234879*^9, 
  3.618218516854801*^9, 3.619334733514081*^9, 3.61977610848472*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["One \[CurlyPhi] propagator", "Subsection",
 CellChangeTimes->{{3.6120802603673077`*^9, 3.612080270864601*^9}, {
   3.6120825528018713`*^9, 3.6120825533707447`*^9}, 3.616221805418157*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphi$45", "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I", "/", "4"}], "/", "s45"}], ")"}], "verEEEVarphionshell123",
      " ", 
     RowBox[{"(", 
      RowBox[{"verEEVARPHIonshell12", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kdotk", "[", 
           RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
          RowBox[{"kdotk", "[", 
           RowBox[{"4", ",", "5"}], "]"}]}], ",", 
         RowBox[{"a", "\[Rule]", "g"}], ",", 
         RowBox[{"b", "\[Rule]", "h"}], ",", 
         RowBox[{"c", "\[Rule]", "i"}], ",", 
         RowBox[{"d", "\[Rule]", "j"}]}], "}"}]}], ")"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.612080274833857*^9, 3.6120803419713907`*^9}, 
   3.612080375279212*^9, {3.612080473549474*^9, 3.612080481619767*^9}, {
   3.612080588061048*^9, 3.6120805892467833`*^9}, {3.612080623766941*^9, 
   3.612080635894451*^9}, {3.612080806001543*^9, 3.612080808149955*^9}, {
   3.6120809347735863`*^9, 3.612080964178095*^9}, {3.612082557010398*^9, 
   3.6120826082313147`*^9}, 3.612082741230233*^9, {3.612082814420052*^9, 
   3.6120829180743427`*^9}, {3.614503393994458*^9, 3.6145034303579407`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612080787420567*^9, 3.612081129527781*^9, 3.612082706870789*^9, 
   3.612082742171274*^9, {3.6120828161805058`*^9, 3.612082843182953*^9}, {
   3.612082877848764*^9, 3.612082918675028*^9}, 3.6126780411293497`*^9, 
   3.6144151940484753`*^9, 3.614416624576837*^9, 3.614503432927997*^9, 
   3.6145068334802113`*^9, 3.614578297962873*^9, 3.6149383266736393`*^9, 
   3.615634887626552*^9, 3.616215741755334*^9, 3.617337243876197*^9, 
   3.617339400632964*^9, 3.618218517246297*^9, 3.619334733915661*^9, 
   3.619776108872066*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Pvarphi$45", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.612080810528059*^9, 3.612080819102273*^9}, 
   3.612082612568445*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612080813273724*^9, 3.612080819441649*^9}, 
   3.612081129737939*^9, 3.6120829276732683`*^9, 3.6126780440793123`*^9, 
   3.6144151940543327`*^9, 3.6144166245923758`*^9, 3.614506833498679*^9, 
   3.614578297983626*^9, 3.614938326683132*^9, 3.6156348876462727`*^9, 
   3.6162157417733793`*^9, 3.617337243893589*^9, 3.617339400651065*^9, 
   3.618218517274316*^9, 3.6193347339228277`*^9, 3.619776108886272*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphi$45$elim", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Pvarphi$45", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"45", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "b"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"b_", ",", "45"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "4"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"5", ",", "b"}], "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612080857867794*^9, 3.612080883227508*^9}, {
  3.6120826165940533`*^9, 3.6120826180362577`*^9}, {3.6145034619262953`*^9, 
  3.6145035592327833`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s45"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612080884571021*^9, 3.612081130889483*^9, 
  3.6120829297226133`*^9, 3.6126780550253477`*^9, 3.614415194157063*^9, 
  3.614416624670273*^9, 3.6145035601380367`*^9, 3.614506833538322*^9, 
  3.6145782980202503`*^9, 3.6149383267415857`*^9, 3.6156348876923656`*^9, 
  3.616215741813468*^9, 3.617337243931525*^9, 3.617339400695909*^9, 
  3.61821851731915*^9, 3.619334733976699*^9, 3.619776108929282*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pvarphi$45$elim", "]"}]], "Input",
 CellChangeTimes->{{3.612080888146202*^9, 3.612080889413281*^9}, 
   3.6120826263159*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 CellChangeTimes->{3.612080889745392*^9, 3.612081130999447*^9, 
  3.6120829377338533`*^9, 3.612678057018302*^9, 3.614415194241973*^9, 
  3.614416624776244*^9, 3.614506833589099*^9, 3.614578298068453*^9, 
  3.614938326790987*^9, 3.6156348877530737`*^9, 3.616215741862771*^9, 
  3.617337243985446*^9, 3.617339400749587*^9, 3.61821851737446*^9, 
  3.619334734021796*^9, 3.61977610897927*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphi$45$elim$nice", "=", 
  RowBox[{"Pvarphi$45$elim", "/.", 
   RowBox[{"Join", "[", 
    RowBox[{"rules$transversality", ",", "rules$massless", ",", "rules$sij"}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6120811261217623`*^9, 3.61208113235892*^9}, {
   3.612082627489995*^9, 3.6120826300065536`*^9}, 3.612678151666147*^9, 
   3.612688146931191*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612081143832451*^9, 3.612082940585828*^9, 
  3.612678154301997*^9, 3.614415194340475*^9, 3.6144166248634663`*^9, 
  3.614506833626639*^9, 3.61457829810655*^9, 3.614938326836543*^9, 
  3.615634887807879*^9, 3.616215741907419*^9, 3.617337244018366*^9, 
  3.617339400792244*^9, 3.61821851741214*^9, 3.6193347340701036`*^9, 
  3.619776109020262*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pvarphi$45$elim$nice", "]"}]], "Input",
 CellChangeTimes->{{3.612081146632247*^9, 3.612081147964855*^9}, 
   3.6120826373444557`*^9}],

Cell[BoxData[
 FormBox["18", TraditionalForm]], "Output",
 CellChangeTimes->{3.612081150712791*^9, 3.612082944429123*^9, 
  3.6126781563539953`*^9, 3.614415194345109*^9, 3.6144166248678207`*^9, 
  3.614506833668556*^9, 3.6145782981478987`*^9, 3.614938326878224*^9, 
  3.615634887857739*^9, 3.6162157419461727`*^9, 3.6173372440562077`*^9, 
  3.617339400839109*^9, 3.618218517455285*^9, 3.619334734119636*^9, 
  3.619776109064364*^9}]
}, Open  ]],

Cell["The full amplitude part from one \[CurlyPhi] propagator is:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.612081243008892*^9, 
   3.61208124512131*^9}, {3.612678169285121*^9, 3.6126781697970247`*^9}, 
   3.61622181089848*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphi$result", "=", 
  RowBox[{"Pvarphi$45$elim$nice", "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pvarphi$45$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pvarphi$45$elim$nice", ",", "3", ",", "5"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pvarphi$45$elim$nice", ",", "2", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pvarphi$45$elim$nice", ",", "2", ",", "5"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pvarphi$45$elim$nice", ",", "2", ",", "4"}], "]"}], ",", "5", 
     ",", "3"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pvarphi$45$elim$nice", ",", "1", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{"Pvarphi$45$elim$nice", ",", "1", ",", "5"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pvarphi$45$elim$nice", ",", "1", ",", "4"}], "]"}], ",", "5", 
     ",", "3"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pvarphi$45$elim$nice", ",", "1", ",", "4"}], "]"}], ",", "5", 
     ",", "2"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.611054282546404*^9, 3.611054334601163*^9}, {
  3.6110543789911127`*^9, 3.611054407469212*^9}, {3.6110544423677807`*^9, 
  3.611054476523299*^9}, {3.612081247598879*^9, 3.6120812551409283`*^9}, {
  3.612081333657134*^9, 3.6120814850197153`*^9}, {3.61208264102675*^9, 
  3.612082664252092*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6110543585259113`*^9, 3.611054514214246*^9, 
  3.612075113351514*^9, 3.6120814972774353`*^9, 3.6120829507874327`*^9, 
  3.614415194434814*^9, 3.614416624957953*^9, 3.614506833729504*^9, 
  3.614578298209125*^9, 3.614938326959296*^9, 3.615634887915555*^9, 
  3.616215742002881*^9, 3.617337244112247*^9, 3.617339400895673*^9, 
  3.6182185175320272`*^9, 3.619334734196577*^9, 3.619776109139537*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pvarphi$result", "]"}]], "Input",
 CellChangeTimes->{{3.611054372311797*^9, 3.6110543734351263`*^9}, 
   3.612081494200481*^9, 3.61208267189284*^9}],

Cell[BoxData[
 FormBox["180", TraditionalForm]], "Output",
 CellChangeTimes->{3.611054373722205*^9, 3.611054514610416*^9, 
  3.6120751138019533`*^9, 3.6120814977047*^9, 3.6120829551103563`*^9, 
  3.612678207558422*^9, 3.614415194593933*^9, 3.614416625116542*^9, 
  3.6145068338458014`*^9, 3.6145782983143463`*^9, 3.614938326964651*^9, 
  3.615634887998744*^9, 3.6162157421101723`*^9, 3.617337244220584*^9, 
  3.617339400976363*^9, 3.6182185176147346`*^9, 3.619334734202334*^9, 
  3.619776109248*^9}]
}, Open  ]],

Cell["It is important to check Bose symmetry:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "1", ",", "2"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "1", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "1", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "1", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "2", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "2", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "2", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "3", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "3", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pvarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphi$result", ",", "4", ",", "5"}], "]"}]}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.612075665681651*^9, 3.612075715637532*^9}, {
  3.612081499567829*^9, 3.612081517291541*^9}, {3.612082673763598*^9, 
  3.6120826987164707`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6120756623050413`*^9, 3.612075795420464*^9, 
  3.612081535280946*^9, 3.6120829632563334`*^9, 3.6126782106741858`*^9, 
  3.614415194687985*^9, 3.61441662521418*^9, 3.614506833947144*^9, 
  3.614578298408742*^9, 3.614938327066003*^9, 3.615634888092064*^9, 
  3.616215742204612*^9, 3.617337244312023*^9, 3.617339401068984*^9, 
  3.61821851770761*^9, 3.619334734297673*^9, 3.619776109344005*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two \[CurlyPhi] propagators", "Subsection",
 CellChangeTimes->{{3.6120802603673077`*^9, 3.612080270864601*^9}, {
   3.6120825528018713`*^9, 3.6120825533707447`*^9}, {3.612083321765675*^9, 
   3.612083323653013*^9}, 3.6162218189536324`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphivarphi$1", "=", 
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"I", "/", "4"}], "/", "s23"}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"I", "/", "4"}], "/", "s45"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"verEEVARPHIonshell12", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kdotk", "[", 
          RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{"kdotk", "[", 
          RowBox[{"2", ",", "3"}], "]"}]}], ",", 
        RowBox[{"a", "\[Rule]", "c"}], ",", 
        RowBox[{"b", "\[Rule]", "d"}], ",", 
        RowBox[{"c", "\[Rule]", "e"}], ",", 
        RowBox[{"d", "\[Rule]", "f"}]}], "}"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"4", "I", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"k", "[", 
          RowBox[{"23", ",", "a"}], "]"}], 
         RowBox[{"k", "[", 
          RowBox[{"45", ",", "b"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"k", "[", 
          RowBox[{"45", ",", "a"}], "]"}], 
         RowBox[{"k", "[", 
          RowBox[{"23", ",", "b"}], "]"}]}]}], ")"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{"verEEVARPHIonshell12", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kdotk", "[", 
          RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
         RowBox[{"kdotk", "[", 
          RowBox[{"4", ",", "5"}], "]"}]}], ",", 
        RowBox[{"a", "\[Rule]", "g"}], ",", 
        RowBox[{"b", "\[Rule]", "h"}], ",", 
        RowBox[{"c", "\[Rule]", "i"}], ",", 
        RowBox[{"d", "\[Rule]", "j"}]}], "}"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612080274833857*^9, 3.6120803419713907`*^9}, 
   3.612080375279212*^9, {3.612080473549474*^9, 3.612080481619767*^9}, {
   3.612080588061048*^9, 3.6120805892467833`*^9}, {3.612080623766941*^9, 
   3.612080635894451*^9}, {3.612080806001543*^9, 3.612080808149955*^9}, {
   3.6120809347735863`*^9, 3.612080964178095*^9}, {3.612082557010398*^9, 
   3.6120826082313147`*^9}, 3.612082741230233*^9, {3.612082814420052*^9, 
   3.6120829180743427`*^9}, {3.612083326186791*^9, 3.612083355531166*^9}, {
   3.612083437693865*^9, 3.612083521860429*^9}, {3.61208358970677*^9, 
   3.6120836739013033`*^9}, {3.612083736469143*^9, 3.612083761772319*^9}, {
   3.614503610684225*^9, 3.614503693151452*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["45",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["45",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612080787420567*^9, 3.612081129527781*^9, 3.612082706870789*^9, 
   3.612082742171274*^9, {3.6120828161805058`*^9, 3.612082843182953*^9}, {
   3.612082877848764*^9, 3.612082918675028*^9}, 3.6120835230159597`*^9, {
   3.6120836450469847`*^9, 3.612083674429929*^9}, {3.612083738881803*^9, 
   3.612083762065844*^9}, 3.6144151948204603`*^9, 3.6144166253468313`*^9, 
   3.614503694154872*^9, 3.614506834054275*^9, 3.614578298478882*^9, 
   3.6149383271478558`*^9, 3.615634888170282*^9, 3.616215742274168*^9, 
   3.617337244382964*^9, 3.617339401142713*^9, 3.618218517780361*^9, 
   3.61933473438157*^9, 3.619776109416403*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Pvarphivarphi$1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.612080810528059*^9, 3.612080819102273*^9}, 
   3.612082612568445*^9, 3.6120833604432697`*^9}],

Cell[BoxData[
 FormBox["2", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612080813273724*^9, 3.612080819441649*^9}, 
   3.612081129737939*^9, 3.6120829276732683`*^9, 3.612083683275776*^9, 
   3.612083764548358*^9, 3.612678745994412*^9, 3.614415194902953*^9, 
   3.614416625430113*^9, 3.614506834096683*^9, 3.614578298510248*^9, 
   3.614938327190302*^9, 3.6156348881766043`*^9, 3.616215742306436*^9, 
   3.617337244414735*^9, 3.617339401149583*^9, 3.618218517788354*^9, 
   3.6193347344261513`*^9, 3.6197761094515543`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphivarphi$1$elim", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Pvarphivarphi$1", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"23", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "b"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"b_", ",", "23"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "2"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"3", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"45", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "b"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"b_", ",", "45"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "4"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "5"}], "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612080857867794*^9, 3.612080883227508*^9}, {
  3.6120826165940533`*^9, 3.6120826180362577`*^9}, {3.6120833630412703`*^9, 
  3.61208336710844*^9}, {3.612083777250079*^9, 3.612083790659212*^9}, {
  3.614503720701962*^9, 3.614503917203949*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["5",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["5",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["5",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["5",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612678790824582*^9, 3.6144151949942408`*^9, 
  3.614416625522778*^9, 3.614503918228972*^9, 3.614506834427199*^9, 
  3.614578298557268*^9, 3.61493832723652*^9, 3.615634888220482*^9, 
  3.61621574234934*^9, 3.6173372444578733`*^9, 3.61733940119451*^9, 
  3.618218517834015*^9, 3.6193347344797773`*^9, 3.6197761095270367`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pvarphivarphi$1$elim", "]"}]], "Input",
 CellChangeTimes->{{3.612080888146202*^9, 3.612080889413281*^9}, 
   3.6120826263159*^9, 3.61208380137521*^9}],

Cell[BoxData[
 FormBox["8", TraditionalForm]], "Output",
 CellChangeTimes->{3.612080889745392*^9, 3.612081130999447*^9, 
  3.6120829377338533`*^9, 3.612083801836629*^9, 3.612678792803051*^9, 
  3.614415195083943*^9, 3.614416625610376*^9, 3.614506834464841*^9, 
  3.614578298568952*^9, 3.6149383272779818`*^9, 3.615634888265154*^9, 
  3.61621574235993*^9, 3.6173372444677887`*^9, 3.6173394012344437`*^9, 
  3.618218517871265*^9, 3.619334734530119*^9, 3.619776109601424*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphivarphi$1$elim$nice", "=", 
  RowBox[{"Pvarphivarphi$1$elim", "/.", 
   RowBox[{"Join", "[", 
    RowBox[{"rules$transversality", ",", "rules$massless", ",", "rules$sij"}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6120811261217623`*^9, 3.61208113235892*^9}, {
   3.612082627489995*^9, 3.6120826300065536`*^9}, {3.612083809431782*^9, 
   3.612083810189001*^9}, 3.612678819682322*^9, 3.612688155325242*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612081143832451*^9, 3.612082940585828*^9, 
  3.612083812946375*^9, 3.6126788204435253`*^9, 3.614415195188525*^9, 
  3.614416625693309*^9, 3.6145068345012817`*^9, 3.614578298600696*^9, 
  3.6149383273815117`*^9, 3.615634888362584*^9, 3.616215742391036*^9, 
  3.617337244499024*^9, 3.617339401269068*^9, 3.618218517963303*^9, 
  3.6193347346173286`*^9, 3.61977610963545*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pvarphivarphi$1$elim$nice", "]"}]], "Input",
 CellChangeTimes->{{3.612081146632247*^9, 3.612081147964855*^9}, 
   3.6120826373444557`*^9, {3.612083816624289*^9, 3.61208381885325*^9}}],

Cell[BoxData[
 FormBox["8", TraditionalForm]], "Output",
 CellChangeTimes->{3.612081150712791*^9, 3.612082944429123*^9, 
  3.612083819406088*^9, 3.61267882288416*^9, 3.614415195196245*^9, 
  3.614416625705464*^9, 3.614506834538903*^9, 3.614578298641203*^9, 
  3.614938327424176*^9, 3.6156348884084473`*^9, 3.6162157424582863`*^9, 
  3.617337244566485*^9, 3.6173394013123217`*^9, 3.6182185180012617`*^9, 
  3.619334734661276*^9, 3.619776109670989*^9}]
}, Open  ]],

Cell["The full amplitude part from one e propagator is:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.612081243008892*^9, 
  3.61208124512131*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pvarphivarphi$result", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pvarphivarphi$1$elim$nice", "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], 
    ")"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pvarphivarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], 
      ")"}], ",", "1", ",", "2"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pvarphivarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], 
      ")"}], ",", "1", ",", "3"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pvarphivarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], 
      ")"}], ",", "1", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pvarphivarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pvarphivarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}]}], 
      ")"}], ",", "1", ",", "5"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.611054282546404*^9, 3.611054334601163*^9}, {
  3.6110543789911127`*^9, 3.611054407469212*^9}, {3.6110544423677807`*^9, 
  3.611054476523299*^9}, {3.612081247598879*^9, 3.6120812551409283`*^9}, {
  3.612081333657134*^9, 3.6120814850197153`*^9}, {3.61208264102675*^9, 
  3.612082664252092*^9}, {3.61208385512154*^9, 3.612083882852788*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "j"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "j"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["i",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["j",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6110543585259113`*^9, 3.611054514214246*^9, 
  3.612075113351514*^9, 3.6120814972774353`*^9, 3.6120829507874327`*^9, 
  3.612083883994122*^9, 3.612678826823359*^9, 3.6144151952840557`*^9, 
  3.6144166257933273`*^9, 3.6145068345844183`*^9, 3.614578298686481*^9, 
  3.614938327485779*^9, 3.615634888548629*^9, 3.616215742501713*^9, 
  3.6173372446101627`*^9, 3.61733940135747*^9, 3.61821851805901*^9, 
  3.619334734726179*^9, 3.619776109729224*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pvarphivarphi$result", "]"}]], "Input",
 CellChangeTimes->{{3.611054372311797*^9, 3.6110543734351263`*^9}, 
   3.612081494200481*^9, 3.61208267189284*^9, {3.612083889162163*^9, 
   3.612083889767927*^9}}],

Cell[BoxData[
 FormBox["120", TraditionalForm]], "Output",
 CellChangeTimes->{3.611054373722205*^9, 3.611054514610416*^9, 
  3.6120751138019533`*^9, 3.6120814977047*^9, 3.6120829551103563`*^9, 
  3.612083890442758*^9, 3.612678832833584*^9, 3.6144151954176617`*^9, 
  3.6144166259270763`*^9, 3.6145068346728287`*^9, 3.6145782987679033`*^9, 
  3.614938327490378*^9, 3.615634888645553*^9, 3.616215742584087*^9, 
  3.6173372446924953`*^9, 3.6173394014429283`*^9, 3.618218518114933*^9, 
  3.619334734731662*^9, 3.619776109812158*^9}]
}, Open  ]],

Cell["It is important to check Bose symmetry:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "1", ",", "2"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "1", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "1", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "1", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "2", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "2", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "2", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "3", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "3", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pvarphivarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pvarphivarphi$result", ",", "4", ",", "5"}], "]"}]}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.612075665681651*^9, 3.612075715637532*^9}, {
  3.612081499567829*^9, 3.612081517291541*^9}, {3.612082673763598*^9, 
  3.6120826987164707`*^9}, {3.612083895837511*^9, 3.6120839114544888`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6120756623050413`*^9, 3.612075795420464*^9, 
  3.612081535280946*^9, 3.6120829632563334`*^9, 3.6120839121721363`*^9, 
  3.612678835341597*^9, 3.614415195500359*^9, 3.614416626010923*^9, 
  3.6145068347434483`*^9, 3.614578298837483*^9, 3.6149383275568247`*^9, 
  3.615634888741778*^9, 3.616215742652616*^9, 3.6173372447591963`*^9, 
  3.617339401509184*^9, 3.618218518182178*^9, 3.619334734798448*^9, 
  3.619776109880486*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["One e, one \[CurlyPhi] propagator", "Subsection",
 CellChangeTimes->{{3.6120802603673077`*^9, 3.612080270864601*^9}, {
   3.6120825528018713`*^9, 3.6120825533707447`*^9}, {3.612083321765675*^9, 
   3.612083323653013*^9}, {3.6120851460664883`*^9, 3.61208515164371*^9}, 
   3.61622183696179*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pevarphi$1", "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"I", "/", "4"}], "/", "s45"}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], 
       RowBox[{"I", "/", "s23"}]}], ")"}], 
     RowBox[{"verEEEonshellmn", "[", 
      RowBox[{
      "2", ",", "3", ",", "c", ",", "d", ",", "e", ",", "f", ",", "m", ",", 
       "n"}], "]"}], 
     RowBox[{"verEEVarphionshellem", "[", 
      RowBox[{"1", ",", "23", ",", "a", ",", "b", ",", "m", ",", "n"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"verEEVARPHIonshell12", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kdotk", "[", 
           RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
          RowBox[{"kdotk", "[", 
           RowBox[{"4", ",", "5"}], "]"}]}], ",", 
         RowBox[{"a", "\[Rule]", "g"}], ",", 
         RowBox[{"b", "\[Rule]", "h"}], ",", 
         RowBox[{"c", "\[Rule]", "i"}], ",", 
         RowBox[{"d", "\[Rule]", "j"}]}], "}"}]}], ")"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.612080274833857*^9, 3.6120803419713907`*^9}, 
   3.612080375279212*^9, {3.612080473549474*^9, 3.612080481619767*^9}, {
   3.612080588061048*^9, 3.6120805892467833`*^9}, {3.612080623766941*^9, 
   3.612080635894451*^9}, {3.612080806001543*^9, 3.612080808149955*^9}, {
   3.6120809347735863`*^9, 3.612080964178095*^9}, {3.612082557010398*^9, 
   3.6120826082313147`*^9}, 3.612082741230233*^9, {3.612082814420052*^9, 
   3.6120829180743427`*^9}, {3.612083326186791*^9, 3.612083355531166*^9}, {
   3.612083437693865*^9, 3.612083521860429*^9}, {3.61208358970677*^9, 
   3.6120836739013033`*^9}, {3.612083736469143*^9, 3.612083761772319*^9}, {
   3.612085159806293*^9, 3.612085180438583*^9}, 3.612085254568486*^9, {
   3.6120853151724443`*^9, 3.612085352035406*^9}, {3.612085437726791*^9, 
   3.612085446989361*^9}, {3.612679417824131*^9, 3.612679430481216*^9}, {
   3.61450393981258*^9, 3.614503984025132*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["23",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "23"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612080787420567*^9, 3.612081129527781*^9, 3.612082706870789*^9, 
   3.612082742171274*^9, {3.6120828161805058`*^9, 3.612082843182953*^9}, {
   3.612082877848764*^9, 3.612082918675028*^9}, 3.6120835230159597`*^9, {
   3.6120836450469847`*^9, 3.612083674429929*^9}, {3.612083738881803*^9, 
   3.612083762065844*^9}, {3.612085419307585*^9, 3.612085448201889*^9}, 
   3.612679740160396*^9, 3.614415196446003*^9, 3.6144166269471483`*^9, 
   3.614503987275354*^9, 3.61450683585069*^9, 3.614578299783986*^9, 
   3.614938328530389*^9, 3.615634889721017*^9, 3.6162157436014*^9, 
   3.617337245701407*^9, 3.61733940248731*^9, 3.6182185191497183`*^9, 
   3.6193347357829657`*^9, 3.619776110848538*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", "Pevarphi$1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.612080810528059*^9, 3.612080819102273*^9}, 
   3.612082612568445*^9, 3.6120833604432697`*^9, 3.612085463293729*^9}],

Cell[BoxData[
 FormBox["42", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612080813273724*^9, 3.612080819441649*^9}, 
   3.612081129737939*^9, 3.6120829276732683`*^9, 3.612083683275776*^9, 
   3.612083764548358*^9, 3.612085463881646*^9, 3.6126797425238247`*^9, 
   3.614415196562862*^9, 3.614416627074078*^9, 3.614503991013344*^9, 
   3.6145068361866837`*^9, 3.614578299848281*^9, 3.614938328617671*^9, 
   3.6156348898096724`*^9, 3.616215743700508*^9, 3.617337245812187*^9, 
   3.6173394025591288`*^9, 3.6182185192592783`*^9, 3.619334735848167*^9, 
   3.619776110951329*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pevarphi$1$elim", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Pevarphi$1", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"23", ",", "b_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "b"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "b"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"b_", ",", "23"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "2"}], "]"}], "+", 
        RowBox[{"kdotk", "[", 
         RowBox[{"b", ",", "3"}], "]"}]}]}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612080857867794*^9, 3.612080883227508*^9}, {
  3.6120826165940533`*^9, 3.6120826180362577`*^9}, {3.6120833630412703`*^9, 
  3.61208336710844*^9}, {3.612083777250079*^9, 3.612083790659212*^9}, {
  3.6120854676233463`*^9, 3.612085494583333*^9}, {3.614504039411235*^9, 
  3.6145041301509733`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "2", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "2"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"4", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]], " ", 
     SubsuperscriptBox["k", "3", "2"], " ", 
     RowBox[{
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}]}], 
    RowBox[{"8", " ", "s23", " ", "s45"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612080884571021*^9, 3.612081130889483*^9, 3.6120829297226133`*^9, 
   3.6120836933567266`*^9, {3.612083766770397*^9, 3.6120837919149847`*^9}, 
   3.6120854953397493`*^9, 3.612679849131879*^9, 3.614415196661111*^9, 
   3.6144166271708717`*^9, 3.6145041309799023`*^9, 3.6145068362301807`*^9, 
   3.614578299903949*^9, 3.614938328680135*^9, 3.615634889869626*^9, 
   3.616215743742894*^9, 3.61733724586095*^9, 3.617339402608417*^9, 
   3.6182185193240633`*^9, 3.619334735917432*^9, 3.6197761110085506`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pevarphi$1$elim", "]"}]], "Input",
 CellChangeTimes->{{3.612080888146202*^9, 3.612080889413281*^9}, 
   3.6120826263159*^9, 3.61208380137521*^9, 3.612085504801342*^9}],

Cell[BoxData[
 FormBox["86", TraditionalForm]], "Output",
 CellChangeTimes->{3.612080889745392*^9, 3.612081130999447*^9, 
  3.6120829377338533`*^9, 3.612083801836629*^9, 3.612085505285961*^9, 
  3.612679853024884*^9, 3.6144151967955437`*^9, 3.6144166273061657`*^9, 
  3.614506836320807*^9, 3.614578299990211*^9, 3.614938328721621*^9, 
  3.6156348900237703`*^9, 3.616215743825438*^9, 3.617337245945776*^9, 
  3.61733940270195*^9, 3.618218519411974*^9, 3.6193347359625273`*^9, 
  3.619776111093873*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pevarphi$1$elim$nice", "=", 
  RowBox[{"Pevarphi$1$elim", "/.", 
   RowBox[{"Join", "[", 
    RowBox[{"rules$transversality", ",", "rules$massless", ",", "rules$sij"}],
     "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6120811261217623`*^9, 3.61208113235892*^9}, {
   3.612082627489995*^9, 3.6120826300065536`*^9}, {3.612083809431782*^9, 
   3.612083810189001*^9}, {3.612085509069971*^9, 3.612085513664817*^9}, 
   3.61267988869339*^9, 3.612688163303936*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"g", "i"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"h", "j"}]]}], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"32", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]], "+", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]], "-", 
   FractionBox[
    RowBox[{"\[ImaginaryI]", " ", "s13", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"g", "i"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"h", "j"}]]}], 
    RowBox[{"16", " ", "s23"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612081143832451*^9, 3.612082940585828*^9, 
  3.612083812946375*^9, 3.612085516747095*^9, 3.612679854781954*^9, 
  3.612679890184471*^9, 3.614415196875514*^9, 3.6144166273978786`*^9, 
  3.614506836357913*^9, 3.614578300024742*^9, 3.6149383287706137`*^9, 
  3.615634890102446*^9, 3.6162157438560038`*^9, 3.6173372459777803`*^9, 
  3.617339402737013*^9, 3.618218519451679*^9, 3.619334736011239*^9, 
  3.619776111132986*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pevarphi$1$elim$nice", "]"}]], "Input",
 CellChangeTimes->{{3.612081146632247*^9, 3.612081147964855*^9}, 
   3.6120826373444557`*^9, {3.612083816624289*^9, 3.61208381885325*^9}, 
   3.612085522648355*^9}],

Cell[BoxData[
 FormBox["32", TraditionalForm]], "Output",
 CellChangeTimes->{3.612081150712791*^9, 3.612082944429123*^9, 
  3.612083819406088*^9, 3.612085523055612*^9, 3.6126798944465017`*^9, 
  3.614415196972116*^9, 3.614416627504877*^9, 3.614506836417206*^9, 
  3.614578300067677*^9, 3.6149383288109694`*^9, 3.61563489017102*^9, 
  3.616215743874804*^9, 3.617337245998605*^9, 3.617339402757835*^9, 
  3.618218519502055*^9, 3.619334736055118*^9, 3.619776111182061*^9}]
}, Open  ]],

Cell["\<\
The full amplitude part from one e propagator and one \[CurlyPhi] propagator \
is:\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.612081243008892*^9, 
   3.61208124512131*^9}, {3.612085550321611*^9, 3.612085554536127*^9}, 
   3.616221846586204*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pevarphi$result", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Pevarphi$1$elim$nice", "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "2", ",", "4"}], "]"}], ",", "3",
        ",", "5"}], "]"}], "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], ",", 
         "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}], "+", 
     RowBox[{"Perm5$ij$", "[", 
      RowBox[{
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], ",", 
         "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}]}], ")"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pevarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{"Pevarphi$1$elim$nice", ",", "2", ",", "4"}], "]"}], ",", 
         "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "2"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pevarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{"Pevarphi$1$elim$nice", ",", "2", ",", "4"}], "]"}], ",", 
         "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "3"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pevarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{"Pevarphi$1$elim$nice", ",", "2", ",", "4"}], "]"}], ",", 
         "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "4"}], "]"}], "+", 
   RowBox[{"Perm5$ij$", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Pevarphi$1$elim$nice", "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{"Pevarphi$1$elim$nice", ",", "2", ",", "4"}], "]"}], ",", 
         "3", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "4"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}], "+", 
       RowBox[{"Perm5$ij$", "[", 
        RowBox[{
         RowBox[{"Perm5$ij$", "[", 
          RowBox[{
           RowBox[{"Perm5$ij$", "[", 
            RowBox[{"Pevarphi$1$elim$nice", ",", "3", ",", "5"}], "]"}], ",", 
           "2", ",", "3"}], "]"}], ",", "4", ",", "5"}], "]"}]}], ")"}], ",", 
     "1", ",", "5"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.611054282546404*^9, 3.611054334601163*^9}, {
  3.6110543789911127`*^9, 3.611054407469212*^9}, {3.6110544423677807`*^9, 
  3.611054476523299*^9}, {3.612081247598879*^9, 3.6120812551409283`*^9}, {
  3.612081333657134*^9, 3.6120814850197153`*^9}, {3.61208264102675*^9, 
  3.612082664252092*^9}, {3.61208385512154*^9, 3.612083882852788*^9}, {
  3.612085559318232*^9, 3.612085599815667*^9}, {3.612085655922749*^9, 
  3.6120856563658524`*^9}, {3.6120856955182343`*^9, 3.612085785547192*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "s15", " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], 
             RowBox[{"16", " ", "s12"}]]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s25", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"16", " ", "s12"}]], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["a",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s12", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"32", " ", "s25"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "1308", "\[RightSkeleton]"}], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "e"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "f"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s24", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"16", " ", "s45"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s25", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"16", " ", "s45"}]], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "e"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "f"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "h"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 264, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 264, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 264, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[264]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6110543585259113`*^9, 3.611054514214246*^9, 
  3.612075113351514*^9, 3.6120814972774353`*^9, 3.6120829507874327`*^9, 
  3.612083883994122*^9, 3.61208560126886*^9, 3.612085786805305*^9, 
  3.612679897948976*^9, 3.6144151973847*^9, 3.614416627943906*^9, 
  3.614506836838461*^9, 3.614578300479909*^9, 3.614938329224909*^9, 
  3.615634890631568*^9, 3.616215744279602*^9, 3.617337246413775*^9, 
  3.617339403183196*^9, 3.618218519917354*^9, 3.6193347364707813`*^9, 
  3.6197761115950327`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Pevarphi$result", "]"}]], "Input",
 CellChangeTimes->{{3.611054372311797*^9, 3.6110543734351263`*^9}, 
   3.612081494200481*^9, 3.61208267189284*^9, {3.612083889162163*^9, 
   3.612083889767927*^9}, 3.612085604898115*^9}],

Cell[BoxData[
 FormBox["960", TraditionalForm]], "Output",
 CellChangeTimes->{3.611054373722205*^9, 3.611054514610416*^9, 
  3.6120751138019533`*^9, 3.6120814977047*^9, 3.6120829551103563`*^9, 
  3.612083890442758*^9, 3.612085605399757*^9, 3.612085788488288*^9, 
  3.612679901938018*^9, 3.614415197484872*^9, 3.614416628034977*^9, 
  3.614506836897278*^9, 3.614578300517315*^9, 3.6149383292706213`*^9, 
  3.615634890688127*^9, 3.616215744328588*^9, 3.617337246456191*^9, 
  3.617339403237753*^9, 3.6182185199617443`*^9, 3.619334736517954*^9, 
  3.619776111638296*^9}]
}, Open  ]],

Cell["It is important to check Bose symmetry:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "1", ",", "2"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "1", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "1", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "1", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "2", ",", "3"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "2", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "2", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "3", ",", "4"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "3", ",", "5"}], "]"}]}], ",", 
   RowBox[{"Pevarphi$result", "-", 
    RowBox[{"Perm5$ij$", "[", 
     RowBox[{"Pevarphi$result", ",", "4", ",", "5"}], "]"}]}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.612075665681651*^9, 3.612075715637532*^9}, {
  3.612081499567829*^9, 3.612081517291541*^9}, {3.612082673763598*^9, 
  3.6120826987164707`*^9}, {3.612083895837511*^9, 3.6120839114544888`*^9}, {
  3.612085608680419*^9, 3.612085622980913*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6120756623050413`*^9, 3.612075795420464*^9, 
  3.612081535280946*^9, 3.6120829632563334`*^9, 3.6120839121721363`*^9, 
  3.6120856245362263`*^9, 3.612085790964965*^9, 3.612679904543928*^9, 
  3.614415198045142*^9, 3.614416628637233*^9, 3.61450683751171*^9, 
  3.614578301031251*^9, 3.614938329799214*^9, 3.615634891264135*^9, 
  3.616215744832571*^9, 3.617337246986277*^9, 3.6173394037868853`*^9, 
  3.618218520475191*^9, 3.619334737046206*^9, 3.619776112160705*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Five e amplitude", "Subsection",
 CellChangeTimes->{{3.612085834165001*^9, 3.612085844526819*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5e", "=", 
  RowBox[{
   RowBox[{"Expand", "[", "ver5e", "]"}], "+", "Pvarphi$result", "+", 
   "Pe$result", "+", "Pee$result", "+", "Pevarphi$result", "+", 
   "Pvarphivarphi$result"}]}]], "Input",
 CellChangeTimes->{{3.612085847766018*^9, 3.6120859294290524`*^9}, {
  3.61208625932561*^9, 3.612086262366638*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "s15", " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["2",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], 
             RowBox[{"16", " ", "s12"}]]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s25", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"16", " ", "s12"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "s14", " ", "s35", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"16", " ", "s12", " ", "s34"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "190553", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s23", " ", "s45"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 267, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 267, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 267, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[267]], TraditionalForm]], "Output",
 CellChangeTimes->{3.612085851605068*^9, 3.6120859846514378`*^9, 
  3.612086315602227*^9, 3.612679961286785*^9, 3.6144152503537207`*^9, 
  3.614416680683339*^9, 3.6145068890253963`*^9, 3.6145783525409203`*^9, 
  3.614938382874341*^9, 3.615634943861103*^9, 3.616215797047624*^9, 
  3.617337298771761*^9, 3.6173394560475807`*^9, 3.6182185730667067`*^9, 
  3.619334788228898*^9, 3.619776164849889*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5e", "]"}]], "Input",
 CellChangeTimes->{{3.612085940170971*^9, 3.612085943601712*^9}}],

Cell[BoxData[
 FormBox["127920", TraditionalForm]], "Output",
 CellChangeTimes->{3.612085985249589*^9, 3.612086316090274*^9, 
  3.6126799758926897`*^9, 3.614415251013947*^9, 3.6144166812008877`*^9, 
  3.6145068898342667`*^9, 3.614578353022504*^9, 3.614938383499957*^9, 
  3.615634944439886*^9, 3.616215797644348*^9, 3.6173372993744917`*^9, 
  3.61733945657134*^9, 3.6182185737189007`*^9, 3.619334788729979*^9, 
  3.619776165411853*^9}]
}, Open  ]],

Cell["Note that transversality is already put in.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
  3.6157145003746557`*^9, 3.615714508342465*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical check: Is the Ward identity satisfied?", "Subsection",
 CellChangeTimes->{{3.612085834165001*^9, 3.612085844526819*^9}, {
  3.612086484467353*^9, 3.612086497855007*^9}, {3.614577753311775*^9, 
  3.61457775350277*^9}}],

Cell["First need 5 light-like momenta adding up to zero.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}, {3.6120866065182667`*^9, 3.612086606758206*^9}, {
   3.612505924058659*^9, 3.612505936532402*^9}, {3.612684208346747*^9, 
   3.6126842128136387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}, {3.612086612732903*^9, 
   3.612086614349341*^9}, {3.612505939428406*^9, 3.6125059543631077`*^9}, {
   3.61268421467281*^9, 3.612684221598008*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{"k31", ",", "k32", ",", "k33", ",", "k34", ",", "k35"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9, {
   3.61208661791853*^9, 3.612086618148158*^9}, {3.612086936652397*^9, 
   3.612086944450577*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k4", "=", 
   RowBox[{"{", 
    RowBox[{"k41", ",", "k42", ",", "k43", ",", "k44", ",", "k45"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}, {3.612086632200843*^9, 3.612086646982294*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k5", "=", 
   RowBox[{"{", 
    RowBox[{"k51", ",", "k52", ",", "k53", ",", "k54", ",", "k55"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.612086654555016*^9, 3.6120866647448187`*^9}, {
  3.61208681096835*^9, 3.612086816309435*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "5", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "5", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.612086707631708*^9, 3.612086713887814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kinsys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k5", ",", "k5"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4", "+", "k5"}], "\[Equal]", 
      "0"}]}], "}"}]}], ";", 
  RowBox[{"kinsys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612258217072095*^9, 3.612258219089881*^9}, {
  3.612258263321577*^9, 3.612258271721939*^9}, {3.612505966669755*^9, 
  3.612505985721085*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k31", "2"]}], "+", 
         SuperscriptBox["k32", "2"], "+", 
         SuperscriptBox["k33", "2"], "+", 
         SuperscriptBox["k34", "2"], "+", 
         SuperscriptBox["k35", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k41", "2"]}], "+", 
         SuperscriptBox["k42", "2"], "+", 
         SuperscriptBox["k43", "2"], "+", 
         SuperscriptBox["k44", "2"], "+", 
         SuperscriptBox["k45", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k51", "2"]}], "+", 
         SuperscriptBox["k52", "2"], "+", 
         SuperscriptBox["k53", "2"], "+", 
         SuperscriptBox["k54", "2"], "+", 
         SuperscriptBox["k55", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"k31", "+", "k41", "+", "k51", "+", "2"}], ",", 
          RowBox[{"k32", "+", "k42", "+", "k52"}], ",", 
          RowBox[{"k33", "+", "k43", "+", "k53"}], ",", 
          RowBox[{"k34", "+", "k44", "+", "k54"}], ",", 
          RowBox[{"k35", "+", "k45", "+", "k55"}]}], "}"}], "\[LongEqual]", 
        "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{3.612258223332856*^9, 3.612258277667809*^9, 
  3.612505994584982*^9, 3.6126800091197*^9, 3.6126842296073713`*^9, 
  3.614415251319221*^9, 3.614416681331402*^9, 3.614506889916788*^9, 
  3.6145783531107807`*^9, 3.61493838358314*^9, 3.615634944521681*^9, 
  3.6157167540016603`*^9, 3.6162157977373037`*^9, 3.617337299458859*^9, 
  3.617339456664722*^9, 3.618218573787261*^9, 3.6193347888389683`*^9, 
  3.6197761654921627`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"FindInstance", "[", 
   RowBox[{"kinsys", ",", 
    RowBox[{"Join", "[", 
     RowBox[{"k4", ",", "k5", ",", "k3"}], "]"}], ",", "1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.612086667146719*^9, 3.612086669789753*^9}, {
   3.61208672018432*^9, 3.6120867609601393`*^9}, {3.612086820399687*^9, 
   3.61208684701149*^9}, {3.6120868882347116`*^9, 3.612086911234775*^9}, {
   3.612086947214334*^9, 3.612086966920597*^9}, {3.612087130200302*^9, 
   3.612087138062559*^9}, {3.612257132872628*^9, 3.6122571670798407`*^9}, 
   3.612257397692018*^9, {3.61225751058984*^9, 3.612257511578771*^9}, {
   3.6122576055168962`*^9, 3.612257613202684*^9}, 3.612257694530752*^9, {
   3.612258060499379*^9, 3.612258062723226*^9}, {3.612258192623537*^9, 
   3.612258193411767*^9}, 3.612258282749514*^9, {3.6125060012757797`*^9, 
   3.612506003735097*^9}, {3.612680017069385*^9, 3.6126800172139387`*^9}, 
   3.612684254591062*^9, 3.6145769005945463`*^9, 3.614576952464837*^9, {
   3.6145770875853148`*^9, 3.614577088568757*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k41", "\[Rule]", "1"}], ",", 
     RowBox[{"k42", "\[Rule]", "4"}], ",", 
     RowBox[{"k43", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k44", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SqrtBox[
        FractionBox["89", "5"]]}]}], ",", 
     RowBox[{"k45", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["3", 
        SqrtBox["5"]]}]}], ",", 
     RowBox[{"k51", "\[Rule]", 
      RowBox[{"-", "3"}]}], ",", 
     RowBox[{"k52", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"k53", "\[Rule]", "0"}], ",", 
     RowBox[{"k54", "\[Rule]", "0"}], ",", 
     RowBox[{"k55", "\[Rule]", 
      RowBox[{"-", 
       SqrtBox["5"]}]}], ",", 
     RowBox[{"k31", "\[Rule]", "0"}], ",", 
     RowBox[{"k32", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"k33", "\[Rule]", "1"}], ",", 
     RowBox[{"k34", "\[Rule]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox[
        FractionBox["89", "5"]]}]}], ",", 
     RowBox[{"k35", "\[Rule]", 
      RowBox[{
       FractionBox["3", 
        SqrtBox["5"]], "+", 
       SqrtBox["5"]}]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.612086762118141*^9, 3.612086780893147*^9}, {
   3.612086823214789*^9, 3.612086847939478*^9}, {3.61208688888518*^9, 
   3.612086911822865*^9}, {3.612086954278853*^9, 3.612086967359386*^9}, {
   3.612087131307373*^9, 3.6120871383511143`*^9}, 3.612257142281363*^9, 
   3.612257394237977*^9, {3.6122575076936417`*^9, 3.612257512163836*^9}, {
   3.6122576069012537`*^9, 3.612257627804504*^9}, {3.612257690411792*^9, 
   3.612257695104991*^9}, 3.612258189484466*^9, 3.61225822195914*^9, 
   3.612258276336063*^9, 3.612259320778799*^9, 3.612511330729707*^9, 
   3.6126803950144*^9, {3.6126842499610157`*^9, 3.612684258655238*^9}, 
   3.6144152518055267`*^9, 3.614416681520438*^9, 3.6145068908943377`*^9, 
   3.614576906819211*^9, 3.614576960270529*^9, 3.614577089264464*^9, 
   3.6145783532449417`*^9, 3.614938384517983*^9, 3.615634945242508*^9, 
   3.615716763753829*^9, 3.616215797986451*^9, 3.617337299646379*^9, 
   3.617339456758937*^9, 3.618218573949119*^9, 3.6193347890203257`*^9, 
   3.619776165621751*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k3", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086972550753*^9, 3.612086977276445*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", 
    RowBox[{"-", "2"}], ",", "1", ",", 
    RowBox[{"\[ImaginaryI]", " ", 
     SqrtBox[
      FractionBox["89", "5"]]}], ",", 
    RowBox[{
     FractionBox["3", 
      SqrtBox["5"]], "+", 
     SqrtBox["5"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086977587695*^9, 3.6122575146527653`*^9, 
  3.612257696324094*^9, 3.612684263546081*^9, 3.6144152519329348`*^9, 
  3.6144166815767603`*^9, 3.614506890949765*^9, 3.614578353276498*^9, 
  3.614938384565001*^9, 3.615634945289898*^9, 3.615716766074543*^9, 
  3.616215798017215*^9, 3.617337299676415*^9, 3.617339456797743*^9, 
  3.618218573984281*^9, 3.6193347890664377`*^9, 3.619776165664377*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k3", ",", "k3"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122571125898314`*^9, 3.612257119072855*^9}, {
  3.612257544299827*^9, 3.612257553190195*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6122571193226643`*^9, 3.612257515599658*^9, {3.612257545928628*^9, 
   3.612257553598151*^9}, 3.612257697150077*^9, 3.612684265607835*^9, 
   3.6144152519576693`*^9, 3.614416681638151*^9, 3.614506890967968*^9, 
   3.61457835328469*^9, 3.614938384605798*^9, 3.615634945325961*^9, 
   3.615716767074236*^9, 3.616215798046818*^9, 3.617337299711178*^9, 
   3.617339456832644*^9, 3.618218574015799*^9, 3.619334789111589*^9, 
   3.619776165695747*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086983780642*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"1", ",", "4", ",", 
    RowBox[{"-", "1"}], ",", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]]}], ",", 
    RowBox[{"-", 
     FractionBox["3", 
      SqrtBox["5"]]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086984684704*^9, 3.612257555469883*^9, 
  3.612257697740192*^9, 3.612684268914393*^9, 3.614415251973494*^9, 
  3.6144166816980267`*^9, 3.614506890983892*^9, 3.614578353290989*^9, 
  3.614938384647709*^9, 3.615634945363903*^9, 3.6157167682912292`*^9, 
  3.616215798191144*^9, 3.617337299746804*^9, 3.617339456867691*^9, 
  3.6182185740487432`*^9, 3.619334789154846*^9, 3.619776165727974*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k4", ",", "k4"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122575625202703`*^9, 3.612257564202305*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.612257565498811*^9, 3.612257698283271*^9, 
  3.6126842714539623`*^9, 3.614415251992217*^9, 3.614416681767228*^9, 
  3.614506890999983*^9, 3.614578353295656*^9, 3.614938384652294*^9, 
  3.615634945401319*^9, 3.615716769807744*^9, 3.616215798222134*^9, 
  3.617337299789431*^9, 3.617339456902569*^9, 3.618218574055382*^9, 
  3.619334789199538*^9, 3.619776165762212*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k5", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086990045686*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "3"}], ",", 
    RowBox[{"-", "2"}], ",", "0", ",", "0", ",", 
    RowBox[{"-", 
     SqrtBox["5"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086990222755*^9, 3.6122575687096653`*^9, 
  3.612257698824397*^9, 3.612684273014686*^9, 3.614415252134819*^9, 
  3.614416681770714*^9, 3.614506891071704*^9, 3.614578353321383*^9, 
  3.61493838465629*^9, 3.615634945437806*^9, 3.615716771191478*^9, 
  3.616215798226701*^9, 3.617337299908387*^9, 3.617339456907874*^9, 
  3.618218574060605*^9, 3.61933478920527*^9, 3.619776165768216*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k5", ",", "k5"}], "]"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6122575845569344`*^9, 3.6122575890669613`*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612257586141511*^9, 3.612257589348277*^9}, 
   3.612257699452682*^9, 3.612684274587776*^9, 3.614415252266694*^9, 
   3.614416681774804*^9, 3.614506891089264*^9, 3.614578353329406*^9, 
   3.614938384660136*^9, 3.615634945473708*^9, 3.6157167728604307`*^9, 
   3.616215798231056*^9, 3.617337299912986*^9, 3.617339456913168*^9, 
   3.6182185740658484`*^9, 3.619334789210023*^9, 3.619776165773459*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4", "+", "k5"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612684288172793*^9, 3.612684297213119*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6126842976505404`*^9, 3.614415252283523*^9, 
  3.6144166818314037`*^9, 3.6145068911103773`*^9, 3.614578353334805*^9, 
  3.614938384700522*^9, 3.615634945508367*^9, 3.615716774069553*^9, 
  3.616215798235667*^9, 3.617337299917261*^9, 3.617339456918147*^9, 
  3.6182185740713167`*^9, 3.619334789214802*^9, 3.619776165778054*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s12", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
     RowBox[{"s13", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"s14", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s15", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s23", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"s24", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s25", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s34", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k3", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s35", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k3", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s45", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k4", ",", "k5"}], "]"}]}]}]}], "}"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.612087426835834*^9, 3.612087432664119*^9}, {
   3.612258338518701*^9, 3.612258339672268*^9}, 3.6145769704085627`*^9, 
   3.614577080572277*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s12", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"s13", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"s14", "\[Rule]", "6"}], ",", 
    RowBox[{"s15", "\[Rule]", "2"}], ",", 
    RowBox[{"s23", "\[Rule]", "4"}], ",", 
    RowBox[{"s24", "\[Rule]", 
     RowBox[{"-", "10"}]}], ",", 
    RowBox[{"s25", "\[Rule]", "10"}], ",", 
    RowBox[{"s34", "\[Rule]", "8"}], ",", 
    RowBox[{"s35", "\[Rule]", 
     RowBox[{"-", "8"}]}], ",", 
    RowBox[{"s45", "\[Rule]", 
     RowBox[{"-", "4"}]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612087439480166*^9, 3.612257591558383*^9, 3.612257700130177*^9, 
   3.612258340118903*^9, 3.6126842783468533`*^9, 3.614415252427136*^9, 
   3.614416681890109*^9, 3.6145068911892233`*^9, {3.6145769429963827`*^9, 
   3.614576970611363*^9}, 3.614578353362673*^9, 3.614938384741045*^9, 
   3.61563494553862*^9, 3.615716776067073*^9, 3.616215798269853*^9, 
   3.617337299947012*^9, 3.617339456954917*^9, 3.618218574108639*^9, 
   3.619334789260832*^9, 3.619776165810261*^9}]
}, Open  ]],

Cell[TextData[{
 "This is to check that the kinematical configuration is not singular (i.e. \
all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "ij"], "\[NotEqual]", "0"}], TraditionalForm]]],
 ")."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EA0ACNrNIA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5e$ward", "=", 
  RowBox[{"amp5e", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s12", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
        RowBox[{"s13", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
        RowBox[{"s14", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s15", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s23", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k3"}], "]"}]}]}], ",", 
        RowBox[{"s24", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s25", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s34", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k3", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s35", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k3", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s45", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k4", ",", "k5"}], "]"}]}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.61208716627921*^9, 3.612087197169098*^9}, {
   3.61208722735645*^9, 3.612087388339983*^9}, {3.612087423745262*^9, 
   3.6120874608775663`*^9}, {3.612258357410972*^9, 3.612258363259796*^9}, 
   3.614576981884356*^9, 3.614577078148025*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{
            FractionBox["7", "40"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["a",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "+", 
           FractionBox[
            RowBox[{"127", " ", "\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], "1280"], "+", 
           RowBox[{
            FractionBox["81", "640"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["a",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "+", 
           RowBox[{
            FractionBox["9", "80"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["5",
              TraditionalForm], 
             FormBox[
              FormBox["a",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "+", 
           RowBox[{"\[LeftSkeleton]", "111848", "\[RightSkeleton]"}], "+", 
           RowBox[{
            FractionBox["1", "128"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "e"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["c",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["h",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{
            FractionBox["1", "128"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "e"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["5",
              TraditionalForm], 
             FormBox[
              FormBox["c",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["h",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}], "-", 
           RowBox[{
            FractionBox["1", "128"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["a",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "e"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["h",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}], "-", 
           RowBox[{
            FractionBox["1", "128"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["5",
              TraditionalForm], 
             FormBox[
              FormBox["a",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "e"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["h",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 285, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 285, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 285, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[285]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6120873181630087`*^9, 3.612087412005423*^9, 
  3.612087495942769*^9, 3.612257746787217*^9, 3.612258397594701*^9, 
  3.612684348201736*^9, 3.6144152860384817`*^9, 3.61441671612873*^9, 
  3.614506924931306*^9, 3.6145769381254168`*^9, 3.614577020827977*^9, 
  3.6145783866464977`*^9, 3.614938419088417*^9, 3.615634980235793*^9, 
  3.615716816091997*^9, 3.616215832790718*^9, 3.6173373338712*^9, 
  3.617339490700891*^9, 3.618218608050396*^9, 3.619334822442586*^9, 
  3.6197761997683563`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5e$ward", "]"}]], "Input",
 CellChangeTimes->{{3.612087467971369*^9, 3.6120874692069407`*^9}, {
  3.612258405183548*^9, 3.612258405902673*^9}}],

Cell[BoxData[
 FormBox["74658", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612087496317582*^9, {3.612257747395446*^9, 3.612257758636992*^9}, 
   3.612258406744185*^9, 3.612684352008749*^9, 3.614415286331321*^9, 
   3.614416716405995*^9, 3.614506925483382*^9, 3.614577024965377*^9, 
   3.614578386877109*^9, 3.6149384194157257`*^9, 3.615634980571536*^9, 
   3.615716816381331*^9, 3.616215833054291*^9, 3.6173373341639843`*^9, 
   3.617339490959072*^9, 3.618218608329924*^9, 3.619334822678985*^9, 
   3.6197762000493307`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5e$ward$2", "=", 
  RowBox[{"amp5e$ward", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k1"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k2"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k3"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k4"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k5"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"a", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"kc", "[", 
          RowBox[{"1", ",", "x"}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6120875237543364`*^9, 3.612087661757189*^9}, {
  3.612087702259516*^9, 3.612087709855068*^9}, {3.612087773040797*^9, 
  3.6120878092411623`*^9}, {3.612258414261525*^9, 3.6122584178997*^9}, {
  3.614504845510065*^9, 3.614504916261285*^9}, {3.614505018615569*^9, 
  3.614505040216443*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["9", "160"]}], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "-", 
           RowBox[{
            FractionBox["9", "160"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "-", 
           RowBox[{
            FractionBox["9", "160"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "-", 
           RowBox[{
            FractionBox["9", "160"], " ", "\[ImaginaryI]", " ", 
            SubsuperscriptBox["k", 
             FormBox["5",
              TraditionalForm], 
             FormBox[
              FormBox["b",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "+", 
           RowBox[{
            FractionBox["7", "32"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "j"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "i"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["d",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]]}], "+", 
           RowBox[{"\[LeftSkeleton]", "55297", "\[RightSkeleton]"}], "+", 
           RowBox[{
            FractionBox["1", "128"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["c",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["e",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["h",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{
            FractionBox["1", "128"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["5",
              TraditionalForm], 
             FormBox[
              FormBox["c",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["e",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["h",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}], "-", 
           RowBox[{
            FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "e"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["2",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["3",
              TraditionalForm], 
             FormBox[
              FormBox["h",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["j",
               TraditionalForm],
              TraditionalForm]]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 287, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 287, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 287, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[287]], TraditionalForm]], "Output",
 CellChangeTimes->{3.61208769328755*^9, 3.6120877341237087`*^9, 
  3.612087832779768*^9, 3.612257784990736*^9, 3.612258434728539*^9, 
  3.612684375567286*^9, 3.614415302746319*^9, 3.614416732878873*^9, 
  3.614506941728097*^9, 3.614577046552202*^9, 3.6145784033222103`*^9, 
  3.614938436145873*^9, 3.6156349972769547`*^9, 3.6157168334526043`*^9, 
  3.616215849517002*^9, 3.6173373507036963`*^9, 3.617339507586845*^9, 
  3.6182186247010603`*^9, 3.619334838965477*^9, 3.619776216371769*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5e$ward$2", "]"}]], "Input",
 CellChangeTimes->{{3.6120876693008537`*^9, 3.6120876695749207`*^9}}],

Cell[BoxData[
 FormBox["37049", TraditionalForm]], "Output",
 CellChangeTimes->{3.612087693716928*^9, 3.61208773446764*^9, 
  3.6120878364510508`*^9, 3.612257785351726*^9, 3.612258439254422*^9, 
  3.612684375849599*^9, 3.614415302933301*^9, 3.6144167330570917`*^9, 
  3.614506942164022*^9, 3.614577046699005*^9, 3.614578403471579*^9, 
  3.6149384363357*^9, 3.615634997465239*^9, 3.615716833601172*^9, 
  3.616215849689897*^9, 3.61733735088078*^9, 3.617339507756154*^9, 
  3.618218624883285*^9, 3.61933483911871*^9, 3.619776216512163*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi1", "=", 
   RowBox[{"{", 
    RowBox[{"xix1", ",", "xix2", ",", "xix3", ",", "xix4", ",", "xix5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043270708568*^9, 3.6040432967635603`*^9}, 
   3.604043499802985*^9, 3.604301554870967*^9, {3.6043021515175753`*^9, 
   3.604302152636281*^9}, {3.612166399986412*^9, 3.612166401456052*^9}, {
   3.615717383769212*^9, 3.61571738455131*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi2", "=", 
   RowBox[{"{", 
    RowBox[{"xiy1", ",", "xiy2", ",", "xiy3", ",", "xiy4", ",", "xiy5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.6040433084930897`*^9, 
   3.6040433346916733`*^9}, 3.604043502795218*^9, {3.612166409439506*^9, 
   3.612166414318565*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{"xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4", ",", "xiz5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9, {3.612166418225318*^9, 
   3.6121664207438507`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi4", "=", 
   RowBox[{"{", 
    RowBox[{"xiu1", ",", "xiu2", ",", "xiu3", ",", "xiu4", ",", "xiu5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.6040433145245943`*^9, 
   3.604043314748054*^9}, {3.6040433534274893`*^9, 3.604043369394578*^9}, 
   3.60404350847479*^9, {3.61216642588039*^9, 3.612166429007922*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi5", "=", 
   RowBox[{"{", 
    RowBox[{"xiv1", ",", "xiv2", ",", "xiv3", ",", "xiv4", ",", "xiv5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.612166469609943*^9, 3.612166482375815*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et1", "=", 
   RowBox[{"{", 
    RowBox[{"etx1", ",", "etx2", ",", "etx3", ",", "etx4", ",", "etx5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, {3.6040433875103607`*^9, 3.604043405643474*^9}, 
   3.604043511306425*^9, 3.604301558638516*^9, {3.604302156974309*^9, 
   3.604302158069281*^9}, {3.612166432744034*^9, 3.6121664410321913`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et2", "=", 
   RowBox[{"{", 
    RowBox[{"ety1", ",", "ety2", ",", "ety3", ",", "ety4", ",", "ety5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.604043389260811*^9, 
   3.6040434154828787`*^9}, 3.6040435138414288`*^9, {3.61216644492061*^9, 
   3.612166446303801*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{"etz1", ",", "etz2", ",", "etz3", ",", "etz4", ",", "etz5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9, {3.612166449248323*^9, 
   3.6121664509560738`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et4", "=", 
   RowBox[{"{", 
    RowBox[{"etu1", ",", "etu2", ",", "etu3", ",", "etu4", ",", "etu5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.604043392149412*^9, 
   3.604043392255167*^9}, {3.6040434286448727`*^9, 3.604043435995811*^9}, 
   3.604043520033565*^9, {3.612166453399662*^9, 3.6121664555841017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et5", "=", 
   RowBox[{"{", 
    RowBox[{"etv1", ",", "etv2", ",", "etv3", ",", "etv4", ",", "etv5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6121664949676847`*^9, 3.6121665077213697`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "xi1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "et1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "xi2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "et2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "xi4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "et4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "xi5"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "et5"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     
     RowBox[{"sols", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.61216653422339*^9, 3.612166556960194*^9}, {
  3.612166600729034*^9, 3.6121666133164167`*^9}, {3.612258455793024*^9, 
  3.612258468175284*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[LongEqual]", "xix2"}]},
      {
       RowBox[{"etx1", "\[LongEqual]", "etx2"}]},
      {
       RowBox[{
        RowBox[{"xiy1", "+", "xiy2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"ety1", "+", "ety2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"xiz3", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "xiz4"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "xiz5"}], 
          SqrtBox["5"]]}], "\[LongEqual]", 
        RowBox[{"2", " ", "xiz2"}]}]},
      {
       RowBox[{
        RowBox[{"etz3", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "etz4"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "etz5"}], 
          SqrtBox["5"]]}], "\[LongEqual]", 
        RowBox[{"2", " ", "etz2"}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"4", " ", "xiu2"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "xiu4"}]}], "\[LongEqual]", 
        RowBox[{"xiu1", "+", "xiu3", "+", 
         FractionBox[
          RowBox[{"3", " ", "xiu5"}], 
          SqrtBox["5"]]}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"4", " ", "etu2"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "etu4"}]}], "\[LongEqual]", 
        RowBox[{"etu1", "+", "etu3", "+", 
         FractionBox[
          RowBox[{"3", " ", "etu5"}], 
          SqrtBox["5"]]}]}]},
      {
       RowBox[{
        RowBox[{"3", " ", "xiv1"}], "\[LongEqual]", 
        RowBox[{
         RowBox[{"2", " ", "xiv2"}], "+", 
         RowBox[{
          SqrtBox["5"], " ", "xiv5"}]}]}]},
      {
       RowBox[{
        RowBox[{"3", " ", "etv1"}], "\[LongEqual]", 
        RowBox[{
         RowBox[{"2", " ", "etv2"}], "+", 
         RowBox[{
          SqrtBox["5"], " ", "etv5"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166557730864*^9, 3.612166613587278*^9, 3.612257786626362*^9, {
   3.612258449865247*^9, 3.6122584694730263`*^9}, 3.612684401222273*^9, 
   3.6144153037766237`*^9, 3.614416733198262*^9, 3.614506942881184*^9, 
   3.6145770516151667`*^9, 3.614578403574582*^9, 3.6149384370663424`*^9, 
   3.615634998183165*^9, 3.6157168339297047`*^9, 3.61571741922215*^9, 
   3.6157966523647614`*^9, 3.6162158522704887`*^9, 3.6173373519442377`*^9, 
   3.6173395085025463`*^9, 3.618218625975627*^9, 3.619334840201126*^9, 
   3.6197762175231047`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "=", 
   RowBox[{
    RowBox[{"FindInstance", "[", 
     RowBox[{"conditions", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
       "xi1", ",", "xi2", ",", "xi3", ",", "xi4", ",", "xi5", ",", "et1", ",",
         "et2", ",", "et3", ",", "et4", ",", "et5"}], "]"}], ",", "5"}], 
     "]"}], "//", "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.612166575888966*^9, 3.612166576370742*^9}, {3.6121666241502*^9, 
   3.612166629642056*^9}, 3.6122577970426483`*^9, {3.6122584771168823`*^9, 
   3.612258481721101*^9}, 3.615716743846897*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.615716687944995*^9, 3.6157166901908703`*^9}, 
   3.615796959672283*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[Rule]", 
        RowBox[{
         FractionBox["72", "5"], "-", 
         FractionBox[
          RowBox[{"109", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xix2", "\[Rule]", 
        RowBox[{
         FractionBox["72", "5"], "-", 
         FractionBox[
          RowBox[{"109", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xix3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["35", "2"]}], "-", 
         FractionBox[
          RowBox[{"219", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xix4", "\[Rule]", 
        RowBox[{
         FractionBox["98", "5"], "-", 
         FractionBox[
          RowBox[{"121", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xix5", "\[Rule]", 
        RowBox[{
         FractionBox["28", "5"], "+", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiy1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["13", "5"]}], "-", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiy2", "\[Rule]", 
        RowBox[{
         FractionBox["13", "5"], "+", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiy3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["56", "5"]}], "-", 
         FractionBox[
          RowBox[{"191", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiy4", "\[Rule]", 
        RowBox[{"19", "-", 
         FractionBox[
          RowBox[{"82", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiy5", "\[Rule]", 
        RowBox[{"22", "-", 
         FractionBox[
          RowBox[{"33", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz1", "\[Rule]", 
        RowBox[{
         FractionBox["41", "5"], "-", 
         FractionBox[
          RowBox[{"153", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["21", "10"]}], "-", 
         FractionBox[
          RowBox[{"59", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiz3", "\[Rule]", 
        RowBox[{
         FractionBox["79", "10"], "-", 
         FractionBox[
          RowBox[{"29", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiz4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["169", "10"]}], "-", 
         FractionBox[
          RowBox[{"73", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz5", "\[Rule]", 
        RowBox[{
         FractionBox["1", "80"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "121"}], "-", 
              RowBox[{"178", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"73", "-", 
              RowBox[{"169", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{"xiu1", "\[Rule]", 
        RowBox[{
         FractionBox["209", "10"], "-", 
         FractionBox[
          RowBox[{"45", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiu2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["47", "5"]}], "-", 
         FractionBox[
          RowBox[{"153", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiu3", "\[Rule]", 
        RowBox[{
         FractionBox["46", "5"], "-", 
         RowBox[{"18", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu4", "\[Rule]", 
        RowBox[{
         FractionBox["77", "10"], "-", 
         FractionBox[
          RowBox[{"25", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiu5", "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "30"]}], "+", 
           FractionBox["\[ImaginaryI]", "30"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"235", "+", 
              RowBox[{"442", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"24", "+", 
              RowBox[{"101", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{"xiv1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["19", "10"]}], "+", 
         FractionBox[
          RowBox[{"63", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiv2", "\[Rule]", 
        RowBox[{
         FractionBox["187", "10"], "+", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiv3", "\[Rule]", 
        RowBox[{"9", "-", 
         FractionBox[
          RowBox[{"21", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiv4", "\[Rule]", 
        RowBox[{
         FractionBox["46", "5"], "+", 
         FractionBox[
          RowBox[{"101", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiv5", "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           FractionBox["431", "10"], "-", 
           FractionBox[
            RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}], 
          SqrtBox["5"]]}]}]},
      {
       RowBox[{"etx1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "22"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "22"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["173", "10"]}], "-", 
         FractionBox[
          RowBox[{"118", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx4", "\[Rule]", 
        RowBox[{"17", "+", 
         FractionBox[
          RowBox[{"231", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etx5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["56", "5"]}], "-", 
         FractionBox[
          RowBox[{"13", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety1", "\[Rule]", 
        RowBox[{
         FractionBox["147", "10"], "-", 
         RowBox[{"14", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"ety2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["147", "10"]}], "+", 
         RowBox[{"14", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"ety3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "9"}], "-", 
         FractionBox[
          RowBox[{"59", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"ety4", "\[Rule]", 
        RowBox[{
         FractionBox["121", "10"], "-", 
         FractionBox[
          RowBox[{"42", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"ety5", "\[Rule]", 
        RowBox[{
         FractionBox["141", "10"], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"etz1", "\[Rule]", 
        RowBox[{"11", "-", 
         FractionBox[
          RowBox[{"119", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["207", "10"]}], "-", 
         FractionBox[
          RowBox[{"32", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz3", "\[Rule]", 
        RowBox[{
         FractionBox["12", "5"], "+", 
         RowBox[{"25", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["109", "5"]}], "+", 
         FractionBox[
          RowBox[{"66", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz5", "\[Rule]", 
        RowBox[{
         FractionBox["1", "40"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "219"}], "-", 
              RowBox[{"189", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"66", "+", 
              RowBox[{"109", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{"etu1", "\[Rule]", 
        RowBox[{"11", "+", 
         FractionBox[
          RowBox[{"108", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu2", "\[Rule]", 
        RowBox[{
         FractionBox["121", "10"], "+", 
         FractionBox[
          RowBox[{"111", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu3", "\[Rule]", 
        RowBox[{
         FractionBox["11", "10"], "-", 
         FractionBox[
          RowBox[{"117", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etu4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["41", "10"]}], "+", 
         RowBox[{"25", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu5", "\[Rule]", 
        RowBox[{
         FractionBox["1", "30"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"363", "+", 
              RowBox[{"789", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"250", "+", 
              RowBox[{"41", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{"etv1", "\[Rule]", 
        RowBox[{
         FractionBox["11", "5"], "+", 
         FractionBox[
          RowBox[{"141", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etv2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["77", "5"]}], "+", 
         FractionBox[
          RowBox[{"117", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etv3", "\[Rule]", 
        RowBox[{
         FractionBox["119", "10"], "-", 
         FractionBox[
          RowBox[{"92", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etv4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["117", "10"]}], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etv5", "\[Rule]", 
        FractionBox[
         RowBox[{
          FractionBox["187", "5"], "-", 
          FractionBox[
           RowBox[{"9", " ", "\[ImaginaryI]"}], "2"]}], 
         SqrtBox["5"]]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.615716686264927*^9, 3.615716690541438*^9}, 
   3.615716837926202*^9, 3.6157969736709547`*^9, 3.616215854088387*^9, 
   3.617337353622591*^9, 3.617339509744925*^9, 3.6182186276162148`*^9, 
   3.619334841871792*^9, 3.619776219119603*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"reprules", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "c"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi2", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "e"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi3", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "g"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi4", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "i"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi5", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "d"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et2", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "f"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et3", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "h"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et4", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "j"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et5", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "]"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"reprules", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612166744922229*^9, 3.6121667659346313`*^9}, {
   3.612166806789146*^9, 3.61216685017785*^9}, {3.612166881494143*^9, 
   3.612166937065545*^9}, {3.612167008004058*^9, 3.612167074754364*^9}, {
   3.612167111235808*^9, 3.612167202273198*^9}, {3.612175654939053*^9, 
   3.6121756683863297`*^9}, {3.612258495288478*^9, 3.612258500192725*^9}, 
   3.6126845445381327`*^9, 3.612685681583201*^9, {3.6145050620116053`*^9, 
   3.6145052111720667`*^9}, 3.615796951739085*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["26", "5"], "+", 
         RowBox[{"9", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "820"}], "-", 
             RowBox[{"1405", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1760", "-", 
              RowBox[{"264", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"164", "+", 
              RowBox[{"190", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1210", "+", 
             RowBox[{"2080", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"660", "-", 
              RowBox[{"99", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"164", "+", 
              RowBox[{"190", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "13"}], "-", 
           FractionBox[
            RowBox[{"45", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
         FractionBox[
          RowBox[{"110", "-", 
           FractionBox[
            RowBox[{"33", " ", "\[ImaginaryI]"}], "2"]}], 
          SqrtBox["5"]]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["103", "10"]}], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["61", "10"]}], "+", 
         FractionBox[
          RowBox[{"271", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "80"], "+", 
           FractionBox["\[ImaginaryI]", "40"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "941"}], "+", 
             RowBox[{"328", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"53", "+", 
              RowBox[{"63", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "80"]}], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"894", "+", 
             RowBox[{"2909", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"169", "+", 
              RowBox[{"73", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["303", "10"]}], "+", 
         FractionBox[
          RowBox[{"36", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["23", "2"]}], "+", 
         FractionBox[
          RowBox[{"189", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "30"]}], "+", 
           FractionBox["\[ImaginaryI]", "30"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1649", "+", 
             RowBox[{"2927", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"24", "+", 
              RowBox[{"101", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["583", "3"], "-", 
           FractionBox[
            RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["125", "6"], "+", 
            FractionBox[
             RowBox[{"77", " ", "\[ImaginaryI]"}], "6"]}], ")"}], " ", 
          SqrtBox[
           FractionBox["89", "5"]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["103", "5"], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["84", "5"]}], "-", 
         RowBox[{"14", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "595"}], "+", 
             RowBox[{"4868", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"92", "+", 
              RowBox[{"101", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4678", "+", 
             RowBox[{"1225", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"101", "-", 
              RowBox[{"92", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["147", "5"]}], "+", 
         RowBox[{"28", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1020", "-", 
             RowBox[{"1990", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1128", "-", 
              RowBox[{"120", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"84", "+", 
              RowBox[{"121", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3225"}], "+", 
             RowBox[{"4090", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"423", "-", 
              RowBox[{"45", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"84", "+", 
              RowBox[{"121", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"735", "-", 
             RowBox[{"700", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"141", "-", 
              RowBox[{"15", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["317", "10"]}], "+", 
         FractionBox[
          RowBox[{"87", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["97", "10"], "+", 
         FractionBox[
          RowBox[{"151", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "40"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3191"}], "-", 
             RowBox[{"505", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"66", "+", 
              RowBox[{"109", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "40"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4071", "-", 
             RowBox[{"1399", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"66", "+", 
              RowBox[{"109", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["11", "10"], "+", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["231", "10"]}], "-", 
         FractionBox[
          RowBox[{"219", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "30"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2211", "+", 
             RowBox[{"4629", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"250", "+", 
              RowBox[{"41", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "30"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1551"}], "-", 
             RowBox[{"3333", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"250", "+", 
              RowBox[{"41", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["88", "5"]}], "+", 
         FractionBox[
          RowBox[{"93", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["66", "5"], "-", 
         FractionBox[
          RowBox[{"75", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "50"]}], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3620", "+", 
             RowBox[{"5127", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"117", "+", 
              RowBox[{"7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"5030", "+", 
             RowBox[{"4907", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"117", "+", 
              RowBox[{"7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166851224063*^9, {3.612166905867807*^9, 3.612166937604322*^9}, {
   3.6121671678821898`*^9, 3.612167203585627*^9}, 3.612175672435413*^9, 
   3.612257803039179*^9, {3.612258489462837*^9, 3.612258501949951*^9}, 
   3.612684415052841*^9, 3.612684547323617*^9, 3.6126856838647547`*^9, 
   3.614415306130569*^9, 3.614416733525731*^9, 3.614505217112989*^9, 
   3.614506945942827*^9, 3.6145784038082542`*^9, 3.6149384396477423`*^9, 
   3.615635000742181*^9, 3.615716733146427*^9, 3.6157169549627037`*^9, 
   3.615796985578032*^9, 3.616215855199746*^9, 3.6173373548412933`*^9, 
   3.6173395107697372`*^9, 3.618218628720899*^9, 3.619334843044755*^9, 
   3.619776220250801*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"reprules2", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"c", ",", "e"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi2", ",", "xi3"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"c", ",", "g"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi2", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"c", ",", "i"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi2", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"e", ",", "g"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"e", ",", "i"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"g", ",", "i"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi4", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"d", ",", "f"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et2", ",", "et3"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"d", ",", "h"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et2", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"d", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et2", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"f", ",", "h"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"f", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"h", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et4", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"b", ",", "d"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et1", ",", "et2"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"b", ",", "f"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et1", ",", "et3"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"b", ",", "h"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et1", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"b", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et1", ",", "et5"}], "]"}]}]}], "}"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"reprules2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612167264558797*^9, 3.612167398925799*^9}, {
   3.612167432691366*^9, 3.61216748291084*^9}, {3.612167533668118*^9, 
   3.612167700191098*^9}, {3.612167759857984*^9, 3.612167800967119*^9}, {
   3.6121682313684673`*^9, 3.612168292531988*^9}, {3.612258517214506*^9, 
   3.612258523383716*^9}, 3.612685688337674*^9, {3.614505237903308*^9, 
   3.614505335631658*^9}, {3.614505373036313*^9, 3.6145055412646427`*^9}, 
   3.615796945939191*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "800"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"7616", "+", 
             RowBox[{"401816", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"35167", "-", 
              RowBox[{"32494", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"39589", "+", 
              RowBox[{"10483", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "300"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "91662"}], "-", 
             RowBox[{"115329", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"155771", "+", 
              RowBox[{"23199", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"30041", "+", 
              RowBox[{"12815", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "i"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "500"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"90105", "+", 
             RowBox[{"2320", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"93665", "-", 
              RowBox[{"21923", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2400"], "-", 
           FractionBox["\[ImaginaryI]", "2400"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"406468", "+", 
             RowBox[{"1210697", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"76779", "+", 
              RowBox[{"9044", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "i"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "4000"], "-", 
           FractionBox[
            RowBox[{"3", " ", "\[ImaginaryI]"}], "4000"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"648686", "-", 
             RowBox[{"188327", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"25173", "+", 
              RowBox[{"125", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"g", "i"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "750"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"809140", "-", 
             RowBox[{"399790", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"28285", "+", 
              RowBox[{"14406", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "400"], "+", 
           FractionBox["\[ImaginaryI]", "400"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"216710", "-", 
             RowBox[{"57646", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"28539", "-", 
              RowBox[{"5175", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"12660", "+", 
              RowBox[{"1719", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["47017", "50"]}], "+", 
           FractionBox[
            RowBox[{"544", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["47", "100"], "-", 
            FractionBox["\[ImaginaryI]", "20"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"363", "+", 
               RowBox[{"789", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
             SqrtBox["5"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"250", "+", 
               RowBox[{"41", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
             SqrtBox["89"]}]}], ")"}]}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"d", "j"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "500"]}], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"310530", "-", 
             RowBox[{"401315", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"11955", "+", 
              RowBox[{"52059", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["592139", "1200"], "+", 
           FractionBox[
            RowBox[{"62059", " ", "\[ImaginaryI]"}], "600"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["9087", "20"], "-", 
            FractionBox[
             RowBox[{"2951", " ", "\[ImaginaryI]"}], "20"]}], ")"}], " ", 
          SqrtBox[
           FractionBox["89", "5"]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "j"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1271185", "-", 
            RowBox[{"1052955", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"29589", "+", 
             RowBox[{"37796", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["445"]}]}], "2000"]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"h", "j"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"13065", "+", 
            RowBox[{"328065", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"95345", "+", 
             RowBox[{"4084", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["445"]}]}], "1500"]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], "\[Rule]", 
        RowBox[{
         FractionBox["71909", "100"], "-", 
         FractionBox[
          RowBox[{"2783", " ", "\[ImaginaryI]"}], "25"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "400"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"217008", "-", 
             RowBox[{"480736", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"22071", "+", 
              RowBox[{"24015", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5975", "+", 
              RowBox[{"13066", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "300"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "290253"}], "+", 
             RowBox[{"148590", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"30399", "+", 
              RowBox[{"93087", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"27467", "+", 
              RowBox[{"7842", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["89"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "j"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "500"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "238725"}], "+", 
             RowBox[{"225260", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"178", "+", 
              RowBox[{"42473", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["5"]}]}], ")"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612167364405326*^9, 3.612167400167985*^9, {3.612167443304433*^9, 
   3.612167483575858*^9}, {3.612167563577479*^9, 3.612167657471463*^9}, 
   3.612167700370111*^9, 3.612167770596114*^9, 3.612167807527257*^9, {
   3.6121682457254963`*^9, 3.61216829281944*^9}, 3.612175692993927*^9, 
   3.61225780705284*^9, {3.6122585063341312`*^9, 3.612258524869982*^9}, 
   3.612684420314109*^9, 3.612684550667274*^9, 3.612685690600247*^9, 
   3.614415307118548*^9, 3.6144167336216383`*^9, 3.614506947221128*^9, 
   3.614578403916479*^9, 3.614938440736401*^9, 3.615635001807446*^9, 
   3.615796995884589*^9, 3.616215856397513*^9, 3.617337356000928*^9, 
   3.617339511790882*^9, 3.618218629897285*^9, 3.619334844191677*^9, 
   3.619776221387616*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5e$ward$3", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"amp5e$ward$2", "/.", 
    RowBox[{"Join", "[", 
     RowBox[{"reprules", ",", "reprules2"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612166654604591*^9, 3.612166656651211*^9}, {
  3.6121667144154987`*^9, 3.6121667426613398`*^9}, {3.6121673724219103`*^9, 
  3.612167378853142*^9}, {3.612167935783339*^9, 3.612167939002335*^9}, {
  3.61216806726926*^9, 3.61216807017867*^9}, {3.612168305300317*^9, 
  3.612168308505945*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4608000000000000"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"52348833404892902042604599569", "-", 
        RowBox[{"16304379916278890908639851257", " ", "\[ImaginaryI]"}]}], 
       ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"6300642743088035710035082267", "+", 
         RowBox[{"10990464331467693646504722483", " ", "\[ImaginaryI]"}]}], 
        ")"}], " ", 
       SqrtBox["5"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"246597476521198981272643027", "-", 
         RowBox[{"630619130977724413783572991", " ", "\[ImaginaryI]"}]}], 
        ")"}], " ", 
       SqrtBox["89"]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1603561971334866737666500792", "+", 
         RowBox[{"850538829971949055391733727", " ", "\[ImaginaryI]"}]}], 
        ")"}], " ", 
       SqrtBox["445"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["5",
        TraditionalForm], 
       FormBox[
        FormBox["b",
         TraditionalForm],
        TraditionalForm]]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6121672154713182`*^9, 3.612167380546661*^9, {3.612167419550359*^9, 
   3.6121674865965843`*^9}, {3.6121675670201674`*^9, 
   3.6121676598776207`*^9}, {3.6121677032897*^9, 3.612167708532875*^9}, 
   3.612167773955621*^9, 3.61216781025496*^9, 3.612167940170179*^9, 
   3.612168071725505*^9, {3.612168249769535*^9, 3.612168309422928*^9}, 
   3.612175696711502*^9, 3.612255957634861*^9, 3.612257978122542*^9, 
   3.6122585546492643`*^9, 3.612684459109888*^9, 3.612684599902536*^9, 
   3.612685733674036*^9, 3.614415345208847*^9, 3.614415507735038*^9, 
   3.614416767923747*^9, 3.614506981861854*^9, 3.614578437067649*^9, 
   3.614938475344945*^9, 3.615635035723611*^9, 3.61579704220089*^9, 
   3.616215898077524*^9, 3.617337397535852*^9, 3.617339553872147*^9, 
   3.618218671212533*^9, 3.6193348858885193`*^9, 3.619776263467561*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "amp5e$ward$3", "]"}]], "Input",
 CellChangeTimes->{{3.615713821976931*^9, 3.6157138228596697`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"2.226368742714493`*^13", "+", 
     RowBox[{"4.3975548446163174`*^12", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
   
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "+", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "+", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], "+", 
     SubsuperscriptBox["k", 
      FormBox["5",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.615713823162196*^9, 3.61579705662918*^9, 
  3.616215898154661*^9, 3.617337397636997*^9, 3.6173395539384203`*^9, 
  3.618218671311385*^9, 3.6193348859607058`*^9, 3.619776263513801*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"amp5e$ward$3", "/.", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"ii", ",", "b"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et1", ",", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<k\>\"", "<>", 
            RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ")"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.612684637295391*^9, 3.6126846735628653`*^9}, {
  3.612684716196723*^9, 3.612684741371846*^9}, {3.615796924773467*^9, 
  3.615796931464487*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612684646297982*^9, 3.612684674050997*^9}, {
   3.612684725964346*^9, 3.612684741820476*^9}, 3.6126857371973133`*^9, 
   3.6144153453332043`*^9, 3.614416768021055*^9, 3.6145069821914387`*^9, 
   3.614578437111768*^9, 3.614938475445105*^9, 3.615635035829014*^9, 
   3.615796932549774*^9, 3.615797059203001*^9, 3.6162158981986723`*^9, 
   3.617337397675591*^9, 3.6173395539903307`*^9, 3.6182186713545227`*^9, 
   3.619334886014659*^9, 3.619776263540023*^9}]
}, Open  ]],

Cell["\<\
Hence, the Ward identity has been successfully tested. Great!\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgekGAzRU3IH3m314wDQAKZ811
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
   3.604652950305522*^9}, 3.604653026772519*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Agreement with KLT (eee and eeee amplitudes)", "Section",
 CellChangeTimes->{{3.602397472711556*^9, 3.602397478116787*^9}, {
  3.614587455913784*^9, 3.6145874695185328`*^9}, {3.614587500610508*^9, 
  3.614587509297192*^9}}],

Cell["\<\
We give the partial 3-point and 4-point amplitudes and apply the KLT formulae.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602500637026964*^9, 3.602500655353221*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell["3 - amplitude", "Subsection",
 CellChangeTimes->{{3.6023974823450947`*^9, 3.602397493399378*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A3partial", "[", 
   RowBox[{"a_", ",", "c_", ",", "e_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"-", "2"}], "I", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "e"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "c"}], "]"}], "-", 
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "c"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "e"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"3", ",", "a"}], "]"}], "-", 
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "a"}], "]"}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"k", "[", 
         RowBox[{"2", ",", "e"}], "]"}], "-", 
        RowBox[{"k", "[", 
         RowBox[{"1", ",", "e"}], "]"}]}], ")"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.6023975380667963`*^9, 3.6023976200432034`*^9}, 
   3.604656531032728*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], "e"], "-", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], "e"]}], ")"}], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], "c"], "-", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], "c"]}], ")"}], " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "e"}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], "a"], "-", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], "a"]}], ")"}], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0F1Ik3EUBvBVUOiFCA2iXGoiuehTs5hm4HE0zaTGaGIkMqatN73IQoXA
sg9rQl7U1nfaCGz0gcQsKwY6PzASmXVhuZybW9qEP26vvhI5q9nzvzj8Lg4c
zvNsMZ7VnVolk8nUmOUx6/5144x6zcq0HFiZlKj3wuiujWZuw536mjIPI2mb
pfokLB1+058xwSi0R3y0HY7kNRt2Q0tJY2smnI8TP49D/84Q46rqDEkeWHa6
MpdbnJ+m4V6y9577DhMOnwhzlZaHMa7bdvXuBGxtOTLghdWmD690Xkb7wg0P
jkPBas0qhX2j0XY7zL8gvuUe3CRcfAE3r4nMuOFLKdD9F+Y5Q37uYFP2Infr
tEL+D95KVhRx2xQfz3OVzanvuYn1qerHk4xcbeR4Ags6nDo77FmJ9C3AqhKP
xFUl92dJMBZnusmVR5dsy5CuiOl/YIL1zJjow/8ubfqGKdx77p8tDjA69vRa
xoEgI3vuM+e9H4yMHaaZ+7C24GtRENbtHW26PY3+hNcpXVATWx/vgg6fY9gP
y1f7vnT+ZDQpsIogzFFd746FGH3quqwdCjMyfKs6VBhhdDS+tlOC7bbGEc08
enMX1hgXsF95t/bGIiNtBcnNUCbM6bN/IYd6oFz/G/lapMCOJUb/AS97PuM=

  "]]
}, Open  ]],

Cell["Ward identity:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602500637026964*^9, 3.602500655353221*^9}, {
  3.610778841196755*^9, 3.6107788427481203`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"A3partial", "[", 
        RowBox[{"a", ",", "c", ",", "e"}], "]"}], 
       RowBox[{"k", "[", 
        RowBox[{"1", ",", "a"}], "]"}]}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"a_", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"a", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}]}], 
        "-", 
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}]}],
      "}"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.610778845494104*^9, 3.61077885403646*^9}, {
  3.6107788895755253`*^9, 3.610778980719324*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.610778854297598*^9, {3.6107788949296913`*^9, 3.610778903434306*^9}, {
   3.6107789552896442`*^9, 3.610778981205852*^9}, 3.614321284078639*^9, 
   3.614587435382195*^9, 3.614938475573361*^9, 3.615635035964815*^9, 
   3.6162158983038588`*^9, 3.617337397777166*^9, 3.6173395541027193`*^9, 
   3.618218671445053*^9, 3.619334886142745*^9, 3.6197762636292067`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"c", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"d", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"e", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"f", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6107789829751472`*^9, 3.610778993631785*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.6107789940802107`*^9, 3.6143212841599894`*^9, 
  3.6145874353887863`*^9, 3.614938475623311*^9, 3.6156350360077543`*^9, 
  3.616215898339891*^9, 3.6173373978113003`*^9, 3.617339554142469*^9, 
  3.6182186714787483`*^9, 3.6193348861875277`*^9, 3.619776263654167*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A3A3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"A3partial", "[", 
     RowBox[{"a", ",", "c", ",", "e"}], "]"}], 
    RowBox[{"A3partial", "[", 
     RowBox[{"b", ",", "d", ",", "f"}], "]"}]}], "//", "Expand"}]}]], "Input",\

 CellChangeTimes->{{3.602397497186481*^9, 3.602397556232785*^9}, {
  3.6023976402863626`*^9, 3.6023976640475597`*^9}, {3.602397828702828*^9, 
  3.602397829404664*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"4", " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], "e"], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], "f"], " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]]}]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "e"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "e"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "e"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "f"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "d"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "d"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "d"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "d"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "c"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "d"], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "e"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "c"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], "c"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "c"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "b"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "c"], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "b"], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "b"], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "b"], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "a"], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], "b"], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.602397652909189*^9, 3.60239766436302*^9}, 
   3.602397830905983*^9, 3.602499857358197*^9, 3.6028320406510468`*^9, 
   3.602832440933429*^9, 3.603088219756629*^9, 3.6030943567006893`*^9, 
   3.604037133768261*^9, 3.604045015581586*^9, 3.60405274029275*^9, 
   3.604057187992126*^9, 3.6043976957705917`*^9, 3.604397911322339*^9, 
   3.604398299153479*^9, 3.604398547196294*^9, 3.6043986412576838`*^9, 
   3.604401038047546*^9, 3.604402026906019*^9, 3.60440216491469*^9, 
   3.604403372229863*^9, 3.604405778540872*^9, 3.604649309920466*^9, 
   3.60465325187357*^9, 3.60465653449924*^9, 3.6048212320063753`*^9, 
   3.6048214156508303`*^9, 3.604827115368326*^9, 3.604901671617052*^9, 
   3.604997551208721*^9, 3.604997879322845*^9, 3.6049980417594023`*^9, 
   3.604998305003875*^9, 3.604998720979351*^9, 3.604999062291952*^9, 
   3.604999609144024*^9, 3.605322265138842*^9, 3.605329290189816*^9, 
   3.605344917916617*^9, 3.6054993995517797`*^9, 3.605499798892456*^9, 
   3.605500310185894*^9, 3.6055010193232937`*^9, 3.605517567933817*^9, 
   3.605518631655117*^9, 3.60601974738058*^9, 3.606624546654682*^9, 
   3.607254847073594*^9, 3.6077468762599077`*^9, 3.608458709389249*^9, 
   3.608461091425419*^9, 3.6086113987971373`*^9, 3.608972286645743*^9, 
   3.609039101624305*^9, 3.60906555271106*^9, 3.609130573729849*^9, 
   3.610078855127281*^9, 3.6101844418463783`*^9, 3.6107688122809973`*^9, 
   3.614321284294433*^9, 3.614587435467107*^9, 3.614938475704186*^9, 
   3.615635036088728*^9, 3.61621589842247*^9, 3.6173373978921547`*^9, 
   3.617339554220818*^9, 3.618218671585067*^9, 3.6193348863063602`*^9, 
   3.6197762637376738`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "A3A3", "]"}]], "Input",
 CellChangeTimes->{{3.602397668557029*^9, 3.6023976701493473`*^9}, {
  3.602397833293709*^9, 3.602397834117096*^9}}],

Cell[BoxData[
 FormBox["36", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwV0FtIk3EYx/E3kRQpUjCcbCSeeKMWZoSgjeHTyA1R0eGstAsVDVGzjIQM
SqSVOg8QeZakboQM0WqWJMsDFdqcFWxNt7V0vhk+oc7NXNSynv/Fj8/17xtd
fFlduofjuNM0SY9JFmRFmNJk5DBFcmlMMtnoFmns5EzgoQambudGxbkFBIWy
u7yATDWMTfE2hGO13t6j5Ii2qTCBdCfdbkkkHQ/+fbCSQg0i059UKl4gb7ku
pjCTiw6nMQPC3lQvkrLgonVmL/9olzn/XNdhI9WVZ6ftpChz8onajmD5Ud+d
S0a/5voHSM+mT89MNV25+ZiZuC2YyDkeR/1ka+SGk6kcl3mZ5SGx4X/Jwv0x
KmbZp/dXmbYC/iVTKpYq+hwITpfyaT8pRE2oB8iRa97JLbL9vtPDnE6YOeEh
c+SVzUz5YsDD3+T5IH/cH3LQcMm8+QXBaM2Li/hKv0Ur39OXEILNOv7UMkL9
/PCrTheCOb5K6CIlCptqmUwpsdTdW0F41/gi6hlpuRMZMkFK8g2zTvJAi/Bx
6BvCDtc2urtKnRxN2W/XEUI/V59RbiCsia8PeUj9Qa0xzY1Q155VUbyFUKU1
7L3rRdh3RBXeQB4P3Nac/IkQm2m8oPEhZFh9S9JfCP8B6cs3KA==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ttmp1", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", "A3A3", "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"i_", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
        "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"i", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}]}], 
         "\[IndentingNewLine]", "-", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"i", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}], 
       "}"}]}], "//", "Expand"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"a", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"b", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"c", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"d", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.602397812701846*^9, 3.602397837819817*^9}, {
  3.602397909559466*^9, 3.6023979245881567`*^9}, {3.602397980113517*^9, 
  3.602398001947196*^9}, {3.6023980544490833`*^9, 3.602398113724799*^9}, {
  3.602398233806396*^9, 3.6023982665836687`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}]}], "+", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "-", 
   RowBox[{"4", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.602397926380211*^9, {3.60239798188883*^9, 3.602398002599249*^9}, {
   3.6023980860228786`*^9, 3.602398114818136*^9}, 3.602398235333893*^9, 
   3.6023982674566593`*^9, 3.6024998577512083`*^9, 3.602832041243437*^9, 
   3.6028324413354263`*^9, 3.603088220229478*^9, 3.603094357198803*^9, 
   3.6040371341472473`*^9, 3.604045016026617*^9, 3.604052740740382*^9, 
   3.604057188472308*^9, 3.6043976963611393`*^9, 3.6043979117091417`*^9, 
   3.604398299605803*^9, 3.604398547586261*^9, 3.6043986416280727`*^9, 
   3.604401038573444*^9, 3.604402027426074*^9, 3.604402165405983*^9, 
   3.6044033727143784`*^9, 3.6044057791117773`*^9, 3.6046493104071407`*^9, 
   3.604653252451743*^9, 3.6048212324100018`*^9, 3.6048214161428833`*^9, 
   3.6048271160189447`*^9, 3.604901672027008*^9, 3.604997551791477*^9, 
   3.604997879853579*^9, 3.604998042303858*^9, 3.6049983055134287`*^9, 
   3.6049987214860163`*^9, 3.604999062755954*^9, 3.604999609731125*^9, 
   3.605322265859806*^9, 3.605329290675506*^9, 3.605344918344901*^9, 
   3.605499399979005*^9, 3.605499799333181*^9, 3.6055003106267014`*^9, 
   3.60550101975313*^9, 3.6055175684733553`*^9, 3.6055186322446613`*^9, 
   3.606019747818038*^9, 3.606624547083981*^9, 3.60725484746283*^9, 
   3.6077468767156067`*^9, 3.608458709874125*^9, 3.608461091829145*^9, 
   3.6086113992130527`*^9, 3.6089722870680857`*^9, 3.6090391020767*^9, 
   3.6090655533450747`*^9, 3.609130574285533*^9, 3.6100788555152683`*^9, 
   3.610768812824801*^9, 3.614321284694202*^9, 3.614587435973229*^9, 
   3.61493847612556*^9, 3.615635036540682*^9, 3.616215898823544*^9, 
   3.617337398295788*^9, 3.617339554614221*^9, 3.6182186719878187`*^9, 
   3.6193348867294893`*^9, 3.619776264116083*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "ttmp1", "]"}]], "Input",
 CellChangeTimes->{{3.602398033532297*^9, 3.6023980361568623`*^9}, 
   3.6023982707584143`*^9}],

Cell[BoxData[
 FormBox["16", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwd0GtIk3EYxuHJ7GTLhAypJCusgZM0GXgK8nFmZiox07STMpRKQTM7IcgI
xddQNgx00nQkhLjZSyiNwIJYB9iKcFkw3Wq58lAPumOupTV6/n24uT7e8Nur
aJTXRggEgjxaiUtVt8GGEJP8/hpz5YSpjRlX/oNj3juYuS+TzClKKnOQByCV
YwYk6vqKaYSMn4a6s+TjwBuT2I4g2iPUSkizT1OdQjacV3cfIjnjZquNnPIG
kdlVdWvXNBkz2JzFzJZL85mRHVNNM+SN+IZl5mUVH2YuLWl77eSRLTUvHGS1
fXJU7kB4sFPdf4o0z0brhsmW3euMzIWE26168mZlxPw7sqk2bPxD5srCTuaI
qDjA1OjTY/+SVbLUAubD4zNXmcGarCf/fXVYpv2EcImvHNOROZsm5cPklU6h
yUd2Kzx+5oVIe5qf/L69tYspLd56f5Wc2LZx/xrZWKH86PmMkCe6mBj3BUHV
7FksnEUwZAyKs10IUdefTfR9RfgQapnTkP1ub4GLDKkXlT3fEKIfmRPGyfGn
kqjnpMpgsThJfdBr5ecR4hO1xvACgjhNd/L1MsLpO8qjx9wId7l23k+6X/a8
zffSz+iZeoUPIYm3rO8IIKQ4S2M5cmCHoFy6Qh2HbOfKfiFYfwtdySGEfz9V
Pgw=
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ttmp2", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"32", "I", " ", "verEEEonshell123"}], "//", "Expand"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"a", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"b", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"c", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"d", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.602398142613809*^9, 3.602398155845673*^9}, {
  3.602398215590613*^9, 3.60239824078852*^9}, {3.602398278303768*^9, 
  3.6023982793896933`*^9}, {3.602400754355736*^9, 3.6024007610086937`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"16", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]]}]}], "+", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "f"}]]}], "+", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"16", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "-", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}], "+", 
   RowBox[{"8", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "d"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.60239813223013*^9, 3.602398156100692*^9}, {
   3.602398221945293*^9, 3.602398241378207*^9}, 3.602398279905416*^9, 
   3.602400761735108*^9, 3.602499857835186*^9, 3.602832041442425*^9, 
   3.602832441586796*^9, 3.603088220553491*^9, 3.603094357433689*^9, 
   3.604037134422567*^9, 3.604045016167205*^9, 3.604052740848364*^9, 
   3.6040571885980864`*^9, 3.6043976965902033`*^9, 3.6043979117832003`*^9, 
   3.6043982998213367`*^9, 3.604398547656341*^9, 3.604398641758358*^9, 
   3.604401038678027*^9, 3.604402027576449*^9, 3.604402165540823*^9, 
   3.604403373024555*^9, 3.60440577930797*^9, 3.604649310592086*^9, 
   3.6046532525533037`*^9, 3.6048212325928802`*^9, 3.604821416258374*^9, 
   3.604827116141697*^9, 3.604901672141036*^9, 3.6049975521530123`*^9, 
   3.604997880043482*^9, 3.6049980425428534`*^9, 3.604998305863263*^9, 
   3.6049987216043*^9, 3.6049990628484583`*^9, 3.6049996100236273`*^9, 
   3.605322266014723*^9, 3.605329290864094*^9, 3.605344918531251*^9, 
   3.6054994001702757`*^9, 3.605499799544632*^9, 3.605500310887966*^9, 
   3.605501019970606*^9, 3.6055175685540648`*^9, 3.6055186323647537`*^9, 
   3.606019748033305*^9, 3.606624547283286*^9, 3.607254847523374*^9, 
   3.607746876987495*^9, 3.608458709996624*^9, 3.608461091986823*^9, 
   3.6086113996614103`*^9, 3.608972287398829*^9, 3.609039102347396*^9, 
   3.609065553455699*^9, 3.6091305743987217`*^9, 3.610078855680414*^9, 
   3.610768812961398*^9, 3.61432128500194*^9, 3.6145874360358458`*^9, 
   3.614938476187315*^9, 3.615635036612772*^9, 3.6162158988859997`*^9, 
   3.617337398352375*^9, 3.617339554666376*^9, 3.618218672046377*^9, 
   3.6193348867888737`*^9, 3.619776264170105*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ttmp2", "//", "TeXForm"}]], "Input",
 CellChangeTimes->{{3.602400674418786*^9, 3.602400693591*^9}, {
  3.602400726800727*^9, 3.602400726948162*^9}}],

Cell["\<\
-16 k_2^a k_2^b g^{ce} g^{df}+16 k_2^b k_1^c g^{ae} g^{df}-8 k_2^b k_1^e g^{ac}
   g^{df}+8 k_2^b k_2^e g^{ac} g^{df}+16 k_2^a k_1^d g^{bf} g^{ce}-16 k_1^c \
k_1^d
   g^{ae} g^{bf}+8 k_1^d k_1^e g^{ac} g^{bf}-8 k_1^d k_2^e g^{ac} g^{bf}-8 \
k_2^a
   k_1^f g^{bd} g^{ce}+8 k_1^c k_1^f g^{ae} g^{bd}+8 k_2^e k_1^f g^{ac} \
g^{bd}+8
   k_2^a k_2^f g^{bd} g^{ce}-8 k_1^c k_2^f g^{ae} g^{bd}+8 k_1^e k_2^f g^{ac}
   g^{bd}\
\>", "Output",
 CellChangeTimes->{{3.602400679682123*^9, 3.602400693976372*^9}, 
   3.6024007276206617`*^9, 3.602499857904214*^9, 3.602832041566358*^9, 
   3.602832441709663*^9, 3.60308822063692*^9, 3.6030943575338993`*^9, 
   3.604037134499518*^9, 3.6040450162650747`*^9, 3.6040527409854507`*^9, 
   3.604057188810919*^9, 3.604397696858073*^9, 3.604397911884136*^9, 
   3.604398299926239*^9, 3.604398547713135*^9, 3.604398641921123*^9, 
   3.6044010387995768`*^9, 3.604402027742222*^9, 3.604402165759392*^9, 
   3.6044033731464157`*^9, 3.604405779529155*^9, 3.604649310691278*^9, 
   3.6046532527141857`*^9, 3.604821232794956*^9, 3.6048214164378347`*^9, 
   3.6048271163481627`*^9, 3.604901672312971*^9, 3.604997552351446*^9, 
   3.60499788024719*^9, 3.604998042734456*^9, 3.6049983059621763`*^9, 
   3.604998721803529*^9, 3.604999062999362*^9, 3.604999610326498*^9, 
   3.6053222662673483`*^9, 3.605329290999016*^9, 3.6053449186813097`*^9, 
   3.605499400315875*^9, 3.6054997996787357`*^9, 3.605500310971212*^9, 
   3.6055010201009083`*^9, 3.605517568699255*^9, 3.605518632533758*^9, 
   3.6060197482237253`*^9, 3.606624547443074*^9, 3.607254847678577*^9, 
   3.6077468770768623`*^9, 3.608458710192964*^9, 3.60846109226298*^9, 
   3.6086113998697357`*^9, 3.608972287506064*^9, 3.6090391024887047`*^9, 
   3.609065553614093*^9, 3.609130574571569*^9, 3.6100788559282303`*^9, 
   3.610768813177997*^9, 3.614321285305768*^9, 3.614587436203432*^9, 
   3.614938476349873*^9, 3.615635036743332*^9, 3.616215899698099*^9, 
   3.61733739847147*^9, 3.617339554747004*^9, 3.618218672187064*^9, 
   3.619334886938438*^9, 3.619776264275464*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "ttmp2", "]"}]], "Input",
 CellChangeTimes->{{3.6023982816323347`*^9, 3.602398282131112*^9}}],

Cell[BoxData[
 FormBox["14", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.602398179280634*^9, {3.602398225217558*^9, 3.602398244677878*^9}, 
   3.602398282432796*^9, 3.60249985792451*^9, 3.6028320417114897`*^9, 
   3.602832441713518*^9, 3.603088220724237*^9, 3.603094357596285*^9, 
   3.60403713458365*^9, 3.604045016290143*^9, 3.604052741081675*^9, 
   3.60405718891833*^9, 3.604397697072526*^9, 3.604397911946528*^9, 
   3.604398299930725*^9, 3.6043985477353563`*^9, 3.604398641925437*^9, 
   3.604401038881072*^9, 3.604402027858979*^9, 3.6044021658800983`*^9, 
   3.604403373242248*^9, 3.604405779534585*^9, 3.604649310705258*^9, 
   3.604653252726997*^9, 3.6048212328081303`*^9, 3.604821416649688*^9, 
   3.604827116376709*^9, 3.6049016725125227`*^9, 3.604997552597014*^9, 
   3.604997880272163*^9, 3.604998042870131*^9, 3.604998306043165*^9, 
   3.604998722029028*^9, 3.6049990631722918`*^9, 3.6049996104409513`*^9, 
   3.605322266606289*^9, 3.605329291003188*^9, 3.605344918686899*^9, 
   3.6054994003205643`*^9, 3.605499799683633*^9, 3.605500311039755*^9, 
   3.605501020105735*^9, 3.6055175687688627`*^9, 3.6055186325386343`*^9, 
   3.6060197482290077`*^9, 3.606624547447833*^9, 3.607254847704405*^9, 
   3.607746877149293*^9, 3.6084587103920937`*^9, 3.6084610924057837`*^9, 
   3.608611399890539*^9, 3.608972287600339*^9, 3.609039102598524*^9, 
   3.609065553620326*^9, 3.6091305745779037`*^9, 3.6100788561520023`*^9, 
   3.610768813193571*^9, 3.614321285317011*^9, 3.6145874365121527`*^9, 
   3.6149384765262814`*^9, 3.615635036919115*^9, 3.616215899824429*^9, 
   3.61733739850275*^9, 3.617339554779825*^9, 3.618218672225923*^9, 
   3.619334887104766*^9, 3.619776264295033*^9}]
}, Open  ]],

Cell["Comparing DFT and KLT 3-amplitudes:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ttmp1", "-", "ttmp2"}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.602397718585774*^9, 3.602397751487314*^9}, {
  3.602398288766192*^9, 3.602398310937566*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], "+", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], "+", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], ")"}], " ", 
   SuperscriptBox["g", 
    RowBox[{"a", "c"}]], " ", 
   SuperscriptBox["g", 
    RowBox[{"b", "d"}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6023977465611677`*^9, 3.602397751815927*^9}, {
   3.602398292355834*^9, 3.602398311351708*^9}, 3.6024998579454*^9, 
   3.6028320417909803`*^9, 3.6028324417873087`*^9, 3.603088220799481*^9, 
   3.6030943576587057`*^9, 3.604037134667595*^9, 3.604045016325433*^9, 
   3.604052741167223*^9, 3.604057189027286*^9, 3.604397697294609*^9, 
   3.604397912005896*^9, 3.604398300002367*^9, 3.604398547753841*^9, 
   3.604398642035392*^9, 3.604401038958054*^9, 3.604402027978264*^9, 
   3.604402165995245*^9, 3.604403373335074*^9, 3.604405779710462*^9, 
   3.604649310789074*^9, 3.604653252796068*^9, 3.60482123292409*^9, 
   3.604821416753954*^9, 3.604827116409684*^9, 3.604901672617828*^9, 
   3.604997552619413*^9, 3.604997880303697*^9, 3.6049980428996162`*^9, 
   3.604998306093289*^9, 3.6049987221257343`*^9, 3.6049990632078037`*^9, 
   3.604999610529127*^9, 3.605322266646274*^9, 3.605329291059835*^9, 
   3.605344918743001*^9, 3.60549940037569*^9, 3.605499799743042*^9, 
   3.605500311109576*^9, 3.605501020163781*^9, 3.605517568838505*^9, 
   3.605518632634713*^9, 3.606019748282337*^9, 3.606624547508196*^9, 
   3.607254847799677*^9, 3.607746877219941*^9, 3.6084587104982357`*^9, 
   3.608461092543395*^9, 3.608611400009428*^9, 3.60897228762466*^9, 
   3.609039102621196*^9, 3.609065553695915*^9, 3.6091305746666403`*^9, 
   3.6100788563064413`*^9, 3.61076881329707*^9, 3.6143212853773937`*^9, 
   3.614587436554551*^9, 3.6149384765729856`*^9, 3.615635036964715*^9, 
   3.6162158998652973`*^9, 3.617337398533065*^9, 3.617339554812957*^9, 
   3.618218672359832*^9, 3.619334887150139*^9, 3.61977626431492*^9}]
}, Open  ]],

Cell["\<\
This vanishes upon using momentum conservation and tranversality. 

As a result:
DFT3[a,b,c,d,e,f] = (32i)^(-1) A3partial[a,c,e] A3partial[b,d,f]\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.604722843171496*^9, 
  3.6047228456566887`*^9}, {3.604722891672101*^9, 3.604722965782902*^9}, {
  3.60472310577988*^9, 3.6047231128466663`*^9}, {3.60472343833885*^9, 
  3.6047234512859297`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{"Expand", "[", 
         RowBox[{"A3A3", " ", 
          RowBox[{"k", "[", 
           RowBox[{"1", ",", "a"}], "]"}]}], "]"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"a", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"b", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"c", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"d", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"e", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"f", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"x_", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}]}], 
        "-", 
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"x", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}], 
      "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"a", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"b", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"c", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"d", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"e", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"f", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", "0"}]}], "}"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.610184448264887*^9, 3.61018453808794*^9}, {
  3.6101845751133327`*^9, 3.610184669455513*^9}, {3.610184762794478*^9, 
  3.610184765984651*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.610184460305937*^9, 3.610184480434387*^9}, 
   3.610184517987256*^9, 3.610184593920363*^9, {3.610184638442355*^9, 
   3.610184670198923*^9}, 3.610184767683268*^9, 3.610768813916915*^9, 
   3.614321285775855*^9, 3.614587436905941*^9, 3.614938476937079*^9, 
   3.61563503735045*^9, 3.6162159002261877`*^9, 3.6173373988777313`*^9, 
   3.617339555154181*^9, 3.618218672713965*^9, 3.6193348875104837`*^9, 
   3.6197762646488647`*^9}]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
   3.60239832958531*^9, 3.602398342112001*^9}, 3.604722838546793*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4 - amplitude", "Subsection",
 CellChangeTimes->{{3.6023974823450947`*^9, 3.602397493399378*^9}, 
   3.602418900750165*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A4partial1234", "[", 
   RowBox[{"a_", ",", "c_", ",", "e_", ",", "g_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "I", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "e"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "g"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "g"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "e"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}], 
          RowBox[{"d", "[", 
           RowBox[{"e", ",", "g"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"I", "/", "s"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}], " ", 
          RowBox[{"k", "[", 
           RowBox[{"1", ",", "c"}], "]"}]}], "-", 
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"2", ",", "a"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "c"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "i"}], "]"}], "-", 
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "i"}], "]"}]}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"e", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"3", ",", "g"}], "]"}]}], "-", 
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"g", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"4", ",", "e"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"e", ",", "g"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "i"}], "]"}], "-", 
            RowBox[{"k", "[", 
             RowBox[{"3", ",", "i"}], "]"}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"I", "/", "u"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"1", ",", "g"}], "]"}]}], "-", 
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"g", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"4", ",", "a"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"a", ",", "g"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"4", ",", "i"}], "]"}], "-", 
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "i"}], "]"}]}], ")"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"e", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"3", ",", "c"}], "]"}]}], "-", 
         RowBox[{"2", 
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"2", ",", "e"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"c", ",", "e"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "i"}], "]"}], "-", 
            RowBox[{"k", "[", 
             RowBox[{"3", ",", "i"}], "]"}]}], ")"}]}]}], ")"}]}]}], "//", 
     "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
      "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.602418909787314*^9, 3.602419113291821*^9}, {
  3.60241944449686*^9, 3.602419548553232*^9}, {3.6024196267548647`*^9, 
  3.60241962959933*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "s", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "g"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "e"}]]}], "u"]}], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "u"], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "u"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "u"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "u"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "u"], "+", 
   RowBox[{"4", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]]}], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]]}], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "u"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "u"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "u"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"]}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwVzl1IU3EYBvCJuQthysZysAnDVBSSlRZBDoOX0fy4kFhtKAuxqVAuEAOj
AjEWKaUIEqmgzIphZn5Q5EcSybF1oWI4ErbOqa21NHll2rZSm/PQ+794+PHA
c/Fk2ZpMDUkSicRA0Ta4tuReBFdz8h7TMLYrniLn8+HYWbL+vd4skFF/SQdz
4ZnTXuVDSM5422glU3d5Lo9HiDelDRwn21tGa0+QklFXVyGZsVS06iUt1Ue2
mHVX7mt8JC/eKWa+UZQamYNcqPkL6Z65F2auFrhFZn71xGOetKe3LQjkwaT/
pUlAcKid/ZdIXyTbOUxefaeZYn7w9rS+INcuqtZXyEaHajpB8pmyAFPhqY0x
b902Kg/J7uvlZcy7VXiDKRPNM0ybzmoY+IrgmbS/cpLb/wTTMHl4Us5FSH4k
EWXGczaLouR03YNOpuOm9kmcdZ0694CM6brXdr4haIpbclQB+tOb+FXxHaHG
NpanDyKEZz/P9f5AwMr+n33k5idpeZA892i/rSeEUOn2aV+Tiix96jx5huMX
/eRGdrpnfJ3+WLkpcYN2R90XPoYRymaHzpduI8hlT8ejZGxuYtn4G6FCeGi3
RRACNSFpewzBqLym7CBLRtSW038Rnqf8uWzeQ5BaNMGCfYT/zgk/DQ==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A4partial1243", "[", 
   RowBox[{"a_", ",", "c_", ",", "g_", ",", "e_"}], "]"}], "=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"A4partial1234", "[", 
     RowBox[{"a", ",", "c", ",", "e", ",", "g"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"u", "\[Rule]", "t"}], ",", 
      RowBox[{"t", "\[Rule]", "u"}], ",", 
      RowBox[{
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], "\[Rule]", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], ",", 
      RowBox[{"e", "\[Rule]", "g"}], ",", 
      RowBox[{"g", "\[Rule]", "e"}]}], "}"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.602489195687731*^9, 3.6024893407920227`*^9}, {
  3.6025830289022303`*^9, 3.6025830554332952`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "e"}]]}], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]]}], "t"], "-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]]}], "t"], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "g"}]]}], "-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "t", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", "u", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "c"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]]}], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "s"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]]}], "t"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["a",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "t"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"8", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["4",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "t"], "+", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"], "-", 
   FractionBox[
    RowBox[{"4", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], " ", 
     SubsuperscriptBox["k", 
      FormBox["2",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SubsuperscriptBox["k", 
      FormBox["3",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], "s"]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.602489303694419*^9, 3.6024893414194613`*^9}, 
   3.6024998580693502`*^9, {3.602583029523205*^9, 3.60258305624041*^9}, 
   3.602832041956779*^9, 3.602832442023015*^9, 3.603088221042457*^9, 
   3.603094357862666*^9, 3.6040371349337177`*^9, 3.604045016491557*^9, 
   3.604052741420877*^9, 3.604057189260891*^9, 3.604397697805389*^9, 
   3.6043979121999807`*^9, 3.6043983002353973`*^9, 3.604398547862818*^9, 
   3.60439864233431*^9, 3.604401039283134*^9, 3.6044020282728977`*^9, 
   3.604402166266922*^9, 3.604403373582362*^9, 3.6044057801729527`*^9, 
   3.604649311051772*^9, 3.604653253194249*^9, 3.6048212332426023`*^9, 
   3.6048214169653673`*^9, 3.6048271169102783`*^9, 3.604901672823739*^9, 
   3.604997552835812*^9, 3.604997880549676*^9, 3.604998043165943*^9, 
   3.604998306293491*^9, 3.604998722429552*^9, 3.604999063381051*^9, 
   3.604999610803529*^9, 3.605322266952112*^9, 3.605329291453466*^9, 
   3.6053449189406157`*^9, 3.605499400610703*^9, 3.6054997999661694`*^9, 
   3.605500311327161*^9, 3.605501020359643*^9, 3.605517569212245*^9, 
   3.60551863304953*^9, 3.606019748502551*^9, 3.6066245477333403`*^9, 
   3.607254848036161*^9, 3.607746877470622*^9, 3.60845871073569*^9, 
   3.608461092913575*^9, 3.608611400244565*^9, 3.6089722878748693`*^9, 
   3.609039102876473*^9, 3.609065554107769*^9, 3.609130575036689*^9, 
   3.6100788566462717`*^9, 3.6107688141785393`*^9, 3.614321286215414*^9, 
   3.614587437063295*^9, 3.614938477107279*^9, 3.615635037526863*^9, 
   3.616215900392618*^9, 3.617337399146152*^9, 3.6173395553385487`*^9, 
   3.61821867290586*^9, 3.619334887695122*^9, 3.619776264897951*^9}]
}, Open  ]],

Cell["We check that the Ward identity is satisfied.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"I", "/", "2"}], " ", 
            RowBox[{"A4partial1234", "[", 
             RowBox[{"a", ",", "c", ",", "e", ",", "g"}], "]"}], 
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "a"}], "]"}]}], "//", "Contract"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"s", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"t", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"u", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"u", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"s", "/", "2"}]}]}], "}"}]}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"i_", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
         "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"LorentzIndex", "[", 
              RowBox[{"i", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}]}], 
          "-", 
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"i", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "-", 
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"i", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}],
         "}"}]}], "//", "Expand"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"e", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"g", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}]}], "}"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.602419775115089*^9, 3.6024198417997932`*^9}, {
  3.602420065340673*^9, 3.602420065679801*^9}, {3.6024868213848553`*^9, 
  3.602486892388907*^9}, {3.6024869257289867`*^9, 3.602486974775758*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"u", " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]]}], ")"}], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}], "u"], TraditionalForm]], "Output",
 CellChangeTimes->{{3.602419784135792*^9, 3.60241984216827*^9}, 
   3.60242006618715*^9, {3.602486840091569*^9, 3.602486863346201*^9}, {
   3.602486946840279*^9, 3.602486975158916*^9}, 3.6024998582536907`*^9, {
   3.602583036707961*^9, 3.602583058188521*^9}, 3.602832042193746*^9, 
   3.602832442197468*^9, 3.6030882212923098`*^9, 3.60309435803388*^9, 
   3.604037135187786*^9, 3.604045016670198*^9, 3.6040527415826387`*^9, 
   3.604057189431403*^9, 3.604397698190477*^9, 3.6043979124081173`*^9, 
   3.604398300418351*^9, 3.6043985480324*^9, 3.604398642599348*^9, 
   3.604401039574088*^9, 3.604402028450944*^9, 3.60440216644201*^9, 
   3.6044033739016647`*^9, 3.604405780381194*^9, 3.604649311302279*^9, 
   3.604653253430829*^9, 3.604821233526299*^9, 3.60482141715266*^9, 
   3.604827117111224*^9, 3.604901673021661*^9, 3.604997553066884*^9, 
   3.6049978807362547`*^9, 3.604998043346455*^9, 3.6049983065043287`*^9, 
   3.6049987226137857`*^9, 3.6049990636364594`*^9, 3.60499961108949*^9, 
   3.605322267257724*^9, 3.6053292919411077`*^9, 3.605344919102186*^9, 
   3.6054994007835417`*^9, 3.60549980014132*^9, 3.605500311552742*^9, 
   3.605501020528458*^9, 3.605517569449194*^9, 3.605518633297443*^9, 
   3.60601974868064*^9, 3.60662454790963*^9, 3.6072548482260647`*^9, 
   3.607746877716614*^9, 3.608458710919241*^9, 3.608461093225053*^9, 
   3.608611400710163*^9, 3.608972288156331*^9, 3.609039103058486*^9, 
   3.609065554348877*^9, 3.6091305752862053`*^9, 3.61007885682299*^9, 
   3.610768814362114*^9, 3.6143212864463778`*^9, 3.614587437284088*^9, 
   3.6149384773331537`*^9, 3.615635037733025*^9, 3.616215900599718*^9, 
   3.617337399320072*^9, 3.617339555527657*^9, 3.618218673130138*^9, 
   3.61933488791626*^9, 3.6197762650994463`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"I", "/", "2"}], " ", 
            RowBox[{"A4partial1243", "[", 
             RowBox[{"a", ",", "c", ",", "g", ",", "e"}], "]"}], 
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "a"}], "]"}]}], "//", "Contract"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"s", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"t", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"u", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"u", "/", "2"}]}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", 
            RowBox[{"s", "/", "2"}]}]}], "}"}]}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"i_", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
         "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"LorentzIndex", "[", 
              RowBox[{"i", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}]}], 
          "-", 
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"i", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
          "-", 
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"i", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}],
         "}"}]}], "//", "Expand"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"e", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"g", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}]}], "}"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.6028310623678913`*^9, 3.6028310716920357`*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["3",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"t", " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "-", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], "+", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]]}], ")"}]}]}], ")"}]}], "t"], 
  TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBwAGI+1bA7t66/cvyZ5h16G0hnHfRtB9E3Y7ZlR9x45egi
ciIrGkhLpn46qH7rleOrGqnZ2kC6L3ZXgj6Q9tLe3GMIpM30gi5cB9LuJ4Re
g+iI5VOkbwBp6fltViA6enqEG4hW6v1eeBNIP2qc/hZEKx249g9Ep30/MvUW
kOb7Mu3QbSDd6vR+ddDtV45VGptnhADpsH+285YB6aRWra0gWkZyZe1KIP1Z
W+3pWSAdnaO57Q+Qdi5SuA+i5xwu/wyiI56EivwF0n2TYjxAtFvvryIQvWNi
wXYQva8lz3n2nVeO08K7N84D0jO+vwxaBqQF5BQOfgTS/uu4P4Po3R+/GX0C
0ieOTu8G0fsOGS/4BaSFXump/gbSETvnXHl/95Vj+9YWFfH7rxxf8/K+8HoA
tKdsj7r1Q6D9Zx/tmvYI6K4pW55MB9L7qhU8HwLpidu4GiY+fuXIYvdSfhOQ
zsoO4NoPpO81vzt5D0h3fFS+uPYpMLySr2799+yVo9jrywFH375yTJ6x1dX9
3SvHlNANaz8B6Vr9vafdPrxyDOKZmZ308ZXjtcQPbG2fXzn6pJSJtAPpDFat
MJOvrxw1/jLFhn5/5fhmhcZDnR+vHAHRXDGO
  "]]
}, Open  ]],

Cell["This, in fact, vanishes.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tmp", "=", 
  RowBox[{
   RowBox[{"s", " ", 
    RowBox[{"A4partial1234", "[", 
     RowBox[{"a", ",", "c", ",", "e", ",", "g"}], "]"}], 
    RowBox[{"A4partial1243", "[", 
     RowBox[{"b", ",", "d", ",", "h", ",", "f"}], "]"}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.602489373559785*^9, 3.602489403688011*^9}, {
  3.6025038333469*^9, 3.602503833510831*^9}, {3.6025045322061043`*^9, 
  3.602504532660037*^9}, {3.602831096617423*^9, 3.602831121305706*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"4", " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "f"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "e"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SuperscriptBox["s", "3"]}], 
             RowBox[{"t", " ", "u"}]]}], "+", 
           FractionBox[
            RowBox[{"8", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["s", "2"]}], "u"], "+", 
           RowBox[{"\[LeftSkeleton]", "1403", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"32", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "-", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 323, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 323, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 323, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[323]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6024893949995127`*^9, 3.602489404411367*^9}, 
   3.602489494973268*^9, 3.6024998585653057`*^9, 3.602503835860565*^9, 
   3.602504533514312*^9, {3.602583010324018*^9, 3.602583059815978*^9}, {
   3.602831098785129*^9, 3.602831122055519*^9}, 3.602832042730628*^9, {
   3.602832096195524*^9, 3.6028321102422047`*^9}, 3.6028324429028254`*^9, {
   3.602832625444882*^9, 3.60283265339165*^9}, 3.603088221995525*^9, 
   3.603094358708192*^9, 3.604037135872623*^9, 3.604045017133773*^9, 
   3.6040527421168537`*^9, 3.604057189994176*^9, 3.60439769886355*^9, 
   3.604397912926927*^9, 3.604398301082839*^9, 3.604398548541231*^9, 
   3.604398643175441*^9, 3.6044010400956793`*^9, 3.60440202916969*^9, 
   3.604402167003392*^9, 3.604403374531057*^9, 3.604405781185493*^9, 
   3.6046493120370197`*^9, 3.604653253954505*^9, 3.604821234255521*^9, 
   3.6048214177199373`*^9, 3.604827117680601*^9, 3.604901673575226*^9, 
   3.604997553649789*^9, 3.604997881544922*^9, 3.6049980441555443`*^9, 
   3.604998307247828*^9, 3.60499872330921*^9, 3.604999064205315*^9, 
   3.604999611868628*^9, 3.6053222680261*^9, 3.605329292761147*^9, 
   3.605344919602251*^9, 3.605499401422477*^9, 3.605499800822289*^9, 
   3.6055003122384233`*^9, 3.605501021027625*^9, 3.605517569977915*^9, 
   3.60551863384673*^9, 3.606019749367585*^9, 3.60662454862745*^9, 
   3.607254848710647*^9, 3.60774687842983*^9, 3.6084587114900312`*^9, 
   3.6084610940831757`*^9, 3.6086114013317537`*^9, 3.608972288899145*^9, 
   3.609039103766362*^9, 3.609065554870422*^9, 3.609130575821032*^9, 
   3.61007885770019*^9, 3.6107688150643063`*^9, 3.614321286973456*^9, 
   3.614587437975957*^9, 3.61493847791777*^9, 3.615635038283276*^9, 
   3.6162159011367683`*^9, 3.6173373998032*^9, 3.617339556018579*^9, 
   3.618218673684651*^9, 3.61933488845175*^9, 3.619776265582203*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.602489477848835*^9, 3.6024894801326637`*^9}}],

Cell[BoxData[
 FormBox["941", TraditionalForm]], "Output",
 CellChangeTimes->{{3.602489480535823*^9, 3.602489496878828*^9}, 
   3.6024998585997868`*^9, {3.6025830403961487`*^9, 3.60258306118552*^9}, 
   3.6028311040915422`*^9, 3.602832042819055*^9, {3.602832077341649*^9, 
   3.602832097565548*^9}, 3.602832442977532*^9, {3.6028326280096273`*^9, 
   3.602832654876494*^9}, 3.603088222085128*^9, 3.603094358791274*^9, 
   3.604037136030349*^9, 3.6040450172465153`*^9, 3.604052742219326*^9, 
   3.604057190176792*^9, 3.604397699089469*^9, 3.6043979129927387`*^9, 
   3.604398301153709*^9, 3.604398548580864*^9, 3.604398643292802*^9, 
   3.6044010401957283`*^9, 3.6044020291885223`*^9, 3.604402167138582*^9, 
   3.6044033746491203`*^9, 3.6044057813858833`*^9, 3.604649312074669*^9, 
   3.6046532540891037`*^9, 3.604821234274407*^9, 3.604821417776287*^9, 
   3.604827117760045*^9, 3.604901673645392*^9, 3.604997553862059*^9, 
   3.60499788157196*^9, 3.604998044184071*^9, 3.604998307275475*^9, 
   3.604998723339164*^9, 3.6049990642997923`*^9, 3.604999612009611*^9, 
   3.605322268071372*^9, 3.605329292882449*^9, 3.605344919752418*^9, 
   3.60549940149104*^9, 3.605499800894021*^9, 3.605500312314941*^9, 
   3.605501021197448*^9, 3.605517570051125*^9, 3.6055186340865583`*^9, 
   3.606019749424987*^9, 3.6066245486880493`*^9, 3.6072548487356873`*^9, 
   3.607746878520849*^9, 3.6084587115498533`*^9, 3.608461094102623*^9, 
   3.608611401455439*^9, 3.608972288934225*^9, 3.6090391038484707`*^9, 
   3.609065555068145*^9, 3.609130575926858*^9, 3.610078857858259*^9, 
   3.6107688150988903`*^9, 3.614321287231614*^9, 3.614587438027253*^9, 
   3.614938477970602*^9, 3.615635038329302*^9, 3.61621590117528*^9, 
   3.617337399843148*^9, 3.617339556061432*^9, 3.618218673737599*^9, 
   3.619334888500949*^9, 3.619776265611444*^9}]
}, Open  ]],

Cell["\<\
The terms with tu pole should simplify and only result in ordinary poles. In \
fact, s/(tu) = -1/u -1/t.
I therefore isolate the s/(tu) terms in order to express s = -t-u.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tmp2", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Tmp", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Power", "[", 
        RowBox[{"u_", ",", 
         RowBox[{"-", "1"}]}], "]"}], "\[Rule]", 
       RowBox[{"A", " ", 
        RowBox[{"Power", "[", 
         RowBox[{"u", ",", 
          RowBox[{"-", "1"}]}], "]"}]}]}], "}"}]}], ")"}], "//", 
   "Expand"}]}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"4", " ", 
              SuperscriptBox["A", "2"], " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "f"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "e"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SuperscriptBox["s", "3"]}], 
             RowBox[{"t", " ", "u"}]]}], "+", 
           FractionBox[
            RowBox[{"8", " ", "A", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["s", "2"]}], "u"], "+", 
           RowBox[{"\[LeftSkeleton]", "1403", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"32", " ", "A", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "-", 
           FractionBox[
            RowBox[{"16", " ", "A", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"16", " ", "A", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 325, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 325, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 325, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[325]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.602832183243438*^9, 3.602832443527453*^9, {3.6028326305078297`*^9, 
   3.6028326562036753`*^9}, 3.603088222473186*^9, 3.603094359167159*^9, 
   3.60403713650574*^9, 3.6040450175650682`*^9, 3.6040527425254383`*^9, 
   3.604057190582719*^9, 3.604397699415954*^9, 3.6043979133662453`*^9, 
   3.604398301520842*^9, 3.604398548915908*^9, 3.6043986437011833`*^9, 
   3.604401040580311*^9, 3.604402029535049*^9, 3.6044021674452267`*^9, 
   3.604403375063229*^9, 3.6044057818607388`*^9, 3.604649312399194*^9, 
   3.604653254483699*^9, 3.604821234601564*^9, 3.6048214180934553`*^9, 
   3.604827118099963*^9, 3.604901673972945*^9, 3.604997554194932*^9, 
   3.604997881924589*^9, 3.6049980445259323`*^9, 3.60499830762272*^9, 
   3.6049987237052603`*^9, 3.604999064646641*^9, 3.6049996124411488`*^9, 
   3.605322268442294*^9, 3.6053292932893543`*^9, 3.60534492005595*^9, 
   3.605499401860751*^9, 3.605499801264412*^9, 3.605500312681815*^9, 
   3.6055010215598097`*^9, 3.605517570539114*^9, 3.605518634473014*^9, 
   3.606019749798634*^9, 3.606624549054648*^9, 3.60725485518965*^9, 
   3.607746878899577*^9, 3.6084587118631573`*^9, 3.6084610944150553`*^9, 
   3.608611401782803*^9, 3.608972289267598*^9, 3.6090391042234087`*^9, 
   3.609065555442181*^9, 3.609130576419888*^9, 3.61007885830508*^9, 
   3.610768815443409*^9, 3.614321287541422*^9, 3.6145874383696823`*^9, 
   3.6149384783255587`*^9, 3.615635038675704*^9, 3.6162159015119143`*^9, 
   3.617337400181799*^9, 3.617339556402725*^9, 3.6182186740771914`*^9, 
   3.619334888850371*^9, 3.619776265931595*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"TmpSbyTU", "=", 
   RowBox[{
    RowBox[{"Filter", "[", 
     RowBox[{"Tmp2", ",", 
      RowBox[{"A", "^", "2"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"A", "\[Rule]", "1"}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.602831800432754*^9, 3.602831801135433*^9}, {
  3.602831879640533*^9, 3.602831891503158*^9}, {3.602832463604115*^9, 
  3.6028325114535522`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tmp3", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Tmp", "-", "TmpSbyTU"}], ")"}], "+", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"TmpSbyTU", "/.", 
      RowBox[{"{", 
       RowBox[{"s", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "t"}], "-", "u"}]}], "}"}]}], "//", "Expand"}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.602832519810804*^9, 3.602832601093398*^9}, 
   3.602832647446159*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"8", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["s", "2"]}], "u"], "+", 
           FractionBox[
            RowBox[{"8", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["s", "2"]}], "t"], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["s", "2"]}], "t"], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SuperscriptBox["s", "2"]}], "u"], "-", 
           FractionBox[
            RowBox[{"8", " ", "t", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", "s"}], "u"], "+", 
           RowBox[{"\[LeftSkeleton]", "1688", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"32", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "-", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 327, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 327, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 327, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[327]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6028325480490417`*^9, 3.602832605005677*^9, {3.602832643834901*^9, 
   3.602832659752434*^9}, 3.602832721814479*^9, 3.603088223104414*^9, 
   3.603094359601712*^9, 3.604037137413013*^9, 3.604045017933263*^9, 
   3.6040527429660473`*^9, 3.6040571910286694`*^9, 3.604397699977727*^9, 
   3.604397913825467*^9, 3.604398301961626*^9, 3.6043985493395033`*^9, 
   3.604398644160585*^9, 3.604401041020987*^9, 3.60440203004897*^9, 
   3.604402167913496*^9, 3.604403375574319*^9, 3.60440578242616*^9, 
   3.604649312915111*^9, 3.6046532549281187`*^9, 3.604821235125708*^9, 
   3.604821418560278*^9, 3.604827118582827*^9, 3.60490167443769*^9, 
   3.604997554694893*^9, 3.604997882491707*^9, 3.604998045101824*^9, 
   3.6049983081879663`*^9, 3.6049987242583313`*^9, 3.604999065099337*^9, 
   3.6049996130211143`*^9, 3.605322269122774*^9, 3.6053292941220007`*^9, 
   3.605344920461669*^9, 3.605499402265646*^9, 3.605499801683956*^9, 
   3.605500313204636*^9, 3.6055010219718637`*^9, 3.6055175710906754`*^9, 
   3.605518634908239*^9, 3.606019750219757*^9, 3.606624549459083*^9, 
   3.60725486016437*^9, 3.607746879470495*^9, 3.608458712331111*^9, 
   3.608461094937007*^9, 3.608611402277796*^9, 3.608972289896954*^9, 
   3.60903910476871*^9, 3.6090655558797827`*^9, 3.609130576876051*^9, 
   3.610078858907373*^9, 3.610768815983863*^9, 3.614321287964992*^9, 
   3.6145874390947113`*^9, 3.614938478743966*^9, 3.615635039064451*^9, 
   3.6162159018819838`*^9, 3.617337400623753*^9, 3.6173395568213797`*^9, 
   3.618218674468174*^9, 3.619334889244031*^9, 3.619776266331028*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "Tmp3", "]"}]], "Input",
 CellChangeTimes->{{3.602832664748332*^9, 3.602832666704877*^9}}],

Cell[BoxData[
 FormBox["1136", TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJwdzmtIU3EYx/ENIsugCCYGkiyaHFHDol7ILOWxUvMy9JhmqDAOK2QKkoK+
EqLgKCik4A0nomaCMgPvoli6SlMTrQTnpkdnbujjLTfUZaU+f1/8+Lz78b0m
5PDP5DKZLIzG7whvrXMIgt6RlWpGMGrd+jTynO6mibMgSCthhkAyYtGmDSaf
lztKb5HVgjgzRw6V3t1gar0++ZjJgddGNbPMWRzJrDu+njtPZqaNbTGrEuXH
TDF8v9JC6lWzJis5IvgaeStCYYVU85gc7dDVt5D5L/geZkXcz8JWMm9QY58i
47iM3n+kBhOWmNFcs+vUMVHxnzQHlUQzb/ip8phSXWMf83P4u/uGBYT9bzMd
9eQD5eWkFnJ5Kn5kl2zrV7uYIZv+t53k8J/hEuaT6cyGQ1Js0/n9JS1Nk7M7
iwjdV7tU3ksIb36I6zHLCG6Nkwu10U/KxcGqFYSz76XVajI1JP6RjdSv3XtZ
/ov6c3yUnSRf+8rzI5m7rpyQyK+c8L3djnAmX9Z75EAwZcsTv2whpI+vPoza
RvBXW9ud5KUL9snI3wiKgg9Zwi6Cb4CXh+hC0HUZFEXk0/N8yp09hJ4rARnJ
BwjbzbG2IDfCCfqyJw0=
  "]]
}, Open  ]],

Cell["Now compare Tmp3 to amp4!", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6044001159150867`*^9, 3.604400123994227*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tmp3DFT", "=", 
  RowBox[{
   RowBox[{"4", "*", "32", " ", "I", " ", "amp4"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.6044001565740013`*^9, 3.60440015674658*^9}, {
  3.604400190375128*^9, 3.604400236784127*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"8", " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "e"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "f"}]], " ", 
              SuperscriptBox["s", "2"]}], "u"]}], "-", 
           FractionBox[
            RowBox[{"8", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["s", "2"]}], "t"], "-", 
           RowBox[{"16", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "f"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", "s"}], "-", 
           FractionBox[
            RowBox[{"16", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", "s"}], "u"], "-", 
           RowBox[{"16", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "f"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", "s"}], "-", 
           FractionBox[
            RowBox[{"16", " ", 
             RowBox[{"\[LeftSkeleton]", "5", "\[RightSkeleton]"}], " ", "s"}],
             "t"], "-", 
           FractionBox[
            RowBox[{"8", " ", 
             RowBox[{"\[LeftSkeleton]", "5", "\[RightSkeleton]"}], " ", "s"}],
             "u"], "+", 
           RowBox[{"\[LeftSkeleton]", "955", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"32", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"32", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"32", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "-", 
           FractionBox[
            RowBox[{"32", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"32", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 329, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 329, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 329, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[329]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604400157271165*^9, {3.604400193151205*^9, 3.604400239163167*^9}, 
   3.604401041405655*^9, 3.604402030637027*^9, 3.604402168376525*^9, 
   3.604403376044837*^9, 3.604405783018882*^9, 3.604649313184127*^9, 
   3.6046532551858*^9, 3.604821235384408*^9, 3.6048214188166113`*^9, 
   3.6048271188268623`*^9, 3.604901674682095*^9, 3.604997555175864*^9, 
   3.604997882782826*^9, 3.604998045382168*^9, 3.604998308468158*^9, 
   3.604998724610765*^9, 3.604999065389143*^9, 3.604999613311103*^9, 
   3.605322269451358*^9, 3.605329295536338*^9, 3.6053449208056*^9, 
   3.605499402697771*^9, 3.605499802102784*^9, 3.60550031355986*^9, 
   3.6055010222941723`*^9, 3.605517571552001*^9, 3.605518635356152*^9, 
   3.606019750618637*^9, 3.6066245498732157`*^9, 3.607254860436297*^9, 
   3.607746879858161*^9, 3.6084587127605343`*^9, 3.6084610951792173`*^9, 
   3.608611402870966*^9, 3.6089722901805563`*^9, 3.6090391051449966`*^9, 
   3.6090655563645782`*^9, 3.609130577540764*^9, 3.610078859422761*^9, 
   3.610768816245035*^9, 3.614321288493697*^9, 3.614587439420001*^9, 
   3.614938479110772*^9, 3.615635039402916*^9, 3.616215902199003*^9, 
   3.617337400912428*^9, 3.617339557115416*^9, 3.618218674806809*^9, 
   3.619334889578425*^9, 3.619776266602425*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tobezero", "=", 
  RowBox[{
   RowBox[{"Tmp3DFT", "+", "Tmp3"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.6044002171369677`*^9, 3.604400219830037*^9}, {
  3.604658006106982*^9, 3.604658006683517*^9}, {3.604658913052762*^9, 
  3.6046589504650087`*^9}, {3.60466048027032*^9, 3.604660493612916*^9}, {
  3.604723313562499*^9, 3.604723319394353*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"4", " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "c"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "f"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["s", "2"]}], "t"]}], "-", 
           FractionBox[
            RowBox[{"4", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SuperscriptBox["s", "2"]}], "u"], "-", 
           FractionBox[
            RowBox[{"8", " ", "t", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", "s"}], "u"], "+", 
           RowBox[{"8", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "e"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "f"}]], " ", "s"}], "-", 
           RowBox[{"16", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "e"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "h"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"c", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"d", "f"}]], " ", "s"}], "+", 
           RowBox[{"\[LeftSkeleton]", "1952", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"], "+", 
           FractionBox[
            RowBox[{"16", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], "s"]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 330, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 330, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 330, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[330]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6044002207405767`*^9, 3.604400243923607*^9}, 
   3.6044010419446*^9, 3.604402031145831*^9, 3.6044021689535646`*^9, 
   3.604403376521618*^9, 3.604405783664872*^9, 3.604649313661661*^9, 
   3.604653255715115*^9, 3.604658008424943*^9, {3.6046589271535788`*^9, 
   3.6046589521096563`*^9}, {3.604660483439694*^9, 3.604660494843248*^9}, {
   3.6047233155146503`*^9, 3.6047233204321404`*^9}, 3.604821235809903*^9, 
   3.6048214192767076`*^9, 3.604827119714903*^9, 3.604901675226571*^9, 
   3.6049975556562233`*^9, 3.6049978832201242`*^9, 3.604998045818228*^9, 
   3.604998308901457*^9, 3.604998725062295*^9, 3.604999065953761*^9, 
   3.604999613753145*^9, 3.6053222699191*^9, 3.60532929609799*^9, 
   3.6053449213246813`*^9, 3.605499403099762*^9, 3.6054998025070963`*^9, 
   3.6055003139573393`*^9, 3.6055010228316603`*^9, 3.605517571947938*^9, 
   3.605518635751399*^9, 3.606019751021371*^9, 3.6066245502979116`*^9, 
   3.607254866418653*^9, 3.6077468802683067`*^9, 3.6084587133782*^9, 
   3.608461095740036*^9, 3.608611403330346*^9, 3.60897229061168*^9, 
   3.609039105558778*^9, 3.609065556776038*^9, 3.609130577954246*^9, 
   3.610078860035562*^9, 3.610768816665526*^9, 3.614321288960717*^9, 
   3.614587440047928*^9, 3.614938479543086*^9, 3.6156350398070498`*^9, 
   3.616215902608025*^9, 3.617337401321011*^9, 3.6173395575216084`*^9, 
   3.618218675214095*^9, 3.619334889983131*^9, 3.619776267002063*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "tobezero", "]"}]], "Input",
 CellChangeTimes->{{3.604658940402315*^9, 3.604658954809559*^9}, {
  3.6047233228380938`*^9, 3.604723323647357*^9}}],

Cell[BoxData[
 FormBox["1334", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.60465895524784*^9, {3.604660485748288*^9, 3.604660497297381*^9}, 
   3.6047233241720037`*^9, 3.604821235866743*^9, 3.604821419376848*^9, 
   3.604827119733591*^9, 3.604901675242441*^9, 3.604997555683889*^9, 
   3.604997883305023*^9, 3.604998045896076*^9, 3.604998308999255*^9, 
   3.604998725096808*^9, 3.604999065985413*^9, 3.604999613865748*^9, 
   3.6053222700918427`*^9, 3.605329296266992*^9, 3.60534492139638*^9, 
   3.605499403169786*^9, 3.605499802576518*^9, 3.6055003141496563`*^9, 
   3.605501022901599*^9, 3.605517572036187*^9, 3.605518635855646*^9, 
   3.606019751082388*^9, 3.606624550358419*^9, 3.607254866522101*^9, 
   3.607746880484893*^9, 3.608458713496517*^9, 3.608461095804838*^9, 
   3.608611403360179*^9, 3.6089722907003937`*^9, 3.60903910576582*^9, 
   3.609065556869585*^9, 3.609130578059667*^9, 3.6100788601942253`*^9, 
   3.610768816827537*^9, 3.614321289035327*^9, 3.614587440110516*^9, 
   3.614938479602919*^9, 3.6156350398541718`*^9, 3.616215902649456*^9, 
   3.61733740139396*^9, 3.6173395576670218`*^9, 3.6182186752612886`*^9, 
   3.619334890036005*^9, 3.6197762670383*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"s", " ", "t", " ", "u", " ", "tobezero"}], "//", 
               "Expand"}], ")"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"u", "\[Rule]", 
                RowBox[{
                 RowBox[{"-", "s"}], "-", "t"}]}], ",", 
               RowBox[{
                RowBox[{"Pair", "[", 
                 RowBox[{
                  RowBox[{"LorentzIndex", "[", 
                   RowBox[{"g_", ",", "D"}], "]"}], ",", 
                  RowBox[{"Momentum", "[", 
                   RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], 
                 "]"}], "\[Rule]", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"Pair", "[", 
                   RowBox[{
                    RowBox[{"LorentzIndex", "[", 
                    RowBox[{"g", ",", "D"}], "]"}], ",", 
                    RowBox[{"Momentum", "[", 
                    RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], 
                   "]"}]}], "-", 
                 RowBox[{"Pair", "[", 
                  RowBox[{
                   RowBox[{"LorentzIndex", "[", 
                    RowBox[{"g", ",", "D"}], "]"}], ",", 
                   RowBox[{"Momentum", "[", 
                    RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], 
                  "]"}], "-", 
                 RowBox[{"Pair", "[", 
                  RowBox[{
                   RowBox[{"LorentzIndex", "[", 
                    RowBox[{"g", ",", "D"}], "]"}], ",", 
                   RowBox[{"Momentum", "[", 
                    RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], 
                  "]"}]}]}]}], "}"}]}], ")"}], "//", "Expand"}], ")"}], "/.", 
         
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"a", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"b", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"c", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"d", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"f", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"g", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"h", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
            "\[Rule]", "0"}]}], "}"}]}], ")"}], "//", "Expand"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"g_", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"g", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}]}], 
        "-", 
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"g", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], "-", 
        
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"g", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}], 
      "}"}]}], "//", "Expand"}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"a", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"b", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"c", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"d", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"e", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"f", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"g", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"h", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{
         RowBox[{"Subscript", "[", 
          RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
     "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.604721839115077*^9, 3.604721864439934*^9}, {
   3.604721947688211*^9, 3.6047219638933153`*^9}, {3.6047220576587677`*^9, 
   3.604722140960944*^9}, 3.60472220951721*^9, {3.6047222429359283`*^9, 
   3.604722247167376*^9}, {3.604722368527738*^9, 3.604722431287159*^9}, 
   3.604723328899961*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604721843066409*^9, 3.6047219136963043`*^9, 3.604722007275907*^9, {
   3.604722074214037*^9, 3.6047220842345943`*^9}, {3.604722118461603*^9, 
   3.604722122720313*^9}, 3.6047222173107243`*^9, 3.604722259639673*^9, 
   3.604722371510227*^9, {3.604722414368268*^9, 3.604722432705225*^9}, 
   3.604723330290567*^9, 3.604821236122601*^9, 3.6048214197144327`*^9, 
   3.604827120010954*^9, 3.604901675501567*^9, 3.604997555964576*^9, 
   3.604997883574355*^9, 3.604998046190613*^9, 3.604998309270383*^9, 
   3.604998725380465*^9, 3.6049990662722073`*^9, 3.604999614145495*^9, 
   3.6053222704149227`*^9, 3.605329296638733*^9, 3.605344921690584*^9, 
   3.605499403469146*^9, 3.605499802863668*^9, 3.60550031443878*^9, 
   3.605501023184574*^9, 3.6055175723622103`*^9, 3.605518636180503*^9, 
   3.606019751371842*^9, 3.606624550650548*^9, 3.6072548696168423`*^9, 
   3.607746880776371*^9, 3.608458713834564*^9, 3.608461096060933*^9, 
   3.608611403628471*^9, 3.60897229095406*^9, 3.609039106052351*^9, 
   3.609065557180834*^9, 3.6091305785137997`*^9, 3.6100788605621147`*^9, 
   3.610768817158833*^9, 3.614321289328258*^9, 3.614587440378723*^9, 
   3.614938479886559*^9, 3.615635040130632*^9, 3.616215902913631*^9, 
   3.617337401656724*^9, 3.617339557941701*^9, 3.618218675526689*^9, 
   3.619334890307822*^9, 3.619776267281536*^9}]
}, Open  ]],

Cell["\<\
This shows that up to a factor the 4e amplitude is the KLT square.

As a result, 
DFT4[a,b,c,d,e,f,g,h] = (-4*32i)^(-1) s A4partial1234[a,c,e,g] \
A4partial1243[b,d,h,f]\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6044001159150867`*^9, 3.604400123994227*^9}, {3.604720820865553*^9, 
  3.60472083813302*^9}, {3.604722666557773*^9, 3.604722695320043*^9}, {
  3.604723091148676*^9, 3.604723095257025*^9}, {3.604723355577581*^9, 
  3.604723398392375*^9}, {3.604723476921307*^9, 3.604723505440467*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
   3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
   3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
   3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
   3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
   3.6044001159150867`*^9, 3.604400123994227*^9}, {3.604720820865553*^9, 
   3.60472083813302*^9}, {3.604722666557773*^9, 3.604722695320043*^9}, 
   3.604722742418379*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["BCFW", "Section",
 CellChangeTimes->{{3.615613740635314*^9, 3.6156137474815607`*^9}}],

Cell[TextData[{
 "Compute the large z behavior of the 4e and maybe 5e tree-level amplitude in \
D>=4 with shifted legs 1 and 2. See Arkani-Hamed & Kaplan for BCFW in D \
dimensions.\n\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 "=(1,1,0,0;0)\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "2"], TraditionalForm]]],
 "=(1,-1,0,0;0)\nq=(0,0,1,i;0)\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", "1"], "\[Rule]", " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 "+ q z\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["k", "2"], "\[Rule]", " "}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "2"], TraditionalForm]]],
 "- q z\n\nAs a consequence for 4 legs,\ns \[Rule] s\nt \[Rule] t + 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "3"],
     TraditionalForm]}], TraditionalForm]]],
 "\[LineSeparator]u \[Rule] u - 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "3"],
     TraditionalForm]}], TraditionalForm]]],
 "\n\nand for 5 legs,\ns13 \[Rule] s13 + 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "3"],
     TraditionalForm]}], TraditionalForm]]],
 "\[LineSeparator]s14 \[Rule] s14 + 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "4"],
     TraditionalForm]}], TraditionalForm]]],
 "\[LineSeparator]s15 \[Rule] s15 + 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "5"],
     TraditionalForm]}], TraditionalForm]]],
 "\[LineSeparator]s23 \[Rule] s23 - 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "3"],
     TraditionalForm]}], TraditionalForm]]],
 "\[LineSeparator]s24 \[Rule] s24 - 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "4"],
     TraditionalForm]}], TraditionalForm]]],
 "\[LineSeparator]s25 \[Rule] s25 - 2z ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox["q",
     TraditionalForm], "\[CenterDot]", 
    FormBox[
     SubscriptBox["k", "5"],
     TraditionalForm]}], TraditionalForm]]],
 "\nwhile the remaining sij stay invariant."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916397190943`*^9}, {3.6049991470911703`*^9, 3.604999168630431*^9}, {
   3.605002430090581*^9, 3.605002432375244*^9}, {3.6054990759359426`*^9, 
   3.605499119541453*^9}, {3.606206548141368*^9, 3.606206580236333*^9}, {
   3.606468618317026*^9, 3.606468643918107*^9}, {3.60646880065837*^9, 
   3.606468804281342*^9}, {3.6065364445021343`*^9, 3.606536446272204*^9}, {
   3.606536485585737*^9, 3.606536616046195*^9}, {3.6065366704739847`*^9, 
   3.6065368070606613`*^9}, {3.606537067212492*^9, 3.6065370906200037`*^9}, {
   3.606537167479435*^9, 3.606537240236066*^9}, {3.606542119558983*^9, 
   3.6065421215376787`*^9}, {3.606622514956808*^9, 3.606622527981255*^9}, {
   3.606622620870788*^9, 3.606622659728304*^9}, {3.615613907629991*^9, 
   3.61561393231953*^9}, 3.615614112679986*^9, {3.615619111139009*^9, 
   3.615619243869882*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[TextData[{
 "First, consider the configuration ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["1", "--"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "++"], TraditionalForm]]],
 ", i.e. ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["\[Xi]", "1"], "-"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["\[Eta]", "1"], "-"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["\[Xi]", "2"], "+"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["\[Xi]", "2"], "+"], TraditionalForm]]],
 " = q."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSl5i+XwLR914l1f4F0nU6Ig0g
muvZIfH/QJqBiUcCRNt9rp3x8c4rx6nBH+eCaLG2Fi7ve0B1E9r5QLSIqhfj
aSCtlFjLAqLjBEUlQPRBhk4wXSM4Qf4NkH669QSYjtm3SQVE51UxmoLoR1rn
rUH0u4vf40A0AEe6xgs=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell["Large z behavior of the 4 e - amplitude", "Subsection",
 CellChangeTimes->{{3.606623070949353*^9, 3.6066230856226597`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$z$mmpp", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"amp4", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e"}], "]"}], "+", 
          RowBox[{"z", " ", 
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"LorentzIndex", "[", 
              RowBox[{"e", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e"}], "]"}], "-", 
          RowBox[{"z", " ", 
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"LorentzIndex", "[", 
              RowBox[{"e", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
        RowBox[{"t", "\[Rule]", 
         RowBox[{"t", "+", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}], ",", 
        RowBox[{"u", "\[Rule]", 
         RowBox[{"u", "-", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}]}], "}"}]}], "//", "Expand"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"a", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"b", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"c", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"d", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.605518832440103*^9, 3.605518838824432*^9}, {
   3.605518942108616*^9, 3.6055190755445013`*^9}, {3.605519130032498*^9, 
   3.605519229538538*^9}, {3.605519266903171*^9, 3.605519279265428*^9}, {
   3.605521278978298*^9, 3.605521282039877*^9}, {3.6055214377376633`*^9, 
   3.6055214789967318`*^9}, {3.605601715242527*^9, 3.6056017163688374`*^9}, {
   3.606206015895928*^9, 3.606206027654336*^9}, {3.60620608216938*^9, 
   3.6062061123008757`*^9}, {3.6064515791196527`*^9, 3.606451584456105*^9}, 
   3.6064516306095047`*^9, 3.606451666383642*^9, {3.6064684143537827`*^9, 
   3.606468416705646*^9}, {3.60653697912342*^9, 3.606536989009515*^9}, {
   3.6065373399063787`*^9, 3.606537340826557*^9}, {3.615614138536968*^9, 
   3.6156141732480288`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["z", "4"]}], 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"u", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "2613", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", 
             RowBox[{"(", 
              RowBox[{"t", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 333, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 333, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 333, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[333]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.605499127784284*^9, {3.605499499768858*^9, 3.605499521122451*^9}, 
   3.605499880760569*^9, 3.605500146042132*^9, 3.605500391374309*^9, 
   3.6055008404842*^9, 3.605517648747908*^9, 3.605518708993024*^9, 
   3.605518839224848*^9, {3.6055190715952044`*^9, 3.6055190763518353`*^9}, {
   3.605519252584773*^9, 3.605519280908113*^9}, 3.605521284156405*^9, 
   3.6055214805603533`*^9, 3.605521550597382*^9, 3.6056017179528*^9, 
   3.606019821454564*^9, 3.606206029315586*^9, 3.606206113856176*^9, 
   3.606451585599312*^9, 3.606451631933923*^9, 3.606451668293376*^9, 
   3.60646841750804*^9, 3.606537429297098*^9, 3.606624621943368*^9, 
   3.607254937109928*^9, 3.6077469532203503`*^9, 3.608458788303104*^9, 
   3.608461173341996*^9, 3.608611481612417*^9, 3.608972363593336*^9, 
   3.609039178356984*^9, 3.6090656310096903`*^9, 3.609130654937583*^9, 
   3.610078938252344*^9, 3.610768889487989*^9, 3.614321363920392*^9, 
   3.6156141871616297`*^9, 3.61563504104077*^9, 3.616215903767048*^9, 
   3.617337402481125*^9, 3.61733955877734*^9, 3.61821867639994*^9, 
   3.619334891170177*^9, 3.6197762680933857`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$z$mmpp", "]"}]], "Input",
 CellChangeTimes->{{3.605519283977066*^9, 3.605519285452222*^9}, 
   3.606537461260193*^9}],

Cell[BoxData[
 FormBox["1722", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.60551928578334*^9, 3.6055212865430803`*^9, 3.605601719997121*^9, 
   3.606019821616028*^9, 3.606206030557598*^9, 3.606206115312195*^9, 
   3.606451586941437*^9, 3.6064516337407618`*^9, 3.606451669721508*^9, 
   3.606468420842093*^9, {3.606537437318708*^9, 3.606537461747727*^9}, 
   3.60662462208832*^9, 3.6072549372065353`*^9, 3.6077469533591213`*^9, 
   3.6084587884278*^9, 3.608461173623581*^9, 3.608611481968874*^9, 
   3.608972363628648*^9, 3.6090391785731897`*^9, 3.609065631211616*^9, 
   3.609130655195355*^9, 3.610078938479043*^9, 3.610768889609758*^9, 
   3.614321364188517*^9, 3.615614189510194*^9, 3.615635041087044*^9, 
   3.6162159038068113`*^9, 3.61733740257205*^9, 3.6173395588293333`*^9, 
   3.618218676436249*^9, 3.619334891222603*^9, 3.6197762681387997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$z$mmppTaylor", "=", 
  RowBox[{"Series", "[", 
   RowBox[{"amp4$z$mmpp", ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.606546492996372*^9, 3.606546505342925*^9}, {
   3.606546555117437*^9, 3.606546569965184*^9}, {3.606546629966028*^9, 
   3.6065466428149242`*^9}, 3.606550172775178*^9, {3.615614201249423*^9, 
   3.615614201270501*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          InterpretationBox[
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              FractionBox["1", 
               RowBox[{"8", " ", "s", " ", 
                SuperscriptBox[
                 FormBox[
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}],
                  TraditionalForm], "2"]}]], 
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"a", "c"}]], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"b", "d"}]], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"e", "g"}]], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"f", "h"}]], " ", 
                  SuperscriptBox[
                   FormBox[
                    RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}],
                    TraditionalForm], "4"]}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["g", 
                   RowBox[{"a", "c"}]], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"b", "d"}]], " ", 
                  SubsuperscriptBox["k", 
                   FormBox["4",
                    TraditionalForm], 
                   FormBox[
                    FormBox["e",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"f", "h"}]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["g",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox[
                   FormBox[
                    RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}],
                    TraditionalForm], "3"]}], "+", 
                 RowBox[{"\[LeftSkeleton]", "60", "\[RightSkeleton]"}], "+", 
                 RowBox[{"s", " ", "t", " ", 
                  SuperscriptBox["g", 
                   RowBox[{"a", "c"}]], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"b", "d"}]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["e",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["f",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["g",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}], "+", 
                 RowBox[{"s", " ", "u", " ", 
                  SuperscriptBox["g", 
                   RowBox[{"a", "c"}]], " ", 
                  SuperscriptBox["g", 
                   RowBox[{"b", "d"}]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["e",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["f",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["g",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}], " ", 
               SuperscriptBox["z", "2"]}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"b", "d"}]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["f",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["g",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["h",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox["t", "2"]}], 
                RowBox[{"16", " ", 
                 SuperscriptBox[
                  FormBox[
                   RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}],
                   TraditionalForm], "3"]}]], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"b", "d"}]], " ", 
                 SubsuperscriptBox["k", 
                  FormBox["4",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"f", "h"}]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["g",
                    TraditionalForm],
                   TraditionalForm]], " ", "t"}], 
                RowBox[{"8", " ", "s"}]], "-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 RowBox[{"\[LeftSkeleton]", "5", "\[RightSkeleton]"}], " ", 
                 "t"}], 
                RowBox[{"8", " ", "s"}]], "+", 
               RowBox[{"\[LeftSkeleton]", "638", "\[RightSkeleton]"}]}], 
              ")"}], " ", "z"}], "+", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"b", "d"}]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["g",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["h",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox["t", "3"]}], 
                RowBox[{"32", " ", 
                 SuperscriptBox[
                  FormBox[
                   RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}],
                   TraditionalForm], "4"]}]]}], "+", 
              RowBox[{"\[LeftSkeleton]", "1818", "\[RightSkeleton]"}]}], 
             ")"}], "+", 
            FractionBox[
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "z"], "+", 
            
            FractionBox[
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
             SuperscriptBox["z", "2"]], "+", 
            InterpretationBox[
             RowBox[{"O", "(", 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["1", "z"], ")"}], "3"], ")"}],
             SeriesData[$CellContext`z, 
              DirectedInfinity[1], {}, -2, 3, 1],
             Editable->False]}],
           SeriesData[$CellContext`z, 
            DirectedInfinity[1], {((Complex[0, 
                 Rational[-1, 8]]/$CellContext`s) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]]^(-2)) ((((((($CellContext`s $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]] + (((((($CellContext`s $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((($CellContext`s 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] - (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] - (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], 
                 D]] + (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + (((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]] + ((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], 
                   D]]^2 + ((((((2 $CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], 
                   D]]^2 - ((((((4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]]^2 + ((((((4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], 
                   D]]^2 + ((((((4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], 
                   D]]^2 - ((((((4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]]^2 - (((((4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]]^3 + (((((4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]^3 - (((((4 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], 
                  D]]^3 + (((((4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]^3 - ((((4 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^4), ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]], ((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]] + ((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`s) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`s) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`s) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`s) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + (((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + (((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 16]]/$CellContext`s) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 16]]/$CellContext`s) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]), (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[1, 32]] $CellContext`s^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]), (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^5) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-6) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^5) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-6) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s^2) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u^2) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s^2) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2)}, -2, 3, 1],
           Editable->False],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 335, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 335, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 335, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[335]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.606546513957818*^9, {3.6065465622492743`*^9, 3.606546574605774*^9}, 
   3.606546647710121*^9, 3.60655017919709*^9, 3.6066246284098186`*^9, 
   3.607254944188587*^9, 3.6077469597510147`*^9, 3.608458795236019*^9, 
   3.608461180156686*^9, 3.6086114883143597`*^9, 3.6089723698736677`*^9, 
   3.609039185626062*^9, 3.609065637712225*^9, 3.609130661548965*^9, 
   3.610078944946905*^9, 3.610768895964142*^9, 3.614321371648365*^9, 
   3.6156142267871103`*^9, 3.6156350480757513`*^9, 3.6162159106541243`*^9, 
   3.617337410161463*^9, 3.617339565319139*^9, 3.61821868280381*^9, 
   3.619334898063553*^9, 3.6197762749598827`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$z$mmppTaylor2", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{"amp4$z$mmppTaylor", " ", 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "a"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "b"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "c"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "d"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", 
      RowBox[{"-", 
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.60654938353685*^9, 3.6065493952257967`*^9}, {
   3.606549625775077*^9, 3.606549633495448*^9}, {3.6065497511286383`*^9, 
   3.606549768507415*^9}, 3.606550855946451*^9, {3.606625452303081*^9, 
   3.6066254583002234`*^9}, {3.606625629221081*^9, 3.6066256609721746`*^9}, {
   3.615614237143352*^9, 3.615614238908536*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}]}], ")"}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["f",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["g",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["h",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["t", "3"]}], 
         RowBox[{"64", " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}],
            TraditionalForm], "2"]}]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["t", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["t", "2"]}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["s", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "3"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["s", "2"], " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]]}], ")"}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 1], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]], 0, ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`t^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`u^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`t^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`u^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
              Rational[-1, 64]] $CellContext`s^2) $CellContext`t) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`t^3) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-1, 64]] $CellContext`s^2) $CellContext`u) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-3, 64]] $CellContext`t^2) $CellContext`u) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-3, 64]] $CellContext`t) $CellContext`u^2) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`u^3) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + (((Complex[0, 
           Rational[-1, 8]] $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2 + (((Complex[0, 
           Rational[-1, 8]] $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2}, 0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.60654948772508*^9, 3.606549727679193*^9, 
  3.6065498612219067`*^9, 3.606550321880106*^9, 3.606624769197317*^9, 
  3.606625599171094*^9, 3.606625802011674*^9, 3.60725508530651*^9, 
  3.607747102134832*^9, 3.60845893318286*^9, 3.608461323542688*^9, 
  3.6086116296102943`*^9, 3.608972507172509*^9, 3.609039324311421*^9, 
  3.609065778603098*^9, 3.609130802020351*^9, 3.610079090215581*^9, 
  3.610769035097612*^9, 3.614321514982201*^9, 3.615614392727537*^9, 
  3.6156351880551434`*^9, 3.61621605047607*^9, 3.6173375494097013`*^9, 
  3.617339706305476*^9, 3.6182188207105722`*^9, 3.619335036287731*^9, 
  3.619776492436224*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"amp4$z$mmppTaylor2", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"kc", "[", 
             RowBox[{"2", ",", "e"}], "]"}]}], "-", 
           RowBox[{"kc", "[", 
            RowBox[{"3", ",", "e"}], "]"}], "-", 
           RowBox[{"kc", "[", 
            RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], ")"}], "//", 
      "Simplify"}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{"u", "\[Rule]", 
    RowBox[{
     RowBox[{"-", "s"}], "-", "t"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6065499474936543`*^9, 3.606550150672154*^9}, {
  3.606550394143621*^9, 3.6065504106545553`*^9}, {3.615614274987946*^9, 
  3.615614373813449*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"64", " ", 
       SuperscriptBox["z", "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}],
         TraditionalForm], "2"]}]], 
     RowBox[{"\[ImaginaryI]", " ", "s", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "s", " ", 
                  SubsuperscriptBox["k", 
                   FormBox["3",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["s", "2"], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["k", 
                   FormBox["3",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}], "+", 
                 RowBox[{"2", " ", "s", " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", "s", " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["g", 
                RowBox[{"f", "h"}]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}]}], "+", 
           RowBox[{
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["e",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["g", 
                RowBox[{"f", "h"}]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["k", 
                 FormBox["3",
                  TraditionalForm], 
                 FormBox[
                  FormBox["h",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], "-", 
              RowBox[{"2", " ", "s", " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
    
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 2, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {((Complex[0, 
         Rational[1, 64]] $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2)) (((2 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) (
         HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]])) ((2 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) ((2 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 4], D]]) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] (((-2) $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] - (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]])) + 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] (((-HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) ((2 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 4], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
              
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
               D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]])) ((2 $CellContext`s) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] + (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]]) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] (((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]]) ((2 $CellContext`s) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] + (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) + 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] ((2 $CellContext`s^2) HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] + ((4 $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]))))}, 2, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{{3.606549952015603*^9, 3.606549975402624*^9}, {
   3.606550030764595*^9, 3.606550066264703*^9}, {3.606550109622099*^9, 
   3.606550151482682*^9}, 3.606550322424789*^9, 3.606550411154688*^9, 
   3.606624824284771*^9, 3.606625972012343*^9, 3.607255086100483*^9, 
   3.607747103293592*^9, 3.6084589340091877`*^9, 3.608461324705229*^9, 
   3.608611630344266*^9, 3.6089725080442133`*^9, 3.609039325099739*^9, 
   3.609065779389412*^9, 3.6091308028537807`*^9, 3.6100790910565357`*^9, 
   3.610769035905163*^9, 3.614321515856081*^9, 3.6156145683552227`*^9, 
   3.615635188536058*^9, 3.6162160511605864`*^9, 3.617337549869976*^9, 
   3.617339706753903*^9, 3.618218821397338*^9, 3.619335036730619*^9, 
   3.619776492866786*^9}]
}, Open  ]],

Cell[TextData[{
 "So, for these polarizations one obtains ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", 
    SuperscriptBox["z", "2"]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSl5i+XwLR914l1f4F0nU6Ig0g
muvZIfH/QJqBiUcCRNt9rp3x8c4rx6nBH+eCaLG2Fi7ve0B1E9r5QLSIqhfj
aSCtlFjLAqLfX7XlANEfEi15QfTHiA2fPgHpF35mX0B0z3H/CzYfXjmmvGwB
0wC8Cb77
  "],
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Open  ]],

Cell["Recursion for the 4e-amplitude TODO", "Subsection",
 CellChangeTimes->{{3.606622987665683*^9, 3.606623003694757*^9}, {
   3.606631630422117*^9, 3.606631632981657*^9}, 3.607324400656323*^9, {
   3.6171811525867567`*^9, 3.6171811531828527`*^9}}],

Cell[CellGroupData[{

Cell["Large z behavior of the 5 e - amplitude", "Subsection",
 CellChangeTimes->{{3.606623070949353*^9, 3.6066230856226597`*^9}, 
   3.6156146440941257`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"amp5e", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e"}], "]"}], "+", 
          RowBox[{"z", " ", 
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"LorentzIndex", "[", 
              RowBox[{"e", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e"}], "]"}], "-", 
          RowBox[{"z", " ", 
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"LorentzIndex", "[", 
              RowBox[{"e", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
        RowBox[{"s13", "\[Rule]", 
         RowBox[{"s13", "+", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}], ",", 
        RowBox[{"s14", "\[Rule]", 
         RowBox[{"s14", "+", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}], ",", 
        RowBox[{"s15", "\[Rule]", 
         RowBox[{"s15", "+", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}], ",", 
        RowBox[{"s23", "\[Rule]", 
         RowBox[{"s23", "-", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}], ",", 
        RowBox[{"s24", "\[Rule]", 
         RowBox[{"s24", "-", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}], ",", 
        RowBox[{"s25", "\[Rule]", 
         RowBox[{"s25", "-", 
          RowBox[{"2", "z", " ", 
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{
                 RowBox[{"Subscript", "[", 
                  RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm]}]}]}]}], "}"}]}], "//", "Expand"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"a", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"b", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"c", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"d", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.605518832440103*^9, 3.605518838824432*^9}, {
   3.605518942108616*^9, 3.6055190755445013`*^9}, {3.605519130032498*^9, 
   3.605519229538538*^9}, {3.605519266903171*^9, 3.605519279265428*^9}, {
   3.605521278978298*^9, 3.605521282039877*^9}, {3.6055214377376633`*^9, 
   3.6055214789967318`*^9}, {3.605601715242527*^9, 3.6056017163688374`*^9}, {
   3.606206015895928*^9, 3.606206027654336*^9}, {3.60620608216938*^9, 
   3.6062061123008757`*^9}, {3.6064515791196527`*^9, 3.606451584456105*^9}, 
   3.6064516306095047`*^9, 3.606451666383642*^9, {3.6064684143537827`*^9, 
   3.606468416705646*^9}, {3.60653697912342*^9, 3.606536989009515*^9}, {
   3.6065373399063787`*^9, 3.606537340826557*^9}, {3.615614138536968*^9, 
   3.6156141732480288`*^9}, {3.61561469191893*^9, 3.615614694283124*^9}, {
   3.6156171121877813`*^9, 3.615617285385393*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["z", "6"]}], 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"s13", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"s24", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["z", "6"]}], 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"s23", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"s14", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "692927", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{"s24", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"s15", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "5"],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{"s24", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"s15", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "5"],
                  TraditionalForm]}]}]}], ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 338, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 338, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 338, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[338]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615714410799288*^9, 3.616216364048943*^9, 
  3.617337861813511*^9, 3.617340021611576*^9, 3.6182191326584806`*^9, 
  3.619335344272195*^9, 3.619776805450904*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp", "]"}]], "Input",
 CellChangeTimes->{{3.605519283977066*^9, 3.605519285452222*^9}, 
   3.606537461260193*^9, 3.615617345345344*^9}],

Cell[BoxData[
 FormBox["462741", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.60551928578334*^9, 3.6055212865430803`*^9, 3.605601719997121*^9, 
   3.606019821616028*^9, 3.606206030557598*^9, 3.606206115312195*^9, 
   3.606451586941437*^9, 3.6064516337407618`*^9, 3.606451669721508*^9, 
   3.606468420842093*^9, {3.606537437318708*^9, 3.606537461747727*^9}, 
   3.60662462208832*^9, 3.6072549372065353`*^9, 3.6077469533591213`*^9, 
   3.6084587884278*^9, 3.608461173623581*^9, 3.608611481968874*^9, 
   3.608972363628648*^9, 3.6090391785731897`*^9, 3.609065631211616*^9, 
   3.609130655195355*^9, 3.610078938479043*^9, 3.610768889609758*^9, 
   3.614321364188517*^9, 3.615614189510194*^9, 3.615617621563086*^9, 
   3.6156355163587227`*^9, 3.615714412415655*^9, 3.616216365499817*^9, 
   3.617337863325012*^9, 3.6173400230667562`*^9, 3.618219134119195*^9, 
   3.619335345661426*^9, 3.619776806951392*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2", "=", 
  RowBox[{"amp5$z$mmpp", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"d", "[", 
        RowBox[{"a", ",", "c"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"d", "[", 
        RowBox[{"b", ",", "d"}], "]"}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6156179904547586`*^9, 3.615618013541847*^9}, {
  3.6156180758746433`*^9, 3.6156180816418962`*^9}, {3.6156194782160807`*^9, 
  3.615619528290913*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "4"],
                TraditionalForm]}], " ", 
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "5"],
                TraditionalForm]}], " ", 
              SuperscriptBox["z", "4"]}], 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{"s13", "+", 
                RowBox[{"2", " ", "z", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"s24", "-", 
                RowBox[{"2", " ", "z", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "4"],
                   TraditionalForm]}]}]}], ")"}]}]]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "4"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}], " ", 
             SuperscriptBox["z", "4"]}], 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{"s13", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"s24", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "356051", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{"s24", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"s15", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "5"],
                  TraditionalForm]}]}]}], ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 340, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 340, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 340, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[340]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615618300359589*^9, 3.6156197280583267`*^9, 
  3.6156356751302443`*^9, 3.615714723459832*^9, 3.616216524581295*^9, 
  3.617338021988009*^9, 3.617340181711701*^9, 3.61821929030048*^9, 
  3.619335500838769*^9, 3.6197769645951443`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2", "]"}]], "Input",
 CellChangeTimes->{{3.615618089704596*^9, 3.615618098090302*^9}}],

Cell[BoxData[
 FormBox["237840", TraditionalForm]], "Output",
 CellChangeTimes->{3.615618301676352*^9, 3.6156197324305058`*^9, 
  3.615635675947692*^9, 3.615714724318047*^9, 3.6162165254111433`*^9, 
  3.617338022801261*^9, 3.61734018247729*^9, 3.618219291116777*^9, 
  3.6193355016104517`*^9, 3.6197769654340143`*^9}]
}, Open  ]],

Cell["\<\
Note that it takes very long to evaluate the following expression:
amp5$z$mmppTaylor = Series[amp5$z$mmpp2, {z, \[Infinity], 2}]

So, let\[CloseCurlyQuote]s just do a numerical check:\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSl5i+XwLR914l1f4F0nU6Ig0g
muvZIfH/QJqBiUcCRNt9rp3x8c4rx6nBH+eCaLG2Fi7ve0B1E9r5QLSIqhfj
aSCtlFjLAqLjBEUlQPRBhk4wXSM4Qf4NkH669QSYjtm3SQVE51UxmoLoR1rn
rUH0u4vf40C0wiauxbkfgOZ/n74ORAMA7zrO4Q==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large z behavior of the 5 e - amplitude numerically", "Subsection",
 CellChangeTimes->{{3.612085834165001*^9, 3.612085844526819*^9}, {
  3.612086484467353*^9, 3.612086497855007*^9}, {3.614577753311775*^9, 
  3.61457775350277*^9}, {3.615623168643466*^9, 3.615623182194241*^9}}],

Cell["First need 5 light-like momenta adding up to zero.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}, {3.6120866065182667`*^9, 3.612086606758206*^9}, {
   3.612505924058659*^9, 3.612505936532402*^9}, {3.612684208346747*^9, 
   3.6126842128136387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}, {3.612086612732903*^9, 
   3.612086614349341*^9}, {3.612505939428406*^9, 3.6125059543631077`*^9}, {
   3.61268421467281*^9, 3.612684221598008*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{"k31", ",", "k32", ",", "k33", ",", "k34", ",", "k35"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9, {
   3.61208661791853*^9, 3.612086618148158*^9}, {3.612086936652397*^9, 
   3.612086944450577*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k4", "=", 
   RowBox[{"{", 
    RowBox[{"k41", ",", "k42", ",", "k43", ",", "k44", ",", "k45"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}, {3.612086632200843*^9, 3.612086646982294*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k5", "=", 
   RowBox[{"{", 
    RowBox[{"k51", ",", "k52", ",", "k53", ",", "k54", ",", "k55"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.612086654555016*^9, 3.6120866647448187`*^9}, {
  3.61208681096835*^9, 3.612086816309435*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "5", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "5", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.612086707631708*^9, 3.612086713887814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kinsys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k5", ",", "k5"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4", "+", "k5"}], "\[Equal]", 
      "0"}]}], "}"}]}], ";", 
  RowBox[{"kinsys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612258217072095*^9, 3.612258219089881*^9}, {
  3.612258263321577*^9, 3.612258271721939*^9}, {3.612505966669755*^9, 
  3.612505985721085*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k31", "2"]}], "+", 
         SuperscriptBox["k32", "2"], "+", 
         SuperscriptBox["k33", "2"], "+", 
         SuperscriptBox["k34", "2"], "+", 
         SuperscriptBox["k35", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k41", "2"]}], "+", 
         SuperscriptBox["k42", "2"], "+", 
         SuperscriptBox["k43", "2"], "+", 
         SuperscriptBox["k44", "2"], "+", 
         SuperscriptBox["k45", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k51", "2"]}], "+", 
         SuperscriptBox["k52", "2"], "+", 
         SuperscriptBox["k53", "2"], "+", 
         SuperscriptBox["k54", "2"], "+", 
         SuperscriptBox["k55", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"k31", "+", "k41", "+", "k51", "+", "2"}], ",", 
          RowBox[{"k32", "+", "k42", "+", "k52"}], ",", 
          RowBox[{"k33", "+", "k43", "+", "k53"}], ",", 
          RowBox[{"k34", "+", "k44", "+", "k54"}], ",", 
          RowBox[{"k35", "+", "k45", "+", "k55"}]}], "}"}], "\[LongEqual]", 
        "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612258223332856*^9, 3.612258277667809*^9, 3.612505994584982*^9, 
   3.6126800091197*^9, 3.6126842296073713`*^9, 3.614415251319221*^9, 
   3.614416681331402*^9, 3.614506889916788*^9, 3.6145783531107807`*^9, 
   3.61493838358314*^9, 3.61562431172897*^9, 3.615635676008398*^9, {
   3.615798577931674*^9, 3.61579860597112*^9}, 3.615800023917783*^9, 
   3.61621652563382*^9, 3.617340182579949*^9, 3.618219291218733*^9, 
   3.619335501721211*^9, 3.619776965537855*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"FindInstance", "[", 
   RowBox[{"kinsys", ",", 
    RowBox[{"Join", "[", 
     RowBox[{"k4", ",", "k5", ",", "k3"}], "]"}], ",", "5"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.612086667146719*^9, 3.612086669789753*^9}, {
   3.61208672018432*^9, 3.6120867609601393`*^9}, {3.612086820399687*^9, 
   3.61208684701149*^9}, {3.6120868882347116`*^9, 3.612086911234775*^9}, {
   3.612086947214334*^9, 3.612086966920597*^9}, {3.612087130200302*^9, 
   3.612087138062559*^9}, {3.612257132872628*^9, 3.6122571670798407`*^9}, 
   3.612257397692018*^9, {3.61225751058984*^9, 3.612257511578771*^9}, {
   3.6122576055168962`*^9, 3.612257613202684*^9}, 3.612257694530752*^9, {
   3.612258060499379*^9, 3.612258062723226*^9}, {3.612258192623537*^9, 
   3.612258193411767*^9}, 3.612258282749514*^9, {3.6125060012757797`*^9, 
   3.612506003735097*^9}, {3.612680017069385*^9, 3.6126800172139387`*^9}, 
   3.612684254591062*^9, 3.6145769005945463`*^9, 3.614576952464837*^9, {
   3.6145770875853148`*^9, 3.614577088568757*^9}, 3.61579856434335*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k41", "\[Rule]", 
       RowBox[{
        FractionBox["1223", "10"], "-", 
        FractionBox[
         RowBox[{"223", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{"k42", "\[Rule]", 
       RowBox[{
        FractionBox["1223", "10"], "-", 
        FractionBox[
         RowBox[{"223", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{"k43", "\[Rule]", "0"}], ",", 
      RowBox[{"k44", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19", "5"]}], "+", "\[ImaginaryI]"}]}], ",", 
      RowBox[{"k45", "\[Rule]", 
       RowBox[{"1", "+", 
        FractionBox[
         RowBox[{"19", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k51", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3", "10"]}], "-", 
        FractionBox[
         RowBox[{"3", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k52", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["21", "5"]}], "+", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k53", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["31", "10"]}], "+", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k54", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1909269456076961", "18998985299620"]}], "+", 
        FractionBox[
         RowBox[{"2900477770481427", " ", "\[ImaginaryI]"}], 
         "37997970599240"]}]}], ",", 
      RowBox[{"k55", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2901743431785683", "37997970599240"]}], "-", 
        FractionBox[
         RowBox[{"1911367423473617", " ", "\[ImaginaryI]"}], 
         "18998985299620"]}]}], ",", 
      RowBox[{"k31", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "124"}], "+", 
        FractionBox[
         RowBox[{"1121", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k32", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1181", "10"]}], "+", 
        FractionBox[
         RowBox[{"1111", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k33", "\[Rule]", 
       RowBox[{
        FractionBox["31", "10"], "-", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k34", "\[Rule]", 
       RowBox[{
        FractionBox["1981465600215517", "18998985299620"], "-", 
        FractionBox[
         RowBox[{"2938475741080667", " ", "\[ImaginaryI]"}], 
         "37997970599240"]}]}], ",", 
      RowBox[{"k35", "\[Rule]", 
       RowBox[{
        FractionBox["2863745461186443", "37997970599240"], "+", 
        FractionBox[
         RowBox[{"1839171279335061", " ", "\[ImaginaryI]"}], 
         "18998985299620"]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k41", "\[Rule]", "0"}], ",", 
      RowBox[{"k42", "\[Rule]", "0"}], ",", 
      RowBox[{"k43", "\[Rule]", "0"}], ",", 
      RowBox[{"k44", "\[Rule]", 
       RowBox[{
        FractionBox["393", "5"], "-", 
        FractionBox[
         RowBox[{"524", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k45", "\[Rule]", 
       RowBox[{
        FractionBox["524", "5"], "+", 
        FractionBox[
         RowBox[{"393", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k51", "\[Rule]", 
       RowBox[{
        FractionBox["31", "10"], "-", 
        FractionBox[
         RowBox[{"21", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k52", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["14", "5"]}], "+", 
        FractionBox["\[ImaginaryI]", "10"]}]}], ",", 
      RowBox[{"k53", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["39", "10"]}], "-", 
        FractionBox[
         RowBox[{"9", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k54", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8613383323", "45129500"]}], "-", 
        FractionBox[
         RowBox[{"7128091521", " ", "\[ImaginaryI]"}], "45129500"]}]}], ",", 
      RowBox[{"k55", "\[Rule]", 
       RowBox[{
        FractionBox["7128615161", "45129500"], "-", 
        FractionBox[
         RowBox[{"8617393303", " ", "\[ImaginaryI]"}], "45129500"]}]}], ",", 
      RowBox[{"k31", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["51", "10"]}], "+", 
        FractionBox[
         RowBox[{"21", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k32", "\[Rule]", 
       RowBox[{
        FractionBox["14", "5"], "-", 
        FractionBox["\[ImaginaryI]", "10"]}]}], ",", 
      RowBox[{"k33", "\[Rule]", 
       RowBox[{
        FractionBox["39", "10"], "+", 
        FractionBox[
         RowBox[{"9", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k34", "\[Rule]", 
       RowBox[{
        FractionBox["5066204623", "45129500"], "+", 
        FractionBox[
         RowBox[{"11857663121", " ", "\[ImaginaryI]"}], "45129500"]}]}], ",", 
      
      RowBox[{"k35", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11858186761", "45129500"]}], "+", 
        FractionBox[
         RowBox[{"5070214603", " ", "\[ImaginaryI]"}], "45129500"]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k41", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["249", "2"]}], "-", 
        RowBox[{"104", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{"k42", "\[Rule]", 
       RowBox[{
        FractionBox["249", "2"], "+", 
        RowBox[{"104", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{"k43", "\[Rule]", "0"}], ",", 
      RowBox[{"k44", "\[Rule]", 
       RowBox[{
        FractionBox["22", "5"], "-", 
        FractionBox[
         RowBox[{"17", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k45", "\[Rule]", 
       RowBox[{
        FractionBox["17", "10"], "+", 
        FractionBox[
         RowBox[{"22", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k51", "\[Rule]", 
       RowBox[{
        FractionBox["21", "5"], "+", 
        FractionBox[
         RowBox[{"43", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k52", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3219431", "526325"]}], "-", 
        FractionBox[
         RowBox[{"4526831", " ", "\[ImaginaryI]"}], "1052650"]}]}], ",", 
      RowBox[{"k53", "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         SqrtBox[
          RowBox[{
           RowBox[{"-", "5477151542902"}], "-", 
           RowBox[{"4567929689986", " ", "\[ImaginaryI]"}]}]], "526325"]}]}], 
      ",", 
      RowBox[{"k54", "\[Rule]", 
       RowBox[{"3", "+", 
        FractionBox["\[ImaginaryI]", "5"]}]}], ",", 
      RowBox[{"k55", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], "+", 
        RowBox[{"3", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{"k31", "\[Rule]", 
       RowBox[{
        FractionBox["1183", "10"], "+", 
        FractionBox[
         RowBox[{"997", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k32", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["124616063", "1052650"]}], "-", 
        FractionBox[
         RowBox[{"104948769", " ", "\[ImaginaryI]"}], "1052650"]}]}], ",", 
      RowBox[{"k33", "\[Rule]", 
       FractionBox[
        SqrtBox[
         RowBox[{
          RowBox[{"-", "5477151542902"}], "-", 
          RowBox[{"4567929689986", " ", "\[ImaginaryI]"}]}]], "526325"]}], 
      ",", 
      RowBox[{"k34", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["37", "5"]}], "+", 
        FractionBox[
         RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{"k35", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3", "2"]}], "-", 
        FractionBox[
         RowBox[{"37", " ", "\[ImaginaryI]"}], "5"]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k41", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["376", "5"]}], "+", 
        FractionBox[
         RowBox[{"609", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k42", "\[Rule]", 
       RowBox[{
        FractionBox["669", "10"], "-", 
        FractionBox[
         RowBox[{"68", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k43", "\[Rule]", 
       RowBox[{
        FractionBox["241", "10"], "-", 
        FractionBox[
         RowBox[{"207", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k44", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["124837", "2"]}], "-", 
          FractionBox[
           RowBox[{"317097", " ", "\[ImaginaryI]"}], "2"]}]]}]}], ",", 
      RowBox[{"k45", "\[Rule]", "0"}], ",", 
      RowBox[{"k51", "\[Rule]", 
       RowBox[{
        FractionBox["9", "2"], "-", 
        FractionBox[
         RowBox[{"17", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k52", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        FractionBox[
         RowBox[{"11", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k53", "\[Rule]", 
       RowBox[{
        FractionBox["9", "10"], "+", 
        FractionBox[
         RowBox[{"11", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k54", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["11305759089", "1161347839780"], "+", 
          FractionBox[
           RowBox[{"2114832055", " ", "\[ImaginaryI]"}], "232269567956"]}], 
         ")"}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["124837", "2"]}], "-", 
          FractionBox[
           RowBox[{"317097", " ", "\[ImaginaryI]"}], "2"]}]]}]}], ",", 
      RowBox[{"k55", "\[Rule]", 
       RowBox[{
        FractionBox["1", "20"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["436808469413555", "58067391989"]}], "-", 
          FractionBox[
           RowBox[{"195407141908737", " ", "\[ImaginaryI]"}], 
           "58067391989"]}]]}]}], ",", 
      RowBox[{"k31", "\[Rule]", 
       RowBox[{
        FractionBox["687", "10"], "-", 
        FractionBox[
         RowBox[{"115", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{"k32", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["639", "10"]}], "+", 
        FractionBox[
         RowBox[{"57", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k33", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "25"}], "+", 
        FractionBox[
         RowBox[{"37", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{"k34", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["220963808867", "1161347839780"], "-", 
          FractionBox[
           RowBox[{"2114832055", " ", "\[ImaginaryI]"}], "232269567956"]}], 
         ")"}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["124837", "2"]}], "-", 
          FractionBox[
           RowBox[{"317097", " ", "\[ImaginaryI]"}], "2"]}]]}]}], ",", 
      RowBox[{"k35", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "20"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["436808469413555", "58067391989"]}], "-", 
          FractionBox[
           RowBox[{"195407141908737", " ", "\[ImaginaryI]"}], 
           "58067391989"]}]]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k41", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["607", "5"]}], "-", 
        FractionBox[
         RowBox[{"389", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k42", "\[Rule]", 
       RowBox[{
        FractionBox["47", "2"], "+", 
        FractionBox[
         RowBox[{"231", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k43", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["491", "10"]}], "+", 
        FractionBox[
         RowBox[{"417", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k44", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["706751", "2"], "+", 
          FractionBox[
           RowBox[{"568423", " ", "\[ImaginaryI]"}], "2"]}]]}]}], ",", 
      RowBox[{"k45", "\[Rule]", "0"}], ",", 
      RowBox[{"k51", "\[Rule]", 
       RowBox[{
        FractionBox["33", "10"], "-", 
        FractionBox[
         RowBox[{"11", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k52", "\[Rule]", 
       RowBox[{
        FractionBox["17", "5"], "+", 
        FractionBox[
         RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k53", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], "-", 
        FractionBox[
         RowBox[{"3", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k54", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["16810284864", "2056504207325"], "-", 
          FractionBox[
           RowBox[{"9429530829", " ", "\[ImaginaryI]"}], "4113008414650"]}], 
         ")"}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["706751", "2"], "+", 
          FractionBox[
           RowBox[{"568423", " ", "\[ImaginaryI]"}], "2"]}]]}]}], ",", 
      RowBox[{"k55", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["2632880163550753", "822601682930"]}], "-", 
          FractionBox[
           RowBox[{"1710336172819541", " ", "\[ImaginaryI]"}], 
           "822601682930"]}]]}]}], ",", 
      RowBox[{"k31", "\[Rule]", 
       RowBox[{
        FractionBox["1161", "10"], "+", 
        RowBox[{"40", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{"k32", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["269", "10"]}], "-", 
        FractionBox[
         RowBox[{"238", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k33", "\[Rule]", 
       RowBox[{
        FractionBox["489", "10"], "-", 
        FractionBox[
         RowBox[{"411", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k34", "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["394490556601", "2056504207325"], "+", 
          FractionBox[
           RowBox[{"9429530829", " ", "\[ImaginaryI]"}], "4113008414650"]}], 
         ")"}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["706751", "2"], "+", 
          FractionBox[
           RowBox[{"568423", " ", "\[ImaginaryI]"}], "2"]}]]}]}], ",", 
      RowBox[{"k35", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["2632880163550753", "822601682930"]}], "-", 
          FractionBox[
           RowBox[{"1710336172819541", " ", "\[ImaginaryI]"}], 
           "822601682930"]}]]}]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.612086762118141*^9, 3.612086780893147*^9}, {
   3.612086823214789*^9, 3.612086847939478*^9}, {3.61208688888518*^9, 
   3.612086911822865*^9}, {3.612086954278853*^9, 3.612086967359386*^9}, {
   3.612087131307373*^9, 3.6120871383511143`*^9}, 3.612257142281363*^9, 
   3.612257394237977*^9, {3.6122575076936417`*^9, 3.612257512163836*^9}, {
   3.6122576069012537`*^9, 3.612257627804504*^9}, {3.612257690411792*^9, 
   3.612257695104991*^9}, 3.612258189484466*^9, 3.61225822195914*^9, 
   3.612258276336063*^9, 3.612259320778799*^9, 3.612511330729707*^9, 
   3.6126803950144*^9, {3.6126842499610157`*^9, 3.612684258655238*^9}, 
   3.6144152518055267`*^9, 3.614416681520438*^9, 3.6145068908943377`*^9, 
   3.614576906819211*^9, 3.614576960270529*^9, 3.614577089264464*^9, 
   3.6145783532449417`*^9, 3.614938384517983*^9, 3.615624316465996*^9, 
   3.615635676146047*^9, 3.615714899232999*^9, {3.6157149809002657`*^9, 
   3.6157150015675077`*^9}, {3.615798562408133*^9, 3.615798619684338*^9}, 
   3.6158000346049633`*^9, 3.616216536691675*^9, 3.6173401935663557`*^9, 
   3.618219301804929*^9, 3.6193355122629633`*^9, 3.619776976100923*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$no", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.615798680984138*^9, 3.615798683466194*^9}, 
   3.61579874759733*^9, 3.615798948451993*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k3", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086972550753*^9, 3.612086977276445*^9}, 
   3.615798688516718*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "124"}], "+", 
     FractionBox[
      RowBox[{"1121", " ", "\[ImaginaryI]"}], "10"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1181", "10"]}], "+", 
     FractionBox[
      RowBox[{"1111", " ", "\[ImaginaryI]"}], "10"]}], ",", 
    RowBox[{
     FractionBox["31", "10"], "-", 
     FractionBox[
      RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}], ",", 
    RowBox[{
     FractionBox["1981465600215517", "18998985299620"], "-", 
     FractionBox[
      RowBox[{"2938475741080667", " ", "\[ImaginaryI]"}], "37997970599240"]}],
     ",", 
    RowBox[{
     FractionBox["2863745461186443", "37997970599240"], "+", 
     FractionBox[
      RowBox[{"1839171279335061", " ", "\[ImaginaryI]"}], 
      "18998985299620"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086977587695*^9, 3.6122575146527653`*^9, 
  3.612257696324094*^9, 3.612684263546081*^9, 3.6144152519329348`*^9, 
  3.6144166815767603`*^9, 3.614506890949765*^9, 3.614578353276498*^9, 
  3.614938384565001*^9, 3.615624317595804*^9, 3.615635676185246*^9, 
  3.615714903166751*^9, 3.615714984383153*^9, 3.615798635246705*^9, 
  3.615798720768486*^9, 3.6157987611768208`*^9, 3.6158000347992277`*^9, 
  3.616216536765512*^9, 3.61734019362176*^9, 3.618219301868989*^9, 
  3.6193355123287907`*^9, 3.6197769761615953`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k3", ",", "k3"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122571125898314`*^9, 3.612257119072855*^9}, {
   3.612257544299827*^9, 3.612257553190195*^9}, 3.615798689776154*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6122571193226643`*^9, 3.612257515599658*^9, {3.612257545928628*^9, 
   3.612257553598151*^9}, 3.612257697150077*^9, 3.612684265607835*^9, 
   3.6144152519576693`*^9, 3.614416681638151*^9, 3.614506890967968*^9, 
   3.61457835328469*^9, 3.614938384605798*^9, 3.615624318827939*^9, 
   3.615635676209746*^9, 3.61579863884573*^9, 3.6157987208171177`*^9, 
   3.615798762847046*^9, 3.615800034888626*^9, 3.616216536814268*^9, 
   3.6173401936645*^9, 3.618219301909808*^9, 3.619335512378003*^9, 
   3.619776976211055*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086983780642*^9, 3.6157986923499823`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FractionBox["1223", "10"], "-", 
     FractionBox[
      RowBox[{"223", " ", "\[ImaginaryI]"}], "2"]}], ",", 
    RowBox[{
     FractionBox["1223", "10"], "-", 
     FractionBox[
      RowBox[{"223", " ", "\[ImaginaryI]"}], "2"]}], ",", "0", ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["19", "5"]}], "+", "\[ImaginaryI]"}], ",", 
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"19", " ", "\[ImaginaryI]"}], "5"]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.612086984684704*^9, 3.612257555469883*^9, 
  3.612257697740192*^9, 3.612684268914393*^9, 3.614415251973494*^9, 
  3.6144166816980267`*^9, 3.614506890983892*^9, 3.614578353290989*^9, 
  3.614938384647709*^9, 3.615624320144247*^9, 3.615635676237996*^9, 
  3.615798640672124*^9, 3.615798720856826*^9, 3.615798764406435*^9, 
  3.615800034945108*^9, 3.616216536859838*^9, 3.617340193696859*^9, 
  3.61821930195021*^9, 3.6193355124276867`*^9, 3.619776976253058*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k4", ",", "k4"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122575625202703`*^9, 3.612257564202305*^9}, 
   3.615798693774818*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.612257565498811*^9, 3.612257698283271*^9, 
  3.6126842714539623`*^9, 3.614415251992217*^9, 3.614416681767228*^9, 
  3.614506890999983*^9, 3.614578353295656*^9, 3.614938384652294*^9, 
  3.615624320795045*^9, 3.615635676265464*^9, 3.615798642279669*^9, 
  3.615798720905188*^9, 3.61579876644022*^9, 3.6158000349978943`*^9, 
  3.616216536905274*^9, 3.617340193729363*^9, 3.618219301991873*^9, 
  3.6193355124783907`*^9, 3.619776976294647*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k5", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086990045686*^9, 3.615798695781567*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", "10"]}], "-", 
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]"}], "5"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["21", "5"]}], "+", 
     FractionBox[
      RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["31", "10"]}], "+", 
     FractionBox[
      RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1909269456076961", "18998985299620"]}], "+", 
     FractionBox[
      RowBox[{"2900477770481427", " ", "\[ImaginaryI]"}], "37997970599240"]}],
     ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["2901743431785683", "37997970599240"]}], "-", 
     FractionBox[
      RowBox[{"1911367423473617", " ", "\[ImaginaryI]"}], 
      "18998985299620"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086990222755*^9, 3.6122575687096653`*^9, 
  3.612257698824397*^9, 3.612684273014686*^9, 3.614415252134819*^9, 
  3.614416681770714*^9, 3.614506891071704*^9, 3.614578353321383*^9, 
  3.61493838465629*^9, 3.6156243216428223`*^9, 3.61563567627129*^9, 
  3.615798643751333*^9, 3.615798720954322*^9, 3.61579876781393*^9, 
  3.615800035048827*^9, 3.6162165369427557`*^9, 3.617340193758995*^9, 
  3.6182193020333853`*^9, 3.619335512520899*^9, 3.6197769763360786`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k5", ",", "k5"}], "]"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6122575845569344`*^9, 3.6122575890669613`*^9}, 
   3.615798697245968*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612257586141511*^9, 3.612257589348277*^9}, 
   3.612257699452682*^9, 3.612684274587776*^9, 3.614415252266694*^9, 
   3.614416681774804*^9, 3.614506891089264*^9, 3.614578353329406*^9, 
   3.614938384660136*^9, 3.615624322877493*^9, 3.615635676278453*^9, 
   3.615798645823174*^9, 3.6157987210290003`*^9, 3.615798770502593*^9, 
   3.615800035102331*^9, 3.616216536947743*^9, 3.617340193792037*^9, 
   3.61821930207483*^9, 3.619335512528142*^9, 3.619776976377133*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4", "+", "k5"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612684288172793*^9, 3.612684297213119*^9}, 
   3.61579869835133*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6126842976505404`*^9, 3.614415252283523*^9, 
  3.6144166818314037`*^9, 3.6145068911103773`*^9, 3.614578353334805*^9, 
  3.614938384700522*^9, 3.615624324172194*^9, 3.615635676284897*^9, 
  3.615798647947219*^9, 3.615798721034935*^9, 3.615798772562004*^9, 
  3.6158000351104317`*^9, 3.6162165369525127`*^9, 3.617340193824555*^9, 
  3.618219302081665*^9, 3.619335512533704*^9, 3.619776976383993*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s12", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
     RowBox[{"s13", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"s14", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s15", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s23", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"s24", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s25", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s34", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k3", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s35", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k3", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s45", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k4", ",", "k5"}], "]"}]}]}]}], "}"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.612087426835834*^9, 3.612087432664119*^9}, {
   3.612258338518701*^9, 3.612258339672268*^9}, 3.6145769704085627`*^9, 
   3.614577080572277*^9, 3.6157987021008253`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s12", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"s13", "\[Rule]", 
     RowBox[{
      FractionBox["59", "5"], "-", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}]}], ",", 
    RowBox[{"s14", "\[Rule]", "0"}], ",", 
    RowBox[{"s15", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["39", "5"]}], "+", 
      RowBox[{"2", " ", "\[ImaginaryI]"}]}]}], ",", 
    RowBox[{"s23", "\[Rule]", 
     RowBox[{
      FractionBox["2421", "5"], "-", 
      FractionBox[
       RowBox[{"2232", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{"s24", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2446", "5"]}], "+", 
      RowBox[{"446", " ", "\[ImaginaryI]"}]}]}], ",", 
    RowBox[{"s25", "\[Rule]", 
     RowBox[{"9", "+", 
      FractionBox[
       RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{"s34", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["14", "5"]}], "+", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{"s35", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2466", "5"]}], "+", 
      RowBox[{"446", " ", "\[ImaginaryI]"}]}]}], ",", 
    RowBox[{"s45", "\[Rule]", 
     RowBox[{"492", "-", 
      FractionBox[
       RowBox[{"2242", " ", "\[ImaginaryI]"}], "5"]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612087439480166*^9, 3.612257591558383*^9, 3.612257700130177*^9, 
   3.612258340118903*^9, 3.6126842783468533`*^9, 3.614415252427136*^9, 
   3.614416681890109*^9, 3.6145068911892233`*^9, {3.6145769429963827`*^9, 
   3.614576970611363*^9}, 3.614578353362673*^9, 3.614938384741045*^9, 
   3.615624325553817*^9, 3.6156356763107758`*^9, 3.615715071574896*^9, 
   3.615798650257248*^9, 3.615798721087057*^9, 3.615798774323966*^9, 
   3.615800035162051*^9, 3.616216536995253*^9, 3.617340193859067*^9, 
   3.618219302123373*^9, 3.6193355125783157`*^9, 3.619776976427829*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2", ",", "s14"}], "]"}]], "Input",
 CellChangeTimes->{{3.615800320033999*^9, 3.6158003233091593`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "4"],
                TraditionalForm]}], " ", 
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "5"],
                TraditionalForm]}], " ", 
              SuperscriptBox["z", "4"]}], 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{"s23", "-", 
                RowBox[{"2", " ", "z", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"s14", "+", 
                RowBox[{"2", " ", "z", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "4"],
                   TraditionalForm]}]}]}], ")"}]}]]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "4"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "5"],
               TraditionalForm]}], " ", 
             SuperscriptBox["z", "4"]}], 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{"s23", "-", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"s14", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], " ", 
             SuperscriptBox["z", "4"]}], 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], 
             " ", 
             RowBox[{"(", 
              RowBox[{"s14", "+", 
               RowBox[{"2", " ", "z", " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                  TraditionalForm]}]}]}], ")"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "209983", "\[RightSkeleton]"}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 359, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 359, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 359, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[359]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615800472750038*^9, 3.616216632776938*^9, 
  3.6173402909267797`*^9, 3.618219396354212*^9, 3.6193356060840063`*^9, 
  3.619777070748849*^9}]
}, Open  ]],

Cell[TextData[{
 "This is to check that the kinematical configuration is not singular (i.e. \
all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "ij"], "\[NotEqual]", "0"}], TraditionalForm]]],
 ").\nHm, actually, in the shifted case s14=0 is not a problem."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EH2j6eHM6R9eOVp4Gc8G0QAyR9ap
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"qq", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "I", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.615623303917725*^9, 3.615623330906939*^9}, {
   3.61570290803546*^9, 3.615702922246525*^9}, 3.615703470805991*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"min", "[", 
     RowBox[{"qq", ",", "k3"}], "]"}], ",", 
    RowBox[{"min", "[", 
     RowBox[{"qq", ",", "k4"}], "]"}], ",", 
    RowBox[{"min", "[", 
     RowBox[{"qq", ",", "k5"}], "]"}]}], "}"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.615623471130151*^9, 3.615623476975369*^9}, 
   3.615624340977724*^9, 3.6157985526575413`*^9, 3.615798737914085*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FractionBox["3056269449938311", "37997970599240"], "+", 
     FractionBox[
      RowBox[{"1920668847256733", " ", "\[ImaginaryI]"}], "18998985299620"]}],
     ",", 
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     FractionBox[
      RowBox[{"19", " ", "\[ImaginaryI]"}], "5"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["3018271479339071", "37997970599240"]}], "-", 
     FractionBox[
      RowBox[{"1848472703118177", " ", "\[ImaginaryI]"}], 
      "18998985299620"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624329018611*^9, 3.6156243416104803`*^9}, 
   3.615635676343768*^9, {3.615702911175829*^9, 3.615702924549855*^9}, 
   3.615703495183576*^9, 3.615715077269908*^9, 3.615798553699625*^9, 
   3.615798738854541*^9, 3.61579878421391*^9, 3.615800035217153*^9, 
   3.6162166328700237`*^9, 3.617340291026952*^9, 3.618219396465646*^9, 
   3.619335606163478*^9, 3.6197770709160633`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num", "=", 
  RowBox[{"amp5$z$mmpp2", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         TagBox[
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True],
          FullForm], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "k3"}], "]"}]}], ",", 
        RowBox[{
         TagBox[
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True],
          FullForm], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "k4"}], "]"}]}], ",", 
        RowBox[{
         TagBox[
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True],
          FullForm], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "k5"}], "]"}]}], ",", 
        RowBox[{"s12", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
        RowBox[{"s13", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
        RowBox[{"s14", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s15", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s23", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k3"}], "]"}]}]}], ",", 
        RowBox[{"s24", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s25", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s34", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k3", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s35", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k3", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s45", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k4", ",", "k5"}], "]"}]}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.615623383571273*^9, 3.6156234563012867`*^9}, {
   3.6156235808796053`*^9, 3.615623609292816*^9}, 3.6157989554900703`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox["392911321961783", "3937613533600"], "+", 
               FractionBox[
                RowBox[{"285754431719147", " ", "\[ImaginaryI]"}], 
                "3937613533600"]}], ")"}], " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "j"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["z", "4"]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FractionBox["2421", "5"], "-", 
                 FractionBox[
                  RowBox[{"2232", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["3056269449938311", "18998985299620"], "+", 
                  FractionBox[
                   RowBox[{"1920668847256733", " ", "\[ImaginaryI]"}], 
                   "9499492649810"]}], ")"}], " ", "z"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}]}]], 
           "+", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "237796", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox["95", "12352"], "+", 
               FractionBox[
                RowBox[{"25", " ", "\[ImaginaryI]"}], "12352"]}], ")"}], " ", 
             
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
             SubsuperscriptBox["k", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FractionBox["2421", "5"], "-", 
                 FractionBox[
                  RowBox[{"2232", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  FractionBox[
                   RowBox[{"3056", 
                    RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], 
                    "38311"}], 
                   RowBox[{"1899", 
                    RowBox[{"\[LeftSkeleton]", "5", "\[RightSkeleton]"}], 
                    "99620"}]], "+", 
                  RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
                 ")"}], " ", "z"}]}], ")"}], " ", "z"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 362, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 362, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 362, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[362]], TraditionalForm]], "Output",
 CellChangeTimes->{3.61562445074515*^9, 3.6156357664992456`*^9, 
  3.6157030176769238`*^9, 3.6157035859262047`*^9, 3.615715244470035*^9, 
  3.615798921759355*^9, 3.6158001563954678`*^9, 3.616216757508*^9, 
  3.617340412641317*^9, 3.618219516487382*^9, 3.619335726027597*^9, 
  3.6197771939248037`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num", "]"}]], "Input",
 CellChangeTimes->{3.61562362092029*^9}],

Cell[BoxData[
 FormBox["158632", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624451455695*^9, 3.615624455847414*^9}, 
   3.615635767054327*^9, 3.6157030181587954`*^9, 3.615703586408149*^9, 
   3.615715244956808*^9, 3.61579893814222*^9, 3.6158001569662037`*^9, 
   3.616216758111229*^9, 3.617340413251438*^9, 3.6182195170696898`*^9, 
   3.619335726587821*^9, 3.619777194531172*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num2", "=", 
  RowBox[{"amp5$z$mmpp2$num", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"a", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156236533620043`*^9, 3.615623667065372*^9}, 
   3.615623964675109*^9, {3.615624006954833*^9, 3.615624027647028*^9}, {
   3.615624087172872*^9, 3.615624088159317*^9}, {3.6156241190861597`*^9, 
   3.615624125409356*^9}, {3.615624198795361*^9, 3.615624201828332*^9}, 
   3.615798960736607*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"\[LeftSkeleton]", "171946", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox["95", "12352"], "+", 
               FractionBox[
                RowBox[{"25", " ", "\[ImaginaryI]"}], "12352"]}], ")"}], " ", 
             
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FractionBox["2421", "5"], "-", 
                 FractionBox[
                  RowBox[{"2232", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  FractionBox[
                   RowBox[{"3056", 
                    RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], 
                    "38311"}], 
                   RowBox[{"1899", 
                    RowBox[{"\[LeftSkeleton]", "5", "\[RightSkeleton]"}], 
                    "99620"}]], "+", 
                  FractionBox[
                   RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                   RowBox[{"\[LeftSkeleton]", "13", "\[RightSkeleton]"}]]}], 
                 ")"}], " ", "z"}]}], ")"}], " ", "z"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 364, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 364, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 364, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[364]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624524822287*^9, 3.615635825188743*^9, 
  3.615703212665555*^9, 3.615703644259124*^9, 3.615715307094092*^9, 
  3.615799046847789*^9, 3.615800243768445*^9, 3.6162168457526407`*^9, 
  3.617340504838088*^9, 3.618219600481159*^9, 3.619335809771578*^9, 
  3.619777280504983*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num2", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}}],

Cell[BoxData[
 FormBox["114708", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.615635825574172*^9, 
  3.6157032130112*^9, 3.61570364459976*^9, 3.615715322272828*^9, 
  3.6157990472899723`*^9, 3.615800244211302*^9, 3.6162168462236*^9, 
  3.6173405053151608`*^9, 3.618219600940942*^9, 3.619335810208082*^9, 
  3.619777280966893*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num2", ",", "a"}], "]"}]], "Input",
 CellChangeTimes->{{3.615624565703869*^9, 3.615624569575453*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.6156245727994537`*^9, 3.615635828192638*^9, 
  3.615703215682513*^9, 3.615703647248221*^9, 3.6157153274977493`*^9, 
  3.615799050481134*^9, 3.615800247474074*^9, 3.616216849365727*^9, 
  3.617340508777391*^9, 3.618219604088037*^9, 3.619335813259811*^9, 
  3.6197772840564938`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num3", "=", 
  RowBox[{"amp5$z$mmpp2$num2", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "b"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "b"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "b"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"b", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156236533620043`*^9, 3.615623667065372*^9}, 
   3.615623964675109*^9, {3.615624006954833*^9, 3.615624027647028*^9}, {
   3.615624087172872*^9, 3.615624088159317*^9}, {3.6156241190861597`*^9, 
   3.615624125409356*^9}, {3.615624198795361*^9, 3.615624201828332*^9}, {
   3.61562454107201*^9, 3.615624564116488*^9}, {3.615703940060794*^9, 
   3.615703978423517*^9}, {3.6157040618305397`*^9, 3.615704062332144*^9}, {
   3.615704146155052*^9, 3.615704171990994*^9}, 3.615798970941*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"\[LeftSkeleton]", "121136", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"\[LeftSkeleton]", "6", "\[RightSkeleton]"}], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], 
             " ", "z"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 367, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 367, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 367, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[367]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624524822287*^9, 3.6156246507027807`*^9, 
  3.615635866017243*^9, 3.615703255987712*^9, 3.615703685325079*^9, 
  3.615704034261116*^9, 3.615704111620109*^9, 3.615715447336382*^9, 
  3.6157991099220552`*^9, 3.615800307993691*^9, 3.616216909404701*^9, 
  3.617340572502771*^9, 3.618219662550748*^9, 3.6193358713656483`*^9, 
  3.619777344282549*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num3", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}, 
   3.615624608643198*^9}],

Cell[BoxData[
 FormBox["80899", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.6156246512033567`*^9, 
  3.6156358662995872`*^9, 3.6157032562378197`*^9, 3.615703685572926*^9, 
  3.615704034651869*^9, 3.615715447584009*^9, 3.6157991102380333`*^9, 
  3.615800308331847*^9, 3.6162169097476788`*^9, 3.617340572927125*^9, 
  3.6182196629027967`*^9, 3.619335871711544*^9, 3.619777344587372*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num3", ",", "b"}], "]"}]], "Input",
 CellChangeTimes->{3.615624660157823*^9, 3.615624796242927*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624773917117*^9, 3.6156247985276413`*^9}, 
   3.615635868077186*^9, 3.615703258052052*^9, 3.615703687408482*^9, 
   3.615704037020315*^9, 3.6157154494077787`*^9, 3.615799112541849*^9, 
   3.6158003106686153`*^9, 3.616216912191258*^9, 3.6173405755165787`*^9, 
   3.6182196653287773`*^9, 3.619335873928482*^9, 3.619777346863538*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num4", "=", 
  RowBox[{"amp5$z$mmpp2$num3", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "c"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "c"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"c", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156248388300047`*^9, 3.615624874140313*^9}, 
   3.615625074766121*^9, 3.615798981116146*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                
                FractionBox["2825614441853975546315227535153", 
                 "721922884830353722344288800"], "+", 
                FractionBox[
                 RowBox[{
                 "4767003721655203365251276882079", " ", "\[ImaginaryI]"}], 
                 "5775383078642829778754310400"]}], ")"}], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              RowBox[{"\[LeftSkeleton]", "4", "\[RightSkeleton]"}], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["z", "4"]}], 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["2421", "5"], "-", 
                  FractionBox[
                   RowBox[{"2232", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   FractionBox["3056269449938311", "18998985299620"], "+", 
                   FractionBox[
                    RowBox[{"1920668847256733", " ", "\[ImaginaryI]"}], 
                    "9499492649810"]}], ")"}], " ", "z"}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
               ")"}]}]]}], "-", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], 
                " ", "z"}], "-", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], ")"}], 
             " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "75548", "\[RightSkeleton]"}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 370, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 370, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 370, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[370]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624908669083*^9, 3.61562510095078*^9, 
  3.615635889473156*^9, 3.615703279497604*^9, 3.615703708690095*^9, 
  3.61571547970577*^9, 3.615799149207375*^9, 3.6158003480815163`*^9, 
  3.616216949931622*^9, 3.617340615622695*^9, 3.618219702595252*^9, 
  3.619335910583363*^9, 3.619777384353984*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num4", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}, 
   3.615624608643198*^9, 3.615624886389485*^9}],

Cell[BoxData[
 FormBox["50477", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.6156246512033567`*^9, 
  3.615625101319693*^9, 3.615635889684332*^9, 3.615703279661849*^9, 
  3.6157037088586884`*^9, 3.615715486462612*^9, 3.615800348307939*^9, 
  3.616216950184484*^9, 3.617340615879044*^9, 3.6182197028392067`*^9, 
  3.619335910821583*^9, 3.6197773846051083`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num4", ",", "c"}], "]"}]], "Input",
 CellChangeTimes->{
  3.615624660157823*^9, 3.615624796242927*^9, {3.6156248883423367`*^9, 
   3.615624890587727*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624773917117*^9, 3.6156247985276413`*^9}, 
   3.6156251027236013`*^9, 3.615635890732575*^9, 3.615703280725604*^9, 
   3.615703709915077*^9, 3.615715489649579*^9, 3.615800349947158*^9, 
   3.616216951632543*^9, 3.617340617480427*^9, 3.618219704374794*^9, 
   3.619335912288989*^9, 3.619777386109316*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num5", "=", 
  RowBox[{"amp5$z$mmpp2$num4", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "d"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "d"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "d"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"d", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156248388300047`*^9, 3.615624874140313*^9}, {
   3.615624961781053*^9, 3.615624980220827*^9}, 3.6156250692152863`*^9, 
   3.6157989908758717`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               
               FractionBox["155825406752121443560734872099", 
                "299242646561804651748928000"], "+", 
               FractionBox[
                RowBox[{
                "2247464704774398481259759892643", " ", "\[ImaginaryI]"}], 
                "299242646561804651748928000"]}], ")"}], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"h", "j"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["z", "3"]}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox["3018271479339071", "18998985299620"]}], "-", 
                  FractionBox[
                   RowBox[{"1848472703118177", " ", "\[ImaginaryI]"}], 
                   "9499492649810"]}], ")"}], " ", "z"}], "-", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox["39", "5"], "-", 
                 RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  FractionBox[
                   RowBox[{"38", " ", "\[ImaginaryI]"}], "5"]}], ")"}], " ", 
                "z"}], "-", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox["2446", "5"], "-", 
                 RowBox[{"446", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]], 
           "-", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], 
             " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "44984", "\[RightSkeleton]"}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 373, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 373, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 373, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[373]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624908669083*^9, 3.615625025823633*^9, 
  3.6156251146557407`*^9, 3.615635902099453*^9, 3.61570329214148*^9, 
  3.6157037212914877`*^9, 3.615715518632037*^9, 3.6157991717269783`*^9, 
  3.6158003724386253`*^9, 3.61621697375142*^9, 3.61734064114645*^9, 
  3.618219727014265*^9, 3.6193359340754347`*^9, 3.6197774093182707`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num5", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}, 
   3.615624608643198*^9, 3.615624886389485*^9, 3.61562496480656*^9}],

Cell[BoxData[
 FormBox["30141", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.6156246512033567`*^9, 
  3.615625026238781*^9, 3.615625114863566*^9, 3.615635902235846*^9, 
  3.615703298063677*^9, 3.6157037213978233`*^9, 3.615715535019311*^9, 
  3.615799171874514*^9, 3.6158003725829144`*^9, 3.61621697392715*^9, 
  3.617340641347406*^9, 3.618219727202375*^9, 3.61933593424666*^9, 
  3.619777409487067*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num5", ",", "d"}], "]"}]], "Input",
 CellChangeTimes->{
  3.615624660157823*^9, 3.615624796242927*^9, {3.6156248883423367`*^9, 
   3.615624890587727*^9}, 3.615624966065217*^9, 3.615625011157996*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624773917117*^9, 3.6156247985276413`*^9}, 
   3.61562504272051*^9, 3.615625115663059*^9, 3.6156359028281527`*^9, 
   3.6157033002361383`*^9, 3.6157037219816437`*^9, 3.6157155374627447`*^9, 
   3.615799172990296*^9, 3.6158003735239887`*^9, 3.616216974810655*^9, 
   3.61734064234149*^9, 3.618219728184999*^9, 3.619335935149701*^9, 
   3.619777410458192*^9}]
}, Open  ]],

Cell["Need more polarization vectors...", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EC3EbWLg9OGVo9fmtWAaAA8H1DY=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{"xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4", ",", "xiz5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9, {3.612166418225318*^9, 
   3.6121664207438507`*^9}, 3.615625616359418*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi4", "=", 
   RowBox[{"{", 
    RowBox[{"xiu1", ",", "xiu2", ",", "xiu3", ",", "xiu4", ",", "xiu5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.6040433145245943`*^9, 
   3.604043314748054*^9}, {3.6040433534274893`*^9, 3.604043369394578*^9}, 
   3.60404350847479*^9, {3.61216642588039*^9, 3.612166429007922*^9}, 
   3.615625616361087*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi5", "=", 
   RowBox[{"{", 
    RowBox[{"xiv1", ",", "xiv2", ",", "xiv3", ",", "xiv4", ",", "xiv5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.612166469609943*^9, 3.612166482375815*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{"etz1", ",", "etz2", ",", "etz3", ",", "etz4", ",", "etz5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9, {3.612166449248323*^9, 
   3.6121664509560738`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et4", "=", 
   RowBox[{"{", 
    RowBox[{"etu1", ",", "etu2", ",", "etu3", ",", "etu4", ",", "etu5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.604043392149412*^9, 
   3.604043392255167*^9}, {3.6040434286448727`*^9, 3.604043435995811*^9}, 
   3.604043520033565*^9, {3.612166453399662*^9, 3.6121664555841017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et5", "=", 
   RowBox[{"{", 
    RowBox[{"etv1", ",", "etv2", ",", "etv3", ",", "etv4", ",", "etv5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6121664949676847`*^9, 3.6121665077213697`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "xi4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "et4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "xi5"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "et5"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     
     RowBox[{"sols", "[", 
      RowBox[{"[", "sols$no", "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.61216653422339*^9, 3.612166556960194*^9}, {
   3.612166600729034*^9, 3.6121666133164167`*^9}, {3.612258455793024*^9, 
   3.612258468175284*^9}, 3.6156256381986628`*^9, 3.615799070695634*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2101479960", "+", 
            RowBox[{"6168790556", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiz1"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2156665884", "+", 
            RowBox[{"5942112796", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiz2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"66769884", "+", 
            RowBox[{"160350152", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiz3"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1160517524", "+", 
            RowBox[{"4926972213", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiz4"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4628469477", "-", 
            RowBox[{"1205605092", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiz5"}]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2101479960", "+", 
            RowBox[{"6168790556", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etz1"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2156665884", "+", 
            RowBox[{"5942112796", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etz2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"66769884", "+", 
            RowBox[{"160350152", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etz3"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1160517524", "+", 
            RowBox[{"4926972213", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etz4"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4628469477", "-", 
            RowBox[{"1205605092", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etz5"}]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "54"}], "+", 
            RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiu1"}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"54", "-", 
            RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiu2"}], 
         "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"14", "-", 
            RowBox[{"24", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiu4"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"24", "+", 
            RowBox[{"14", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiu5"}]}], 
        "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "54"}], "+", 
            RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etu1"}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"54", "-", 
            RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etu2"}], 
         "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"14", "-", 
            RowBox[{"24", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etu4"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"24", "+", 
            RowBox[{"14", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etu5"}]}], 
        "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"26110308", "-", 
            RowBox[{"1488384", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiv1"}],
          "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"50451512", "-", 
            RowBox[{"156554144", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiv2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"66769884", "+", 
            RowBox[{"160350152", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiv3"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1183316492", "+", 
            RowBox[{"4775487053", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiv4"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4779954637", "-", 
            RowBox[{"1182806124", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "xiv5"}]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"26110308", "-", 
            RowBox[{"1488384", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etv1"}],
          "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"50451512", "-", 
            RowBox[{"156554144", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etv2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"66769884", "+", 
            RowBox[{"160350152", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etv3"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1183316492", "+", 
            RowBox[{"4775487053", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etv4"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4779954637", "-", 
            RowBox[{"1182806124", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etv5"}]}], "\[LongEqual]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166557730864*^9, 3.612166613587278*^9, 3.612257786626362*^9, {
   3.612258449865247*^9, 3.6122584694730263`*^9}, 3.612684401222273*^9, 
   3.6144153037766237`*^9, 3.614416733198262*^9, 3.614506942881184*^9, 
   3.6145770516151667`*^9, 3.614578403574582*^9, 3.6149384370663424`*^9, 
   3.615625645137738*^9, 3.615635902921464*^9, 3.61570372215546*^9, 
   3.6157155590397253`*^9, 3.615799182121047*^9, 3.615800373632674*^9, 
   3.616216975121376*^9, 3.617340642677696*^9, 3.61821972847199*^9, 
   3.619335935457631*^9, 3.619777410765703*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "=", 
   RowBox[{
    RowBox[{"FindInstance", "[", 
     RowBox[{"conditions", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
       "xi3", ",", "xi4", ",", "xi5", ",", "et3", ",", "et4", ",", "et5"}], 
       "]"}], ",", "5"}], "]"}], "//", "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.612166575888966*^9, 3.612166576370742*^9}, {3.6121666241502*^9, 
   3.612166629642056*^9}, 3.6122577970426483`*^9, {3.6122584771168823`*^9, 
   3.612258481721101*^9}, {3.6156256519370327`*^9, 3.615625681121189*^9}, {
   3.61562725972334*^9, 3.6156272741427593`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol$no", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.615799200394259*^9, 3.61579920842603*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"sols$pol", "[", 
    RowBox[{"[", "sols$pol$no", "]"}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.6157163530290813`*^9, 3.615716476062681*^9}, {
   3.615716511701067*^9, 3.61571654575108*^9}, {3.6157165770734453`*^9, 
   3.615716595970683*^9}, 3.615799212685491*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xiz1", "\[Rule]", 
        RowBox[{"5.6`", "\[VeryThinSpace]", "-", 
         RowBox[{"3.1`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz2", "\[Rule]", 
        RowBox[{"19.`", "\[VeryThinSpace]", "-", 
         RowBox[{"16.4`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "8.7`"}], "-", 
         RowBox[{"5.1`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz4", "\[Rule]", 
        RowBox[{"7.6`", "\[VeryThinSpace]", "+", 
         RowBox[{"18.4`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "38.665679775022014`"}], "-", 
         RowBox[{"8.437516003005058`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "2.1`"}], "-", 
         RowBox[{"11.8`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu2", "\[Rule]", 
        RowBox[{"7.9`", "\[VeryThinSpace]", "-", 
         RowBox[{"5.8`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "22.3`"}], "+", 
         RowBox[{"13.6`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "16.9`"}], "-", 
         RowBox[{"7.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "36.020207253886014`"}], "+", 
         RowBox[{"507.2367875647668`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "16.1`"}], "+", 
         RowBox[{"4.8`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv2", "\[Rule]", 
        RowBox[{"1.`", "\[VeryThinSpace]", "+", 
         RowBox[{"7.6`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "17.3`"}], "+", 
         RowBox[{"12.7`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv4", "\[Rule]", 
        RowBox[{"24.6`", "\[VeryThinSpace]", "-", 
         RowBox[{"16.4`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv5", "\[Rule]", 
        RowBox[{"15.536407013394495`", "\[VeryThinSpace]", "+", 
         RowBox[{"23.942378557388718`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "22.`"}], "+", 
         RowBox[{"1.6`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz2", "\[Rule]", 
        RowBox[{"8.8`", "\[VeryThinSpace]", "-", 
         RowBox[{"13.9`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "4.`"}], "+", 
         RowBox[{"23.7`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz4", "\[Rule]", 
        RowBox[{"7.1`", "\[VeryThinSpace]", "-", 
         RowBox[{"22.7`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "0.7831840623551487`"}], "-", 
         RowBox[{"31.55025046013685`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu1", "\[Rule]", 
        RowBox[{"16.9`", "\[VeryThinSpace]", "-", 
         RowBox[{"4.1`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu2", "\[Rule]", 
        RowBox[{"10.`", "\[VeryThinSpace]", "+", 
         RowBox[{"10.5`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "19.9`"}], "-", 
         RowBox[{"5.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu4", "\[Rule]", 
        RowBox[{"14.7`", "\[VeryThinSpace]", "-", 
         RowBox[{"14.`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "693.5831606217616`"}], "+", 
         RowBox[{"12.7860103626943`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "9.`"}], "-", 
         RowBox[{"11.8`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv2", "\[Rule]", 
        RowBox[{"8.2`", "\[VeryThinSpace]", "-", 
         RowBox[{"15.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv3", "\[Rule]", 
        RowBox[{"6.6`", "\[VeryThinSpace]", "-", 
         RowBox[{"9.9`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv4", "\[Rule]", 
        RowBox[{"22.`", "\[VeryThinSpace]", "-", 
         RowBox[{"3.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv5", "\[Rule]", 
        RowBox[{"3.939574645526684`", "\[VeryThinSpace]", "+", 
         RowBox[{"22.58886685051277`", " ", "\[ImaginaryI]"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.615716385781748*^9, 3.6157164766109877`*^9}, {
   3.615716513236689*^9, 3.615716546096121*^9}, {3.6157165774701643`*^9, 
   3.61571659620504*^9}, 3.6157992132997093`*^9, 3.6158003737263527`*^9, 
   3.61621697520196*^9, 3.6173406427534733`*^9, 3.618219728546302*^9, 
   3.6193359355451517`*^9, 3.6197774108326807`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"reprules", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "e"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi3", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "g"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi4", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "i"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi5", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "f"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et3", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "h"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et4", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "j"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et5", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "]"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "sols$no", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"reprules", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612166744922229*^9, 3.6121667659346313`*^9}, {
   3.612166806789146*^9, 3.61216685017785*^9}, {3.612166881494143*^9, 
   3.612166937065545*^9}, {3.612167008004058*^9, 3.612167074754364*^9}, {
   3.612167111235808*^9, 3.612167202273198*^9}, {3.612175654939053*^9, 
   3.6121756683863297`*^9}, {3.612258495288478*^9, 3.612258500192725*^9}, 
   3.6126845445381327`*^9, 3.612685681583201*^9, {3.6145050620116053`*^9, 
   3.6145052111720667`*^9}, {3.615625744383524*^9, 3.6156257519355297`*^9}, 
   3.6157990808877573`*^9, 3.615799232592648*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["67", "5"], "-", 
         FractionBox[
          RowBox[{"133", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["123", "5"]}], "+", 
         FractionBox[
          RowBox[{"39", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["77769121606743647820817", "762540444579232733100"], "-", 
         FractionBox[
          RowBox[{"2545647557357512876329191", " ", "\[ImaginaryI]"}], 
          "762540444579232733100"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["69228668627456241210097", "762540444579232733100"]}], 
         "+", 
         FractionBox[
          RowBox[{"2540919806601121633383971", " ", "\[ImaginaryI]"}], 
          "762540444579232733100"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"10", "+", 
         RowBox[{"6", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["29", "5"]}], "+", 
         FractionBox[
          RowBox[{"88", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["513733462050165537739", "9167010407066650"]}], "+", 
         FractionBox[
          RowBox[{"163793251991331568591", " ", "\[ImaginaryI]"}], 
          "4583505203533325"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["513694960606455857809", "9167010407066650"], "-", 
         FractionBox[
          RowBox[{"163901422714134955061", " ", "\[ImaginaryI]"}], 
          "4583505203533325"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["171", "10"], "+", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["151", "10"], "-", 
         FractionBox[
          RowBox[{"62", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          
          FractionBox["5536087294114534976941501", 
           "2424699665874970514500"]}], "+", 
         FractionBox[
          RowBox[{"3404058349506236736692013", " ", "\[ImaginaryI]"}], 
          "2424699665874970514500"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["5458011964873360926374601", "2424699665874970514500"], 
         "-", 
         FractionBox[
          RowBox[{"3380781232713837019752813", " ", "\[ImaginaryI]"}], 
          "2424699665874970514500"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["154", "5"], "-", 
         FractionBox[
          RowBox[{"31", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["66", "5"], "+", 
         FractionBox[
          RowBox[{"123", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1642068141936227078645801", "762540444579232733100"], 
         "-", 
         FractionBox[
          RowBox[{"1339787716944976278630001", " ", "\[ImaginaryI]"}], 
          "254180148193077577700"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1675619921497713318902201", "762540444579232733100"]}],
          "+", 
         FractionBox[
          RowBox[{"1340601093419194126878641", " ", "\[ImaginaryI]"}], 
          "254180148193077577700"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["69", "10"]}], "+", 
         FractionBox[
          RowBox[{"73", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["269", "10"]}], "-", 
         FractionBox[
          RowBox[{"32", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["7898281443011678893917", "146672166513066400"]}], "-", 
         
         FractionBox[
          RowBox[{"209035241823692338441", " ", "\[ImaginaryI]"}], 
          "2933443330261328"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["7903238962239820538237", "146672166513066400"], "+", 
         FractionBox[
          RowBox[{"1045055937941920977757", " ", "\[ImaginaryI]"}], 
          "14667216651306640"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["86", "5"], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["4", "5"], "+", 
         FractionBox[
          RowBox[{"271", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          
          FractionBox["3804625052644189602463071", 
           "2424699665874970514500"]}], "+", 
         FractionBox[
          RowBox[{"5455939770472443674573333", " ", "\[ImaginaryI]"}], 
          "2424699665874970514500"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["3760980458658440133202071", "2424699665874970514500"], 
         "-", 
         FractionBox[
          RowBox[{"5513162682587092978715533", " ", "\[ImaginaryI]"}], 
          "2424699665874970514500"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166851224063*^9, {3.612166905867807*^9, 3.612166937604322*^9}, {
   3.6121671678821898`*^9, 3.612167203585627*^9}, 3.612175672435413*^9, 
   3.612257803039179*^9, {3.612258489462837*^9, 3.612258501949951*^9}, 
   3.612684415052841*^9, 3.612684547323617*^9, 3.6126856838647547`*^9, 
   3.614415306130569*^9, 3.614416733525731*^9, 3.614505217112989*^9, 
   3.614506945942827*^9, 3.6145784038082542`*^9, 3.6149384396477423`*^9, 
   3.615625790387403*^9, 3.6156359056548977`*^9, 3.615703722483737*^9, 
   3.615715569373487*^9, 3.615799233576213*^9, 3.6158003737901697`*^9, 
   3.616216975272902*^9, 3.617340642823454*^9, 3.618219728622641*^9, 
   3.619335935627532*^9, 3.6197774109095592`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"reprules2", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"e", ",", "g"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"e", ",", "i"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"g", ",", "i"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi4", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"f", ",", "h"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"f", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"h", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et4", ",", "et5"}], "]"}]}]}], "}"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "sols$no", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"reprules2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612167264558797*^9, 3.612167398925799*^9}, {
   3.612167432691366*^9, 3.61216748291084*^9}, {3.612167533668118*^9, 
   3.612167700191098*^9}, {3.612167759857984*^9, 3.612167800967119*^9}, {
   3.6121682313684673`*^9, 3.612168292531988*^9}, {3.612258517214506*^9, 
   3.612258523383716*^9}, 3.612685688337674*^9, {3.614505237903308*^9, 
   3.614505335631658*^9}, {3.614505373036313*^9, 3.6145055412646427`*^9}, {
   3.615625821871605*^9, 3.615625864432789*^9}, 3.615625909974094*^9, 
   3.6157990869167957`*^9, 3.615799237880918*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], "\[Rule]", 
        RowBox[{
         FractionBox["889664265248343990239672723", 
          "147170305803791917488300"], "-", 
         FractionBox[
          RowBox[{"487132586920734428441119197", " ", "\[ImaginaryI]"}], 
          "24528384300631986248050"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "i"}]], "\[Rule]", 
        RowBox[{
         FractionBox["2423063933374149097909200718045465094912267", 
          "4622328902968542697562886029989370449875"], "-", 
         FractionBox[
          RowBox[{
          "12940432100784630518388156416715718988472299", " ", 
           "\[ImaginaryI]"}], 
          "18489315611874170790251544119957481799500"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"g", "i"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          
          FractionBox["1528490285288775598237722498", 
           "116991758878467327324625"]}], "+", 
         FractionBox[
          RowBox[{"3028522490248876176004518781", " ", "\[ImaginaryI]"}], 
          "467967035513869309298500"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], "\[Rule]", 
        RowBox[{
         FractionBox["90514159456543282761240869", "58868122321516766995320"],
          "+", 
         FractionBox[
          RowBox[{"2043248617860709573930826589", " ", "\[ImaginaryI]"}], 
          "98113537202527944992200"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "j"}]], "\[Rule]", 
        RowBox[{
         FractionBox["2966282479933893821577331193590138981567007", 
          "4622328902968542697562886029989370449875"], "-", 
         FractionBox[
          RowBox[{
          "4449526868429745131222630768102440332123506", " ", 
           "\[ImaginaryI]"}], "4622328902968542697562886029989370449875"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"h", "j"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          
          FractionBox["2325537960808318040488783831", 
           "935934071027738618597000"]}], "-", 
         FractionBox[
          RowBox[{"7354451170772226240724533141", " ", "\[ImaginaryI]"}], 
          "467967035513869309298500"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612167364405326*^9, 3.612167400167985*^9, {3.612167443304433*^9, 
   3.612167483575858*^9}, {3.612167563577479*^9, 3.612167657471463*^9}, 
   3.612167700370111*^9, 3.612167770596114*^9, 3.612167807527257*^9, {
   3.6121682457254963`*^9, 3.61216829281944*^9}, 3.612175692993927*^9, 
   3.61225780705284*^9, {3.6122585063341312`*^9, 3.612258524869982*^9}, 
   3.612684420314109*^9, 3.612684550667274*^9, 3.612685690600247*^9, 
   3.614415307118548*^9, 3.6144167336216383`*^9, 3.614506947221128*^9, 
   3.614578403916479*^9, 3.614938440736401*^9, {3.615625893527792*^9, 
   3.615625910425831*^9}, 3.6156359064782133`*^9, 3.615703722650671*^9, 
   3.6157158165272017`*^9, 3.615799238564086*^9, 3.615800373829967*^9, 
   3.616216975326271*^9, 3.617340642864484*^9, 3.61821972868539*^9, 
   3.619335935682075*^9, 3.619777410970167*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"reprules3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"e", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi3", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"f", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et3", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"g", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi4", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"h", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et4", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"i", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi5", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"j", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et5", ",", "qq"}], "]"}]}]}], "}"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}], ",", 
      RowBox[{"sols$pol", "[", 
       RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.6156259430430326`*^9, 3.615626074477318*^9}, 
   3.615799090416448*^9, 3.61579924303267*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["271", "10"]}], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      FractionBox["187", "10"], "+", 
      FractionBox[
       RowBox[{"154", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "15"}], "-", 
      FractionBox[
       RowBox[{"33", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["h",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["59", "10"]}], "+", 
      FractionBox[
       RowBox[{"47", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["9", "10"]}], "+", 
      FractionBox[
       RowBox[{"373", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      FractionBox["99", "10"], "+", 
      FractionBox[
       RowBox[{"121", " ", "\[ImaginaryI]"}], "10"]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.61562607519976*^9, 3.615635906544237*^9, 
  3.615703327921301*^9, 3.615703722689159*^9, 3.615715860630789*^9, 
  3.6157992440017347`*^9, 3.6158003738728247`*^9, 3.616216975371217*^9, 
  3.617340642909091*^9, 3.618219728731468*^9, 3.6193359357393017`*^9, 
  3.619777411020053*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num5$pols", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"amp5$z$mmpp2$num5", "/.", 
     RowBox[{"Join", "[", 
      RowBox[{"reprules", ",", "reprules2", ",", "reprules3"}], "]"}]}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.615626118625678*^9, 3.615626136381537*^9}, {
  3.6156261905944357`*^9, 3.6156261935485697`*^9}, {3.615626257876563*^9, 
  3.6156262613082438`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
         "20333384401010536997579221444388146555715823970687457719260220084148\
285522474964042518680029803114174801993509863984991982901192466598965553344800\
910318143237044604979247640088525612486600718053095959460839743", "/", 
          "5263565873601932264060198389198209070268393503679484231601040756143\
113387156073560754383902894259328851718953811404362736116591282808694790400000\
00000"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
           "980958119163731275985470448671407028995645727167581259665138236695\
671233287485512731479978297097778380544640380309290552660000463096898574919407\
3907505450862916223212799166107927948833398030072637623401632399", " ", 
            "\[ImaginaryI]"}], ")"}], "/", 
          "1754521957867310754686732796399403023422797834559828077200346918714\
371129052024520251461300964753109617239651270468120912038863760936231596800000\
00000"}]}], ")"}], " ", 
       SuperscriptBox["z", "3"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"12", "+", 
            RowBox[{"7", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], "-", 
         RowBox[{"(", 
          RowBox[{"54", "-", 
           RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1320867676", "+", 
            RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}],
          "-", 
         RowBox[{"(", 
          RowBox[{"12110903352", "-", 
           RowBox[{"4258145844", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1320867676", "+", 
            RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}],
          "+", 
         RowBox[{"(", 
          RowBox[{"226677760", "+", 
           RowBox[{"55185924", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1343666644", "+", 
            RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}],
          "+", 
         RowBox[{"(", 
          RowBox[{"155065760", "+", 
           RowBox[{"24341204", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1343666644", "+", 
            RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}],
          "+", 
         RowBox[{"(", 
          RowBox[{"158042528", "+", 
           RowBox[{"76561820", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}], 
      ")"}]}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "506214223778871986146507891551244716458934523707158449590011744058104\
151564217184775412662492969957827659957156859063956642856745378724777801616389\
5236182695670283650279099388295863140526047587556569639341034139", "/", 
         "86826343043177173244753699924380713723230764633345338179401783413300\
930232574546771418469509281371834904423768000089060518846334836075050816000000\
0000"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "6826578792865308669521600453203464257729744373370643988389587038822\
792236133217088491621667327445000216112649865941013603771402731208934991301642\
39226830632666029306084248456105624653708620343235666661755355043", " ", 
           "\[ImaginaryI]"}], ")"}], "/", 
         "86826343043177173244753699924380713723230764633345338179401783413300\
930232574546771418469509281371834904423768000089060518846334836075050816000000\
0000"}]}], ")"}], " ", 
      SuperscriptBox["z", "2"]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"12", "+", 
           RowBox[{"7", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], "-", 
        RowBox[{"(", 
         RowBox[{"54", "-", 
          RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "-", 
        RowBox[{"(", 
         RowBox[{"12110903352", "-", 
          RowBox[{"4258145844", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"226677760", "+", 
          RowBox[{"55185924", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"155065760", "+", 
          RowBox[{"24341204", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"158042528", "+", 
          RowBox[{"76561820", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}], 
     ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "385003156277703851973367244789535114464238766904474757742050001086361\
771160378576930375221903516058188152743830431321726282681371609145557926361195\
64593929902864336696543126989796857012271048292097821", "/", 
         "66837004554757154343149609155414462565077484876911032460611318792617\
751317097839537382677778978305785703668806226651307343990373200000000000"}], 
        "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "9651448865349651735436288053916442442466644047977850788908961010584\
026886625345591754682417496634812581671440356311203172118587972663969475287870\
62742038753850768751082965792313188251067153968684597473", " ", 
           "\[ImaginaryI]"}], ")"}], "/", 
         "66837004554757154343149609155414462565077484876911032460611318792617\
751317097839537382677778978305785703668806226651307343990373200000000000"}]}],
        ")"}], " ", "z"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"12", "+", 
           RowBox[{"7", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], "-", 
        RowBox[{"(", 
         RowBox[{"54", "-", 
          RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "-", 
        RowBox[{"(", 
         RowBox[{"12110903352", "-", 
          RowBox[{"4258145844", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"226677760", "+", 
          RowBox[{"55185924", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"155065760", "+", 
          RowBox[{"24341204", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"158042528", "+", 
          RowBox[{"76561820", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}], 
     ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "14073420883568760780045774122329427116011116200852812125072445227941539\
792267410252977229826544901691813387267491533958874970771435965100864346617449\
27192259080361258971009549020776186943", "/", 
       "3908805508453125758776448279577682257512343871741183875210360352942971\
501033229495140812263760239610732712291692595400000000000"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "123090488418776976048185982737042291223524053555811266419373466048598\
471164382051195245709667108078383987033188922923399645805849452250601419544813\
11474930914636775954738701171154392718419", " ", "\[ImaginaryI]"}], ")"}], 
       "/", "35179249576078131828988034516199140317611094845670654876893243176\
486743509299065456267310373842156496594410625233358600000000000"}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"12", "+", 
           RowBox[{"7", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], "-", 
        RowBox[{"(", 
         RowBox[{"54", "-", 
          RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "-", 
        RowBox[{"(", 
         RowBox[{"12110903352", "-", 
          RowBox[{"4258145844", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"226677760", "+", 
          RowBox[{"55185924", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"155065760", "+", 
          RowBox[{"24341204", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"158042528", "+", 
          RowBox[{"76561820", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}], 
     ")"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "97293575568170737846653649268442861909942895664112659309872391366032029\
284040165260112203689587672211742760350187664706436318205025244266707084539811\
61", "/", 
       "2279138213714112511584642163882816022999977437395386007665015774118005\
4969458511993812500000000"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "112086007621180174766198149402932862456576288363761857316249996613364\
003605194988914066241185126938133693536913642498187900960418814150324663946988\
01823", " ", "\[ImaginaryI]"}], ")"}], "/", 
       "2279138213714112511584642163882816022999977437395386007665015774118005\
4969458511993812500000000"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"12", "+", 
           RowBox[{"7", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], "-", 
        RowBox[{"(", 
         RowBox[{"54", "-", 
          RowBox[{"1169", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "-", 
        RowBox[{"(", 
         RowBox[{"12110903352", "-", 
          RowBox[{"4258145844", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1320867676", "+", 
           RowBox[{"4860202329", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"226677760", "+", 
          RowBox[{"55185924", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"155065760", "+", 
          RowBox[{"24341204", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1343666644", "+", 
           RowBox[{"4708717169", " ", "\[ImaginaryI]"}]}], ")"}], " ", "z"}], 
        "+", 
        RowBox[{"(", 
         RowBox[{"158042528", "+", 
          RowBox[{"76561820", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}], " ", 
      "z"}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.615626165446826*^9, 3.6156262294598*^9, 
  3.615626285066786*^9, 3.61563594130284*^9, 3.615703367070438*^9, 
  3.6157037475285187`*^9, 3.6157158928037024`*^9, 3.615799256968678*^9, 
  3.615800376683827*^9, 3.616216978177167*^9, 3.6173406460145597`*^9, 
  3.618219731625884*^9, 3.61933593859754*^9, 3.619777413959238*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num5$pols", "]"}]], "Input",
 CellChangeTimes->{{3.615626151915247*^9, 3.6156261532414713`*^9}, {
  3.6156262481030903`*^9, 3.615626269853163*^9}}],

Cell[BoxData[
 FormBox["5", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6156261659116507`*^9, {3.6156262297129717`*^9, 3.615626252640942*^9}, 
   3.615626285228375*^9, 3.6156359414022303`*^9, 3.6157033671342707`*^9, 
   3.615703420047542*^9, 3.615703747595233*^9, 3.6157158967618*^9, 
   3.6157992706283207`*^9, 3.6158003767615347`*^9, 3.616216978259116*^9, 
   3.617340646110976*^9, 3.618219731701784*^9, 3.619335938664605*^9, 
   3.6197774140399733`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmppTaylor", "=", 
  RowBox[{"Series", "[", 
   RowBox[{"amp5$z$mmpp2$num5$pols", ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61562636012924*^9, 3.615626377507485*^9}, {
   3.615626457731526*^9, 3.615626461185981*^9}, 3.615626561820788*^9, {
   3.615626603494576*^9, 3.615626608154716*^9}, {3.61570343608624*^9, 
   3.61570344895673*^9}, {3.615716983707404*^9, 3.615717047364599*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["z", "2"]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "277484064163403495756367634642400139515371480892939264436308969368778\
645909156743688830503099730099001812481129445988518031921404253710682159908408\
373462421817413277477772518031892148546958140084989628630585239296571790872795\
538727014471749411664713", "/", 
         "37579971174716649802373534320531268889365560846560972591649584534031\
693951009540246023647777065865154095024017642912101111307949292983502579665851\
353292954768136072893258805818832090128645491274286512940770523578951086720000\
000000"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "1597449143293651985758909684936031630195536375761807292542224139453\
051751817954380359058624864154851552309855863153129674748663235665867805414364\
731499687983681607326436697697321925458310561423233143603326918620125760565270\
308764372867510069942287", " ", "\[ImaginaryI]"}], ")"}], "/", 
         "50106628232955533069831379094041691852487414462081296788866112712042\
258601346053661364863702754486872126698690190549468148410599057311336772887801\
804390606357514763857678407758442786838193988365715350587694031438601448960000\
0000"}]}], ")"}]}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 2, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {
     Complex[
      Rational[-\
277484064163403495756367634642400139515371480892939264436308969368778645909156\
743688830503099730099001812481129445988518031921404253710682159908408373462421\
817413277477772518031892148546958140084989628630585239296571790872795538727014\
471749411664713, 
       37579971174716649802373534320531268889365560846560972591649584534031693\
951009540246023647777065865154095024017642912101111307949292983502579665851353\
292954768136072893258805818832090128645491274286512940770523578951086720000000\
000], 
      Rational[
      159744914329365198575890968493603163019553637576180729254222413945305175\
181795438035905862486415485155230985586315312967474866323566586780541436473149\
968798368160732643669769732192545831056142323314360332691862012576056527030876\
4372867510069942287, 
       50106628232955533069831379094041691852487414462081296788866112712042258\
601346053661364863702754486872126698690190549468148410599057311336772887801804\
390606357514763857678407758442786838193988365715350587694031438601448960000000\
0]]}, 2, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6156263626072187`*^9, 3.615626383021606*^9}, 
   3.6156264615986013`*^9, 3.61562656226861*^9, 3.61562660880966*^9, 
   3.615635942260517*^9, 3.6157033680429497`*^9, {3.6157034219546413`*^9, 
   3.6157034404373703`*^9}, 3.6157037476694117`*^9, 3.615715901702347*^9, {
   3.615716987642564*^9, 3.615717047731558*^9}, 3.6157992808309107`*^9, 
   3.615800376795998*^9, 3.616216978290905*^9, 3.617340646150498*^9, 
   3.6182197317357388`*^9, 3.6193359387177057`*^9, 3.6197774140851183`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "amp5$z$mmppTaylor", "]"}]], "Input",
 CellChangeTimes->{{3.6157160787593*^9, 3.6157160794961*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"7.383828552537353`*^18", "-", 
       RowBox[{"3.188099458352691`*^18", " ", "\[ImaginaryI]"}]}], 
      SuperscriptBox["z", "2"]]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 2, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {
     Complex[-7.383828552537353*^18, 3.188099458352691*^18]}, 2, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615716079900894*^9, {3.615799291448784*^9, 3.6157992960473824`*^9}, 
   3.615800376843617*^9, 3.616216978326548*^9, 3.617340646184882*^9, 
   3.6182197317725143`*^9, 3.6193359387723703`*^9, 3.619777414139563*^9}]
}, Open  ]],

Cell[TextData[{
 "Thus, the scaling here is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"1", "/", 
     SuperscriptBox["z", "2"]}], ")"}], TraditionalForm]]],
 " but note that this is just a numerical check."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.615626182633637*^9, {3.615627535754664*^9, 
   3.615627573577817*^9}, {3.61580100350154*^9, 3.6158010055786343`*^9}, {
   3.615803489753994*^9, 3.615803526607231*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
   3.604652950305522*^9}, 3.604653026772519*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Large z behavior of the 5 e - amplitude numerically (undertermined \
polarizations give ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["z", "0"], TraditionalForm]]],
 " scaling!)"
}], "Subsection",
 CellChangeTimes->{{3.612085834165001*^9, 3.612085844526819*^9}, {
  3.612086484467353*^9, 3.612086497855007*^9}, {3.614577753311775*^9, 
  3.61457775350277*^9}, {3.615623168643466*^9, 3.615623182194241*^9}, {
  3.615800688763836*^9, 3.615800693522389*^9}, {3.615803534809108*^9, 
  3.61580355280689*^9}}],

Cell["First need 5 light-like momenta adding up to zero.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
  3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
  3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
  3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}, {3.6120866065182667`*^9, 3.612086606758206*^9}, {
   3.612505924058659*^9, 3.612505936532402*^9}, {3.612684208346747*^9, 
   3.6126842128136387`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}, {3.612086612732903*^9, 
   3.612086614349341*^9}, {3.612505939428406*^9, 3.6125059543631077`*^9}, {
   3.61268421467281*^9, 3.612684221598008*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{"k31", ",", "k32", ",", "k33", ",", "k34", ",", "k35"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9, {
   3.61208661791853*^9, 3.612086618148158*^9}, {3.612086936652397*^9, 
   3.612086944450577*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k4", "=", 
   RowBox[{"{", 
    RowBox[{"k41", ",", "k42", ",", "k43", ",", "k44", ",", "k45"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}, {3.612086632200843*^9, 3.612086646982294*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k5", "=", 
   RowBox[{"{", 
    RowBox[{"k51", ",", "k52", ",", "k53", ",", "k54", ",", "k55"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.612086654555016*^9, 3.6120866647448187`*^9}, {
  3.61208681096835*^9, 3.612086816309435*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "5", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "5", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.612086707631708*^9, 3.612086713887814*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kinsys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k5", ",", "k5"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4", "+", "k5"}], "\[Equal]", 
      "0"}]}], "}"}]}], ";", 
  RowBox[{"kinsys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612258217072095*^9, 3.612258219089881*^9}, {
  3.612258263321577*^9, 3.612258271721939*^9}, {3.612505966669755*^9, 
  3.612505985721085*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k31", "2"]}], "+", 
         SuperscriptBox["k32", "2"], "+", 
         SuperscriptBox["k33", "2"], "+", 
         SuperscriptBox["k34", "2"], "+", 
         SuperscriptBox["k35", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k41", "2"]}], "+", 
         SuperscriptBox["k42", "2"], "+", 
         SuperscriptBox["k43", "2"], "+", 
         SuperscriptBox["k44", "2"], "+", 
         SuperscriptBox["k45", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k51", "2"]}], "+", 
         SuperscriptBox["k52", "2"], "+", 
         SuperscriptBox["k53", "2"], "+", 
         SuperscriptBox["k54", "2"], "+", 
         SuperscriptBox["k55", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"k31", "+", "k41", "+", "k51", "+", "2"}], ",", 
          RowBox[{"k32", "+", "k42", "+", "k52"}], ",", 
          RowBox[{"k33", "+", "k43", "+", "k53"}], ",", 
          RowBox[{"k34", "+", "k44", "+", "k54"}], ",", 
          RowBox[{"k35", "+", "k45", "+", "k55"}]}], "}"}], "\[LongEqual]", 
        "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612258223332856*^9, 3.612258277667809*^9, 3.612505994584982*^9, 
   3.6126800091197*^9, 3.6126842296073713`*^9, 3.614415251319221*^9, 
   3.614416681331402*^9, 3.614506889916788*^9, 3.6145783531107807`*^9, 
   3.61493838358314*^9, 3.61562431172897*^9, 3.615635676008398*^9, {
   3.615798577931674*^9, 3.61579860597112*^9}, 3.615800023917783*^9, {
   3.615800607279175*^9, 3.615800631526265*^9}, 3.615800678815898*^9, 
   3.616216978391515*^9, 3.6173406462542553`*^9, 3.618219731844945*^9, 
   3.61933593886817*^9, 3.619777414276021*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"FindInstance", "[", 
   RowBox[{"kinsys", ",", 
    RowBox[{"Join", "[", 
     RowBox[{"k4", ",", "k5", ",", "k3"}], "]"}], ",", "1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.612086667146719*^9, 3.612086669789753*^9}, {
   3.61208672018432*^9, 3.6120867609601393`*^9}, {3.612086820399687*^9, 
   3.61208684701149*^9}, {3.6120868882347116`*^9, 3.612086911234775*^9}, {
   3.612086947214334*^9, 3.612086966920597*^9}, {3.612087130200302*^9, 
   3.612087138062559*^9}, {3.612257132872628*^9, 3.6122571670798407`*^9}, 
   3.612257397692018*^9, {3.61225751058984*^9, 3.612257511578771*^9}, {
   3.6122576055168962`*^9, 3.612257613202684*^9}, 3.612257694530752*^9, {
   3.612258060499379*^9, 3.612258062723226*^9}, {3.612258192623537*^9, 
   3.612258193411767*^9}, 3.612258282749514*^9, {3.6125060012757797`*^9, 
   3.612506003735097*^9}, {3.612680017069385*^9, 3.6126800172139387`*^9}, 
   3.612684254591062*^9, 3.6145769005945463`*^9, 3.614576952464837*^9, {
   3.6145770875853148`*^9, 3.614577088568757*^9}, 3.61579856434335*^9, 
   3.615800610269499*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k41", "\[Rule]", "1"}], ",", 
     RowBox[{"k42", "\[Rule]", "4"}], ",", 
     RowBox[{"k43", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k44", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SqrtBox[
        FractionBox["89", "5"]]}]}], ",", 
     RowBox[{"k45", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["3", 
        SqrtBox["5"]]}]}], ",", 
     RowBox[{"k51", "\[Rule]", 
      RowBox[{"-", "3"}]}], ",", 
     RowBox[{"k52", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"k53", "\[Rule]", "0"}], ",", 
     RowBox[{"k54", "\[Rule]", "0"}], ",", 
     RowBox[{"k55", "\[Rule]", 
      RowBox[{"-", 
       SqrtBox["5"]}]}], ",", 
     RowBox[{"k31", "\[Rule]", "0"}], ",", 
     RowBox[{"k32", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"k33", "\[Rule]", "1"}], ",", 
     RowBox[{"k34", "\[Rule]", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox[
        FractionBox["89", "5"]]}]}], ",", 
     RowBox[{"k35", "\[Rule]", 
      RowBox[{
       FractionBox["3", 
        SqrtBox["5"]], "+", 
       SqrtBox["5"]}]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.612086762118141*^9, 3.612086780893147*^9}, {
   3.612086823214789*^9, 3.612086847939478*^9}, {3.61208688888518*^9, 
   3.612086911822865*^9}, {3.612086954278853*^9, 3.612086967359386*^9}, {
   3.612087131307373*^9, 3.6120871383511143`*^9}, 3.612257142281363*^9, 
   3.612257394237977*^9, {3.6122575076936417`*^9, 3.612257512163836*^9}, {
   3.6122576069012537`*^9, 3.612257627804504*^9}, {3.612257690411792*^9, 
   3.612257695104991*^9}, 3.612258189484466*^9, 3.61225822195914*^9, 
   3.612258276336063*^9, 3.612259320778799*^9, 3.612511330729707*^9, 
   3.6126803950144*^9, {3.6126842499610157`*^9, 3.612684258655238*^9}, 
   3.6144152518055267`*^9, 3.614416681520438*^9, 3.6145068908943377`*^9, 
   3.614576906819211*^9, 3.614576960270529*^9, 3.614577089264464*^9, 
   3.6145783532449417`*^9, 3.614938384517983*^9, 3.615624316465996*^9, 
   3.615635676146047*^9, 3.615714899232999*^9, {3.6157149809002657`*^9, 
   3.6157150015675077`*^9}, {3.615798562408133*^9, 3.615798619684338*^9}, 
   3.6158000346049633`*^9, {3.6158006108823137`*^9, 3.615800631618147*^9}, 
   3.6158006789137506`*^9, 3.616216978476124*^9, 3.617340646347684*^9, 
   3.618219731935677*^9, 3.6193359389688797`*^9, 3.619777414374716*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$no", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.615798680984138*^9, 3.615798683466194*^9}, 
   3.61579874759733*^9, 3.615798948451993*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k3", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086972550753*^9, 3.612086977276445*^9}, 
   3.615798688516718*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", 
    RowBox[{"-", "2"}], ",", "1", ",", 
    RowBox[{"\[ImaginaryI]", " ", 
     SqrtBox[
      FractionBox["89", "5"]]}], ",", 
    RowBox[{
     FractionBox["3", 
      SqrtBox["5"]], "+", 
     SqrtBox["5"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612086977587695*^9, 3.6122575146527653`*^9, 3.612257696324094*^9, 
   3.612684263546081*^9, 3.6144152519329348`*^9, 3.6144166815767603`*^9, 
   3.614506890949765*^9, 3.614578353276498*^9, 3.614938384565001*^9, 
   3.615624317595804*^9, 3.615635676185246*^9, 3.615714903166751*^9, 
   3.615714984383153*^9, 3.615798635246705*^9, 3.615798720768486*^9, 
   3.6157987611768208`*^9, 3.6158000347992277`*^9, {3.615800619583563*^9, 
   3.615800631659972*^9}, 3.615800678984565*^9, 3.6162169785077553`*^9, 
   3.617340646383407*^9, 3.618219731971114*^9, 3.619335939019575*^9, 
   3.6197774144216137`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k3", ",", "k3"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122571125898314`*^9, 3.612257119072855*^9}, {
   3.612257544299827*^9, 3.612257553190195*^9}, 3.615798689776154*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6122571193226643`*^9, 3.612257515599658*^9, {3.612257545928628*^9, 
   3.612257553598151*^9}, 3.612257697150077*^9, 3.612684265607835*^9, 
   3.6144152519576693`*^9, 3.614416681638151*^9, 3.614506890967968*^9, 
   3.61457835328469*^9, 3.614938384605798*^9, 3.615624318827939*^9, 
   3.615635676209746*^9, 3.61579863884573*^9, 3.6157987208171177`*^9, 
   3.615798762847046*^9, 3.615800034888626*^9, {3.615800620930738*^9, 
   3.615800631692978*^9}, 3.615800679030789*^9, 3.616216978536731*^9, 
   3.617340646415374*^9, 3.618219732004753*^9, 3.619335939063726*^9, 
   3.6197774144638357`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086983780642*^9, 3.6157986923499823`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"1", ",", "4", ",", 
    RowBox[{"-", "1"}], ",", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]]}], ",", 
    RowBox[{"-", 
     FractionBox["3", 
      SqrtBox["5"]]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086984684704*^9, 3.612257555469883*^9, 
  3.612257697740192*^9, 3.612684268914393*^9, 3.614415251973494*^9, 
  3.6144166816980267`*^9, 3.614506890983892*^9, 3.614578353290989*^9, 
  3.614938384647709*^9, 3.615624320144247*^9, 3.615635676237996*^9, 
  3.615798640672124*^9, 3.615798720856826*^9, 3.615798764406435*^9, 
  3.615800034945108*^9, 3.615800631699449*^9, 3.615800679069523*^9, 
  3.6162169785661592`*^9, 3.617340646447348*^9, 3.618219732038233*^9, 
  3.619335939106894*^9, 3.619777414505106*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k4", ",", "k4"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122575625202703`*^9, 3.612257564202305*^9}, 
   3.615798693774818*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.612257565498811*^9, 3.612257698283271*^9, 
  3.6126842714539623`*^9, 3.614415251992217*^9, 3.614416681767228*^9, 
  3.614506890999983*^9, 3.614578353295656*^9, 3.614938384652294*^9, 
  3.615624320795045*^9, 3.615635676265464*^9, 3.615798642279669*^9, 
  3.615798720905188*^9, 3.61579876644022*^9, 3.6158000349978943`*^9, 
  3.615800631707671*^9, 3.615800679109866*^9, 3.616216978596334*^9, 
  3.617340646479286*^9, 3.618219732071607*^9, 3.619335939113863*^9, 
  3.6197774145103197`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k5", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086990045686*^9, 3.615798695781567*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "3"}], ",", 
    RowBox[{"-", "2"}], ",", "0", ",", "0", ",", 
    RowBox[{"-", 
     SqrtBox["5"]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086990222755*^9, 3.6122575687096653`*^9, 
  3.612257698824397*^9, 3.612684273014686*^9, 3.614415252134819*^9, 
  3.614416681770714*^9, 3.614506891071704*^9, 3.614578353321383*^9, 
  3.61493838465629*^9, 3.6156243216428223`*^9, 3.61563567627129*^9, 
  3.615798643751333*^9, 3.615798720954322*^9, 3.61579876781393*^9, 
  3.615800035048827*^9, 3.6158006317132597`*^9, 3.615800679149468*^9, 
  3.6162169786014023`*^9, 3.617340646484578*^9, 3.618219732076983*^9, 
  3.619335939119186*^9, 3.619777414515818*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k5", ",", "k5"}], "]"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6122575845569344`*^9, 3.6122575890669613`*^9}, 
   3.615798697245968*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.612257586141511*^9, 3.612257589348277*^9}, 
   3.612257699452682*^9, 3.612684274587776*^9, 3.614415252266694*^9, 
   3.614416681774804*^9, 3.614506891089264*^9, 3.614578353329406*^9, 
   3.614938384660136*^9, 3.615624322877493*^9, 3.615635676278453*^9, 
   3.615798645823174*^9, 3.6157987210290003`*^9, 3.615798770502593*^9, 
   3.615800035102331*^9, 3.6158006317185593`*^9, 3.6158006792120447`*^9, 
   3.61621697860627*^9, 3.61734064648958*^9, 3.618219732081777*^9, 
   3.619335939123945*^9, 3.619777414521072*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4", "+", "k5"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612684288172793*^9, 3.612684297213119*^9}, 
   3.61579869835133*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6126842976505404`*^9, 3.614415252283523*^9, 
  3.6144166818314037`*^9, 3.6145068911103773`*^9, 3.614578353334805*^9, 
  3.614938384700522*^9, 3.615624324172194*^9, 3.615635676284897*^9, 
  3.615798647947219*^9, 3.615798721034935*^9, 3.615798772562004*^9, 
  3.6158000351104317`*^9, 3.615800631754396*^9, 3.615800679275621*^9, 
  3.616216978610733*^9, 3.617340646494904*^9, 3.618219732086874*^9, 
  3.619335939168062*^9, 3.619777414526023*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s12", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
     RowBox[{"s13", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"s14", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s15", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s23", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"s24", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s25", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k2", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s34", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k3", ",", "k4"}], "]"}]}]}], ",", 
     RowBox[{"s35", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k3", ",", "k5"}], "]"}]}]}], ",", 
     RowBox[{"s45", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k4", ",", "k5"}], "]"}]}]}]}], "}"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.612087426835834*^9, 3.612087432664119*^9}, {
   3.612258338518701*^9, 3.612258339672268*^9}, 3.6145769704085627`*^9, 
   3.614577080572277*^9, 3.6157987021008253`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s12", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"s13", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"s14", "\[Rule]", "6"}], ",", 
    RowBox[{"s15", "\[Rule]", "2"}], ",", 
    RowBox[{"s23", "\[Rule]", "4"}], ",", 
    RowBox[{"s24", "\[Rule]", 
     RowBox[{"-", "10"}]}], ",", 
    RowBox[{"s25", "\[Rule]", "10"}], ",", 
    RowBox[{"s34", "\[Rule]", "8"}], ",", 
    RowBox[{"s35", "\[Rule]", 
     RowBox[{"-", "8"}]}], ",", 
    RowBox[{"s45", "\[Rule]", 
     RowBox[{"-", "4"}]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612087439480166*^9, 3.612257591558383*^9, 3.612257700130177*^9, 
   3.612258340118903*^9, 3.6126842783468533`*^9, 3.614415252427136*^9, 
   3.614416681890109*^9, 3.6145068911892233`*^9, {3.6145769429963827`*^9, 
   3.614576970611363*^9}, 3.614578353362673*^9, 3.614938384741045*^9, 
   3.615624325553817*^9, 3.6156356763107758`*^9, 3.615715071574896*^9, 
   3.615798650257248*^9, 3.615798721087057*^9, 3.615798774323966*^9, 
   3.615800035162051*^9, 3.615800631786983*^9, 3.615800679341641*^9, 
   3.616216978643594*^9, 3.617340646529118*^9, 3.618219732121924*^9, 
   3.619335939212391*^9, 3.619777414570023*^9}]
}, Open  ]],

Cell[TextData[{
 "This is to check that the kinematical configuration is not singular (i.e. \
all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "ij"], "\[NotEqual]", "0"}], TraditionalForm]]],
 ").\nHm, actually, in the shifted case s14=0 is not a problem."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EH2j6eHM6R9eOVp4Gc8G0QAyR9ap
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"qq", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "I", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.615623303917725*^9, 3.615623330906939*^9}, {
   3.61570290803546*^9, 3.615702922246525*^9}, 3.615703470805991*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"min", "[", 
     RowBox[{"qq", ",", "k3"}], "]"}], ",", 
    RowBox[{"min", "[", 
     RowBox[{"qq", ",", "k4"}], "]"}], ",", 
    RowBox[{"min", "[", 
     RowBox[{"qq", ",", "k5"}], "]"}]}], "}"}], "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "sols$no", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.615623471130151*^9, 3.615623476975369*^9}, 
   3.615624340977724*^9, 3.6157985526575413`*^9, 3.615798737914085*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", "-", 
     SqrtBox[
      FractionBox["89", "5"]]}], ",", 
    RowBox[{
     SqrtBox[
      FractionBox["89", "5"]], "-", "1"}], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624329018611*^9, 3.6156243416104803`*^9}, 
   3.615635676343768*^9, {3.615702911175829*^9, 3.615702924549855*^9}, 
   3.615703495183576*^9, 3.615715077269908*^9, 3.615798553699625*^9, 
   3.615798738854541*^9, 3.61579878421391*^9, 3.615800035217153*^9, 
   3.615800679395256*^9, 3.6162169786804237`*^9, 3.617340646566834*^9, 
   3.618219732160635*^9, 3.619335939263783*^9, 3.6197774146198473`*^9}]
}, Open  ]],

Cell["\<\
On the other hand, it is because of q.k5=0 that the scaling is worse!\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EH2j6eHM6R9eOVp4Gc8G0SeuaFxM/AgUv8R5BUQD
APZj4MA=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num", "=", 
  RowBox[{"amp5$z$mmpp2", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         TagBox[
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True],
          FullForm], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "k3"}], "]"}]}], ",", 
        RowBox[{
         TagBox[
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True],
          FullForm], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "k4"}], "]"}]}], ",", 
        RowBox[{
         TagBox[
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True],
          FullForm], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "k5"}], "]"}]}], ",", 
        RowBox[{"s12", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
        RowBox[{"s13", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
        RowBox[{"s14", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s15", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k1", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s23", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k3"}], "]"}]}]}], ",", 
        RowBox[{"s24", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s25", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k2", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s34", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k3", ",", "k4"}], "]"}]}]}], ",", 
        RowBox[{"s35", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k3", ",", "k5"}], "]"}]}]}], ",", 
        RowBox[{"s45", "\[Rule]", 
         RowBox[{"2", 
          RowBox[{"min", "[", 
           RowBox[{"k4", ",", "k5"}], "]"}]}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.615623383571273*^9, 3.6156234563012867`*^9}, {
   3.6156235808796053`*^9, 3.615623609292816*^9}, 3.6157989554900703`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SqrtBox[
                 FractionBox["89", "5"]]}], ")"}], " ", 
              SubsuperscriptBox["k", 
               FormBox["5",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "j"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "i"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "h"}]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["g",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["z", "4"]}], 
             RowBox[{"16", " ", 
              RowBox[{"(", 
               RowBox[{"4", "-", 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SqrtBox[
                    FractionBox["89", "5"]]}], ")"}], " ", "z"}]}], 
               ")"}]}]]}], "+", 
           RowBox[{"\[LeftSkeleton]", "230516", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 412, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 412, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 412, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[412]], TraditionalForm]], "Output",
 CellChangeTimes->{3.61562445074515*^9, 3.6156357664992456`*^9, 
  3.6157030176769238`*^9, 3.6157035859262047`*^9, 3.615715244470035*^9, 
  3.615798921759355*^9, 3.6158001563954678`*^9, 3.6158007719863453`*^9, 
  3.616217069174082*^9, 3.617340744652529*^9, 3.6182198228956127`*^9, 
  3.6193360281182117`*^9, 3.619777507844138*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num", "]"}]], "Input",
 CellChangeTimes->{3.61562362092029*^9}],

Cell[BoxData[
 FormBox["153878", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624451455695*^9, 3.615624455847414*^9}, 
   3.615635767054327*^9, 3.6157030181587954`*^9, 3.615703586408149*^9, 
   3.615715244956808*^9, 3.61579893814222*^9, 3.6158001569662037`*^9, 
   3.615800772535254*^9, 3.616217069733836*^9, 3.617340745216785*^9, 
   3.618219823407333*^9, 3.619336028605761*^9, 3.619777508397936*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num2", "=", 
  RowBox[{"amp5$z$mmpp2$num", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"a", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156236533620043`*^9, 3.615623667065372*^9}, 
   3.615623964675109*^9, {3.615624006954833*^9, 3.615624027647028*^9}, {
   3.615624087172872*^9, 3.615624088159317*^9}, {3.6156241190861597`*^9, 
   3.615624125409356*^9}, {3.615624198795361*^9, 3.615624201828332*^9}, 
   3.615798960736607*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"\[LeftSkeleton]", "151133", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}]}]], 
           "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 414, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 414, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 414, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[414]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624524822287*^9, 3.615635825188743*^9, 
  3.615703212665555*^9, 3.615703644259124*^9, 3.615715307094092*^9, 
  3.615799046847789*^9, 3.615800243768445*^9, 3.6158008312809763`*^9, 
  3.6162171287497463`*^9, 3.6173408033484163`*^9, 3.618219880757331*^9, 
  3.619336085932332*^9, 3.619777568135398*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num2", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}}],

Cell[BoxData[
 FormBox["100994", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.615635825574172*^9, 
  3.6157032130112*^9, 3.61570364459976*^9, 3.615715322272828*^9, 
  3.6157990472899723`*^9, 3.615800244211302*^9, 3.6158008316213837`*^9, 
  3.616217129071086*^9, 3.617340803702199*^9, 3.6182198810950003`*^9, 
  3.6193360862611933`*^9, 3.6197775685191393`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num2", ",", "a"}], "]"}]], "Input",
 CellChangeTimes->{{3.615624565703869*^9, 3.615624569575453*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.6156245727994537`*^9, 3.615635828192638*^9, 
  3.615703215682513*^9, 3.615703647248221*^9, 3.6157153274977493`*^9, 
  3.615799050481134*^9, 3.615800247474074*^9, 3.615800834253227*^9, 
  3.616217131690189*^9, 3.6173408064096518`*^9, 3.618219883725872*^9, 
  3.61933608885883*^9, 3.61977757116949*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num3", "=", 
  RowBox[{"amp5$z$mmpp2$num2", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "b"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "b"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "b"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"b", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156236533620043`*^9, 3.615623667065372*^9}, 
   3.615623964675109*^9, {3.615624006954833*^9, 3.615624027647028*^9}, {
   3.615624087172872*^9, 3.615624088159317*^9}, {3.6156241190861597`*^9, 
   3.615624125409356*^9}, {3.615624198795361*^9, 3.615624201828332*^9}, {
   3.61562454107201*^9, 3.615624564116488*^9}, {3.615703940060794*^9, 
   3.615703978423517*^9}, {3.6157040618305397`*^9, 3.615704062332144*^9}, {
   3.615704146155052*^9, 3.615704171990994*^9}, 3.615798970941*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"\[LeftSkeleton]", "98534", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{"32", " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                FractionBox["89", "5"]]}], ")"}], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]], " ", 
             SuperscriptBox[
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
             SubsuperscriptBox["k", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                FractionBox["89", "5"]]}], ")"}], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 417, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 417, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 417, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[417]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624524822287*^9, 3.6156246507027807`*^9, 
  3.615635866017243*^9, 3.615703255987712*^9, 3.615703685325079*^9, 
  3.615704034261116*^9, 3.615704111620109*^9, 3.615715447336382*^9, 
  3.6157991099220552`*^9, 3.615800307993691*^9, 3.6158008733066607`*^9, 
  3.616217169450192*^9, 3.617340844347597*^9, 3.6182199213557863`*^9, 
  3.61933612635566*^9, 3.619777610004568*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num3", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}, 
   3.615624608643198*^9}],

Cell[BoxData[
 FormBox["65856", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.6156246512033567`*^9, 
  3.6156358662995872`*^9, 3.6157032562378197`*^9, 3.615703685572926*^9, 
  3.615704034651869*^9, 3.615715447584009*^9, 3.6157991102380333`*^9, 
  3.615800308331847*^9, 3.615800873549946*^9, 3.616217169689287*^9, 
  3.6173408446002893`*^9, 3.618219921604478*^9, 3.619336126605077*^9, 
  3.6197776102462482`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num3", ",", "b"}], "]"}]], "Input",
 CellChangeTimes->{3.615624660157823*^9, 3.615624796242927*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624773917117*^9, 3.6156247985276413`*^9}, 
   3.615635868077186*^9, 3.615703258052052*^9, 3.615703687408482*^9, 
   3.615704037020315*^9, 3.6157154494077787`*^9, 3.615799112541849*^9, 
   3.6158003106686153`*^9, 3.615800875420549*^9, 3.616217171479229*^9, 
   3.617340846504415*^9, 3.618219923381077*^9, 3.619336128374112*^9, 
   3.6197776120388193`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num4", "=", 
  RowBox[{"amp5$z$mmpp2$num3", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "c"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "c"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"c", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156248388300047`*^9, 3.615624874140313*^9}, 
   3.615625074766121*^9, 3.615798981116146*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 SqrtBox[
                  FractionBox["89", "5"]]}], ")"}], "2"], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "j"}]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["g",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["h",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["z", "4"]}], 
             RowBox[{"80", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SqrtBox[
                    FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
               ")"}]}]]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                SqrtBox[
                 FractionBox["89", "5"]]}], ")"}], "2"], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "j"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["z", "4"]}], 
            RowBox[{"80", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "+", "6"}], 
              ")"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "54006", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                FractionBox["89", "5"]]}], ")"}], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                FractionBox["89", "5"]]}], ")"}], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"32", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 420, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 420, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 420, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[420]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624908669083*^9, 3.61562510095078*^9, 
  3.615635889473156*^9, 3.615703279497604*^9, 3.615703708690095*^9, 
  3.61571547970577*^9, 3.615799149207375*^9, 3.6158003480815163`*^9, 
  3.615800897352248*^9, 3.616217192631816*^9, 3.6173408678720493`*^9, 
  3.618219944790681*^9, 3.619336149592828*^9, 3.619777634479208*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num4", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}, 
   3.615624608643198*^9, 3.615624886389485*^9}],

Cell[BoxData[
 FormBox["36121", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.6156246512033567`*^9, 
  3.615625101319693*^9, 3.615635889684332*^9, 3.615703279661849*^9, 
  3.6157037088586884`*^9, 3.615715486462612*^9, 3.615800348307939*^9, 
  3.615800897516164*^9, 3.616217192811739*^9, 3.617340868035063*^9, 
  3.618219944949085*^9, 3.61933614976527*^9, 3.619777634637991*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num4", ",", "c"}], "]"}]], "Input",
 CellChangeTimes->{
  3.615624660157823*^9, 3.615624796242927*^9, {3.6156248883423367`*^9, 
   3.615624890587727*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624773917117*^9, 3.6156247985276413`*^9}, 
   3.6156251027236013`*^9, 3.615635890732575*^9, 3.615703280725604*^9, 
   3.615703709915077*^9, 3.615715489649579*^9, 3.615800349947158*^9, 
   3.615800898574526*^9, 3.616217193856059*^9, 3.617340869093446*^9, 
   3.6182199460042467`*^9, 3.619336150831002*^9, 3.619777635746995*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num5", "=", 
  RowBox[{"amp5$z$mmpp2$num4", "/.", 
   RowBox[{"Simplify", "[", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "d"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "d"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k4", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"5", ",", "d"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{"k5", ",", "qq"}], "]"}]}], ",", 
        RowBox[{
         RowBox[{"dc", "[", 
          RowBox[{"d", ",", "x_"}], "]"}], "\[Rule]", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{"x", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}]}], ")"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6156248388300047`*^9, 3.615624874140313*^9}, {
   3.615624961781053*^9, 3.615624980220827*^9}, 3.6156250692152863`*^9, 
   3.6157989908758717`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SqrtBox[
                 FractionBox["89", "5"]]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 SqrtBox[
                  FractionBox["89", "5"]]}], ")"}], "2"], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["g",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["i",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["j",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["z", "3"]}], 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SqrtBox[
                    FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
               ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", 
                   SqrtBox[
                    FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "10"}],
                ")"}]}]]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SqrtBox[
                 FractionBox["89", "5"]]}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SqrtBox[
                FractionBox["89", "5"]]}], ")"}], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["z", "3"]}], 
            RowBox[{"8", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "10"}], 
              ")"}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "28555", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               SqrtBox[
                FractionBox["89", "5"]]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               SqrtBox[
                FractionBox["89", "5"]]}], ")"}], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"16", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  SqrtBox[
                   FractionBox["89", "5"]]}], ")"}], " ", "z"}], "-", "4"}], 
              ")"}]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 423, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 423, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 423, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[423]], TraditionalForm]], "Output",
 CellChangeTimes->{3.615624908669083*^9, 3.615625025823633*^9, 
  3.6156251146557407`*^9, 3.615635902099453*^9, 3.61570329214148*^9, 
  3.6157037212914877`*^9, 3.615715518632037*^9, 3.6157991717269783`*^9, 
  3.6158003724386253`*^9, 3.615800910087487*^9, 3.616217205329299*^9, 
  3.617340880853339*^9, 3.618219957457562*^9, 3.6193361622635107`*^9, 
  3.619777647877754*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num5", "]"}]], "Input",
 CellChangeTimes->{{3.615624470142194*^9, 3.6156244714195538`*^9}, 
   3.615624608643198*^9, 3.615624886389485*^9, 3.61562496480656*^9}],

Cell[BoxData[
 FormBox["19137", TraditionalForm]], "Output",
 CellChangeTimes->{3.615624525313168*^9, 3.6156246512033567`*^9, 
  3.615625026238781*^9, 3.615625114863566*^9, 3.615635902235846*^9, 
  3.615703298063677*^9, 3.6157037213978233`*^9, 3.615715535019311*^9, 
  3.615799171874514*^9, 3.6158003725829144`*^9, 3.615800910201412*^9, 
  3.616217205445766*^9, 3.617340881003153*^9, 3.618219957567328*^9, 
  3.6193361623802557`*^9, 3.619777648070366*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{"amp5$z$mmpp2$num5", ",", "d"}], "]"}]], "Input",
 CellChangeTimes->{
  3.615624660157823*^9, 3.615624796242927*^9, {3.6156248883423367`*^9, 
   3.615624890587727*^9}, 3.615624966065217*^9, 3.615625011157996*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.615624773917117*^9, 3.6156247985276413`*^9}, 
   3.61562504272051*^9, 3.615625115663059*^9, 3.6156359028281527`*^9, 
   3.6157033002361383`*^9, 3.6157037219816437`*^9, 3.6157155374627447`*^9, 
   3.615799172990296*^9, 3.6158003735239887`*^9, 3.615800910788192*^9, 
   3.616217206026308*^9, 3.617340881664125*^9, 3.618219958158083*^9, 
   3.619336162975089*^9, 3.619777648685856*^9}]
}, Open  ]],

Cell["Need more polarization vectors...", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EC3EbWLg9OGVo9fmtWAaAA8H1DY=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{"xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4", ",", "xiz5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9, {3.612166418225318*^9, 
   3.6121664207438507`*^9}, 3.615625616359418*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi4", "=", 
   RowBox[{"{", 
    RowBox[{"xiu1", ",", "xiu2", ",", "xiu3", ",", "xiu4", ",", "xiu5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.6040433145245943`*^9, 
   3.604043314748054*^9}, {3.6040433534274893`*^9, 3.604043369394578*^9}, 
   3.60404350847479*^9, {3.61216642588039*^9, 3.612166429007922*^9}, 
   3.615625616361087*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi5", "=", 
   RowBox[{"{", 
    RowBox[{"xiv1", ",", "xiv2", ",", "xiv3", ",", "xiv4", ",", "xiv5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.612166469609943*^9, 3.612166482375815*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{"etz1", ",", "etz2", ",", "etz3", ",", "etz4", ",", "etz5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9, {3.612166449248323*^9, 
   3.6121664509560738`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et4", "=", 
   RowBox[{"{", 
    RowBox[{"etu1", ",", "etu2", ",", "etu3", ",", "etu4", ",", "etu5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.604043392149412*^9, 
   3.604043392255167*^9}, {3.6040434286448727`*^9, 3.604043435995811*^9}, 
   3.604043520033565*^9, {3.612166453399662*^9, 3.6121664555841017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et5", "=", 
   RowBox[{"{", 
    RowBox[{"etv1", ",", "etv2", ",", "etv3", ",", "etv4", ",", "etv5"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6121664949676847`*^9, 3.6121665077213697`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "xi4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "et4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "xi5"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "et5"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     
     RowBox[{"sols", "[", 
      RowBox[{"[", "sols$no", "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.61216653422339*^9, 3.612166556960194*^9}, {
   3.612166600729034*^9, 3.6121666133164167`*^9}, {3.612258455793024*^9, 
   3.612258468175284*^9}, 3.6156256381986628`*^9, 3.615799070695634*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{"xiz3", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "xiz4"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "xiz5"}], 
          SqrtBox["5"]]}], "\[LongEqual]", 
        RowBox[{"2", " ", "xiz2"}]}]},
      {
       RowBox[{
        RowBox[{"etz3", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "etz4"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "etz5"}], 
          SqrtBox["5"]]}], "\[LongEqual]", 
        RowBox[{"2", " ", "etz2"}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"4", " ", "xiu2"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "xiu4"}]}], "\[LongEqual]", 
        RowBox[{"xiu1", "+", "xiu3", "+", 
         FractionBox[
          RowBox[{"3", " ", "xiu5"}], 
          SqrtBox["5"]]}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"4", " ", "etu2"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox[
           FractionBox["89", "5"]], " ", "etu4"}]}], "\[LongEqual]", 
        RowBox[{"etu1", "+", "etu3", "+", 
         FractionBox[
          RowBox[{"3", " ", "etu5"}], 
          SqrtBox["5"]]}]}]},
      {
       RowBox[{
        RowBox[{"3", " ", "xiv1"}], "\[LongEqual]", 
        RowBox[{
         RowBox[{"2", " ", "xiv2"}], "+", 
         RowBox[{
          SqrtBox["5"], " ", "xiv5"}]}]}]},
      {
       RowBox[{
        RowBox[{"3", " ", "etv1"}], "\[LongEqual]", 
        RowBox[{
         RowBox[{"2", " ", "etv2"}], "+", 
         RowBox[{
          SqrtBox["5"], " ", "etv5"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166557730864*^9, 3.612166613587278*^9, 3.612257786626362*^9, {
   3.612258449865247*^9, 3.6122584694730263`*^9}, 3.612684401222273*^9, 
   3.6144153037766237`*^9, 3.614416733198262*^9, 3.614506942881184*^9, 
   3.6145770516151667`*^9, 3.614578403574582*^9, 3.6149384370663424`*^9, 
   3.615625645137738*^9, 3.615635902921464*^9, 3.61570372215546*^9, 
   3.6157155590397253`*^9, 3.615799182121047*^9, 3.615800373632674*^9, 
   3.615800910881835*^9, 3.616217206120352*^9, 3.6173408817436666`*^9, 
   3.61821995826538*^9, 3.619336163083234*^9, 3.619777648772727*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "=", 
   RowBox[{
    RowBox[{"FindInstance", "[", 
     RowBox[{"conditions", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
       "xi3", ",", "xi4", ",", "xi5", ",", "et3", ",", "et4", ",", "et5"}], 
       "]"}], ",", "5"}], "]"}], "//", "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.612166575888966*^9, 3.612166576370742*^9}, {3.6121666241502*^9, 
   3.612166629642056*^9}, 3.6122577970426483`*^9, {3.6122584771168823`*^9, 
   3.612258481721101*^9}, {3.6156256519370327`*^9, 3.615625681121189*^9}, {
   3.61562725972334*^9, 3.6156272741427593`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol$no", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.615799200394259*^9, 3.61579920842603*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", 
   RowBox[{"sols$pol", "[", 
    RowBox[{"[", "sols$pol$no", "]"}], "]"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.6157163530290813`*^9, 3.615716476062681*^9}, {
   3.615716511701067*^9, 3.61571654575108*^9}, {3.6157165770734453`*^9, 
   3.615716595970683*^9}, 3.615799212685491*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xiz1", "\[Rule]", 
        RowBox[{"4.9`", "\[VeryThinSpace]", "+", 
         RowBox[{"24.5`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "20.7`"}], "-", 
         RowBox[{"22.1`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "4.`"}], "+", 
         RowBox[{"18.4`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "5.6`"}], "-", 
         RowBox[{"20.1`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiz5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "34.15649538910373`"}], "-", 
         RowBox[{"10.893445131496232`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu1", "\[Rule]", 
        RowBox[{"10.`", "\[VeryThinSpace]", "+", 
         RowBox[{"10.5`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu2", "\[Rule]", 
        RowBox[{"14.7`", "\[VeryThinSpace]", "-", 
         RowBox[{"14.`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "0.6`"}], "+", 
         RowBox[{"15.2`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "0.1`"}], "-", 
         RowBox[{"3.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu5", "\[Rule]", 
        RowBox[{"26.443206784234274`", "\[VeryThinSpace]", "-", 
         RowBox[{"60.58111854950905`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv1", "\[Rule]", 
        RowBox[{"20.9`", "\[VeryThinSpace]", "-", 
         RowBox[{"22.5`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "9.4`"}], "-", 
         RowBox[{"15.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv3", "\[Rule]", 
        RowBox[{"6.5`", "\[VeryThinSpace]", "+", 
         RowBox[{"21.4`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiv4", "\[Rule]", "xiv4"}]},
      {
       RowBox[{"xiv5", "\[Rule]", 
        RowBox[{"36.44790803324657`", "\[VeryThinSpace]", "-", 
         RowBox[{"16.502181673948446`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz1", "\[Rule]", "etz1"}]},
      {
       RowBox[{"etz2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "22.`"}], "+", 
         RowBox[{"1.6`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz3", "\[Rule]", 
        RowBox[{"8.8`", "\[VeryThinSpace]", "-", 
         RowBox[{"13.9`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "4.`"}], "+", 
         RowBox[{"23.7`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz5", "\[Rule]", 
        RowBox[{"13.190120452219075`", "\[VeryThinSpace]", "+", 
         RowBox[{"9.496585867934101`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu1", "\[Rule]", 
        RowBox[{"4.7`", "\[VeryThinSpace]", "+", 
         RowBox[{"12.4`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "3.3`"}], "+", 
         RowBox[{"10.9`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "24.`"}], "-", 
         RowBox[{"19.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu4", "\[Rule]", 
        RowBox[{"3.2`", "\[VeryThinSpace]", "+", 
         RowBox[{"10.4`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu5", "\[Rule]", 
        RowBox[{"37.25113947871246`", "\[VeryThinSpace]", "+", 
         RowBox[{"27.577564413719415`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv1", "\[Rule]", 
        RowBox[{"22.`", "\[VeryThinSpace]", "-", 
         RowBox[{"3.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "11.7`"}], "-", 
         RowBox[{"16.7`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "12.8`"}], "-", 
         RowBox[{"3.`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "16.9`"}], "-", 
         RowBox[{"7.3`", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv5", "\[Rule]", 
        RowBox[{"39.98089543769624`", "\[VeryThinSpace]", "+", 
         RowBox[{"10.50951949424901`", " ", "\[ImaginaryI]"}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.615716385781748*^9, 3.6157164766109877`*^9}, {
   3.615716513236689*^9, 3.615716546096121*^9}, {3.6157165774701643`*^9, 
   3.61571659620504*^9}, 3.6157992132997093`*^9, 3.6158003737263527`*^9, 
   3.615800911000637*^9, 3.616217208038286*^9, 3.6173408837686872`*^9, 
   3.6182199601567*^9, 3.619336165004941*^9, 3.619777650674224*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"reprules", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "e"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi3", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "g"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi4", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "i"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"xi5", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "f"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et3", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "h"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et4", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"ii", ",", "j"}], "]"}], "\[Rule]", 
          RowBox[{"min", "[", 
           RowBox[{"et5", ",", 
            RowBox[{"ToExpression", "[", 
             RowBox[{"\"\<k\>\"", "<>", 
              RowBox[{"ToString", "[", "ii", "]"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", "5"}], "}"}]}], "]"}]}], "]"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "sols$no", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"reprules", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612166744922229*^9, 3.6121667659346313`*^9}, {
   3.612166806789146*^9, 3.61216685017785*^9}, {3.612166881494143*^9, 
   3.612166937065545*^9}, {3.612167008004058*^9, 3.612167074754364*^9}, {
   3.612167111235808*^9, 3.612167202273198*^9}, {3.612175654939053*^9, 
   3.6121756683863297`*^9}, {3.612258495288478*^9, 3.612258500192725*^9}, 
   3.6126845445381327`*^9, 3.612685681583201*^9, {3.6145050620116053`*^9, 
   3.6145052111720667`*^9}, {3.615625744383524*^9, 3.6156257519355297`*^9}, 
   3.6157990808877573`*^9, 3.615799232592648*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["128", "5"]}], "-", 
         FractionBox[
          RowBox[{"233", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["79", "5"], "-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "80"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8626"}], "+", 
             RowBox[{"5574", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"56", "+", 
              RowBox[{"201", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "20"], "+", 
           FractionBox["\[ImaginaryI]", "80"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2234", "+", 
             RowBox[{"2578", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"44", "-", 
              RowBox[{"25", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["47", "10"], "-", 
         FractionBox[
          RowBox[{"49", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["247", "10"]}], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1526", "15"], "-", 
           FractionBox[
            RowBox[{"524", " ", "\[ImaginaryI]"}], "3"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["11", "2"], "-", 
            FractionBox["\[ImaginaryI]", "6"]}], ")"}], " ", 
          SqrtBox[
           FractionBox["89", "5"]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1226", "15"]}], "+", 
           FractionBox[
            RowBox[{"587", " ", "\[ImaginaryI]"}], "3"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["11", "2"], "-", 
            FractionBox["\[ImaginaryI]", "6"]}], ")"}], " ", 
          SqrtBox[
           FractionBox["89", "5"]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["303", "10"]}], "+", 
         FractionBox[
          RowBox[{"36", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["23", "2"]}], "+", 
         FractionBox[
          RowBox[{"189", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "50"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"10", " ", "\[ImaginaryI]", " ", 
            SqrtBox["445"], " ", "xiv4"}], "+", 
           RowBox[{"(", 
            RowBox[{"7785", "-", 
             RowBox[{"352", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "50"]}], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"10", " ", 
            SqrtBox["445"], " ", "xiv4"}], "+", 
           RowBox[{"(", 
            RowBox[{"1898", "-", 
             RowBox[{"5695", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "etz1"}], "-", 
         RowBox[{"(", 
          RowBox[{"22", "-", 
           FractionBox[
            RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "etz1"}], "+", 
         RowBox[{"(", 
          RowBox[{"22", "-", 
           FractionBox[
            RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "80"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"80", " ", "etz1"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"237", "+", 
              RowBox[{"40", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}], "-", 
           RowBox[{"(", 
            RowBox[{"6160", "-", 
             RowBox[{"1111", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"3", " ", "etz1"}], "+", 
         RowBox[{
          FractionBox["1", "80"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"6160", "-", 
              RowBox[{"1111", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"237", "+", 
               RowBox[{"40", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
             SqrtBox["445"]}]}], ")"}]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "8"}], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["7", "5"]}], "-", 
         FractionBox[
          RowBox[{"233", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "30"], "+", 
           FractionBox["\[ImaginaryI]", "15"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1116", "+", 
             RowBox[{"575", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"8", "-", 
              RowBox[{"48", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "15"]}], "+", 
           FractionBox["\[ImaginaryI]", "30"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "539"}], "+", 
             RowBox[{"762", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"48", "+", 
              RowBox[{"8", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["337", "10"]}], "-", 
         FractionBox[
          RowBox[{"67", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["103", "10"]}], "+", 
         RowBox[{"20", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["3841", "25"], "+", 
           RowBox[{"68", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["73", "10"], "-", 
            FractionBox[
             RowBox[{"169", " ", "\[ImaginaryI]"}], "10"]}], ")"}], " ", 
          SqrtBox[
           FractionBox["89", "5"]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "50"], "+", 
           FractionBox["\[ImaginaryI]", "50"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4606"}], "+", 
             RowBox[{"876", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"48", "+", 
              RowBox[{"121", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166851224063*^9, {3.612166905867807*^9, 3.612166937604322*^9}, {
   3.6121671678821898`*^9, 3.612167203585627*^9}, 3.612175672435413*^9, 
   3.612257803039179*^9, {3.612258489462837*^9, 3.612258501949951*^9}, 
   3.612684415052841*^9, 3.612684547323617*^9, 3.6126856838647547`*^9, 
   3.614415306130569*^9, 3.614416733525731*^9, 3.614505217112989*^9, 
   3.614506945942827*^9, 3.6145784038082542`*^9, 3.6149384396477423`*^9, 
   3.615625790387403*^9, 3.6156359056548977`*^9, 3.615703722483737*^9, 
   3.615715569373487*^9, 3.615799233576213*^9, 3.6158003737901697`*^9, 
   3.6158009117203903`*^9, 3.616217208740447*^9, 3.617340884524618*^9, 
   3.61821996084603*^9, 3.619336165752192*^9, 3.619777651363634*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"reprules2", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"e", ",", "g"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"e", ",", "i"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"g", ",", "i"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi4", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"f", ",", "h"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"f", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"dc", "[", 
         RowBox[{"h", ",", "j"}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et4", ",", "et5"}], "]"}]}]}], "}"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "sols$no", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"reprules2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612167264558797*^9, 3.612167398925799*^9}, {
   3.612167432691366*^9, 3.61216748291084*^9}, {3.612167533668118*^9, 
   3.612167700191098*^9}, {3.612167759857984*^9, 3.612167800967119*^9}, {
   3.6121682313684673`*^9, 3.612168292531988*^9}, {3.612258517214506*^9, 
   3.612258523383716*^9}, 3.612685688337674*^9, {3.614505237903308*^9, 
   3.614505335631658*^9}, {3.614505373036313*^9, 3.6145055412646427`*^9}, {
   3.615625821871605*^9, 3.615625864432789*^9}, 3.615625909974094*^9, 
   3.6157990869167957`*^9, 3.615799237880918*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], "\[Rule]", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1119679"}], "+", 
              RowBox[{"4692013", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"212165", "+", 
               RowBox[{"40574", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
             SqrtBox["445"]}]}], ")"}]}], "2400"]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "i"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "4000"]}], "+", 
           FractionBox["\[ImaginaryI]", "4000"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "29000"}], "+", 
              RowBox[{"51400", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiv4"}],
            "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"131480", "+", 
              RowBox[{"11671", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}], "+", 
           RowBox[{"(", 
            RowBox[{"3156290", "+", 
             RowBox[{"4390610", " ", "\[ImaginaryI]"}]}], ")"}]}], 
          ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"g", "i"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "1500"]}], "+", 
           FractionBox["\[ImaginaryI]", "750"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1950"}], "+", 
              RowBox[{"1050", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiv4"}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"10502", "+", 
              RowBox[{"8012", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}], "-", 
           RowBox[{"(", 
            RowBox[{"1460456", "-", 
             RowBox[{"1322493", " ", "\[ImaginaryI]"}]}], ")"}]}], 
          ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2400"], "+", 
           FractionBox["\[ImaginaryI]", "2400"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "20520"}], "-", 
              RowBox[{"9240", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etz1"}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"50811", "+", 
              RowBox[{"105994", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}], "-", 
           RowBox[{"(", 
            RowBox[{"812306", "+", 
             RowBox[{"886467", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "j"}]], "\[Rule]", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1079525"}], "+", 
             RowBox[{"659450", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"202478", "+", 
              RowBox[{"91455", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["445"]}]}], "4000"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"22", "-", 
            FractionBox[
             RowBox[{"33", " ", "\[ImaginaryI]"}], "10"]}], ")"}], " ", 
          "etz1"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"h", "j"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["40097", "300"], "+", 
           FractionBox[
            RowBox[{"100717", " ", "\[ImaginaryI]"}], "75"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["25124", "75"], "-", 
            FractionBox[
             RowBox[{"1042", " ", "\[ImaginaryI]"}], "75"]}], ")"}], " ", 
          SqrtBox[
           FractionBox["89", "5"]]}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612167364405326*^9, 3.612167400167985*^9, {3.612167443304433*^9, 
   3.612167483575858*^9}, {3.612167563577479*^9, 3.612167657471463*^9}, 
   3.612167700370111*^9, 3.612167770596114*^9, 3.612167807527257*^9, {
   3.6121682457254963`*^9, 3.61216829281944*^9}, 3.612175692993927*^9, 
   3.61225780705284*^9, {3.6122585063341312`*^9, 3.612258524869982*^9}, 
   3.612684420314109*^9, 3.612684550667274*^9, 3.612685690600247*^9, 
   3.614415307118548*^9, 3.6144167336216383`*^9, 3.614506947221128*^9, 
   3.614578403916479*^9, 3.614938440736401*^9, {3.615625893527792*^9, 
   3.615625910425831*^9}, 3.6156359064782133`*^9, 3.615703722650671*^9, 
   3.6157158165272017`*^9, 3.615799238564086*^9, 3.615800373829967*^9, 
   3.615800912245191*^9, 3.6162172091610537`*^9, 3.6173408849720573`*^9, 
   3.618219961268587*^9, 3.619336166188944*^9, 3.619777651855837*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"reprules3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"e", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi3", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"f", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et3", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"g", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi4", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"h", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et4", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"i", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi5", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"j", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et5", ",", "qq"}], "]"}]}]}], "}"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "sols$no", "]"}], "]"}], ",", 
      RowBox[{"sols$pol", "[", 
       RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "]"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.6156259430430326`*^9, 3.615626074477318*^9}, 
   3.615799090416448*^9, 3.61579924303267*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      FractionBox["161", "10"], "+", 
      FractionBox[
       RowBox[{"64", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["149", "10"]}], "-", 
      FractionBox[
       RowBox[{"179", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      FractionBox["27", "10"], "+", 
      FractionBox[
       RowBox[{"151", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["h",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["172", "5"]}], "-", 
      FractionBox[
       RowBox[{"161", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", "xiv4"}], "+", 
      RowBox[{"(", 
       RowBox[{
        FractionBox["13", "2"], "+", 
        FractionBox[
         RowBox[{"107", " ", "\[ImaginaryI]"}], "5"]}], ")"}]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["11", "2"]}], "-", 
      FractionBox[
       RowBox[{"199", " ", "\[ImaginaryI]"}], "10"]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.61562607519976*^9, 3.615635906544237*^9, 
  3.615703327921301*^9, 3.615703722689159*^9, 3.615715860630789*^9, 
  3.6157992440017347`*^9, 3.6158003738728247`*^9, 3.615800912294634*^9, 
  3.616217209225667*^9, 3.617340885034438*^9, 3.6182199613329*^9, 
  3.6193361662670307`*^9, 3.619777651915122*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmpp2$num5$pols", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"amp5$z$mmpp2$num5", "/.", 
     RowBox[{"Join", "[", 
      RowBox[{"reprules", ",", "reprules2", ",", "reprules3"}], "]"}]}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.615626118625678*^9, 3.615626136381537*^9}, {
  3.6156261905944357`*^9, 3.6156261935485697`*^9}, {3.615626257876563*^9, 
  3.6156262613082438`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["7593885248915077", "80000"], "+", 
        FractionBox[
         RowBox[{"2941930730988079", " ", "\[ImaginaryI]"}], "80000"]}], 
       ")"}], " ", 
      SqrtBox[
       FractionBox["89", "5"]], " ", "etz1", " ", 
      SuperscriptBox["z", "3"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "5"}], "+", 
           SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]]}], "+", 
   
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["185587976097319649", "400000"], "+", 
       FractionBox[
        RowBox[{"22586493680171209", " ", "\[ImaginaryI]"}], "80000"]}], 
      ")"}], " ", "etz1", " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["28665279497683", "8000"], "+", 
       FractionBox[
        RowBox[{"22454083637091", " ", "\[ImaginaryI]"}], "8000"]}], ")"}], 
     " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "etz1", " ", "xiv4", " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["647232491129141", "40000"], "+", 
       FractionBox[
        RowBox[{"144862224602103", " ", "\[ImaginaryI]"}], "8000"]}], ")"}], 
     " ", "etz1", " ", "xiv4", " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["25913393381377081", "48000"], "+", 
       FractionBox[
        RowBox[{"203026959668780449", " ", "\[ImaginaryI]"}], "240000"]}], 
      ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "xiv4", " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["11637297214283876287", "4800000"], "+", 
       FractionBox[
        RowBox[{"17879218993418347433", " ", "\[ImaginaryI]"}], "4800000"]}], 
      ")"}], " ", "xiv4", " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["8184816659308841171", "480000"], "+", 
       FractionBox[
        RowBox[{"11675305506723821587", " ", "\[ImaginaryI]"}], "800000"]}], 
      ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["3652530838428942108563", "48000000"], "+", 
       FractionBox[
        RowBox[{"1023242848554358130669", " ", "\[ImaginaryI]"}], 
        "16000000"]}], ")"}], " ", 
     SuperscriptBox["z", "3"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["370286114456444287", "360000"], "+", 
       FractionBox[
        RowBox[{"232594172129596403", " ", "\[ImaginaryI]"}], "720000"]}], 
      ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "etz1", " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["7504372526202387683", "1800000"], "+", 
       FractionBox[
        RowBox[{"2005600476383595049", " ", "\[ImaginaryI]"}], "3600000"]}], 
      ")"}], " ", "etz1", " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["3431031558967799", "72000"], "+", 
       FractionBox[
        RowBox[{"262016799134453", " ", "\[ImaginaryI]"}], "12000"]}], ")"}], 
     " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "etz1", " ", "xiv4", " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["15650026206255437", "72000"], "+", 
       FractionBox[
        RowBox[{"3436600725324601", " ", "\[ImaginaryI]"}], "60000"]}], ")"}],
      " ", "etz1", " ", "xiv4", " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["37236541571191145503", "5760000"], "+", 
       FractionBox[
        RowBox[{"24757661888581304201", " ", "\[ImaginaryI]"}], "5760000"]}], 
      ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "xiv4", " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["769002283027860255893", "28800000"], "+", 
       FractionBox[
        RowBox[{"484000272962863663303", " ", "\[ImaginaryI]"}], 
        "28800000"]}], ")"}], " ", "xiv4", " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["7285308327467757383587", "57600000"], "+", 
       FractionBox[
        RowBox[{"4299678589193786792663", " ", "\[ImaginaryI]"}], 
        "57600000"]}], ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["29109150085852528103413", "57600000"], "+", 
       FractionBox[
        RowBox[{"85531690333473700409809", " ", "\[ImaginaryI]"}], 
        "288000000"]}], ")"}], " ", 
     SuperscriptBox["z", "2"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["5040208261210076011", "240000"], "+", 
       FractionBox[
        RowBox[{"264186724837454740583", " ", "\[ImaginaryI]"}], "7200000"]}],
       ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "etz1", " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["22383886424661241823", "300000"], "+", 
       FractionBox[
        RowBox[{"5851975252780358715589", " ", "\[ImaginaryI]"}], 
        "36000000"]}], ")"}], " ", "etz1", " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["894969838361405", "1152"], "-", 
       FractionBox[
        RowBox[{"103746899761857019", " ", "\[ImaginaryI]"}], "360000"]}], 
      ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "etz1", " ", "xiv4", " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1115812325686582897", "360000"], "-", 
       FractionBox[
        RowBox[{"1006207573836782051", " ", "\[ImaginaryI]"}], "720000"]}], 
      ")"}], " ", "etz1", " ", "xiv4", " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1064050012386068418631", "19200000"], "+", 
       FractionBox[
        RowBox[{"156622886613061941239", " ", "\[ImaginaryI]"}], 
        "19200000"]}], ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "xiv4", " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1449482957642571529307", "6400000"], "+", 
       FractionBox[
        RowBox[{"747915128785322485039", " ", "\[ImaginaryI]"}], 
        "19200000"]}], ")"}], " ", "xiv4", " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["32247646520121787221257", "288000000"], "-", 
       FractionBox[
        RowBox[{"23241278450327704740523", " ", "\[ImaginaryI]"}], 
        "9600000"]}], ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["55317663954737487710639", "180000000"], "-", 
       FractionBox[
        RowBox[{"1717099893330058329172583", " ", "\[ImaginaryI]"}], 
        "160000000"]}], ")"}], " ", "z"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["20979907800059174819", "1440000"], "+", 
       FractionBox[
        RowBox[{"258654437276327233883", " ", "\[ImaginaryI]"}], "7200000"]}],
       ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "etz1"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["119739051773622954209", "1440000"], "+", 
       FractionBox[
        RowBox[{"1016748356682329226491", " ", "\[ImaginaryI]"}], 
        "7200000"]}], ")"}], " ", "etz1"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["184951028329029541", "288000"], "-", 
       FractionBox[
        RowBox[{"102176223323196857", " ", "\[ImaginaryI]"}], "288000"]}], 
      ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "etz1", " ", "xiv4"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["33901953470212579", "11520"], "-", 
       FractionBox[
        RowBox[{"1652297109625801423", " ", "\[ImaginaryI]"}], "1440000"]}], 
      ")"}], " ", "etz1", " ", "xiv4"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["20831464502397515299", "460800"], "+", 
       FractionBox[
        RowBox[{"2172345163793153183", " ", "\[ImaginaryI]"}], "384000"]}], 
      ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]], " ", "xiv4"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["11713739204907978397439", "57600000"], "+", 
       FractionBox[
        RowBox[{"46235942292538595209", " ", "\[ImaginaryI]"}], "2400000"]}], 
      ")"}], " ", "xiv4"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["31226435763148528552231", "192000000"], "-", 
       FractionBox[
        RowBox[{"1376052025680516586225573", " ", "\[ImaginaryI]"}], 
        "576000000"]}], ")"}], " ", 
     SqrtBox[
      FractionBox["89", "5"]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     FractionBox["167157799699784597885713", "192000000"], "-", 
     FractionBox[
      RowBox[{"5366659434284452794801967", " ", "\[ImaginaryI]"}], 
      "576000000"]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "10"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "15"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          SqrtBox["445"]}], ")"}], " ", "z"}], "+", "25"}], ")"}]}]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.615626165446826*^9, 3.6156262294598*^9, 
  3.615626285066786*^9, 3.61563594130284*^9, 3.615703367070438*^9, 
  3.6157037475285187`*^9, 3.6157158928037024`*^9, 3.615799256968678*^9, 
  3.615800376683827*^9, 3.615800940000246*^9, 3.616217236007333*^9, 
  3.617340913976832*^9, 3.618219987813389*^9, 3.619336192943841*^9, 
  3.6197776795002604`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp5$z$mmpp2$num5$pols", "]"}]], "Input",
 CellChangeTimes->{{3.615626151915247*^9, 3.6156261532414713`*^9}, {
  3.6156262481030903`*^9, 3.615626269853163*^9}}],

Cell[BoxData[
 FormBox["32", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6156261659116507`*^9, {3.6156262297129717`*^9, 3.615626252640942*^9}, 
   3.615626285228375*^9, 3.6156359414022303`*^9, 3.6157033671342707`*^9, 
   3.615703420047542*^9, 3.615703747595233*^9, 3.6157158967618*^9, 
   3.6157992706283207`*^9, 3.6158003767615347`*^9, 3.615800940087027*^9, 
   3.616217236072466*^9, 3.61734091401476*^9, 3.618219987877657*^9, 
   3.619336192997073*^9, 3.6197776795579348`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp5$z$mmppTaylor", "=", 
  RowBox[{"Series", "[", 
   RowBox[{"amp5$z$mmpp2$num5$pols", ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61562636012924*^9, 3.615626377507485*^9}, {
   3.615626457731526*^9, 3.615626461185981*^9}, 3.615626561820788*^9, {
   3.615626603494576*^9, 3.615626608154716*^9}, {3.61570343608624*^9, 
   3.61570344895673*^9}, {3.615716983707404*^9, 3.615717047364599*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox["445"], "-", "5"}], ")"}], "3"]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["199", "48000000"], "-", 
         FractionBox[
          RowBox[{"11", " ", "\[ImaginaryI]"}], "9600000"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"125822249894400", "+", 
            RowBox[{"170176503058800", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          SqrtBox["445"], " ", "etz1", " ", "xiv4"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2504447632030800", "+", 
            RowBox[{"5059889283288000", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          "etz1", " ", "xiv4"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3798743417622360", "+", 
            RowBox[{"2823932541144720", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          
          SqrtBox["445"], " ", "etz1"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"86484459666831120", "+", 
            RowBox[{"92002721054163000", " ", "\[ImaginaryI]"}]}], ")"}], " ",
           "etz1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"13716833512586000", "+", 
            RowBox[{"44600523768560040", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          SqrtBox["445"], " ", "xiv4"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"312594449632731730", "+", 
            RowBox[{"984848666653184520", " ", "\[ImaginaryI]"}]}], ")"}], 
          " ", "xiv4"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"583443641664980660", "+", 
            RowBox[{"865291790815375856", " ", "\[ImaginaryI]"}]}], ")"}], 
          " ", 
          SqrtBox["445"]}], "-", 
         RowBox[{"(", 
          RowBox[{"13091037555386158402", "+", 
           RowBox[{"19043897543765392483", " ", "\[ImaginaryI]"}]}], ")"}]}], 
        ")"}]}]}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "16501182610431766000"}], "-", 
          RowBox[{"3675154137858049200", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
        SqrtBox["445"], " ", "etz1", " ", "xiv4"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"325361015577788606000", "+", 
          RowBox[{"95348574018799158000", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "etz1", " ", "xiv4"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"305887156699148671720", "+", 
          RowBox[{"36894050161738830280", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", 
        SqrtBox["445"], " ", "etz1"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6421675557689309004200", "+", 
          RowBox[{"1254255963984063086600", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "etz1"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1999261576488883743520", "+", 
          RowBox[{"910390577008084113770", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", 
        SqrtBox["445"], " ", "xiv4"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"42310208125085495355500", "+", 
          RowBox[{"20183488018018736140150", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "xiv4"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"33215848027687095102250", "+", 
          RowBox[{"16249745863809219164981", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", 
        SqrtBox["445"]}], "+", 
       RowBox[{"(", 
        RowBox[{"718482926585195651428160", "+", 
         RowBox[{"355024215039920326795495", " ", "\[ImaginaryI]"}]}], 
        ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"72000000", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox["445"], "-", "5"}], ")"}], "4"], " ", "z"}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SqrtBox["445"], "-", "5"}], ")"}], "5"], " ", 
       SuperscriptBox["z", "2"]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "144000000"], "+", 
        FractionBox["\[ImaginaryI]", "144000000"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3452794813399225670800"}], "+", 
           RowBox[{"9796255699251902497200", " ", "\[ImaginaryI]"}]}], ")"}], 
         " ", 
         SqrtBox["445"], " ", "etz1", " ", "xiv4"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"65961568923898431344000", "-", 
           RowBox[{"209034662614856295552000", " ", "\[ImaginaryI]"}]}], 
          ")"}], " ", "etz1", " ", "xiv4"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"542621420115884888983200", "+", 
           RowBox[{"183618428999624814867400", " ", "\[ImaginaryI]"}]}], 
          ")"}], " ", 
         SqrtBox["445"], " ", "etz1"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"11297316405020598642560760", "+", 
           RowBox[{"4249987017230924979908960", " ", "\[ImaginaryI]"}]}], 
          ")"}], " ", "etz1"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"460452621700815487014675", "-", 
           RowBox[{"403860416929712625197255", " ", "\[ImaginaryI]"}]}], 
          ")"}], " ", 
         SqrtBox["445"], " ", "xiv4"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"9588523045359075491630625", "-", 
           RowBox[{"8340705091647475465930075", " ", "\[ImaginaryI]"}]}], 
          ")"}], " ", "xiv4"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"20306513284701938791077293", "+", 
           RowBox[{"25966872760212133316837984", " ", "\[ImaginaryI]"}]}], 
          ")"}], " ", 
         SqrtBox["445"]}], "+", 
        RowBox[{"(", 
         RowBox[{"439237355305764252323567140", "+", 
          RowBox[{"554727426512066598561451744", " ", "\[ImaginaryI]"}]}], 
         ")"}]}], ")"}]}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {(Complex[
        Rational[-199, 48000000], 
        Rational[11, 9600000]] (-5 + 445^Rational[1, 2])^(-3)) (
      Complex[-13091037555386158402, -19043897543765392483] + 
      Complex[583443641664980660, 865291790815375856] 445^Rational[1, 2] + 
      Complex[-86484459666831120, -92002721054163000] $CellContext`etz1 + (
        Complex[3798743417622360, 2823932541144720] 
        445^Rational[1, 2]) $CellContext`etz1 + 
      Complex[-312594449632731730, -984848666653184520] $CellContext`xiv4 + (
        Complex[13716833512586000, 44600523768560040] 
        445^Rational[1, 2]) $CellContext`xiv4 + (
        Complex[-2504447632030800, -5059889283288000] $CellContext`etz1) \
$CellContext`xiv4 + ((Complex[125822249894400, 170176503058800] 
         445^Rational[1, 2]) $CellContext`etz1) $CellContext`xiv4), (
      Rational[1, 72000000] (-5 + 445^Rational[1, 2])^(-4)) (
      Complex[718482926585195651428160, 355024215039920326795495] + 
      Complex[-33215848027687095102250, -16249745863809219164981] 
       445^Rational[1, 2] + 
      Complex[6421675557689309004200, 
         1254255963984063086600] $CellContext`etz1 + (
        Complex[-305887156699148671720, -36894050161738830280] 
        445^Rational[1, 2]) $CellContext`etz1 + 
      Complex[42310208125085495355500, 
         20183488018018736140150] $CellContext`xiv4 + (
        Complex[-1999261576488883743520, -910390577008084113770] 
        445^Rational[1, 2]) $CellContext`xiv4 + (
        Complex[325361015577788606000, 
          95348574018799158000] $CellContext`etz1) $CellContext`xiv4 + ((
         Complex[-16501182610431766000, -3675154137858049200] 
         445^Rational[1, 2]) $CellContext`etz1) $CellContext`xiv4), (Complex[
        Rational[1, 144000000], 
        Rational[1, 144000000]] (-5 + 445^Rational[1, 2])^(-5)) (
      Complex[439237355305764252323567140, 554727426512066598561451744] + 
      Complex[-20306513284701938791077293, -25966872760212133316837984] 
       445^Rational[1, 2] + 
      Complex[11297316405020598642560760, 
         4249987017230924979908960] $CellContext`etz1 + (
        Complex[-542621420115884888983200, -183618428999624814867400] 
        445^Rational[1, 2]) $CellContext`etz1 + 
      Complex[9588523045359075491630625, -8340705091647475465930075] \
$CellContext`xiv4 + (
        Complex[-460452621700815487014675, 403860416929712625197255] 
        445^Rational[1, 2]) $CellContext`xiv4 + (
        Complex[65961568923898431344000, -209034662614856295552000] \
$CellContext`etz1) $CellContext`xiv4 + ((
         Complex[-3452794813399225670800, 9796255699251902497200] 
         445^Rational[1, 2]) $CellContext`etz1) $CellContext`xiv4)}, 0, 3, 1],
   
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6156263626072187`*^9, 3.615626383021606*^9}, 
   3.6156264615986013`*^9, 3.61562656226861*^9, 3.61562660880966*^9, 
   3.615635942260517*^9, 3.6157033680429497`*^9, {3.6157034219546413`*^9, 
   3.6157034404373703`*^9}, 3.6157037476694117`*^9, 3.615715901702347*^9, {
   3.615716987642564*^9, 3.615717047731558*^9}, 3.6157992808309107`*^9, 
   3.615800376795998*^9, 3.615800940496398*^9, 3.616217236453329*^9, 
   3.617340914412372*^9, 3.618219988259725*^9, 3.619336193376317*^9, 
   3.619777679944866*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", "amp5$z$mmppTaylor", "]"}]], "Input",
 CellChangeTimes->{{3.6157160787593*^9, 3.6157160794961*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "9.94344841999479`*^-10"}], "+", 
       RowBox[{"2.7481892618076047`*^-10", " ", "\[ImaginaryI]"}]}], ")"}], 
     " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.497756372096635`*^14", "-", 
          RowBox[{"1.470012018529748`*^15", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "etz1", " ", "xiv4"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6.34987948415656`*^15", "+", 
          RowBox[{"3.243179883839943`*^16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "etz1"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.3237529692425024`*^16", "+", 
          RowBox[{"4.399958704939341`*^16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "xiv4"}], "-", 
       RowBox[{"(", 
        RowBox[{"7.83280451238955`*^17", "+", 
         RowBox[{"7.905472198562591`*^17", " ", "\[ImaginaryI]"}]}], ")"}]}], 
      ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "z"], 
     RowBox[{"2.0696699075549345`*^-13", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2.2731812927127618`*^19"}], "+", 
           RowBox[{"1.7821112548867506`*^19", " ", "\[ImaginaryI]"}]}], ")"}],
          " ", "etz1", " ", "xiv4"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3.102108184852352`*^19", "-", 
           RowBox[{"4.7597512321068184`*^20", " ", "\[ImaginaryI]"}]}], ")"}],
          " ", "etz1"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.357389666592804`*^20", "+", 
           RowBox[{"9.787777571536943`*^20", " ", "\[ImaginaryI]"}]}], ")"}], 
         " ", "xiv4"}], "+", 
        RowBox[{"(", 
         RowBox[{"1.7793844831890407`*^22", "+", 
          RowBox[{"1.2235450515641808`*^22", " ", "\[ImaginaryI]"}]}], 
         ")"}]}], ")"}]}]}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "2"]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.42953381751865`*^-15", "+", 
        RowBox[{"6.42953381751865`*^-15", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6.875217457910626`*^21"}], "-", 
           RowBox[{"2.3824222503231145`*^21", " ", "\[ImaginaryI]"}]}], ")"}],
          " ", "etz1", " ", "xiv4"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.4929499215795465`*^23", "-", 
           RowBox[{"3.765520141117081`*^23", " ", "\[ImaginaryI]"}]}], ")"}], 
         " ", "etz1"}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1.2473565035492728`*^23", "-", 
           RowBox[{"1.78739736589596`*^23", " ", "\[ImaginaryI]"}]}], ")"}], 
         " ", "xiv4"}], "+", 
        RowBox[{"(", 
         RowBox[{"1.0870988286958083`*^25", "+", 
          RowBox[{"6.955645547999567`*^24", " ", "\[ImaginaryI]"}]}], ")"}]}],
        ")"}]}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {
    Complex[-9.94344841999479*^-10, 2.7481892618076047`*^-10] (
      Complex[-7.83280451238955*^17, -7.905472198562591*^17] + 
      Complex[-6.34987948415656*^15, -3.243179883839943*^16] \
$CellContext`etz1 + 
      Complex[-2.3237529692425024`*^16, -4.399958704939341*^16] \
$CellContext`xiv4 + (
        Complex[1.497756372096635*^14, -1.470012018529748*^15] \
$CellContext`etz1) $CellContext`xiv4), 
     2.0696699075549345`*^-13 (
      Complex[1.7793844831890407`*^22, 1.2235450515641808`*^22] + 
      Complex[-3.102108184852352*^19, 
         4.7597512321068184`*^20] $CellContext`etz1 + 
      Complex[1.357389666592804*^20, 
         9.787777571536943*^20] $CellContext`xiv4 + (
        Complex[-2.2731812927127618`*^19, 
          1.7821112548867506`*^19] $CellContext`etz1) $CellContext`xiv4), 
     Complex[6.42953381751865*^-15, 6.42953381751865*^-15] (
      Complex[1.0870988286958083`*^25, 6.955645547999567*^24] + 
      Complex[-1.4929499215795465`*^23, 
         3.765520141117081*^23] $CellContext`etz1 + 
      Complex[-1.2473565035492728`*^23, 
         1.78739736589596*^23] $CellContext`xiv4 + (
        Complex[-6.875217457910626*^21, -2.3824222503231145`*^21] \
$CellContext`etz1) $CellContext`xiv4)}, 0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.615716079900894*^9, {3.615799291448784*^9, 3.6157992960473824`*^9}, 
   3.615800376843617*^9, 3.6158009405345497`*^9, 3.61621723649866*^9, 
   3.617340914455736*^9, 3.6182199883191566`*^9, 3.619336193424232*^9, 
   3.619777679995392*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["z", "0"], TraditionalForm]]],
 " scaling!"
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.615626182633637*^9, {3.615627535754664*^9, 
   3.615627573577817*^9}, {3.6158035818089857`*^9, 3.615803586678727*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
   3.604652950305522*^9}, 3.604653026772519*^9, {3.61580057893937*^9, 
   3.615800580314097*^9}, 3.615803593990686*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Investigating the \[CurlyPhi] pole structure (eeeeee amplitude)", \
"Section",
 CellChangeTimes->{{3.615001410063856*^9, 3.61500141931849*^9}, {
  3.615003513060601*^9, 3.615003517099753*^9}, {3.616221481114705*^9, 
  3.616221483034251*^9}}],

Cell[TextData[{
 "First we define the remainder that results from computing the Ward identity \
of the 4e amplitude:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["A", 
      RowBox[{"ij", "..."}]], 
     SubscriptBox["p", "i"]}], "=", 
    RowBox[{
     SuperscriptBox["p", "j"], 
     SuperscriptBox["A", "..."]}]}], TraditionalForm]]],
 "\nHere the remainder is ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["A", "..."], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.615626182633637*^9, {3.615627535754664*^9, 
   3.615627573577817*^9}, {3.6158035818089857`*^9, 3.615803586678727*^9}, {
   3.616302329106204*^9, 3.616302482882966*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A4e$wardremainder", "[", 
    RowBox[{
    "x_", ",", "ia_", ",", "ib_", ",", "y_", ",", "ic_", ",", "id_", ",", 
     "z_", ",", "ie_", ",", "if_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"amp4$wardremainder", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"c", "\[Rule]", "ia"}], ",", 
        RowBox[{"d", "\[Rule]", "ib"}], ",", 
        RowBox[{"e", "\[Rule]", "ic"}], ",", 
        RowBox[{"f", "\[Rule]", "id"}], ",", 
        RowBox[{"g", "\[Rule]", "ie"}], ",", 
        RowBox[{"h", "\[Rule]", "if"}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"2", ",", "ee_"}], "]"}], "\[Rule]", 
       RowBox[{"kc", "[", 
        RowBox[{"x", ",", "ee"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "ee_"}], "]"}], "\[Rule]", 
       RowBox[{"kc", "[", 
        RowBox[{"y", ",", "ee"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "ee_"}], "]"}], "\[Rule]", 
       RowBox[{"kc", "[", 
        RowBox[{"z", ",", "ee"}], "]"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616300616012846*^9, 3.616300673844586*^9}, {
  3.616300720492848*^9, 3.616300900436598*^9}, {3.6163010117938843`*^9, 
  3.616301019788104*^9}, {3.6163011293652554`*^9, 3.616301170011714*^9}, {
  3.616301296767293*^9, 3.616301382507565*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A4e$wardremainder", "[", 
   RowBox[{
   "2", ",", "c", ",", "d", ",", "3", ",", "e", ",", "f", ",", "4", ",", "g", 
    ",", "h"}], "]"}], "-", "amp4$wardremainder"}]], "Input",
 CellChangeTimes->{{3.6170095964219227`*^9, 3.6170096038614893`*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.617009605807304*^9, 3.6173409145184593`*^9, 
  3.618219988378603*^9, 3.619336193484172*^9, 3.619777680056321*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A4e$wardremainder", "[", 
  RowBox[{
  "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "4", ",", "g", 
   ",", "h"}], "]"}]], "Input",
 CellChangeTimes->{{3.616300909227153*^9, 3.6163009668210373`*^9}, {
   3.616301024952463*^9, 3.616301030406467*^9}, 3.6163013617887297`*^9, 
   3.616301452891478*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.616300936980872*^9, 3.616300967782936*^9}, {
   3.61630103161259*^9, 3.616301036646975*^9}, {3.616301153078557*^9, 
   3.616301171390008*^9}, 3.616301267222252*^9, 3.6163012979902973`*^9, {
   3.616301359630868*^9, 3.616301385059835*^9}, 3.6163014531642036`*^9, 
   3.6173409145657377`*^9, 3.618219988425091*^9, 3.6193361935319977`*^9, 
   3.619777680102372*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A4e$wardremainder", "[", 
  RowBox[{
  "2", ",", "c", ",", "d", ",", "5", ",", "o", ",", "p", ",", "6", ",", "u", 
   ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{{3.616301477290872*^9, 3.616301518389985*^9}, 
   3.616301633083474*^9, 3.616301722691557*^9, 3.616302300074357*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.616301526230875*^9, 3.6163016343472357`*^9, 
  3.616301723242079*^9, 3.616302300559287*^9, 3.617340914617259*^9, 
  3.618219988471941*^9, 3.6193361935824423`*^9, 3.619777680173766*^9}]
}, Open  ]],

Cell[TextData[{
 "Then we define the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["e", "3"], "\[CurlyPhi]"}], TraditionalForm]]],
 " amplitude:"
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.615626182633637*^9, {3.615627535754664*^9, 
   3.615627573577817*^9}, {3.6158035818089857`*^9, 3.615803586678727*^9}, {
   3.616302329106204*^9, 3.6163025040243473`*^9}, {3.6163025715999107`*^9, 
   3.616302602897203*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"A3e\[CurlyPhi]", "[", 
    RowBox[{
    "x_", ",", "ia_", ",", "ib_", ",", "y_", ",", "ic_", ",", "id_", ",", 
     "z_", ",", "ie_", ",", "if_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"ampEEEVarphi$simple", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "ia"}], ",", 
        RowBox[{"b", "\[Rule]", "ib"}], ",", 
        RowBox[{"c", "\[Rule]", "ic"}], ",", 
        RowBox[{"d", "\[Rule]", "id"}], ",", 
        RowBox[{"e", "\[Rule]", "ie"}], ",", 
        RowBox[{"f", "\[Rule]", "if"}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"1", ",", "ee_"}], "]"}], "\[Rule]", 
       RowBox[{"kc", "[", 
        RowBox[{"x", ",", "ee"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"2", ",", "ee_"}], "]"}], "\[Rule]", 
       RowBox[{"kc", "[", 
        RowBox[{"y", ",", "ee"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "ee_"}], "]"}], "\[Rule]", 
       RowBox[{"kc", "[", 
        RowBox[{"z", ",", "ee"}], "]"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.615008932953882*^9, 3.6150090312350483`*^9}, {
   3.615009076237915*^9, 3.615009175153873*^9}, {3.61500923325574*^9, 
   3.615009301056024*^9}, {3.615017827156567*^9, 3.6150178419830236`*^9}, {
   3.615018315531745*^9, 3.6150183240032473`*^9}, 3.615018424827182*^9, {
   3.616302665343779*^9, 3.616302687969277*^9}, {3.6163027880421343`*^9, 
   3.616302929394709*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"A3e\[CurlyPhi]", "[", 
   RowBox[{
   "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "2", ",", "c", 
    ",", "d"}], "]"}], "-", "ampEEEVarphi$simple"}]], "Input",
 CellChangeTimes->{{3.617009622983571*^9, 3.617009644439808*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.61700963767494*^9, 3.617009645043672*^9}, 
   3.61734091467732*^9, 3.618219988518568*^9, 3.619336193636228*^9, 
   3.619777680257031*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A3e\[CurlyPhi]", "[", 
  RowBox[{
  "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "4", ",", "g", 
   ",", "h"}], "]"}]], "Input",
 CellChangeTimes->{{3.616302934796051*^9, 3.616302961826106*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["b",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"f", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["a",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"e", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "g"}]], " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["e",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["1",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["h",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "f"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6163029526427393`*^9, 3.616302962228224*^9}, 
   3.617340914749196*^9, 3.6182199885746393`*^9, 3.619336193683004*^9, 
   3.6197776803240843`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A3e\[CurlyPhi]", "[", 
  RowBox[{
  "2", ",", "c", ",", "d", ",", "5", ",", "o", ",", "p", ",", "6", ",", "u", 
   ",", "v"}], "]"}]], "Input",
 CellChangeTimes->{3.616302976290058*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["d",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"p", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["p",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "v"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["6",
      TraditionalForm], 
     FormBox[
      FormBox["c",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"o", "u"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["o",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "u"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
    SubsuperscriptBox["k", 
     FormBox["2",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["5",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.616302977121725*^9, 3.61734091483187*^9, 
  3.618219988665638*^9, 3.6193361937685623`*^9, 3.619777680454763*^9}]
}, Open  ]],

Cell["Now we have to sum 6 residues:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.615626182633637*^9, {3.615627535754664*^9, 
   3.615627573577817*^9}, {3.6158035818089857`*^9, 3.615803586678727*^9}, {
   3.616302329106204*^9, 3.6163025040243473`*^9}, {3.6163025715999107`*^9, 
   3.616302602897203*^9}, {3.6163030265595512`*^9, 3.616303038022621*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"residue134", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "s134"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "4", 
             ",", "g", ",", "h"}], "]"}], 
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "5", ",", "o", ",", "p", ",", "6", 
             ",", "u", ",", "v"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"1", "/", "16"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "4", 
             ",", "g", ",", "h"}], "]"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "5", ",", "o", ",", "p", ",", "6", 
             ",", "u", ",", "v"}], "]"}]}]}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e"}], "]"}], "+", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e"}], "]"}], "-", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}]}], "}"}]}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s134"}], "/", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
           FullForm], "+", 
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True]}], 
         StyleBox[")",
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616303158708231*^9, 3.616303194539942*^9}, 
   3.616303225640554*^9, {3.616303750117805*^9, 3.6163037883450413`*^9}, {
   3.616303826946178*^9, 3.61630386969279*^9}, {3.616303906638454*^9, 
   3.616303935306404*^9}, {3.6163039739320993`*^9, 3.616303984599699*^9}, {
   3.61630402725368*^9, 3.616304084796977*^9}, {3.616304135325795*^9, 
   3.616304174809568*^9}, {3.616304219896071*^9, 3.6163042370779047`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "residue134", "]"}]], "Input",
 CellChangeTimes->{{3.616304165543777*^9, 3.616304168538165*^9}}],

Cell[BoxData[
 FormBox["2636", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6163041692220488`*^9, 3.616304175692142*^9}, {
   3.616304233277639*^9, 3.616304238057891*^9}, 3.617340914972005*^9, 
   3.6182199887804937`*^9, 3.6193361938923817`*^9, 3.6197776806366253`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"residue135", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "s135"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "5", 
             ",", "o", ",", "p"}], "]"}], 
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "4", ",", "g", ",", "h", ",", "6", 
             ",", "u", ",", "v"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"1", "/", "16"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "5", 
             ",", "o", ",", "p"}], "]"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "4", ",", "g", ",", "h", ",", "6", 
             ",", "u", ",", "v"}], "]"}]}]}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e"}], "]"}], "+", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e"}], "]"}], "-", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}]}], "}"}]}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s135"}], "/", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
           FullForm], "+", 
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True]}], 
         StyleBox[")",
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616303158708231*^9, 3.616303194539942*^9}, 
   3.616303225640554*^9, {3.616303750117805*^9, 3.6163037883450413`*^9}, {
   3.616303826946178*^9, 3.61630386969279*^9}, {3.616303906638454*^9, 
   3.616303935306404*^9}, {3.6163039739320993`*^9, 3.616303984599699*^9}, {
   3.61630402725368*^9, 3.616304084796977*^9}, {3.616304135325795*^9, 
   3.616304174809568*^9}, {3.6163042437154303`*^9, 3.616304308827917*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "residue135", "]"}]], "Input",
 CellChangeTimes->{{3.6163043167524137`*^9, 3.616304316824605*^9}}],

Cell[BoxData[
 FormBox["2636", TraditionalForm]], "Output",
 CellChangeTimes->{3.6163043171814737`*^9, 3.61734091513276*^9, 
  3.618219988922228*^9, 3.619336194001066*^9, 3.619777680742591*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"residue136", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "s136"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "6", 
             ",", "u", ",", "v"}], "]"}], 
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "5", ",", "o", ",", "p", ",", "4", 
             ",", "g", ",", "h"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"1", "/", "16"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "3", ",", "e", ",", "f", ",", "6", 
             ",", "u", ",", "v"}], "]"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "5", ",", "o", ",", "p", ",", "4", 
             ",", "g", ",", "h"}], "]"}]}]}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e"}], "]"}], "+", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e"}], "]"}], "-", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}]}], "}"}]}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{
        RowBox[{"s136", "/", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
           FullForm], "+", 
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True]}], 
         StyleBox[")",
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616304345930006*^9, 3.616304395306512*^9}, {
  3.6163050629677267`*^9, 3.616305081237267*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "residue136", "]"}]], "Input",
 CellChangeTimes->{3.616304332641851*^9}],

Cell[BoxData[
 FormBox["2636", TraditionalForm]], "Output",
 CellChangeTimes->{3.6163044090461073`*^9, 3.6173409152238398`*^9, 
  3.618219989009424*^9, 3.619336194089426*^9, 3.619777680860408*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"residue145", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "s145"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "5", ",", "o", ",", "p", ",", "4", 
             ",", "g", ",", "h"}], "]"}], 
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "3", ",", "e", ",", "f", ",", "6", 
             ",", "u", ",", "v"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"1", "/", "16"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "5", ",", "o", ",", "p", ",", "4", 
             ",", "g", ",", "h"}], "]"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "3", ",", "e", ",", "f", ",", "6", 
             ",", "u", ",", "v"}], "]"}]}]}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e"}], "]"}], "+", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e"}], "]"}], "-", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}]}], "}"}]}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "s145"}], "/", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
           FullForm], "+", 
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True]}], 
         StyleBox[")",
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616304422895483*^9, 3.616304474427631*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "residue145", "]"}]], "Input",
 CellChangeTimes->{{3.616304487205913*^9, 3.616304489177478*^9}}],

Cell[BoxData[
 FormBox["2636", TraditionalForm]], "Output",
 CellChangeTimes->{3.616304489580956*^9, 3.617340915315852*^9, 
  3.618219989119618*^9, 3.61933619421451*^9, 3.619777680964813*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"residue146", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "s146"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "6", ",", "u", ",", "v", ",", "4", 
             ",", "g", ",", "h"}], "]"}], 
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "3", ",", "e", ",", "f", ",", "5", 
             ",", "o", ",", "p"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"1", "/", "16"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "6", ",", "u", ",", "v", ",", "4", 
             ",", "g", ",", "h"}], "]"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "3", ",", "e", ",", "f", ",", "5", 
             ",", "o", ",", "p"}], "]"}]}]}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e"}], "]"}], "+", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e"}], "]"}], "-", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}]}], "}"}]}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{
        RowBox[{"s146", "/", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
           FullForm], "+", 
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True]}], 
         StyleBox[")",
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616304422895483*^9, 3.616304474427631*^9}, {
  3.616304509681415*^9, 3.616304553777182*^9}, {3.61630504062844*^9, 
  3.61630505054531*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "residue146", "]"}]], "Input",
 CellChangeTimes->{{3.616304487205913*^9, 3.616304489177478*^9}, 
   3.616304566938448*^9}],

Cell[BoxData[
 FormBox["2636", TraditionalForm]], "Output",
 CellChangeTimes->{3.616304489580956*^9, 3.616304567048438*^9, 
  3.6173409154047747`*^9, 3.618219989204557*^9, 3.619336194302492*^9, 
  3.6197776810503063`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"residue156", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "s156"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "6", ",", "u", ",", "v", ",", "5", 
             ",", "o", ",", "p"}], "]"}], 
           RowBox[{"A4e$wardremainder", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "3", ",", "e", ",", "f", ",", "4", 
             ",", "g", ",", "h"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"1", "/", "16"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "1", ",", "a", ",", "b", ",", "6", ",", "u", ",", "v", ",", "5", 
             ",", "o", ",", "p"}], "]"}], 
           RowBox[{"A3e\[CurlyPhi]", "[", 
            RowBox[{
            "2", ",", "c", ",", "d", ",", "3", ",", "e", ",", "f", ",", "4", 
             ",", "g", ",", "h"}], "]"}]}]}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e"}], "]"}], "+", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
         RowBox[{
          RowBox[{"kc", "[", 
           RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e"}], "]"}], "-", 
           RowBox[{"z", " ", 
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"LorentzIndex", "[", 
               RowBox[{"e", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}]}], "}"}]}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{"z", "\[Rule]", 
       RowBox[{
        RowBox[{"s156", "/", "2"}], "/", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           StyleBox[
            RowBox[{"Pair", "[", 
             RowBox[{
              RowBox[{"Momentum", "[", 
               RowBox[{"q", ",", "D"}], "]"}], ",", 
              RowBox[{"Momentum", "[", 
               RowBox[{
                RowBox[{"Subscript", "[", 
                 RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
           FullForm], "+", 
          StyleBox[
           RowBox[{"Pair", "[", 
            RowBox[{
             RowBox[{"Momentum", "[", 
              RowBox[{"q", ",", "D"}], "]"}], ",", 
             RowBox[{"Momentum", "[", 
              RowBox[{
               RowBox[{"Subscript", "[", 
                RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
           ShowSpecialCharacters->False,
           ShowStringCharacters->True,
           NumberMarks->True]}], 
         StyleBox[")",
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True]}]}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616304422895483*^9, 3.616304474427631*^9}, {
  3.616304509681415*^9, 3.616304644148814*^9}, {3.616304999580489*^9, 
  3.616305008116146*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "residue156", "]"}]], "Input",
 CellChangeTimes->{{3.616304487205913*^9, 3.616304489177478*^9}, {
  3.616304566938448*^9, 3.6163045839382887`*^9}}],

Cell[BoxData[
 FormBox["2636", TraditionalForm]], "Output",
 CellChangeTimes->{3.616304489580956*^9, 3.616304567048438*^9, 
  3.6163046604104443`*^9, 3.6163050096832113`*^9, 3.617340915492098*^9, 
  3.6182199892894897`*^9, 3.6193361944026623`*^9, 3.6197776811555758`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumresidues", "=", 
  RowBox[{
  "residue134", "+", "residue135", "+", "residue136", "+", "residue145", "+", 
   "residue146", "+", "residue156"}]}]], "Input",
 CellChangeTimes->{{3.616304671020071*^9, 3.6163047078652153`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "u"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "v"}]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["o",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["p",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["s134", "3"]}], 
             RowBox[{"4096", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}], "+", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "4"],
                   TraditionalForm]}]}], ")"}], "4"]}]]}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "u"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "v"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["o",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["p",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["s134", "3"]}], 
            RowBox[{"2048", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}], ")"}], "4"]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "23898", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "o"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "p"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["u",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["v",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"256", " ", "s134"}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "o"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "p"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["u",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["v",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"256", " ", "s134"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 463, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 463, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 463, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[463]], TraditionalForm]], "Output",
 CellChangeTimes->{3.616304718844722*^9, 3.616305019377787*^9, 
  3.6163051173238573`*^9, 3.6173409245207853`*^9, 3.618219997439562*^9, 
  3.619336202631487*^9, 3.6197776896755953`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "sumresidues", "]"}]], "Input",
 CellChangeTimes->{{3.61630472729985*^9, 3.616304728640501*^9}}],

Cell[BoxData[
 FormBox["15816", TraditionalForm]], "Output",
 CellChangeTimes->{3.61630472900469*^9, 3.616305021475151*^9, 
  3.616305119660433*^9, 3.617340924686027*^9, 3.6182199975886106`*^9, 
  3.6193362027399273`*^9, 3.619777689886495*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"6", "*", 
  RowBox[{"Length", "[", "residue156", "]"}]}]], "Input",
 CellChangeTimes->{{3.616304737250259*^9, 3.61630473826593*^9}}],

Cell[BoxData[
 FormBox["15816", TraditionalForm]], "Output",
 CellChangeTimes->{3.6163047390770073`*^9, 3.6173409247500753`*^9, 
  3.618219997623313*^9, 3.619336202794651*^9, 3.619777689922554*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumresidues2", "=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{"sumresidues", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"6", ",", "e_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"kc", "[", 
          RowBox[{"1", ",", "e"}], "]"}]}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "e"}], "]"}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e"}], "]"}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "e"}], "]"}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"5", ",", "e"}], "]"}]}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"5", ",", "o"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"5", ",", "p"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"6", ",", "u"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"6", ",", "v"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.6163051361040907`*^9, 3.616305292915913*^9}, {
  3.616305489627017*^9, 3.616305491361741*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "u"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "v"}]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["o",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["p",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["s134", "3"]}], 
             RowBox[{"4096", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}], "+", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "4"],
                   TraditionalForm]}]}], ")"}], "4"]}]]}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "u"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "v"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["o",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["p",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["s134", "3"]}], 
            RowBox[{"2048", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}], ")"}], "4"]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "72498", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "o"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "p"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["u",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["v",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"256", " ", "s134"}]], "-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "o"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "p"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["u",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["5",
               TraditionalForm], 
              FormBox[
               FormBox["v",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"256", " ", "s134"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 466, 23722603476002858625, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 466, 23722603476002858625, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 466, 23722603476002858625, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[466]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6163053246855497`*^9, 3.616305519585393*^9, 
  3.617340952866639*^9, 3.618220024780979*^9, 3.619336229920138*^9, 
  3.619777717962843*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "sumresidues2", "]"}]], "Input",
 CellChangeTimes->{{3.6163053483988543`*^9, 3.6163053495666113`*^9}}],

Cell[BoxData[
 FormBox["48456", TraditionalForm]], "Output",
 CellChangeTimes->{3.6163053499112577`*^9, 3.6163055227115707`*^9, 
  3.617340953091444*^9, 3.618220024998294*^9, 3.61933623010606*^9, 
  3.6197777181358852`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sumresidues2", "[", 
  RowBox[{"[", "22440", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.616305412695804*^9, 3.616305439218295*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"s134", " ", 
    SubsuperscriptBox["k", 
     FormBox["4",
      TraditionalForm], 
     FormBox[
      FormBox["f",
       TraditionalForm],
      TraditionalForm]], " ", 
    SubsuperscriptBox["k", 
     FormBox["3",
      TraditionalForm], 
     FormBox[
      FormBox["g",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["u",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["v",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"a", "e"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"b", "h"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"c", "o"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"d", "p"}]]}], 
   RowBox[{"512", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}]}], ")"}], "2"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.616305414630104*^9, 3.6163054399825163`*^9}, 
   3.617340953131678*^9, 3.618220025037581*^9, 3.619336230157336*^9, 
   3.619777718173688*^9}]
}, Open  ]],

Cell["\<\
Is sumresidues zero?

Do a numerical check:\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.615626182633637*^9, {3.615627535754664*^9, 
   3.615627573577817*^9}, {3.6158035818089857`*^9, 3.615803586678727*^9}, {
   3.616302329106204*^9, 3.6163025040243473`*^9}, {3.6163025715999107`*^9, 
   3.616302602897203*^9}, {3.6163030265595512`*^9, 3.616303038022621*^9}, {
   3.616304845661141*^9, 3.616304866539874*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell["Numerical double - check", "Subsection",
 CellChangeTimes->{{3.6040429149922333`*^9, 3.604042928995213*^9}, 
   3.6049979404856853`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"qq", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "I", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}, {3.604899559101565*^9, 3.604899561217864*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}, {3.6048995645157824`*^9, 
   3.604899583819702*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9, {
   3.604899568850964*^9, 3.604899570340403*^9}, {3.6049062663935328`*^9, 
   3.604906268278619*^9}, 3.6049797927881527`*^9, 3.616306320632778*^9, {
   3.6163067652814074`*^9, 3.616306770127633*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k4", "=", 
   RowBox[{"{", 
    RowBox[{
    "k41", ",", "k42", ",", "k43", ",", "k44", ",", "k45", ",", "k46"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604899542614592*^9, 3.604899555579792*^9}, 
   3.604899591205002*^9, 3.60489966716361*^9, {3.616306326653276*^9, 
   3.6163063291750803`*^9}, {3.6163065671397676`*^9, 
   3.6163065759270782`*^9}, {3.61630681520126*^9, 3.616306821463626*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k5", "=", 
   RowBox[{"{", 
    RowBox[{
    "k51", ",", "k52", ",", "k53", ",", "k54", ",", "k55", ",", "k56"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604899593993885*^9, 3.604899614274732*^9}, 
   3.6048996778599377`*^9, 3.60499113416997*^9, 3.616306337425602*^9, 
   3.616306406497772*^9, {3.616306830964299*^9, 3.6163068494066343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k6", "=", 
   RowBox[{"{", 
    RowBox[{
    "k61", ",", "k62", ",", "k63", ",", "k64", ",", "k65", ",", "k66"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}, {3.6048996222039003`*^9, 3.604899628243999*^9}, 
   3.6049797966857557`*^9, 3.6049979041213703`*^9, 3.6163063438246202`*^9, 
   3.616306388138445*^9, {3.616306857174378*^9, 3.616306878944181*^9}}],

Cell["Define Minkowski product:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "5", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "5", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "6", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "6", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.604043634462092*^9, 3.604043700535356*^9}, {
  3.60489975789191*^9, 3.604899764017948*^9}}],

Cell["Find a kinematical configuration with well-defined residues:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.616306931681178*^9, 3.6163069525761347`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kinsys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k5", ",", "k5"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k6", ",", "k6"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4", "+", "k5", "+", "k6"}], 
      "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"qq", ",", 
        RowBox[{"k3", "+", "k4"}]}], "]"}], "\[NotEqual]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"qq", ",", 
        RowBox[{"k3", "+", "k5"}]}], "]"}], "\[NotEqual]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"qq", ",", 
        RowBox[{"k4", "+", "k5"}]}], "]"}], "\[NotEqual]", "0"}]}], "}"}]}], 
  ";", 
  RowBox[{"kinsys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612258217072095*^9, 3.612258219089881*^9}, {
  3.612258263321577*^9, 3.612258271721939*^9}, {3.612505966669755*^9, 
  3.612505985721085*^9}, {3.616306957479412*^9, 3.616307014999588*^9}, {
  3.616308213002777*^9, 3.6163082337419043`*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k41", "2"]}], "+", 
         SuperscriptBox["k42", "2"], "+", 
         SuperscriptBox["k43", "2"], "+", 
         SuperscriptBox["k44", "2"], "+", 
         SuperscriptBox["k45", "2"], "+", 
         SuperscriptBox["k46", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k51", "2"]}], "+", 
         SuperscriptBox["k52", "2"], "+", 
         SuperscriptBox["k53", "2"], "+", 
         SuperscriptBox["k54", "2"], "+", 
         SuperscriptBox["k55", "2"], "+", 
         SuperscriptBox["k56", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k61", "2"]}], "+", 
         SuperscriptBox["k62", "2"], "+", 
         SuperscriptBox["k63", "2"], "+", 
         SuperscriptBox["k64", "2"], "+", 
         SuperscriptBox["k65", "2"], "+", 
         SuperscriptBox["k66", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"k41", "+", "k51", "+", "k61", "+", "3"}], ",", 
          RowBox[{"k42", "+", "k52", "+", "k62"}], ",", 
          RowBox[{"k43", "+", "k53", "+", "k63"}], ",", 
          RowBox[{"k44", "+", "k54", "+", "k64"}], ",", 
          RowBox[{"k45", "+", "k55", "+", "k65", "+", "1"}], ",", 
          RowBox[{"k46", "+", "k56", "+", "k66"}]}], "}"}], "\[LongEqual]", 
        "0"}]},
      {
       RowBox[{
        RowBox[{"k43", "+", 
         RowBox[{"\[ImaginaryI]", " ", "k44"}]}], "\[NotEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"k53", "+", 
         RowBox[{"\[ImaginaryI]", " ", "k54"}]}], "\[NotEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"k43", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{"k44", "+", "k54"}], ")"}]}], "+", "k53"}], "\[NotEqual]", 
        "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612258223332856*^9, 3.612258277667809*^9, 3.612505994584982*^9, 
   3.6126800091197*^9, 3.6126842296073713`*^9, 3.614415251319221*^9, 
   3.614416681331402*^9, 3.614506889916788*^9, 3.6145783531107807`*^9, 
   3.61493838358314*^9, 3.61562431172897*^9, 3.615635676008398*^9, {
   3.615798577931674*^9, 3.61579860597112*^9}, 3.615800023917783*^9, {
   3.615800607279175*^9, 3.615800631526265*^9}, 3.615800678815898*^9, 
   3.616216978391515*^9, 3.616306969081918*^9, {3.6163070161618643`*^9, 
   3.616307038906681*^9}, {3.616308218184618*^9, 3.6163082343293123`*^9}, 
   3.6163139198132343`*^9, 3.617340953213607*^9, 3.618220025175337*^9, 
   3.6193362302565107`*^9, 3.6197777182895317`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols", "=", 
   RowBox[{"FindInstance", "[", 
    RowBox[{"kinsys", ",", 
     RowBox[{"Join", "[", 
      RowBox[{"k4", ",", "k5", ",", "k6"}], "]"}], ",", "1"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.612086667146719*^9, 3.612086669789753*^9}, {
   3.61208672018432*^9, 3.6120867609601393`*^9}, {3.612086820399687*^9, 
   3.61208684701149*^9}, {3.6120868882347116`*^9, 3.612086911234775*^9}, {
   3.612086947214334*^9, 3.612086966920597*^9}, {3.612087130200302*^9, 
   3.612087138062559*^9}, {3.612257132872628*^9, 3.6122571670798407`*^9}, 
   3.612257397692018*^9, {3.61225751058984*^9, 3.612257511578771*^9}, {
   3.6122576055168962`*^9, 3.612257613202684*^9}, 3.612257694530752*^9, {
   3.612258060499379*^9, 3.612258062723226*^9}, {3.612258192623537*^9, 
   3.612258193411767*^9}, 3.612258282749514*^9, {3.6125060012757797`*^9, 
   3.612506003735097*^9}, {3.612680017069385*^9, 3.6126800172139387`*^9}, 
   3.612684254591062*^9, 3.6145769005945463`*^9, 3.614576952464837*^9, {
   3.6145770875853148`*^9, 3.614577088568757*^9}, 3.61579856434335*^9, 
   3.615800610269499*^9, 3.6163070520081882`*^9, {3.61631378269361*^9, 
   3.616313784821432*^9}, 3.61631385701342*^9, 3.616314043028998*^9, 
   3.616314077685668*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$no", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{{3.615798680984138*^9, 3.615798683466194*^9}, 
   3.61579874759733*^9, 3.615798948451993*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"kk", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"k1", ",", "k2", ",", "k3", ",", "k4", ",", "k5", ",", "k6"}], 
    "}"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.616307067522895*^9, 3.61630709594221*^9}, 
   3.6163084990746098`*^9, {3.6163151382181168`*^9, 3.616315138853209*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "0", "0", "0", "0"},
     {"1", 
      RowBox[{"-", "1"}], "0", "0", "0", "0"},
     {"1", "0", "0", "0", "1", "0"},
     {"1", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "1", 
      RowBox[{"-", 
       SqrtBox["2"]}], 
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[ImaginaryI]"}]},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "1", "1", 
      RowBox[{"\[ImaginaryI]", " ", 
       SqrtBox["2"]}]},
     {
      RowBox[{"-", "3"}], "2", "1", 
      RowBox[{"-", "2"}], 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       SqrtBox["2"]}], 
      RowBox[{
       RowBox[{"2", " ", "\[ImaginaryI]"}], "-", 
       RowBox[{"\[ImaginaryI]", " ", 
        SqrtBox["2"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.616307073290202*^9, 3.616307096961957*^9}, 
   3.6163084997845078`*^9, 3.616313860135373*^9, 3.616313929286395*^9, 
   3.616314082078678*^9, 3.616315139348568*^9, 3.617340954414907*^9, 
   3.61822002633305*^9, 3.6193362313540287`*^9, 3.6197777193921824`*^9}]
}, Open  ]],

Cell["Now generate random transverse polarizations.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499045872794*^9, 
  3.6049906005276213`*^9}, {3.60499063619753*^9, 3.6049907790162907`*^9}, {
  3.604990813417522*^9, 3.604990888980734*^9}, {3.604991154299855*^9, 
  3.604991166873405*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{
    "xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4", ",", "xiz5", ",", "xiz6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9, {3.612166418225318*^9, 
   3.6121664207438507`*^9}, 3.615625616359418*^9, {3.6163085821415663`*^9, 
   3.616308584883966*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi4", "=", 
   RowBox[{"{", 
    RowBox[{
    "xiu1", ",", "xiu2", ",", "xiu3", ",", "xiu4", ",", "xiu5", ",", "xiu6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.6040433145245943`*^9, 
   3.604043314748054*^9}, {3.6040433534274893`*^9, 3.604043369394578*^9}, 
   3.60404350847479*^9, {3.61216642588039*^9, 3.612166429007922*^9}, 
   3.615625616361087*^9, {3.616308588790559*^9, 3.616308615332107*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi5", "=", 
   RowBox[{"{", 
    RowBox[{
    "xiv1", ",", "xiv2", ",", "xiv3", ",", "xiv4", ",", "xiv5", ",", "xiv6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.612166469609943*^9, 3.612166482375815*^9}, {
  3.616308619493566*^9, 3.616308623579524*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi6", "=", 
   RowBox[{"{", 
    RowBox[{
    "xiw1", ",", "xiw2", ",", "xiw3", ",", "xiw4", ",", "xiw5", ",", "xiw6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616308359037798*^9, 3.616308372698777*^9}, {
  3.616308627365835*^9, 3.6163086299393883`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{
    "etz1", ",", "etz2", ",", "etz3", ",", "etz4", ",", "etz5", ",", "etz6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9, {3.612166449248323*^9, 
   3.6121664509560738`*^9}, {3.6163086325739117`*^9, 3.616308635419083*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et4", "=", 
   RowBox[{"{", 
    RowBox[{
    "etu1", ",", "etu2", ",", "etu3", ",", "etu4", ",", "etu5", ",", "etu6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.604043392149412*^9, 
   3.604043392255167*^9}, {3.6040434286448727`*^9, 3.604043435995811*^9}, 
   3.604043520033565*^9, {3.612166453399662*^9, 3.6121664555841017`*^9}, {
   3.616308639454392*^9, 3.616308642995675*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et5", "=", 
   RowBox[{"{", 
    RowBox[{
    "etv1", ",", "etv2", ",", "etv3", ",", "etv4", ",", "etv5", ",", "etv6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6121664949676847`*^9, 3.6121665077213697`*^9}, {
  3.616308646531448*^9, 3.616308649419546*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et6", "=", 
   RowBox[{"{", 
    RowBox[{
    "etw1", ",", "etw2", ",", "etw3", ",", "etw4", ",", "etw5", ",", "etw6"}],
     "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616308380757498*^9, 3.6163083923260727`*^9}, {
  3.6163086522756968`*^9, 3.616308653965049*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "xi4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "et4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "xi5"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k5", ",", "et5"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k6", ",", "xi6"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k6", ",", "et6"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     
     RowBox[{"sols", "[", 
      RowBox[{"[", "sols$no", "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.61216653422339*^9, 3.612166556960194*^9}, {
   3.612166600729034*^9, 3.6121666133164167`*^9}, {3.612258455793024*^9, 
   3.612258468175284*^9}, 3.6156256381986628`*^9, 3.615799070695634*^9, {
   3.616308462509293*^9, 3.6163084705230293`*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xiz1", "\[LongEqual]", "xiz5"}]},
      {
       RowBox[{"etz1", "\[LongEqual]", "etz5"}]},
      {
       RowBox[{
        RowBox[{"xiu1", "+", "xiu2", "+", "xiu3", "+", 
         RowBox[{
          SqrtBox["2"], " ", "xiu5"}], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "xiu6"}]}], "\[LongEqual]", 
        "xiu4"}]},
      {
       RowBox[{
        RowBox[{"etu1", "+", "etu2", "+", "etu3", "+", 
         RowBox[{
          SqrtBox["2"], " ", "etu5"}], "+", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "etu6"}]}], "\[LongEqual]", 
        "etu4"}]},
      {
       RowBox[{
        RowBox[{"xiv1", "+", "xiv4", "+", "xiv5", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", "xiv6"}]}], "\[LongEqual]", "xiv2"}]},
      {
       RowBox[{
        RowBox[{"etv1", "+", "etv4", "+", "etv5", "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          SqrtBox["2"], " ", "etv6"}]}], "\[LongEqual]", "etv2"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"3", " ", "xiw1"}], "+", 
         RowBox[{"2", " ", "xiw2"}], "+", "xiw3", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"xiw5", "-", 
            RowBox[{"\[ImaginaryI]", " ", "xiw6"}]}], ")"}]}]}], 
        "\[LongEqual]", 
        RowBox[{"2", " ", "xiw4"}]}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"3", " ", "etw1"}], "+", 
         RowBox[{"2", " ", "etw2"}], "+", "etw3", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"etw5", "-", 
            RowBox[{"\[ImaginaryI]", " ", "etw6"}]}], ")"}]}]}], 
        "\[LongEqual]", 
        RowBox[{"2", " ", "etw4"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166557730864*^9, 3.612166613587278*^9, 3.612257786626362*^9, {
   3.612258449865247*^9, 3.6122584694730263`*^9}, 3.612684401222273*^9, 
   3.6144153037766237`*^9, 3.614416733198262*^9, 3.614506942881184*^9, 
   3.6145770516151667`*^9, 3.614578403574582*^9, 3.6149384370663424`*^9, 
   3.615625645137738*^9, 3.615635902921464*^9, 3.61570372215546*^9, 
   3.6157155590397253`*^9, 3.615799182121047*^9, 3.615800373632674*^9, 
   3.615800910881835*^9, 3.616217206120352*^9, 3.616308473221073*^9, 
   3.6163085766621017`*^9, 3.616308665191386*^9, 3.6163138672940397`*^9, 
   3.616313936661744*^9, 3.616314090773514*^9, 3.617340955008628*^9, 
   3.618220026919188*^9, 3.619336231936934*^9, 3.619777720018157*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "=", 
   RowBox[{
    RowBox[{"FindInstance", "[", 
     RowBox[{"conditions", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
       "xi3", ",", "xi4", ",", "xi5", ",", "xi6", ",", "et3", ",", "et4", ",",
         "et5", ",", "et6"}], "]"}], ",", "5"}], "]"}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.612166575888966*^9, 3.612166576370742*^9}, {3.6121666241502*^9, 
   3.612166629642056*^9}, 3.6122577970426483`*^9, {3.6122584771168823`*^9, 
   3.612258481721101*^9}, {3.6156256519370327`*^9, 3.615625681121189*^9}, {
   3.61562725972334*^9, 3.6156272741427593`*^9}, {3.61630868019057*^9, 
   3.61630868849868*^9}, 3.616313835039401*^9, {3.616313906351156*^9, 
   3.616313908879396*^9}, 3.6163139610396023`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol$no", "=", "5"}], ";"}]], "Input",
 CellChangeTimes->{{3.615799200394259*^9, 3.61579920842603*^9}, {
  3.6163139836354523`*^9, 3.616314033103105*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "[", 
   RowBox[{"[", "sols$pol$no", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.6163100201603107`*^9, 3.6163100233674088`*^9}, {
  3.6163137431115637`*^9, 3.61631374584936*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xiz1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["78", "5"]}], "+", 
         FractionBox[
          RowBox[{"35", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiz2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["72", "5"]}], "+", 
         FractionBox[
          RowBox[{"67", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz3", "\[Rule]", 
        RowBox[{
         FractionBox["109", "5"], "+", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiz4", "\[Rule]", 
        RowBox[{
         FractionBox["43", "5"], "+", 
         FractionBox[
          RowBox[{"139", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["78", "5"]}], "+", 
         FractionBox[
          RowBox[{"35", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiz6", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["129", "10"]}], "-", 
         FractionBox[
          RowBox[{"88", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["21", "10"]}], "-", 
         FractionBox[
          RowBox[{"59", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu2", "\[Rule]", 
        RowBox[{
         FractionBox["79", "10"], "-", 
         FractionBox[
          RowBox[{"29", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["169", "10"]}], "-", 
         FractionBox[
          RowBox[{"73", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiu4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "9"}], "-", 
         FractionBox[
          RowBox[{"59", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu5", "\[Rule]", 
        RowBox[{
         FractionBox["41", "5"], "-", 
         FractionBox[
          RowBox[{"153", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiu6", "\[Rule]", 
        RowBox[{
         FractionBox["1", "20"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"131", "-", 
             RowBox[{"21", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"153", "+", 
              RowBox[{"82", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{"xiv1", "\[Rule]", 
        RowBox[{
         FractionBox["159", "10"], "+", 
         FractionBox[
          RowBox[{"118", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiv2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["179", "10"]}], "+", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiv3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "24"}], "-", 
         FractionBox[
          RowBox[{"193", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiv4", "\[Rule]", 
        RowBox[{
         FractionBox["169", "10"], "-", 
         FractionBox[
          RowBox[{"41", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiv5", "\[Rule]", 
        RowBox[{"10", "+", 
         FractionBox[
          RowBox[{"21", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiv6", "\[Rule]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           FractionBox["122", "5"], "-", 
           FractionBox[
            RowBox[{"607", " ", "\[ImaginaryI]"}], "10"]}], 
          SqrtBox["2"]]}]}]},
      {
       RowBox[{"xiw1", "\[Rule]", 
        RowBox[{
         FractionBox["149", "10"], "-", 
         FractionBox[
          RowBox[{"11", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiw2", "\[Rule]", 
        RowBox[{
         FractionBox["59", "10"], "-", 
         FractionBox[
          RowBox[{"62", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiw3", "\[Rule]", 
        RowBox[{
         FractionBox["49", "2"], "-", 
         FractionBox["\[ImaginaryI]", "10"]}]}]},
      {
       RowBox[{"xiw4", "\[Rule]", 
        RowBox[{
         FractionBox["161", "10"], "+", 
         FractionBox[
          RowBox[{"127", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiw5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["161", "10"]}], "+", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiw6", "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "764"}], "-", 
            RowBox[{"810", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"48", "+", 
             RowBox[{"161", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"10", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}]}]]}]},
      {
       RowBox[{"etz1", "\[Rule]", 
        RowBox[{
         FractionBox["147", "10"], "-", 
         RowBox[{"14", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz2", "\[Rule]", "etz2"}]},
      {
       RowBox[{"etz3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["79", "10"]}], "+", 
         FractionBox[
          RowBox[{"29", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"etz4", "\[Rule]", 
        RowBox[{
         FractionBox["16", "5"], "+", 
         FractionBox[
          RowBox[{"52", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz5", "\[Rule]", 
        RowBox[{
         FractionBox["147", "10"], "-", 
         RowBox[{"14", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz6", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["153", "10"]}], "+", 
         FractionBox[
          RowBox[{"49", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"etu1", "\[Rule]", 
        RowBox[{
         FractionBox["28", "5"], "-", 
         FractionBox[
          RowBox[{"31", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etu2", "\[Rule]", 
        RowBox[{"19", "-", 
         FractionBox[
          RowBox[{"82", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["87", "10"]}], "-", 
         FractionBox[
          RowBox[{"51", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etu4", "\[Rule]", 
        RowBox[{
         FractionBox["38", "5"], "+", 
         FractionBox[
          RowBox[{"92", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["53", "10"]}], "-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu6", "\[Rule]", 
        RowBox[{
         FractionBox["1", "20"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"430", "+", 
             RowBox[{"83", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"24", "-", 
              RowBox[{"53", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{"etv1", "\[Rule]", 
        RowBox[{"11", "+", 
         FractionBox[
          RowBox[{"108", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etv2", "\[Rule]", 
        RowBox[{
         FractionBox["121", "10"], "+", 
         FractionBox[
          RowBox[{"111", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etv3", "\[Rule]", 
        RowBox[{"4", "-", 
         FractionBox[
          RowBox[{"249", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etv4", "\[Rule]", 
        RowBox[{
         FractionBox["11", "10"], "-", 
         FractionBox[
          RowBox[{"117", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etv5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["41", "10"]}], "+", 
         RowBox[{"25", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etv6", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], " ", 
         SqrtBox[
          RowBox[{"7224", "+", 
           RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}]}]},
      {
       RowBox[{"etw1", "\[Rule]", 
        RowBox[{
         FractionBox["73", "5"], "+", 
         FractionBox[
          RowBox[{"177", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etw2", "\[Rule]", 
        RowBox[{
         FractionBox["98", "5"], "-", 
         FractionBox[
          RowBox[{"121", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etw3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["117", "10"]}], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etw4", "\[Rule]", 
        RowBox[{
         FractionBox["161", "10"], "+", 
         FractionBox[
          RowBox[{"93", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etw5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["219", "10"]}], "+", 
         FractionBox[
          RowBox[{"5", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"etw6", "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "382"}], "-", 
            RowBox[{"829", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"25", "+", 
             RowBox[{"219", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"10", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}]}]]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6163100236337833`*^9, 3.616313592372921*^9, 3.616313746274973*^9, 
   3.6163138395812073`*^9, 3.6163138705656843`*^9, {3.616313946340415*^9, 
   3.616314035524581*^9}, 3.6163140944286127`*^9, 3.61734095630275*^9, 
   3.618220028187055*^9, 3.619336233123592*^9, 3.619777721252357*^9}]
}, Open  ]],

Cell["Checking invariants:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
  3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
  3.604893189378476*^9, 3.604893268806697*^9}, {3.60499045872794*^9, 
  3.6049906005276213`*^9}, {3.60499063619753*^9, 3.6049907790162907`*^9}, {
  3.604990813417522*^9, 3.604990888980734*^9}, {3.604991154299855*^9, 
  3.604991166873405*^9}, {3.616314151581605*^9, 3.616314159099408*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"norm", "[", "x_", "]"}], ":=", 
  RowBox[{"min", "[", 
   RowBox[{"x", ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6049998030206327`*^9, 3.6049998148368063`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s123", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k2", "+", "k3"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604906119439341*^9, 3.6049061379342012`*^9}, {
   3.6049797497765913`*^9, 3.604979751930819*^9}, {3.604979810389492*^9, 
   3.604979811640518*^9}, {3.604999820115843*^9, 3.604999825792666*^9}, 
   3.616314238563074*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s123", "\[Rule]", 
   RowBox[{"-", "8"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604906138630332*^9, 3.604906352766217*^9, {3.6049797374441767`*^9, 
   3.60497975238229*^9}, {3.604979806741324*^9, 3.604979812238117*^9}, 
   3.604979942284562*^9, 3.6049822677166147`*^9, 3.604991188265051*^9, 
   3.604997557300171*^9, 3.604997885389267*^9, 3.6049980473830347`*^9, 
   3.604998310423888*^9, 3.6049987269551907`*^9, 3.60499906723881*^9, 
   3.604999615514303*^9, 3.604999826237495*^9, 3.604999883342071*^9, 
   3.605322272546988*^9, 3.6053292987061853`*^9, 3.605344922462297*^9, 
   3.605499404335804*^9, 3.605499804100226*^9, 3.6055003158003397`*^9, 
   3.6055175737321253`*^9, 3.6055186380517473`*^9, 3.606019752283524*^9, 
   3.606624552129339*^9, 3.60725486988876*^9, 3.60774688195333*^9, 
   3.608458715067593*^9, 3.608461097264595*^9, 3.6086114050089073`*^9, 
   3.608972291985814*^9, 3.609039107345831*^9, 3.609065558150703*^9, 
   3.609130580482294*^9, 3.610078861725718*^9, 3.610768818118512*^9, 
   3.614321290553763*^9, {3.616314171678709*^9, 3.6163141784524603`*^9}, 
   3.616314262796959*^9, 3.617340956353722*^9, 3.618220028233102*^9, 
   3.619336233176811*^9, 3.6197777212917967`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s124", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k2", "+", "k4"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604993908926878*^9, 3.604993912115819*^9}, {
   3.604999828187541*^9, 3.6049998315518847`*^9}, {3.616314185508234*^9, 
   3.616314201615734*^9}, 3.616314237172892*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s124", "\[Rule]", 
   RowBox[{"-", "8"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604993912843521*^9, 3.6049975573050013`*^9, 3.6049978856818447`*^9, 
   3.6049980474194717`*^9, 3.6049983104283752`*^9, 3.6049987269906387`*^9, 
   3.604999067274152*^9, 3.604999615553236*^9, 3.604999831997696*^9, 
   3.604999884066041*^9, 3.605322272552329*^9, 3.60532929886696*^9, 
   3.605344922468752*^9, 3.605499404392592*^9, 3.605499804105098*^9, 
   3.605500315805224*^9, 3.605517573736539*^9, 3.6055186380576153`*^9, 
   3.606019752291225*^9, 3.6066245522283497`*^9, 3.607254869893467*^9, 
   3.607746881958194*^9, 3.608458715073017*^9, 3.608461097279681*^9, 
   3.608611405029769*^9, 3.608972292002109*^9, 3.609039107350727*^9, 
   3.6090655582281427`*^9, 3.609130580586364*^9, 3.6100788618795433`*^9, 
   3.61076881813246*^9, 3.614321290607596*^9, {3.616314181716961*^9, 
   3.616314202365036*^9}, 3.617340956360806*^9, 3.618220028240349*^9, 
   3.6193362331835623`*^9, 3.6197777213006363`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s125", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k2", "+", "k5"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604993922775345*^9, 3.604993930799724*^9}, {
  3.604999834073457*^9, 3.604999836967327*^9}, {3.616314205623212*^9, 
  3.616314235062042*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"s125", "\[Rule]", "0"}], TraditionalForm]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGBQA+KIrpqPv26/cnT6vXrbHyCt37XtPohOL3j3GUQr778g
8hdIv1v4wANE/1qaVQyiAzd82g6i2/SWXQbRDDdn3ATRdQmiLrPvvHKcL5+4
aR6QtjLyD14GpA0P9hz8CKQFOps/g2jv55XGn4D0nx3bF/wC0jEMh1R/A2mf
Bs6r7+++cswqF1AVv//KMWr/nldeD145lrx30LB++MrRbEPq7mmPXjlqlek+
nQ6k515f4vkQSNdMa2iY+PiV44GYbIVNQPrE5jNc+4H0Eqlpp+4B6dyiPRfX
Pn3l2HLSZdu/Z68c+xYFBx59+8rR8sr57EkfXznylUkXg2ipy92H2z+/chR/
3P7f5Osrxxeiaqxh34HuuKI5XffHK0cA5IW5aQ==
  "]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s126", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k2", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6049939415411158`*^9, 3.60499394491576*^9}, {
  3.6049997670882874`*^9, 3.6049997774537783`*^9}, {3.604999839546784*^9, 
  3.604999857400239*^9}, {3.616314208703216*^9, 3.616314219527811*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"s126", "\[Rule]", "8"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.604993951370552*^9, 3.604997557399868*^9, 3.604997885726268*^9, 
   3.604998047456893*^9, 3.604998310560308*^9, 3.604998727056036*^9, 
   3.604999067338587*^9, 3.604999615686139*^9, 3.604999784294837*^9, 
   3.604999885546955*^9, 3.605322272739731*^9, 3.605329299101831*^9, 
   3.6053449224805517`*^9, 3.60549940440904*^9, 3.6054998041149693`*^9, 
   3.605500315878334*^9, 3.605517573815482*^9, 3.605518638158396*^9, 
   3.606019752302127*^9, 3.606624552574705*^9, 3.607254869909984*^9, 
   3.607746882033988*^9, 3.608458715196064*^9, 3.608461097429818*^9, 
   3.608611405166967*^9, 3.608972292023384*^9, 3.609039107359067*^9, 
   3.609065558402643*^9, 3.6091305807923307`*^9, 3.610078861897777*^9, 
   3.610768818251665*^9, 3.614321290624955*^9, {3.61631420911939*^9, 
   3.616314219913479*^9}, 3.616314266093771*^9, 3.617340956401922*^9, 
   3.6182200282829313`*^9, 3.619336233242288*^9, 3.619777721313519*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s134", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k3", "+", "k4"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6049997513007383`*^9, 3.604999789374015*^9}, {
  3.6049998407062283`*^9, 3.604999860216421*^9}, {3.616314223096096*^9, 
  3.616314231886097*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"s134", "\[Rule]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6049997901272593`*^9, 3.6049998866552973`*^9, 3.605322272773815*^9, 
   3.605329299112692*^9, 3.605344922538142*^9, 3.605499404414317*^9, 
   3.605499804174947*^9, 3.6055003158888693`*^9, 3.6055175738206863`*^9, 
   3.6055186381634417`*^9, 3.606019752356985*^9, 3.606624552578907*^9, 
   3.607254869914612*^9, 3.607746882038378*^9, 3.608458715211959*^9, 
   3.6084610974390163`*^9, 3.60861140519238*^9, 3.608972292131489*^9, 
   3.609039107428146*^9, 3.609065558408175*^9, 3.609130580895851*^9, 
   3.6100788619072247`*^9, 3.610768818265676*^9, 3.6143212906765757`*^9, {
   3.6163142247728853`*^9, 3.616314232610478*^9}, 3.61631426817905*^9, 
   3.617340956437426*^9, 3.618220028316177*^9, 3.619336233292883*^9, 
   3.619777721354064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s135", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k3", "+", "k5"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{
  3.60499979663179*^9, {3.604999841569065*^9, 3.6049998621187763`*^9}, 
   3.60499990467898*^9, 3.6163142412461157`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s135", "\[Rule]", "2"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604999887414968*^9, 3.6049999069745293`*^9}, 
   3.605322272779315*^9, 3.605329299117888*^9, 3.605344922548883*^9, 
   3.605499404419245*^9, 3.605499804180212*^9, 3.6055003158930798`*^9, 
   3.605517573825091*^9, 3.605518638168038*^9, 3.6060197523622932`*^9, 
   3.6066245525827303`*^9, 3.607254869918866*^9, 3.607746882043002*^9, 
   3.60845871522583*^9, 3.608461097449573*^9, 3.60861140520583*^9, 
   3.608972292152391*^9, 3.609039107432818*^9, 3.609065558412814*^9, 
   3.609130581000257*^9, 3.6100788620632153`*^9, 3.610768818279389*^9, 
   3.6143212906833143`*^9, 3.6163142779310427`*^9, 3.617340956474514*^9, 
   3.618220028322209*^9, 3.61933623330023*^9, 3.619777721386334*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s136", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k3", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.60499991187042*^9, 3.604999914007307*^9}, 
   3.6163142421186666`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s136", "\[Rule]", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"5", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604999914166789*^9, 3.605322272899034*^9, 
  3.605329299123005*^9, 3.605344922555059*^9, 3.605499404476315*^9, 
  3.605499804185401*^9, 3.605500315897111*^9, 3.605517573897993*^9, 
  3.605518638172697*^9, 3.606019752367724*^9, 3.6066245525865583`*^9, 
  3.6072548699230833`*^9, 3.607746882113694*^9, 3.608458715334897*^9, 
  3.6084610974546013`*^9, 3.608611405330267*^9, 3.60897229217693*^9, 
  3.609039107437201*^9, 3.609065558490959*^9, 3.609130581103673*^9, 
  3.610078862071638*^9, 3.610768818294249*^9, 3.614321290693701*^9, 
  3.6163142791247683`*^9, 3.61734095651136*^9, 3.618220028354495*^9, 
  3.619336233343667*^9, 3.619777721416748*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s145", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k4", "+", "k5"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6049999207594748`*^9, 3.604999922861805*^9}, 
   3.616314242759964*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s145", "\[Rule]", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604999922996305*^9, 3.605322272929727*^9, 
  3.605329299127787*^9, 3.605344922560377*^9, 3.605499404481773*^9, 
  3.605499804190078*^9, 3.6055003159696913`*^9, 3.6055175739027977`*^9, 
  3.6055186382700043`*^9, 3.6060197523727093`*^9, 3.60662455264532*^9, 
  3.607254869933728*^9, 3.6077468821180363`*^9, 3.608458715349264*^9, 
  3.608461097597229*^9, 3.608611405344483*^9, 3.608972292181903*^9, 
  3.609039107441698*^9, 3.60906555849692*^9, 3.609130581206987*^9, 
  3.61007886207979*^9, 3.6107688183020678`*^9, 3.614321290698884*^9, 
  3.616314280703888*^9, 3.6173409565469227`*^9, 3.61822002839121*^9, 
  3.619336233392864*^9, 3.619777721452784*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s146", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k4", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604999928799528*^9, 3.604999935234538*^9}, 
   3.616314243319346*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s146", "\[Rule]", "6"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.60499993002991*^9, 3.6049999355102386`*^9}, 
   3.605322273005357*^9, 3.6053292991957293`*^9, 3.605344922618243*^9, 
   3.6054994045520763`*^9, 3.605499804251318*^9, 3.6055003159804287`*^9, 
   3.605517573906941*^9, 3.605518638495345*^9, 3.606019752429831*^9, 
   3.606624552649522*^9, 3.607254869938632*^9, 3.6077468821222067`*^9, 
   3.608458715361041*^9, 3.608461097606495*^9, 3.608611405358736*^9, 
   3.608972292279911*^9, 3.60903910751053*^9, 3.609065558502057*^9, 
   3.609130581419992*^9, 3.610078862087275*^9, 3.6107688184096193`*^9, 
   3.614321290703836*^9, 3.6163142820603113`*^9, 3.61734095658295*^9, 
   3.618220028426374*^9, 3.619336233437716*^9, 3.6197777214588327`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s156", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k1", "+", "k5", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604999940030385*^9, 3.604999943650434*^9}, 
   3.616314244453459*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s156", "\[Rule]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604999943943989*^9, 3.6053222732396507`*^9, 
  3.605329299205982*^9, 3.605344922630067*^9, 3.6054994045573797`*^9, 
  3.605499804256804*^9, 3.605500315985202*^9, 3.605517573911145*^9, 
  3.605518638499786*^9, 3.606019752560783*^9, 3.606624552653338*^9, 
  3.607254869943338*^9, 3.60774688219128*^9, 3.60845871537199*^9, 
  3.608461097616768*^9, 3.608611405377861*^9, 3.608972292299746*^9, 
  3.609039107515329*^9, 3.6090655585067873`*^9, 3.609130581426643*^9, 
  3.6100788622332687`*^9, 3.610768818423493*^9, 3.614321290756625*^9, 
  3.61631428338118*^9, 3.617340956614009*^9, 3.618220028459717*^9, 
  3.619336233480112*^9, 3.619777721489287*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s234", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k2", "+", "k3", "+", "k4"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6049939906408863`*^9, 3.604994006570949*^9}, {
   3.604999842257708*^9, 3.604999863282909*^9}, 3.616314245941383*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s234", "\[Rule]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604994007403122*^9, 3.604997557439447*^9, 
  3.604997885941051*^9, 3.604998047566844*^9, 3.604998310619679*^9, 
  3.60499872706153*^9, 3.604999067401842*^9, 3.604999615718193*^9, 
  3.604999888546544*^9, 3.605322273269959*^9, 3.605329299210854*^9, 
  3.605344922636119*^9, 3.6054994045682707`*^9, 3.605499804262055*^9, 
  3.605500315989821*^9, 3.605517573984632*^9, 3.605518638503974*^9, 
  3.6060197525656853`*^9, 3.606624552657221*^9, 3.607254869947976*^9, 
  3.607746882197154*^9, 3.6084587154797087`*^9, 3.6084610976224337`*^9, 
  3.6086114053854733`*^9, 3.608972292318823*^9, 3.609039107519888*^9, 
  3.609065558582426*^9, 3.609130581432096*^9, 3.610078862244211*^9, 
  3.610768818437551*^9, 3.6143212907629423`*^9, 3.616314284525473*^9, 
  3.61734095665306*^9, 3.6182200284993763`*^9, 3.619336233531288*^9, 
  3.619777721527145*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s235", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k2", "+", "k3", "+", "k5"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604994016783595*^9, 3.6049940319591827`*^9}, {
   3.604999843028067*^9, 3.604999864557534*^9}, 3.6163142470525913`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s235", "\[Rule]", "6"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604994037738598*^9, 3.604997557481937*^9, 
  3.604997886135995*^9, 3.604998047590744*^9, 3.604998310625054*^9, 
  3.6049987271773243`*^9, 3.6049990674261417`*^9, 3.6049996157547007`*^9, 
  3.604999889853437*^9, 3.6053222732777157`*^9, 3.605329299215735*^9, 
  3.605344922642741*^9, 3.605499404572606*^9, 3.605499804267267*^9, 
  3.605500316058084*^9, 3.605517573989794*^9, 3.605518638601688*^9, 
  3.60601975257018*^9, 3.6066245527178087`*^9, 3.6072548699593277`*^9, 
  3.6077468822015676`*^9, 3.608458715488549*^9, 3.608461097763381*^9, 
  3.6086114055528*^9, 3.608972292335178*^9, 3.609039107524417*^9, 
  3.6090655585890713`*^9, 3.609130581437888*^9, 3.61007886225329*^9, 
  3.610768818445385*^9, 3.614321290772347*^9, 3.616314285677657*^9, 
  3.617340956685876*^9, 3.618220028532509*^9, 3.619336233575774*^9, 
  3.6197777215586*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s236", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k2", "+", "k3", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604996117464788*^9, 3.604996144921558*^9}, {
   3.6049998437778482`*^9, 3.604999865949987*^9}, 3.616314248126799*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s236", "\[Rule]", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604996145310998*^9, 3.60499755755709*^9, 
  3.60499788642437*^9, 3.6049980476216593`*^9, 3.604998310707562*^9, 
  3.604998727210999*^9, 3.60499906746493*^9, 3.6049996157854443`*^9, 
  3.604999890670021*^9, 3.605322273417169*^9, 3.605329299220586*^9, 
  3.605344922704812*^9, 3.605499404628737*^9, 3.60549980432841*^9, 
  3.6055003162353687`*^9, 3.60551757399457*^9, 3.605518638607251*^9, 
  3.606019752574389*^9, 3.6066245527224483`*^9, 3.607254869964253*^9, 
  3.607746882205944*^9, 3.6084587154990177`*^9, 3.60846109777356*^9, 
  3.608611405589264*^9, 3.608972292425048*^9, 3.609039107593099*^9, 
  3.6090655585940723`*^9, 3.6091305814432163`*^9, 3.610078862262373*^9, 
  3.6107688185471888`*^9, 3.614321290777349*^9, 3.616314287971348*^9, 
  3.617340956717473*^9, 3.618220028565527*^9, 3.619336233619484*^9, 
  3.619777721588462*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s245", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k2", "+", "k4", "+", "k5"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6049963433986197`*^9, 3.604996348369256*^9}, {
   3.604999844931769*^9, 3.604999867492403*^9}, 3.616314249654014*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s245", "\[Rule]", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{"5", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604996348573078*^9, 3.6049975575851097`*^9, 
  3.60499788661436*^9, 3.6049980476275473`*^9, 3.6049983107325497`*^9, 
  3.6049987272456636`*^9, 3.6049990675954847`*^9, 3.6049996157907248`*^9, 
  3.604999891944028*^9, 3.605322273450129*^9, 3.605329299312951*^9, 
  3.605344922716331*^9, 3.605499404634809*^9, 3.605499804334391*^9, 
  3.605500316241954*^9, 3.605517573999189*^9, 3.6055186386126347`*^9, 
  3.6060197526228037`*^9, 3.606624552847522*^9, 3.607254869968936*^9, 
  3.6077468822103853`*^9, 3.608458715507958*^9, 3.608461097808675*^9, 
  3.608611405620863*^9, 3.608972292449451*^9, 3.609039107824421*^9, 
  3.6090655586711197`*^9, 3.609130581447772*^9, 3.610078862409198*^9, 
  3.6107688185634193`*^9, 3.614321290830982*^9, 3.616314289740801*^9, 
  3.617340956754837*^9, 3.618220028602195*^9, 3.619336233666686*^9, 
  3.619777721624557*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s246", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k2", "+", "k4", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.60499615279862*^9, 3.604996159288258*^9}, {
   3.604999845699354*^9, 3.604999868804957*^9}, 3.6163142508213654`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s246", "\[Rule]", "2"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604996159654163*^9, 3.604997557617703*^9, 
  3.604997886636055*^9, 3.604998047717457*^9, 3.60499831076369*^9, 
  3.604998727251091*^9, 3.604999067621179*^9, 3.604999615895088*^9, 
  3.6049998925972548`*^9, 3.605322273480465*^9, 3.605329299704221*^9, 
  3.605344922722609*^9, 3.60549940464011*^9, 3.605499804338943*^9, 
  3.605500316246883*^9, 3.6055175740728283`*^9, 3.605518638617938*^9, 
  3.606019752627549*^9, 3.606624552851812*^9, 3.607254869973401*^9, 
  3.607746882279427*^9, 3.608458715513172*^9, 3.608461097954458*^9, 
  3.608611405633662*^9, 3.608972292474124*^9, 3.609039107842277*^9, 
  3.609065558676284*^9, 3.609130581539969*^9, 3.610078862574951*^9, 
  3.610768818578245*^9, 3.614321290837328*^9, 3.616314291012754*^9, 
  3.617340956761198*^9, 3.61822002860861*^9, 3.619336233712699*^9, 
  3.619777721655892*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s256", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k2", "+", "k5", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.604996165983235*^9, 3.604996171960606*^9}, {
   3.6049998465408573`*^9, 3.604999870216155*^9}, 3.6163142522815027`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s256", "\[Rule]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"(", 
     RowBox[{"4", "+", 
      SqrtBox["2"]}], ")"}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6049961731751003`*^9, 3.604997557654352*^9, 
  3.604997886670075*^9, 3.604998047750132*^9, 3.604998310796825*^9, 
  3.604998727336039*^9, 3.604999067656131*^9, 3.604999615987458*^9, 
  3.6049998931998253`*^9, 3.605322273526474*^9, 3.605329299894665*^9, 
  3.605344922727912*^9, 3.605499404649444*^9, 3.6054998043981447`*^9, 
  3.605500316250799*^9, 3.605517574078472*^9, 3.605518638717455*^9, 
  3.606019752631901*^9, 3.606624552855921*^9, 3.607254869984439*^9, 
  3.607746882284586*^9, 3.6084587156198397`*^9, 3.608461097963706*^9, 
  3.608611405774851*^9, 3.608972292497284*^9, 3.60903910786213*^9, 
  3.609065558682138*^9, 3.6091305815484743`*^9, 3.610078862583659*^9, 
  3.6107688185947847`*^9, 3.614321290846972*^9, 3.6163142926454163`*^9, 
  3.617340956794775*^9, 3.618220028641384*^9, 3.6193362337557507`*^9, 
  3.619777721686667*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s345", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k3", "+", "k4", "+", "k5"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.60499623353568*^9, 3.60499624554862*^9}, {
   3.604999847392756*^9, 3.60499987292118*^9}, 3.616314252896302*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s345", "\[Rule]", "8"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.604996223551127*^9, 3.604996246092699*^9}, 
   3.604997557728734*^9, 3.604997886897119*^9, 3.6049980477774267`*^9, 
   3.604998310894054*^9, 3.604998727371459*^9, 3.604999067661394*^9, 
   3.604999615992116*^9, 3.604999893981782*^9, 3.605322273630333*^9, 
   3.605329300004547*^9, 3.6053449227326307`*^9, 3.605499404654213*^9, 
   3.605499804403019*^9, 3.6055003163205214`*^9, 3.605517574082608*^9, 
   3.605518638723177*^9, 3.6060197526364326`*^9, 3.606624552859808*^9, 
   3.6072548699889393`*^9, 3.607746882288794*^9, 3.608458715630127*^9, 
   3.608461097973529*^9, 3.608611405879456*^9, 3.608972292594584*^9, 
   3.6090391078795223`*^9, 3.6090655586869183`*^9, 3.6091305816555862`*^9, 
   3.610078862592136*^9, 3.6107688187005177`*^9, 3.614321290852272*^9, 
   3.616314294373733*^9, 3.6173409568282633`*^9, 3.618220028675329*^9, 
   3.619336233801323*^9, 3.6197777217204247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s346", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k3", "+", "k4", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6049962533533363`*^9, 3.604996257201901*^9}, {
   3.604999848572413*^9, 3.604999874569232*^9}, 3.616314254071062*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s346", "\[Rule]", "0"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6049962599268217`*^9, 3.60499755777101*^9, 
  3.60499788710345*^9, 3.604998047803602*^9, 3.604998310923747*^9, 
  3.604998727400303*^9, 3.604999067720886*^9, 3.604999616120284*^9, 
  3.6049998949266043`*^9, 3.6053222736695833`*^9, 3.6053293001315928`*^9, 
  3.605344922794186*^9, 3.605499404659655*^9, 3.605499804407989*^9, 
  3.605500316330618*^9, 3.60551757415596*^9, 3.605518638727831*^9, 
  3.606019752683078*^9, 3.606624552922804*^9, 3.6072548699936533`*^9, 
  3.607746882292994*^9, 3.608458715640356*^9, 3.608461097978459*^9, 
  3.608611405884654*^9, 3.60897229261945*^9, 3.6090391080134*^9, 
  3.609065558764327*^9, 3.609130581760253*^9, 3.610078862600028*^9, 
  3.610768818763156*^9, 3.614321290905177*^9, 3.6163142958032017`*^9, 
  3.61734095683488*^9, 3.6182200286814632`*^9, 3.619336233807488*^9, 
  3.619777721727747*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s356", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k3", "+", "k5", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6049962674082203`*^9, 3.604996275846898*^9}, {
   3.604999849619253*^9, 3.604999876066917*^9}, 3.616314256382564*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s356", "\[Rule]", 
   RowBox[{"-", "8"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6049962770062103`*^9, 3.604997557853771*^9, 
  3.604997887402192*^9, 3.6049980478877783`*^9, 3.604998310960038*^9, 
  3.604998727433897*^9, 3.6049990677577467`*^9, 3.604999616146062*^9, 
  3.604999895645761*^9, 3.605322273717142*^9, 3.6053293002526083`*^9, 
  3.605344922801241*^9, 3.6054994047170973`*^9, 3.6054998044128323`*^9, 
  3.6055003163351803`*^9, 3.60551757416063*^9, 3.605518638822454*^9, 
  3.606019752688122*^9, 3.6066245529406137`*^9, 3.607254869998436*^9, 
  3.607746882362636*^9, 3.608458715645438*^9, 3.608461098112102*^9, 
  3.608611406002987*^9, 3.60897229264005*^9, 3.609039108029942*^9, 
  3.609065558769597*^9, 3.609130581861637*^9, 3.610078862745433*^9, 
  3.6107688187707987`*^9, 3.614321290917375*^9, 3.6163142978470497`*^9, 
  3.617340956840242*^9, 3.6182200286875267`*^9, 3.619336233813282*^9, 
  3.619777721733609*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"s456", "\[Rule]", 
    RowBox[{"norm", "[", 
     RowBox[{"k4", "+", "k5", "+", "k6"}], "]"}]}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.60499628610369*^9, 3.604996296590135*^9}, {
   3.6049998504563103`*^9, 3.604999877535389*^9}, 3.6163142574125633`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"s456", "\[Rule]", 
   RowBox[{"-", "8"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.604996297277093*^9, 3.604997557933996*^9, 
  3.604997887550166*^9, 3.604998047982191*^9, 3.604998310996311*^9, 
  3.604998727594412*^9, 3.604999067796159*^9, 3.604999616167726*^9, 
  3.604999896261456*^9, 3.6053222737723513`*^9, 3.605329300346715*^9, 
  3.605344922807267*^9, 3.605499404723566*^9, 3.605499804473858*^9, 
  3.605500316340067*^9, 3.605517574165345*^9, 3.6055186388274*^9, 
  3.606019752693143*^9, 3.606624552948827*^9, 3.6072548700100307`*^9, 
  3.60774688254076*^9, 3.608458715746015*^9, 3.6084610981212606`*^9, 
  3.6086114060292473`*^9, 3.60897229265867*^9, 3.609039108036582*^9, 
  3.60906555877521*^9, 3.609130581963285*^9, 3.6100788629557047`*^9, 
  3.6107688188756943`*^9, 3.614321290922714*^9, 3.616314299358078*^9, 
  3.617340956845626*^9, 3.618220028693467*^9, 3.619336233818769*^9, 
  3.619777721739242*^9}]
}, Open  ]],

Cell["Now do the numerical check:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.6049014132904787`*^9, 3.604901422302884*^9}, {3.6049912315231323`*^9, 
  3.6049913398007936`*^9}, {3.6049913717013073`*^9, 3.604991376887697*^9}, {
  3.616314362670579*^9, 3.616314369850911*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s134", "\[Rule]", 
       RowBox[{"norm", "[", 
        RowBox[{"k1", "+", "k3", "+", "k4"}], "]"}]}], ",", 
      RowBox[{"s135", "\[Rule]", 
       RowBox[{"norm", "[", 
        RowBox[{"k1", "+", "k3", "+", "k5"}], "]"}]}], ",", 
      RowBox[{"s136", "\[Rule]", 
       RowBox[{"norm", "[", 
        RowBox[{"k1", "+", "k3", "+", "k6"}], "]"}]}], ",", 
      RowBox[{"s145", "\[Rule]", 
       RowBox[{"norm", "[", 
        RowBox[{"k1", "+", "k4", "+", "k5"}], "]"}]}], ",", 
      RowBox[{"s146", "\[Rule]", 
       RowBox[{"norm", "[", 
        RowBox[{"k1", "+", "k4", "+", "k6"}], "]"}]}], ",", 
      RowBox[{"s156", "\[Rule]", 
       RowBox[{"norm", "[", 
        RowBox[{"k1", "+", "k5", "+", "k6"}], "]"}]}]}], "}"}], "/.", 
    RowBox[{"sols", "[", 
     RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.616314396577641*^9, 3.616314397934855*^9}, {
  3.61631447733619*^9, 3.616314595620429*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s134", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        SqrtBox["2"]}], ")"}]}]}], ",", 
    RowBox[{"s135", "\[Rule]", "2"}], ",", 
    RowBox[{"s136", "\[Rule]", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        SqrtBox["2"]}], ")"}]}]}], ",", 
    RowBox[{"s145", "\[Rule]", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SqrtBox["2"]}], ")"}]}]}], ",", 
    RowBox[{"s146", "\[Rule]", "6"}], ",", 
    RowBox[{"s156", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["2"]}], ")"}]}]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.616314510863427*^9, 3.616314596692325*^9, 
  3.6163153624010553`*^9, 3.616317079224271*^9, 3.6173409568849707`*^9, 
  3.6182200287335997`*^9, 3.619336233868932*^9, 3.6197777217754602`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       TagBox[
        StyleBox[
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True],
        FullForm], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"qq", ",", "k3"}], "]"}]}], ",", 
      RowBox[{
       TagBox[
        StyleBox[
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True],
        FullForm], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"qq", ",", "k4"}], "]"}]}], ",", 
      RowBox[{
       TagBox[
        StyleBox[
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "5"}], "]"}], ",", "D"}], "]"}]}], "]"}],
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True],
        FullForm], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"qq", ",", "k5"}], "]"}]}]}], "}"}], "/.", 
    RowBox[{"sols", "[", 
     RowBox[{"[", "sols$no", "]"}], "]"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.61631468665042*^9, 3.61631474562464*^9}, 
   3.61631706413419*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      FormBox["q",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "3"],
       TraditionalForm]}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FormBox["q",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "4"],
       TraditionalForm]}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}], ",", 
    RowBox[{
     RowBox[{
      FormBox["q",
       TraditionalForm], "\[CenterDot]", 
      FormBox[
       SubscriptBox["k", "5"],
       TraditionalForm]}], "\[Rule]", "\[ImaginaryI]"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.6163170648248587`*^9, 3.6163170804742737`*^9}, 
   3.61734095692684*^9, 3.618220028772781*^9, 3.6193362339151907`*^9, 
   3.6197777218120317`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Contract", "/@", 
      RowBox[{"Flatten", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "a"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "qq"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "b"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "qq"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "c"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "qq"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "d"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "qq"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "e"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "xi3"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "f"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "et3"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "g"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "xi4"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "h"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "et4"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "o"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "xi5"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "p"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "et5"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "u"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "xi6"}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"i", ",", "v"}], "]"}], "\[Rule]", 
            RowBox[{"min", "[", 
             RowBox[{
              RowBox[{"kk", "[", 
               RowBox[{"[", "i", "]"}], "]"}], ",", "et6"}], "]"}]}]}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], "]"}]}], "/.", 
     RowBox[{"sols$pol", "[", 
      RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "//", "Simplify"}]}], ";", 
  RowBox[{"rules3", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.6163148231937637`*^9, 3.6163148421882057`*^9}, {
  3.616315115922203*^9, 3.616315124452546*^9}, {3.6163152736483*^9, 
  3.616315276547591*^9}, {3.61631534379445*^9, 3.616315393481907*^9}, {
  3.6170104570598183`*^9, 3.617010461081037*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["6", "5"], "-", 
         FractionBox[
          RowBox[{"54", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"etz2", "-", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["147", "10"], "-", 
           RowBox[{"14", " ", "\[ImaginaryI]"}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"10", "+", 
         RowBox[{"6", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["67", "5"], "-", 
         FractionBox[
          RowBox[{"133", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["o",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["169", "5"]}], "-", 
         RowBox[{"18", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["p",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["11", "10"], "+", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["u",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "9"}], "-", 
         FractionBox[
          RowBox[{"69", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["v",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"5", "-", 
         FractionBox[
          RowBox[{"419", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"30", "-", 
         FractionBox[
          RowBox[{"121", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "etz2"}], "-", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["147", "10"], "-", 
           RowBox[{"14", " ", "\[ImaginaryI]"}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["29", "5"]}], "+", 
         FractionBox[
          RowBox[{"88", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["123", "5"]}], "+", 
         FractionBox[
          RowBox[{"39", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["o",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"2", "-", 
         FractionBox[
          RowBox[{"146", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["p",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["231", "10"]}], "-", 
         FractionBox[
          RowBox[{"219", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["u",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["104", "5"]}], "+", 
         FractionBox[
          RowBox[{"179", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["v",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["171", "5"]}], "+", 
         FractionBox[
          RowBox[{"13", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["103", "10"], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["109", "10"]}], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["o",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["59", "10"]}], "-", 
         FractionBox[
          RowBox[{"131", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["p",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["151", "10"]}], "+", 
         FractionBox[
          RowBox[{"17", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["u",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "31"}], "+", 
         FractionBox[
          RowBox[{"103", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["v",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["73", "2"]}], "-", 
         FractionBox[
          RowBox[{"76", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[ImaginaryI]"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "184"}], "+", 
             RowBox[{"137", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"156", "-", 
              RowBox[{"175", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "etz2"}], "-", 
         FractionBox[
          RowBox[{
           FractionBox["147", "5"], "-", 
           RowBox[{"28", " ", "\[ImaginaryI]"}]}], 
          SqrtBox["2"]], "+", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["227", "5"], "+", 
           FractionBox[
            RowBox[{"81", " ", "\[ImaginaryI]"}], "2"]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["o",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"429", "-", 
             RowBox[{"140", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"507", "+", 
              RowBox[{"139", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["p",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"306", "-", 
             RowBox[{"260", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"250", "+", 
              RowBox[{"41", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}], "-", 
           RowBox[{"2", " ", 
            SqrtBox[
             RowBox[{"7224", "+", 
              RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["u",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"714", "-", 
            RowBox[{"818", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"292", "-", 
             RowBox[{"307", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"20", "-", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}]]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["v",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"546", "-", 
            RowBox[{"99", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"32", "-", 
             RowBox[{"129", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"10", "-", 
          RowBox[{"5", " ", 
           SqrtBox["2"]}]}]]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "\[ImaginaryI]"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "\[ImaginaryI]"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "\[ImaginaryI]"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "\[ImaginaryI]"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "422"}], "-", 
             RowBox[{"82", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"129", "+", 
              RowBox[{"176", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "etz2"}], "-", 
         FractionBox[
          RowBox[{"49", "+", 
           FractionBox[
            RowBox[{"153", " ", "\[ImaginaryI]"}], "5"]}], 
          SqrtBox["2"]], "+", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["163", "5"], "-", 
           FractionBox[
            RowBox[{"88", " ", "\[ImaginaryI]"}], "5"]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "20"], "+", 
           FractionBox["\[ImaginaryI]", "20"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "368"}], "+", 
             RowBox[{"12", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"76", "+", 
              RowBox[{"55", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "20"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"634", "+", 
             RowBox[{"116", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"430", "+", 
              RowBox[{"83", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["o",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["p",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["41", "10"]}], "+", 
           FractionBox[
            RowBox[{"127", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
         RowBox[{
          FractionBox["1", "5"], " ", "\[ImaginaryI]", " ", 
          SqrtBox[
           RowBox[{"3612", "+", 
            FractionBox[
             RowBox[{"5207", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["u",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"251", "+", 
            RowBox[{"196", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"450", "-", 
             RowBox[{"260", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"10", "-", 
          RowBox[{"5", " ", 
           SqrtBox["2"]}]}]]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["5",
          TraditionalForm], 
         FormBox[
          FormBox["v",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"222", "+", 
            RowBox[{"1210", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"721", "+", 
             RowBox[{"248", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"20", "-", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}]]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "10"], " ", "\[ImaginaryI]", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "209"}], "+", 
             RowBox[{"46", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"304", "+", 
              RowBox[{"332", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"20", " ", "etz2"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"392", "+", 
              RowBox[{"13", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}], "-", 
           RowBox[{"(", 
            RowBox[{"486", "+", 
             RowBox[{"509", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1", "20"]}], "-", 
           FractionBox["\[ImaginaryI]", "20"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "22"}], "+", 
             RowBox[{"68", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"76", "+", 
              RowBox[{"55", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["279", "10"], "-", 
           FractionBox[
            RowBox[{"193", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
         FractionBox[
          RowBox[{
           FractionBox["83", "10"], "-", 
           RowBox[{"43", " ", "\[ImaginaryI]"}]}], 
          SqrtBox["2"]]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["o",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "52"}], "+", 
             RowBox[{"743", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"507", "+", 
              RowBox[{"139", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["p",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"631", "+", 
             RowBox[{"704", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"41", "-", 
              RowBox[{"250", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}], "-", 
           RowBox[{"2", " ", "\[ImaginaryI]", " ", 
            SqrtBox[
             RowBox[{"7224", "+", 
              RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}]}], ")"}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["u",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["6",
          TraditionalForm], 
         FormBox[
          FormBox["v",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61631527837376*^9, {3.616315349603011*^9, 3.616315394027794*^9}, 
   3.616317081795573*^9, 3.617010461692952*^9, 3.617340957168489*^9, 
   3.61822002900478*^9, 3.619336234162067*^9, 3.6197777220393744`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules4", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"f", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"v", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"f", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"h", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"f", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"p", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et3", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"e", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"u", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"e", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"o", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"e", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"g", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi3", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"v", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"p", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"h", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"u", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"g", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"v", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"u", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"p", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"o", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"o", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi5"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"g", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"h", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"o", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"u", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi5", ",", "xi6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"p", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"v", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et5", ",", "et6"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"o", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"g", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi5", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"f", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et3"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"u", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"g", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"xi6", ",", "xi4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"e", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi3"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"p", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"h", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et5", ",", "et4"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"e", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "xi3"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"f", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", "et3"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"v", ",", "D"}], "]"}], ",", 
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"h", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"et6", ",", "et4"}], "]"}]}]}], "}"}], "/.", 
     RowBox[{"sols$pol", "[", 
      RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "//", "Simplify"}]}], ";", 
  RowBox[{"rules4", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.616315438331254*^9, 3.61631552866617*^9}, 
   3.6163155868876133`*^9, {3.6163156273947678`*^9, 3.6163156331426487`*^9}, {
   3.61631591434028*^9, 3.616315930521441*^9}, {3.616316061298304*^9, 
   3.61631607351882*^9}, {3.616316301351726*^9, 3.616316321189212*^9}, {
   3.6163164068809547`*^9, 3.616316748440713*^9}, 3.616317039097804*^9, {
   3.616317163986902*^9, 3.6163172260272408`*^9}, {3.617010792705461*^9, 
   3.617010799753941*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "v"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1960", "-", 
             RowBox[{"2420", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SqrtBox["2"], "-", "2"}], ")"}], " ", "etz2"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"136349", "-", 
             RowBox[{"7658", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{"(", 
           RowBox[{"419289", "-", 
            RowBox[{"36833", " ", "\[ImaginaryI]"}]}], ")"}]}], 
         RowBox[{"100", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}]}]]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "200"], "+", 
           FractionBox[
            RowBox[{"3", " ", "\[ImaginaryI]"}], "200"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "604"}], "-", 
              RowBox[{"1468", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etz2"}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5128", "-", 
              RowBox[{"1395", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}], "+", 
           RowBox[{"(", 
            RowBox[{"28584", "+", 
             RowBox[{"49889", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"f", "p"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "100"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1210", "+", 
              RowBox[{"2220", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etz2"}], 
           "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"153", "-", 
              RowBox[{"245", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox[
             RowBox[{"7224", "+", 
              RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}], "+", 
           RowBox[{"(", 
            RowBox[{"28028", "+", 
             RowBox[{"49009", " ", "\[ImaginaryI]"}]}], ")"}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "u"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "203540"}], "+", 
            RowBox[{"260986", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"101912", "-", 
             RowBox[{"40233", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"100", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}]}]]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "o"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1277", "5"], "-", 
           FractionBox[
            RowBox[{"1455", " ", "\[ImaginaryI]"}], "4"]}], ")"}], "+", 
         FractionBox[
          RowBox[{
           FractionBox["34577", "25"], "-", 
           FractionBox[
            RowBox[{"35359", " ", "\[ImaginaryI]"}], "100"]}], 
          SqrtBox["2"]]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "200"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "109193"}], "-", 
             RowBox[{"29315", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5305", "+", 
              RowBox[{"37506", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"d", "v"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["303", "10"]}], "+", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"d", "p"}]], "\[Rule]", 
        RowBox[{
         FractionBox["157", "10"], "-", 
         FractionBox[
          RowBox[{"119", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["271", "10"]}], "+", 
         FractionBox[
          RowBox[{"5", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "u"}]], "\[Rule]", 
        RowBox[{
         FractionBox["59", "5"], "+", 
         RowBox[{"16", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["51", "10"]}], "-", 
         FractionBox[
          RowBox[{"163", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "v"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["303", "10"]}], "+", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "u"}]], "\[Rule]", 
        RowBox[{
         FractionBox["59", "5"], "+", 
         RowBox[{"16", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "p"}]], "\[Rule]", 
        RowBox[{
         FractionBox["157", "10"], "-", 
         FractionBox[
          RowBox[{"119", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "o"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["199", "10"]}], "-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "o"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["199", "10"]}], "-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["51", "10"]}], "-", 
         FractionBox[
          RowBox[{"163", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["271", "10"]}], "+", 
         FractionBox[
          RowBox[{"5", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"o", "u"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"66571", "+", 
            RowBox[{"80266", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"251038", "-", 
             RowBox[{"178261", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"100", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}]}]]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"p", "v"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "233098"}], "+", 
            RowBox[{"132140", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"119451", "-", 
             RowBox[{"80489", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"382", "+", 
             RowBox[{"829", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox[
            RowBox[{"7224", "+", 
             RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}]}], 
         RowBox[{"100", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}]}]]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"g", "o"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "400"], "+", 
           FractionBox["\[ImaginaryI]", "400"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"107767", "+", 
             RowBox[{"300835", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"32712", "+", 
              RowBox[{"51929", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox["2"]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["183", "10"]}], "+", 
         FractionBox[
          RowBox[{"177", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"g", "u"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"30198", "+", 
            RowBox[{"32536", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"120307", "+", 
             RowBox[{"199227", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"200", " ", 
          RowBox[{"(", 
           RowBox[{
            SqrtBox["2"], "-", "2"}], ")"}]}]]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], "\[Rule]", 
        RowBox[{
         FractionBox["79", "10"], "+", 
         FractionBox[
          RowBox[{"52", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"h", "p"}]], "\[Rule]", 
        RowBox[{
         FractionBox["1", "200"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"116579", "+", 
             RowBox[{"34025", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"430", "+", 
              RowBox[{"83", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
            SqrtBox[
             RowBox[{"7224", "+", 
              RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}]}], ")"}]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], "\[Rule]", 
        RowBox[{
         FractionBox["79", "10"], "+", 
         FractionBox[
          RowBox[{"52", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["183", "10"]}], "+", 
         FractionBox[
          RowBox[{"177", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"h", "v"}]], "\[Rule]", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6759", "+", 
            RowBox[{"263342", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"92672", "-", 
             RowBox[{"38109", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
           SqrtBox["2"]}]}], 
         RowBox[{"400", "-", 
          RowBox[{"200", " ", 
           SqrtBox["2"]}]}]]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{3.616317039662265*^9, 3.616317084424241*^9, 
  3.6163172269109488`*^9, 3.6170108002171*^9, 3.617340957328651*^9, 
  3.618220029145433*^9, 3.619336234365345*^9, 3.619777722177167*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules5", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"e", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi3", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"f", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et3", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"g", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi4", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"h", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et4", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"o", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi5", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"p", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et5", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"u", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"xi6", ",", "qq"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"v", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
       RowBox[{"min", "[", 
        RowBox[{"et6", ",", "qq"}], "]"}]}]}], "}"}], "/.", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "sols$pol$no", "]"}], "]"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.616316780005916*^9, 3.616316814460655*^9}, {
  3.616316848093586*^9, 3.616316999875269*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      FractionBox["79", "10"], "+", 
      FractionBox[
       RowBox[{"52", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["183", "10"]}], "+", 
      FractionBox[
       RowBox[{"177", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["51", "10"]}], "-", 
      FractionBox[
       RowBox[{"163", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["h",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["271", "10"]}], "+", 
      FractionBox[
       RowBox[{"5", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["o",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["199", "10"]}], "-", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["p",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      FractionBox["157", "10"], "-", 
      FractionBox[
       RowBox[{"119", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["u",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      FractionBox["59", "5"], "+", 
      RowBox[{"16", " ", "\[ImaginaryI]"}]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["v",
        TraditionalForm],
       TraditionalForm]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["303", "10"]}], "+", 
      FractionBox[
       RowBox[{"77", " ", "\[ImaginaryI]"}], "5"]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.616317003748104*^9, 3.616317086623617*^9, 
  3.617340957432081*^9, 3.618220029299653*^9, 3.619336234430645*^9, 
  3.619777722235515*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sumresidues$num", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"sumresidues", "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
      "rules1", ",", "rules2", ",", "rules3", ",", "rules4", ",", "rules5"}], 
      "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.616314604068974*^9, 3.616314609998035*^9}, {
  3.616314747554021*^9, 3.616314751095793*^9}, {3.6163154039629107`*^9, 
  3.616315404669486*^9}, {3.616315535833557*^9, 3.6163155371592293`*^9}, {
  3.6163160962615023`*^9, 3.6163160999206953`*^9}, {3.616316350913348*^9, 
  3.6163163863923063`*^9}, {3.6163170104095087`*^9, 3.61631701127563*^9}, {
  3.616317124646742*^9, 3.6163171315442963`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "sumresidues$num", "]"}]], "Input",
 CellChangeTimes->{{3.616314662543356*^9, 3.616314663980406*^9}, 
   3.61631713486123*^9}],

Cell[BoxData[
 FormBox["226", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616314664353731*^9, 3.616314778862327*^9, 3.61631636253953*^9, 
   3.6163164394261208`*^9, {3.616316489327174*^9, 3.6163165475795918`*^9}, 
   3.616316579567968*^9, 3.6163167126874523`*^9, 3.616316767983551*^9, 
   3.616317016602273*^9, {3.616317105590104*^9, 3.616317135544965*^9}, 
   3.616317235265655*^9, 3.617340958705662*^9, 3.618220030455832*^9, 
   3.619336235540567*^9, 3.6197777233455276`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "sumresidues$num", "]"}]], "Input",
 CellChangeTimes->{{3.616317137892486*^9, 3.6163171392954407`*^9}, {
  3.616317251780521*^9, 3.61631725740245*^9}, {3.616317295413686*^9, 
  3.6163172962821083`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"22", "+", 
      RowBox[{"9", " ", 
       SqrtBox["2"]}]}]], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "9600000000000"], "-", 
       FractionBox[
        RowBox[{"11", " ", "\[ImaginaryI]"}], "19200000000000"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"15", "+", 
          RowBox[{"20", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"32651706902709683378261", "+", 
            RowBox[{"5573612626667012734089", " ", "\[ImaginaryI]"}]}], ")"}],
           "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"32440607970247492447020", "+", 
             RowBox[{"3069327710566024407613", " ", "\[ImaginaryI]"}]}], 
            ")"}], " ", 
           SqrtBox["2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"162295551477012947700", "+", 
             RowBox[{"89979059819299588128", " ", "\[ImaginaryI]"}]}], ")"}], 
           " ", 
           SqrtBox[
            RowBox[{"7224", "+", 
             RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}]}], ")"}], " ", 
        "etz2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"20826933700193725699150", "-", 
          RowBox[{"111311132203079674587110", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", 
        SqrtBox[
         RowBox[{"7224", "+", 
          RowBox[{"5207", " ", "\[ImaginaryI]"}]}]]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"12009711634911610771929574", "+", 
          RowBox[{"11232952734164823580707677", " ", "\[ImaginaryI]"}]}], 
         ")"}], " ", 
        SqrtBox["2"]}], "-", 
       RowBox[{"(", 
        RowBox[{"6590539714293139795630188", "+", 
         RowBox[{"3959938884034522546566755", " ", "\[ImaginaryI]"}]}], 
        ")"}]}], ")"}]}]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616317140889955*^9, {3.6163172372774878`*^9, 3.616317257947541*^9}, 
   3.6173409591197777`*^9, 3.618220030857663*^9, 3.6193362359666643`*^9, 
   3.61977772376683*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"N", "[", "sumresidues$num", "]"}], "\[Equal]", "0"}]], "Input",
 CellChangeTimes->{{3.616317299631379*^9, 3.616317300255397*^9}, {
  3.616317855436654*^9, 3.616317877747814*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.584571191095436`*^11", "-", 
      RowBox[{"4.4165846637579565`*^11", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2.4419030223752975`*^10", "-", 
       RowBox[{"1.355518056211933`*^10", " ", "\[ImaginaryI]"}]}], ")"}], " ",
      "etz2"}]}], "\[LongEqual]", "0"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.616317300719521*^9, {3.616317859998331*^9, 3.616317878737349*^9}, 
   3.617340959163003*^9, 3.618220030900976*^9, 3.619336236011763*^9, 
   3.6197777238031178`*^9}]
}, Open  ]],

Cell["This is non-zero!", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
  3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
  3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
  3.6049014132904787`*^9, 3.604901422302884*^9}, {3.6049912315231323`*^9, 
  3.6049913398007936`*^9}, {3.6049913717013073`*^9, 3.604991376887697*^9}, {
  3.616314362670579*^9, 3.616314369850911*^9}, {3.616317278759955*^9, 
  3.616317282333585*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Playground", "Section",
 CellChangeTimes->{{3.615708175912779*^9, 3.615708195888957*^9}, {
  3.616926404251737*^9, 3.616926405175959*^9}}],

Cell[CellGroupData[{

Cell["Gauge theory in light-cone gauge", "Subsection",
 CellChangeTimes->{{3.617354764267334*^9, 3.6173547740905237`*^9}, {
  3.619774572166725*^9, 3.6197745727970257`*^9}}],

Cell["\<\
This is to check that the q light-cone propagator gives a consistent 4-gluon \
amplitude. In fact, the additional contributions with weird poles cancel out \
for each channel (s, t, u) separately.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6044001159150867`*^9, 3.604400123994227*^9}, {3.604720820865553*^9, 
  3.60472083813302*^9}, {3.604722666557773*^9, 3.604722695320043*^9}, {
  3.604723091148676*^9, 3.604723095257025*^9}, {3.604723355577581*^9, 
  3.604723398392375*^9}, {3.604723476921307*^9, 3.604723505440467*^9}, {
  3.61743231154848*^9, 3.617432370363323*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp$u", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"fAEDfBCE", " ", 
     RowBox[{"Contract", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "m"}], "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", 
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "e"}], "]"}]}], "+", 
             RowBox[{"k", "[", 
              RowBox[{"4", ",", "e"}], "]"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"e", ",", "m"}], "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "i"}], "]"}]}], "-", 
             RowBox[{"2", 
              RowBox[{"k", "[", 
               RowBox[{"4", ",", "i"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"e", ",", "i"}], "]"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"k", "[", 
              RowBox[{"4", ",", "m"}], "]"}], "-", 
             RowBox[{"k", "[", 
              RowBox[{"1", ",", "m"}], "]"}]}], ")"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"0", 
            RowBox[{"d", "[", 
             RowBox[{"m", ",", "n"}], "]"}]}], "+", 
           RowBox[{"0", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "m"}], "]"}], "+", 
              RowBox[{"k", "[", 
               RowBox[{"4", ",", "m"}], "]"}]}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "n"}], "]"}], "+", 
              RowBox[{"k", "[", 
               RowBox[{"4", ",", "n"}], "]"}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "m"}], "]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "n"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"4", ",", "n"}], "]"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "m"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"4", ",", "m"}], "]"}]}], ")"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "n"}], "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{
              TagBox[
               StyleBox[
                RowBox[{"Pair", "[", 
                 RowBox[{
                  RowBox[{"Momentum", "[", 
                   RowBox[{"q", ",", "D"}], "]"}], ",", 
                  RowBox[{"Momentum", "[", 
                   RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}],
                ShowSpecialCharacters->False,
                ShowStringCharacters->True,
                NumberMarks->True],
               FullForm], "+", 
              TagBox[
               StyleBox[
                RowBox[{"Pair", "[", 
                 RowBox[{
                  RowBox[{"Momentum", "[", 
                   RowBox[{"q", ",", "D"}], "]"}], ",", 
                  RowBox[{"Momentum", "[", 
                   RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
                ShowSpecialCharacters->False,
                ShowStringCharacters->True,
                NumberMarks->True],
               FullForm]}], ")"}]}], "+", 
           RowBox[{"X", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "m"}], "]"}], "+", 
              RowBox[{"k", "[", 
               RowBox[{"4", ",", "m"}], "]"}]}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "n"}], "]"}], "+", 
              RowBox[{"k", "[", 
               RowBox[{"4", ",", "n"}], "]"}]}], ")"}]}]}], ")"}], "/", "u"}],
         " ", 
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"a", ",", "c"}], "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"k", "[", 
                RowBox[{"2", ",", "n"}], "]"}], "-", 
               RowBox[{"k", "[", 
                RowBox[{"3", ",", "n"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"c", ",", "n"}], "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", 
                RowBox[{"k", "[", 
                 RowBox[{"3", ",", "a"}], "]"}]}], "+", 
               RowBox[{"k", "[", 
                RowBox[{"2", ",", "a"}], "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"n", ",", "a"}], "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], 
                RowBox[{"k", "[", 
                 RowBox[{"2", ",", "c"}], "]"}]}], "-", 
               RowBox[{"k", "[", 
                RowBox[{"3", ",", "c"}], "]"}]}], ")"}]}]}], ")"}], "/.", 
          RowBox[{"{", "}"}]}], "]"}]}], "]"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        StyleBox["Pair",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        RowBox[{
         RowBox[{
          StyleBox[
           RowBox[{
            StyleBox["M",
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True], "omentum"}]], "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"1", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        StyleBox["Pair",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        RowBox[{
         RowBox[{
          StyleBox[
           RowBox[{
            StyleBox["M",
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True], "omentum"}]], "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{"s", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{
        StyleBox["Pair",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        RowBox[{
         RowBox[{
          StyleBox[
           RowBox[{
            StyleBox["M",
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True], "omentum"}]], "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{"t", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{
        StyleBox["Pair",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        RowBox[{
         RowBox[{
          StyleBox[
           RowBox[{
            StyleBox["M",
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True], "omentum"}]], "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{"u", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{
        StyleBox["Pair",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        RowBox[{
         RowBox[{
          StyleBox[
           RowBox[{
            StyleBox["M",
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True], "omentum"}]], "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{"s", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{
        StyleBox["Pair",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        RowBox[{
         RowBox[{
          StyleBox[
           RowBox[{
            StyleBox["M",
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True], "omentum"}]], "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{"t", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{
        StyleBox["Pair",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        StyleBox["[",
         ShowSpecialCharacters->False,
         ShowStringCharacters->True,
         NumberMarks->True], 
        RowBox[{
         RowBox[{
          StyleBox[
           RowBox[{
            StyleBox["M",
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True], "omentum"}]], "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{"u", "/", "2"}]}]}], "}"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.616999931275319*^9, 3.617000073564972*^9}, {
   3.617000118573657*^9, 3.617000230378804*^9}, {3.61700026120089*^9, 
   3.617000445911125*^9}, {3.617000657979334*^9, 3.6170007015663843`*^9}, {
   3.617000768011404*^9, 3.6170008478524103`*^9}, 3.617009192204674*^9, {
   3.617354584019458*^9, 3.6173545981665173`*^9}, {3.617354651603714*^9, 
   3.617354656672823*^9}, {3.617354695984832*^9, 3.617354785661902*^9}, {
   3.6173550824607973`*^9, 3.617355117934743*^9}, {3.6175978425465813`*^9, 
   3.6175979622855177`*^9}, {3.617598101920257*^9, 3.6175981227370462`*^9}, {
   3.6175988796144457`*^9, 3.617598903823771*^9}, {3.617598949948246*^9, 
   3.6175989900988073`*^9}, {3.6175991319975443`*^9, 3.617599134278308*^9}, {
   3.61759918824761*^9, 3.617599243446105*^9}, {3.6175993247434473`*^9, 
   3.61759936458174*^9}, {3.618646189048774*^9, 3.618646189458589*^9}, {
   3.61864622442668*^9, 3.6186462707823544`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "fAEDfBCE", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]]}], ")"}], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "i"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "4"],
            TraditionalForm]}], "-", 
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "1"],
            TraditionalForm]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}], 
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.617000136077211*^9, 3.617000231604393*^9, {3.6170002858984423`*^9, 
   3.617000352494934*^9}, 3.617000397528357*^9, 3.617000451408598*^9, 
   3.6170007056456842`*^9, {3.617000833421893*^9, 3.6170008518093147`*^9}, 
   3.617000918803113*^9, 3.617009195931912*^9, 3.617340963144573*^9, 
   3.617354605477013*^9, 3.617354679985634*^9, 3.617354714186861*^9, 
   3.617354751466748*^9, 3.61735478827533*^9, 3.6173551209383793`*^9, 
   3.6174311335041924`*^9, 3.617597891543028*^9, {3.617597921675747*^9, 
   3.617597964578958*^9}, {3.617598113232299*^9, 3.617598124950097*^9}, {
   3.617598880816944*^9, 3.617598905010325*^9}, {3.617598973561019*^9, 
   3.6175989926938267`*^9}, 3.617599100320375*^9, 3.617599136893351*^9, {
   3.617599205101563*^9, 3.617599245139247*^9}, {3.617599329963524*^9, 
   3.617599366903575*^9}, 3.618220033696065*^9, 3.6186461925106277`*^9, 
   3.6186462759056*^9, 3.6193362413163347`*^9, 3.619777728088153*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp$t", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"tmp$u", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "\[Rule]", "t"}], ",", 
       RowBox[{"t", "\[Rule]", "u"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "e"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e"}], "]"}]}], ",", 
       StyleBox[
        RowBox[{
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], "->", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}]}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True], 
       StyleBox[",",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True], 
       RowBox[{"fAEDfBCE", "\[Rule]", "fAECfBDE"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e", "\[Rule]", "c"}], ",", 
     RowBox[{"c", "\[Rule]", "e"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6173547936437483`*^9, 3.6173548750424213`*^9}, {
  3.617354915426792*^9, 3.6173549663971043`*^9}, {3.61735501547602*^9, 
  3.617355030241119*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "fAECfBDE", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["3",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["3",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]]}], ")"}], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "i"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}], "-", 
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "1"],
            TraditionalForm]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}], 
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.617354932501493*^9, 3.6173549672981043`*^9, 
  3.6173550306467237`*^9, 3.61735513059406*^9, 3.6174311362895203`*^9, 
  3.617599038598065*^9, 3.617599369995529*^9, 3.6182200338337793`*^9, 
  3.619336241405514*^9, 3.6197777281461573`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp$s", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"tmp$u", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"u", "\[Rule]", "s"}], ",", 
       RowBox[{"s", "\[Rule]", "u"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "e"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "e"}], "]"}]}], ",", 
       StyleBox[
        RowBox[{
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], "->", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}]}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True], 
       StyleBox[",",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True], 
       RowBox[{"fAEDfBCE", "\[Rule]", "fAEBfDCE"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e", "\[Rule]", "a"}], ",", 
     RowBox[{"a", "\[Rule]", "e"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{
  3.617355044752964*^9, {3.617355137443469*^9, 3.617355220393012*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", "fAEBfDCE", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["2",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]]}], ")"}], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["2",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "i"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "2"],
            TraditionalForm]}], "-", 
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "1"],
            TraditionalForm]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}], 
    RowBox[{"s", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.61735522157191*^9, 3.61743114006565*^9, 
  3.617599041217806*^9, 3.6175993714817877`*^9, 3.618220033893791*^9, 
  3.6193362414770327`*^9, 3.6197777281940117`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp$all", "=", 
  RowBox[{
   RowBox[{"tmp$u", "+", "tmp$t", "+", 
    RowBox[{"(", 
     RowBox[{"tmp$s", "/.", 
      RowBox[{"{", 
       RowBox[{"fAEBfDCE", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "fAECfBDE"}], "+", "fAEDfBCE"}]}], "}"}]}], ")"}]}], "//",
    "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.6173552343546762`*^9, 3.617355332590838*^9}, {
  3.617599379186162*^9, 3.617599380075*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"s", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "1"],
          TraditionalForm]}], "+", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "2"],
          TraditionalForm]}]}], ")"}]}]], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"fAECfBDE", "-", "fAEDfBCE"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["2",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["2",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]]}], ")"}], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "i"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "1"],
            TraditionalForm]}], "-", 
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "2"],
            TraditionalForm]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}]}], "-", 
   FractionBox[
    RowBox[{"2", " ", "fAECfBDE", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["3",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["3",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]]}], ")"}], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "i"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}], "-", 
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "1"],
            TraditionalForm]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}], 
    RowBox[{"t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], ")"}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "fAEDfBCE", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["c",
             TraditionalForm],
            TraditionalForm]]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SubsuperscriptBox["k", 
           FormBox["1",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]], "+", 
          SubsuperscriptBox["k", 
           FormBox["4",
            TraditionalForm], 
           FormBox[
            FormBox["a",
             TraditionalForm],
            TraditionalForm]]}], ")"}], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"e", "i"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "4"],
            TraditionalForm]}], "-", 
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "1"],
            TraditionalForm]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}], 
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "+", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}]}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6173553030723352`*^9, 3.61735533360905*^9}, 
   3.617431146078122*^9, 3.617599043816429*^9, {3.617599373918894*^9, 
   3.617599381223361*^9}, 3.61822003451685*^9, 3.619336242111486*^9, 
   3.6197777288292837`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"tmp$all", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e"}], "]"}]}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "e"}], "]"}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"1", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "e"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"4", ",", "c"}], "]"}]}], "\[Rule]", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.617355337683*^9, 3.617355367573378*^9}, {
   3.617355497420334*^9, 3.6173554988048153`*^9}, {3.617355696748329*^9, 
   3.617355729004822*^9}, {3.617355768428784*^9, 3.617355769788931*^9}, {
   3.617355804971546*^9, 3.617355811161063*^9}, {3.617426126892414*^9, 
   3.6174261480986137`*^9}, 3.617426183790382*^9, {3.6174298494290648`*^9, 
   3.6174299216184464`*^9}, {3.6174299858682737`*^9, 3.617429986375236*^9}, {
   3.617430787406303*^9, 3.61743078877565*^9}, {3.617430908335524*^9, 
   3.6174309128445473`*^9}, {3.617430948136018*^9, 3.617431008737221*^9}, {
   3.617431061202175*^9, 3.617431064212381*^9}, {3.617431096326033*^9, 
   3.6174311108441153`*^9}, 3.617431374332883*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.617355353026691*^9, 3.617355359134118*^9}, 
   3.617355394565003*^9, 3.617355499175757*^9, {3.6173557193128977`*^9, 
   3.6173557293043947`*^9}, 3.617355771020817*^9, 3.617355811918367*^9, {
   3.617426162009872*^9, 3.617426184802723*^9}, {3.617429859421218*^9, 
   3.617429874254938*^9}, {3.617429904350629*^9, 3.617429922350586*^9}, 
   3.6174299867007113`*^9, 3.617430789381847*^9, {3.6174309133428707`*^9, 
   3.617430972598575*^9}, 3.6174310173973103`*^9, 3.6174310645974283`*^9, {
   3.617431097044326*^9, 3.61743111128666*^9}, 3.617431164318838*^9, 
   3.617431378982461*^9, 3.617599048337455*^9, 3.617599388756589*^9, 
   3.618220034805341*^9, 3.61933624239093*^9, 3.6197777291248283`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"tmp$s", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e"}], "]"}]}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "e"}], "]"}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"1", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "e"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"4", ",", "c"}], "]"}]}], "\[Rule]", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{3.617431176414824*^9, 3.617431377245059*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.617431176887342*^9, 3.617431380102797*^9, 
  3.6175981487320337`*^9, 3.6175993904879913`*^9, 3.618220034931464*^9, 
  3.6193362424831057`*^9, 3.619777729220675*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"tmp$t", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e"}], "]"}]}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "e"}], "]"}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"1", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "e"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"4", ",", "c"}], "]"}]}], "\[Rule]", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.617431176414824*^9, 3.617431189461773*^9}, 
   3.617431384492741*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61743119026441*^9, {3.6174313823105907`*^9, 3.617431385055126*^9}, 
   3.61759939184916*^9, 3.6182200349821568`*^9, 3.619336242533782*^9, 
   3.619777729250387*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"tmp$u", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e"}], "]"}]}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "e"}], "]"}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"1", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"4", ",", "e"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"2", ",", "c"}], "]"}], "+", 
     RowBox[{"kc", "[", 
      RowBox[{"4", ",", "c"}], "]"}]}], "\[Rule]", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.617431176414824*^9, 3.617431193663086*^9}, 
   3.617431386788571*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.617431194208562*^9, 3.6174313875819807`*^9, 
  3.617598918865732*^9, 3.617599004421041*^9, 3.6175992109196863`*^9, 
  3.617599263943108*^9, 3.61759930931746*^9, 3.617599352492036*^9, 
  3.617599393390841*^9, 3.618220035034993*^9, 3.618646301613097*^9, 
  3.6193362426054792`*^9, 3.619777729292766*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{"tmp$u", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"3", ",", "e_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"kc", "[", 
          RowBox[{"1", ",", "e"}], "]"}]}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "e"}], "]"}], "-", 
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "i"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "e"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.617431176414824*^9, 3.617431193663086*^9}, {
  3.617431367502224*^9, 3.61743137180182*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"2", " ", "fAEDfBCE", " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["a",
         TraditionalForm],
        TraditionalForm]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SubsuperscriptBox["k", 
       FormBox["1",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["2",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]], "+", 
      SubsuperscriptBox["k", 
       FormBox["4",
        TraditionalForm], 
       FormBox[
        FormBox["c",
         TraditionalForm],
        TraditionalForm]]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"e", "i"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "4"],
           TraditionalForm]}], "-", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "1"],
           TraditionalForm]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["i",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["i",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}]}], 
   RowBox[{"u", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "1"],
        TraditionalForm]}], "+", 
      RowBox[{
       FormBox["q",
        TraditionalForm], "\[CenterDot]", 
       FormBox[
        SubscriptBox["k", "4"],
        TraditionalForm]}]}], ")"}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.617431194208562*^9, {3.6174313685381517`*^9, 3.617431372088752*^9}, 
   3.617599296263567*^9, 3.617599395324651*^9, 3.618220035082679*^9, 
   3.6186462964126587`*^9, 3.6193362426647167`*^9, 3.619777729323462*^9}]
}, Open  ]],

Cell["Deriving the light-cone propagator:", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEa+2sdeD/8sqxYna1I4gGAOe0qbk=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prop", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "2"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "i"}], "]"}]}], "]"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"m", ",", "nn"}], "]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "m"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "nn"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "m"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "nn"}], "]"}]}]}], ")"}], "/", 
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"k", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Contract", "[", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"k", ",", "i"}], "]"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"k", ",", "i"}], "]"}]}], "]"}]}], 
            RowBox[{"d", "[", 
             RowBox[{"m", ",", "n"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"k", ",", "m"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"k", ",", "n"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "i"}], "]"}]}], "]"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"mm", ",", "n"}], "]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "n"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "mm"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "n"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "mm"}], "]"}]}]}], ")"}], "/", 
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"k", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"1", "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "i"}], "]"}]}], "]"}]}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d", "[", 
           RowBox[{"mm", ",", "nn"}], "]"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "mm"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "nn"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "mm"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "nn"}], "]"}]}]}], ")"}], "/", 
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"k", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}], ")"}]}]}], "]"}], 
     "]"}], "/.", 
    RowBox[{"{", "}"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.617618464986755*^9, 3.6176185172623672`*^9}, {
   3.6176185531116734`*^9, 3.6176188484283123`*^9}, {3.61761888408701*^9, 
   3.6176189671626167`*^9}, {3.617619021572495*^9, 3.617619052937133*^9}, {
   3.617619095132729*^9, 3.617619095698152*^9}, {3.6176191683815203`*^9, 
   3.617619219943185*^9}, {3.6176192878041677`*^9, 3.617619329624165*^9}, 
   3.617622005514742*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"mm", "nn"}]], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["k",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["nn",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["mm",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{
       FormBox["k",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["mm",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["k",
           TraditionalForm], 
          FormBox[
           FormBox["nn",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["nn",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["k",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}]}]}], ")"}]}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.617618763752887*^9, 3.617618859613668*^9, {3.617618954288986*^9, 
   3.617618967769568*^9}, {3.617619024103242*^9, 3.6176190536317863`*^9}, 
   3.6176190997625093`*^9, 3.617619179654331*^9, 3.617619221297245*^9, {
   3.617619288631589*^9, 3.617619330001069*^9}, 3.617622006976574*^9, 
   3.618220035204687*^9, 3.619336242787685*^9, 3.6197777294573402`*^9}]
}, Open  ]],

Cell["Most general ansatz", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEa+2sdeD/8sqxYna1I4hOuq7gwvX1laOeZi+YBgC/
17DT
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Amn", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"1", "/", 
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"k", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"k", ",", "i"}], "]"}]}], "]"}]}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"d", "[", 
      RowBox[{"m", ",", "n"}], "]"}], "-", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"k", ",", "m"}], "]"}], 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "n"}], "]"}], "/", 
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"k", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"FVD", "[", 
       RowBox[{"k", ",", "n"}], "]"}], 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "m"}], "]"}], "/", 
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"k", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}], "+", 
     RowBox[{"b", " ", 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "m"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "n"}], "]"}], 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"k", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"k", ",", "i"}], "]"}]}], "]"}], "/", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"k", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}]}]}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.618132522031871*^9, 3.618132616931004*^9}, {
  3.618132709296373*^9, 3.618132749272421*^9}, {3.618132867760211*^9, 
  3.618132870214102*^9}, {3.61813309481389*^9, 3.618133094970263*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["k", "n"], " ", 
      SuperscriptBox["q", "m"]}], 
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]], "+", 
    FractionBox[
     RowBox[{"b", " ", 
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], "2"], " ", 
      SuperscriptBox["q", "m"], " ", 
      SuperscriptBox["q", "n"]}], 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]], "+", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "m"], " ", 
      SuperscriptBox["q", "n"]}], 
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]]}], 
   SuperscriptBox[
    FormBox["k",
     TraditionalForm], "2"]], TraditionalForm]], "Output",
 CellChangeTimes->{3.618132749769167*^9, 3.61813287168569*^9, 
  3.6181329988641768`*^9, 3.618133095811961*^9, 3.618220035252707*^9, 
  3.619336242852311*^9, 3.61977772948569*^9}]
}, Open  ]],

Cell["Mixed terms J A\[CloseCurlyQuote]", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEa+2sdeD/8sqxYna1I4hOuq7gwvX1laOeZi+YPnXg
RBqIPtc7KR1EAwAiU7o0
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"k", ",", "i"}], "]"}]}], "]"}]}], " ", 
           RowBox[{"d", "[", 
            RowBox[{"m", ",", "n"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "m"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"k", ",", "n"}], "]"}]}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"m", ",", "l"}], "]"}], 
           RowBox[{"Amn", "[", 
            RowBox[{"n", ",", "r"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Amn", "[", 
            RowBox[{"m", ",", "r"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"n", ",", "l"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"d", "[", 
        RowBox[{"l", ",", "r"}], "]"}]}], "//", "Expand"}], "//", 
     "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Pair", "[", 
      RowBox[{
       RowBox[{"LorentzIndex", "[", 
        RowBox[{"l", ",", "D"}], "]"}], ",", 
       RowBox[{"Momentum", "[", 
        RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618132801208424*^9, 3.618132911700852*^9}, {
  3.618133050277779*^9, 3.6181330637052383`*^9}, {3.618133475071376*^9, 
  3.618133562677636*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a", " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["l",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["r",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["k",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b", " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["l",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["r",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["k",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["l",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], 
      FormBox[
       FormBox["r",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["k",
      TraditionalForm], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6181335644041643`*^9, 3.618220035342823*^9, 
  3.619336242958165*^9, 3.619777729569737*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "\[Rule]", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{"b", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.618133066160054*^9, 3.6181331003211393`*^9}, {
  3.6181334070703897`*^9, 3.618133412367847*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.618133076950266*^9, 3.618133100869583*^9}, 
   3.618133422636116*^9, 3.618133595066671*^9, 3.618220035348752*^9, 
   3.6193362429646893`*^9, 3.6197777295866003`*^9}]
}, Open  ]],

Cell["Hence, the propagator is:", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEa+2sdeD/8sqxYna1I4hOuq7gwvX1laOeZi+YPnXg
RBqIPtc7KR1E/7BiuAOiZSclgWkADMfChA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", 
         RowBox[{"Amn", "[", 
          RowBox[{"m", ",", "r"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Contract", "[", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"k", ",", "i"}], "]"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"k", ",", "i"}], "]"}]}], "]"}]}], " ", 
            RowBox[{"d", "[", 
             RowBox[{"m", ",", "n"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"k", ",", "m"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"k", ",", "n"}], "]"}]}]}], ")"}], 
         RowBox[{"Amn", "[", 
          RowBox[{"n", ",", "s"}], "]"}]}], "+", 
        RowBox[{"Amn", "[", 
         RowBox[{"r", ",", "s"}], "]"}]}], ")"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"b", "\[Rule]", "0"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], "}"}]}], "//",
   "Simplify"}]], "Input",
 CellChangeTimes->{{3.618133735548052*^9, 3.6181339691040897`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"r", "s"}]], " ", 
       RowBox[{
        FormBox["k",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["s",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["r",
         TraditionalForm],
        TraditionalForm]]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["k",
        TraditionalForm], 
       FormBox[
        FormBox["r",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["s",
         TraditionalForm],
        TraditionalForm]]}]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["k",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["k",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.618133797627433*^9, 3.618133851524345*^9}, {
   3.6181338825886297`*^9, 3.618133969761448*^9}, 3.618220035446342*^9, 
   3.619336243065003*^9, 3.619777729703412*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gravity in light-cone gauge?", "Subsection",
 CellChangeTimes->{{3.6175115845088453`*^9, 3.617511624543292*^9}}],

Cell["What is the light-cone gravity propagator?", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
  3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
  3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
  3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
  3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
  3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
  3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
  3.6044001159150867`*^9, 3.604400123994227*^9}, {3.604720820865553*^9, 
  3.60472083813302*^9}, {3.604722666557773*^9, 3.604722695320043*^9}, {
  3.604723091148676*^9, 3.604723095257025*^9}, {3.604723355577581*^9, 
  3.604723398392375*^9}, {3.604723476921307*^9, 3.604723505440467*^9}, {
  3.61743231154848*^9, 3.617432370363323*^9}, {3.617511615112288*^9, 
  3.617511633847177*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["Let\[CloseCurlyQuote]s first study the s-channel in the 4e-amplitude.", \
"Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UE0APG2qt0=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$s$lightcone", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"verEEEonshellmn", "[", 
          RowBox[{
          "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", 
           ",", "j"}], "]"}], 
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}], 
         RowBox[{"I", "/", "s"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "m"}], "]"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "i"}], "]"}], 
               RowBox[{"k", "[", 
                RowBox[{"12", ",", "m"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "m"}], "]"}], 
               RowBox[{"k", "[", 
                RowBox[{"12", ",", "i"}], "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"Contract", "[", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "e"}], "]"}], 
               RowBox[{"k", "[", 
                RowBox[{"12", ",", "e"}], "]"}]}], "]"}], ")"}]}]}], ")"}]}], 
        "]"}], "]"}], 
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "n"}], "]"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "j"}], "]"}], 
               RowBox[{"k", "[", 
                RowBox[{"12", ",", "n"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "n"}], "]"}], 
               RowBox[{"k", "[", 
                RowBox[{"12", ",", "j"}], "]"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"Contract", "[", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "e"}], "]"}], 
               RowBox[{"k", "[", 
                RowBox[{"12", ",", "e"}], "]"}]}], "]"}], ")"}]}]}], ")"}], 
         RowBox[{"verEEEonshellmn", "[", 
          RowBox[{
          "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", ",", "m", 
           ",", "n"}], "]"}]}], "]"}], "]"}]}], "]"}], "]"}], "+", 
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{"2", 
      RowBox[{"I", "/", "s"}], " ", 
      RowBox[{"verEEEonshellmn", "[", 
       RowBox[{
       "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", 
        "j"}], "]"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"X", " ", 
          RowBox[{"k", "[", 
           RowBox[{"12", ",", "i"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"12", ",", "j"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "m"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "n"}], "]"}]}], "+", 
         RowBox[{"Y", " ", 
          RowBox[{"k", "[", 
           RowBox[{"12", ",", "m"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"12", ",", "n"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "j"}], "]"}]}]}], ")"}], "/", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "e"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"12", ",", "e"}], "]"}]}], "]"}], "^", "2"}]}], " ", 
      RowBox[{"verEEEonshellmn", "[", 
       RowBox[{
       "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", ",", "m", ",", 
        "n"}], "]"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6182226344715643`*^9, 3.6182227840443277`*^9}, {
  3.618308728768602*^9, 3.618308731886154*^9}}],

Cell[BoxData[
 FormBox["$Aborted", TraditionalForm]], "Output",
 CellChangeTimes->{3.618223076633713*^9, 3.6183090055880613`*^9, 
  3.619336510061872*^9, 3.6197778757904053`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$s$lightcone2", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"amp4$channel$s$lightcone", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"kc", "[", 
        RowBox[{"12", ",", "e_"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "e"}], "]"}], "+", 
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "e"}], "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"kdotk", "[", 
        RowBox[{"12", ",", "12"}], "]"}], "\[Rule]", "s"}], ",", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "e_"}], "]"}], ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "12"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "e"}], "]"}], ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], "+", 
        
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "e"}], "]"}], ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}]}],
      "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.618222826687645*^9, 3.618222844306226*^9}, {
  3.6182232450317717`*^9, 3.6182232486560907`*^9}, {3.618223307104556*^9, 
  3.618223451638084*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "X", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox[
                 SubscriptBox["k", "1"],
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "2"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}], 
            RowBox[{"2", " ", "s", " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "12"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox[
                 SubscriptBox["k", "1"],
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "2"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}], 
            RowBox[{"2", " ", "s", " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "12"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "X", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox[
                 SubscriptBox["k", "1"],
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "2"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}], 
            RowBox[{"2", " ", "s", " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "12"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "6002", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "X", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "4"],
               TraditionalForm]}]}], 
            RowBox[{"2", " ", "s", " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "12"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "4"],
               TraditionalForm]}]}], 
            RowBox[{"2", " ", "s", " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "12"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 543, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 543, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 543, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[543]], TraditionalForm]], "Output",
 CellChangeTimes->{3.618223187494865*^9, 3.618223250207527*^9, 
  3.618223373552103*^9, 3.618223463434737*^9, 3.618309019174728*^9, 
  3.619336512545519*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$channel$s$lightcone2", "]"}]], "Input",
 CellChangeTimes->{{3.618223255958213*^9, 3.618223257894493*^9}}],

Cell[BoxData[
 FormBox["4008", TraditionalForm]], "Output",
 CellChangeTimes->{3.61822325858689*^9, 3.618223373660645*^9, 
  3.618223465854698*^9, 3.618309026770626*^9, 3.619336512627144*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$s$lightcone", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"verEEEonshellmn", "[", 
          RowBox[{
          "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", 
           ",", "j"}], "]"}], 
         RowBox[{"(", 
          RowBox[{"-", "2"}], ")"}], 
         RowBox[{"I", "/", "s"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "m"}], "]"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "i"}], "]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "m"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"2", ",", "m"}], "]"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "m"}], "]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "i"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"2", ",", "i"}], "]"}]}], ")"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"Contract", "[", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "e"}], "]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "e"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"2", ",", "e"}], "]"}]}], ")"}]}], "]"}], ")"}]}]}],
           ")"}]}], "]"}], "]"}], 
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "n"}], "]"}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "j"}], "]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "n"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"2", ",", "n"}], "]"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "n"}], "]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "j"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"2", ",", "j"}], "]"}]}], ")"}]}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"Contract", "[", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "e"}], "]"}], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"k", "[", 
                  RowBox[{"1", ",", "e"}], "]"}], "+", 
                 RowBox[{"k", "[", 
                  RowBox[{"2", ",", "e"}], "]"}]}], ")"}]}], "]"}], ")"}]}]}],
           ")"}], 
         RowBox[{"verEEEonshellmn", "[", 
          RowBox[{
          "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", ",", "m", 
           ",", "n"}], "]"}]}], "]"}], "]"}]}], "]"}], "]"}], "+", 
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{"2", 
      RowBox[{"I", "/", "s"}], " ", 
      RowBox[{"verEEEonshellmn", "[", 
       RowBox[{
       "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", 
        "j"}], "]"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "i"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "i"}], "]"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "j"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "j"}], "]"}]}], ")"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "m"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "n"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "m"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "m"}], "]"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "n"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "n"}], "]"}]}], ")"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "j"}], "]"}]}]}], ")"}], "/", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "e"}], "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"k", "[", 
             RowBox[{"1", ",", "e"}], "]"}], "+", 
            RowBox[{"k", "[", 
             RowBox[{"2", ",", "e"}], "]"}]}], ")"}]}], "]"}], "^", "2"}]}], 
      " ", 
      RowBox[{"verEEEonshellmn", "[", 
       RowBox[{
       "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", ",", "m", ",", 
        "n"}], "]"}]}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6175116853590517`*^9, 3.617511685572633*^9}, {
   3.617511733288739*^9, 3.6175119031217623`*^9}, 3.61751193733841*^9, {
   3.617511969857749*^9, 3.617511985437868*^9}, {3.617512042022925*^9, 
   3.617512090355052*^9}, {3.6175130902331533`*^9, 3.617513127926104*^9}, {
   3.618221322286178*^9, 3.618221522094413*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["b",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["1",
                TraditionalForm], 
               FormBox[
                FormBox["c",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["1",
                TraditionalForm], 
               FormBox[
                FormBox["d",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], 
             RowBox[{"4", " ", "s"}]]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"4", " ", "s"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"4", " ", "s"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "3350", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}]}], 
            RowBox[{"4", " ", "s", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "1"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}]}], ")"}], "2"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}]}], 
            RowBox[{"4", " ", "s", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "1"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}]}], ")"}], "2"]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 545, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 545, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 545, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[545]], TraditionalForm]], "Output",
 CellChangeTimes->{3.617511938323552*^9, 3.617512001023484*^9, 
  3.6175120533083687`*^9, 3.617513085107339*^9, 3.617514202095256*^9, 
  3.6182210950926228`*^9, 3.6182227995967817`*^9, 3.619337813962696*^9}]
}, Open  ]],

Cell["\<\
Substract the part from the e-exchange s-channel with the ordinary propagator.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QDQDrcrOq

  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$s$lightcone3", "=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Expand", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"amp4$channel$s$lightcone2", "-", 
                RowBox[{"Contract", "[", 
                 RowBox[{"Expand", "[", 
                  RowBox[{
                   RowBox[{"verEEEonshellmn", "[", 
                    RowBox[{
                    "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", 
                    ",", "i", ",", "j"}], "]"}], 
                   RowBox[{"(", 
                    RowBox[{"-", "2"}], ")"}], 
                   RowBox[{"I", "/", "s"}], " ", 
                   RowBox[{"verEEEonshellmn", "[", 
                    RowBox[{
                    "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", 
                    ",", "i", ",", "j"}], "]"}]}], "]"}], "]"}]}], ")"}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
                 RowBox[{"s", "/", "2"}]}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
                 RowBox[{"t", "/", "2"}]}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
                 RowBox[{"u", "/", "2"}]}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
                 RowBox[{"u", "/", "2"}]}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
                 RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
                 RowBox[{"s", "/", "2"}]}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kc", "[", 
                  RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
                RowBox[{
                 RowBox[{"kdotk", "[", 
                  RowBox[{"4", ",", "4"}], "]"}], "\[Rule]", "0"}]}], "}"}]}],
              ")"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"kc", "[", 
                RowBox[{"4", ",", "e_"}], "]"}], "\[Rule]", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"kc", "[", 
                  RowBox[{"1", ",", "e"}], "]"}]}], "-", 
                RowBox[{"kc", "[", 
                 RowBox[{"2", ",", "e"}], "]"}], "-", 
                RowBox[{"kc", "[", 
                 RowBox[{"3", ",", "e"}], "]"}]}]}], ",", 
              RowBox[{"u", "\[Rule]", 
               RowBox[{
                RowBox[{"-", "s"}], "-", "t"}]}], ",", 
              RowBox[{
               RowBox[{"Pair", "[", 
                RowBox[{
                 RowBox[{"Momentum", "[", 
                  RowBox[{
                   RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], ",", 
                 RowBox[{"Momentum", "[", 
                  RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"Pair", "[", 
                  RowBox[{
                   RowBox[{"Momentum", "[", 
                    RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
                   RowBox[{"Momentum", "[", 
                    RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}], "-", 
                RowBox[{"Pair", "[", 
                 RowBox[{
                  RowBox[{"Momentum", "[", 
                   RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}], ",", 
                  RowBox[{"Momentum", "[", 
                   RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "-", 
                RowBox[{"Pair", "[", 
                 RowBox[{
                  RowBox[{"Momentum", "[", 
                   RowBox[{
                    RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
                  RowBox[{"Momentum", "[", 
                   RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], "}"}]}], 
           "]"}], ")"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], 
        ")"}], 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "12"}], "]"}], ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "^", "2"}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "12"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
       "\[Rule]", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}], "+", 
        
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}]}]}], 
      "}"}]}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.617514480948741*^9, 3.617514512057523*^9}, {
  3.617514779446175*^9, 3.6175148134451714`*^9}, {3.6175149344245443`*^9, 
  3.617515009873118*^9}, {3.617515103825861*^9, 3.6175151270075073`*^9}, {
  3.617515403500017*^9, 3.6175154413989973`*^9}, {3.6182232183423243`*^9, 
  3.618223221424917*^9}, {3.618223626702816*^9, 3.618223692948166*^9}, {
  3.618223750831585*^9, 3.618223793969639*^9}, {3.618223916285098*^9, 
  3.618223989358801*^9}, {3.618224060922654*^9, 3.618224064187026*^9}, {
  3.618224143284171*^9, 3.618224145359744*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox["1", 
            RowBox[{"16", " ", "s"}]], 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[LeftSkeleton]", "1027", "\[RightSkeleton]"}], "+", 
              RowBox[{
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["a",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[LeftSkeleton]", "325", "\[RightSkeleton]"}], "+", 
                 
                 RowBox[{"2", " ", 
                  RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"4", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["d",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["k", 
                    FormBox["1",
                    TraditionalForm], 
                    FormBox[
                    FormBox["f",
                    TraditionalForm],
                    TraditionalForm]], "+", 
                    SubsuperscriptBox["k", 
                    FormBox["2",
                    TraditionalForm], 
                    FormBox[
                    FormBox["f",
                    TraditionalForm],
                    TraditionalForm]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SubsuperscriptBox["k", 
                    FormBox["3",
                    TraditionalForm], 
                    FormBox[
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                    TraditionalForm]], " ", 
                    SuperscriptBox["g", 
                    RowBox[{"e", "g"}]]}], "-", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "-", 
                    RowBox[{
                    SuperscriptBox["g", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], 
                    " ", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]}], 
                    ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SubsuperscriptBox["k", 
                    FormBox["1",
                    TraditionalForm], 
                    FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], "+", 
                    SubsuperscriptBox["k", 
                    FormBox["2",
                    TraditionalForm], 
                    FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], "+", 
                    SubsuperscriptBox["k", 
                    FormBox["3",
                    TraditionalForm], 
                    FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox[
                    SubscriptBox["k", "1"],
                    TraditionalForm]}], "+", 
                    RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox[
                    SubscriptBox["k", "2"],
                    TraditionalForm]}]}], ")"}]}], "+", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 546, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 546, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 546, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[546]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.617515133928956*^9, 3.617515447474166*^9, 3.6175163572184143`*^9, 
   3.61822110028222*^9, 3.618223230807187*^9, 3.618223287512691*^9, 
   3.6182234751454678`*^9, {3.618223655586512*^9, 3.618223700922611*^9}, 
   3.618223799804586*^9, {3.618223942182619*^9, 3.618223954198091*^9}, 
   3.618223999586611*^9, 3.61822406946163*^9, 3.618224165542349*^9, 
   3.6183092655894136`*^9, 3.619338027356018*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$channel$s$lightcone3", "]"}]], "Input",
 CellChangeTimes->{{3.617514504013565*^9, 3.617514505227133*^9}, 
   3.6182232952989063`*^9}],

Cell[BoxData[
 FormBox["3", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.617514518282745*^9, 3.617514819095274*^9, 3.617515140609468*^9, 
   3.617515449808852*^9, 3.618221100395158*^9, 3.618223296735209*^9, 
   3.618223478598689*^9, {3.618223658621789*^9, 3.6182237009826603`*^9}, 
   3.6182238019819937`*^9, 3.618224002910111*^9, 3.618224073164875*^9, 
   3.618224168750667*^9, 3.619338027431679*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{"amp4$channel$s$lightcone3", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"X", "\[Rule]", "1"}], ",", 
      RowBox[{"Y", "\[Rule]", "1"}]}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6183093571932507`*^9, 3.618309399117269*^9}}],

Cell[BoxData[
 FormBox["1101", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6183093647634487`*^9, 3.618309399813436*^9}, 
   3.619338027493771*^9}]
}, Open  ]],

Cell["\<\
For a moment choose q so generic that all polarizations can be chosen to be \
orthogonal (would have to add all diagrams to get the amplitude first!).\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QvfVSDy+I
/r1gtiiIBgCA7L4M
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$s$lightcone2$qorthogonalpols", "=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{"amp4$channel$s$lightcone3", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"a", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"b", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"c", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"d", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"e", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"f", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"g", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{
        TagBox[
         StyleBox[
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{"h", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
          ShowSpecialCharacters->False,
          ShowStringCharacters->True,
          NumberMarks->True],
         FullForm], "\[Rule]", "0"}], ",", 
       RowBox[{"u", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "s"}], "-", "t"}]}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "e_"}], "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"kc", "[", 
           RowBox[{"1", ",", "e"}], "]"}]}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"2", ",", "e"}], "]"}], "-", 
         RowBox[{"kc", "[", 
          RowBox[{"3", ",", "e"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
        "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{
              RowBox[{"Subscript", "[", 
               RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}]}], 
         "-", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}], "-", 
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"Momentum", "[", 
            RowBox[{"q", ",", "D"}], "]"}], ",", 
           RowBox[{"Momentum", "[", 
            RowBox[{
             RowBox[{"Subscript", "[", 
              RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], 
          "]"}]}]}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}]}], "}"}]}]}]], "Input",\

 CellChangeTimes->{{3.6175156157631397`*^9, 3.6175156166932077`*^9}, {
   3.617515706979704*^9, 3.617515768410907*^9}, {3.617516248810782*^9, 
   3.617516342780851*^9}, 3.6175163793771973`*^9, {3.617516433451825*^9, 
   3.617516457683138*^9}, 3.6182235093162127`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "16"]}], " ", "\[ImaginaryI]", " ", "s", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", 
            SuperscriptBox[
             FormBox[
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "1"],
                TraditionalForm]}],
              TraditionalForm], "2"]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "t", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "1"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}], 
            RowBox[{"8", " ", "s"}]], "+", 
           RowBox[{
            FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["e",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", 
            SubsuperscriptBox["k", 
             FormBox["1",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox[
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "1"],
                TraditionalForm]}],
              TraditionalForm], "2"]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "1"],
                 TraditionalForm]}],
               TraditionalForm], "2"]}], 
            RowBox[{"4", " ", "s"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "455", "\[RightSkeleton]"}], "+", 
           RowBox[{
            FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", "X", 
            " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", 
            SuperscriptBox[
             FormBox[
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "3"],
                TraditionalForm]}],
              TraditionalForm], "2"]}], "-", 
           RowBox[{
            FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "2"],
              TraditionalForm]}], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}]}], "+", 
           RowBox[{
            FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", "X", 
            " ", 
            SuperscriptBox["g", 
             RowBox[{"a", "c"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"b", "d"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            SuperscriptBox["g", 
             RowBox[{"f", "h"}]], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "2"],
              TraditionalForm]}], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}]}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 549, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 549, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 549, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[549]], TraditionalForm]], "Output",
 CellChangeTimes->{3.618221100763653*^9, 3.618223509792391*^9, 
  3.619338027735054*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$channel$s$lightcone2$qorthogonalpols", 
  "]"}]], "Input",
 CellChangeTimes->{{3.6175158071582947`*^9, 3.617515808590797*^9}}],

Cell[BoxData[
 FormBox["339", TraditionalForm]], "Output",
 CellChangeTimes->{3.617515808920308*^9, 3.617516271631165*^9, 
  3.617516333901258*^9, 3.617516385302813*^9, 3.617516462774405*^9, 
  3.617518376265012*^9, 3.6182211008194847`*^9, 3.618223513107051*^9, 
  3.619338027770599*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4Eexchange", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",", 
         "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], 
       RowBox[{"I", "/", "s"}], " ", 
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", ",", "m", ",", 
         "n"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "1", ",", "3", ",", "a", ",", "b", ",", "e", ",", "f", ",", "i", ",", 
         "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], 
       RowBox[{"I", "/", "t"}], " ", 
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "2", ",", "4", ",", "c", ",", "d", ",", "g", ",", "h", ",", "i", ",", 
         "j"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "1", ",", "4", ",", "a", ",", "b", ",", "g", ",", "h", ",", "i", ",", 
         "j"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"-", "2"}], ")"}], 
       RowBox[{"I", "/", "u"}], " ", 
       RowBox[{"verEEEonshellmn", "[", 
        RowBox[{
        "2", ",", "3", ",", "c", ",", "d", ",", "e", ",", "f", ",", "i", ",", 
         "j"}], "]"}]}]}], "//", "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
      RowBox[{"u", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"t", "/", "2"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"kdotk", "[", 
       RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
      RowBox[{"s", "/", "2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.617511643522704*^9, 3.617511645042643*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"16", " ", "u"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["s", "2"]}], 
            RowBox[{"16", " ", "t"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", "s"}], 
            RowBox[{"8", " ", "u"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", "s"}], 
            RowBox[{"8", " ", "t"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "816", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["m",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["n",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "i"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["m",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["n",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s"}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["m",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["n",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"8", " ", "s"}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 551, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 551, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 551, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[551]], TraditionalForm]], "Output",
 CellChangeTimes->{3.618221102734928*^9, 3.619338029699383*^9}]
}, Open  ]],

Cell[TextData[{
 "Generic ansatz for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "ij"], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQA2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QvfVSDy+I
/r1gtiiItmDYKbT7yyvHxetERUA0AKOWxj4=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eij", "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "/", 
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", 
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "j"}], "]"}], 
         RowBox[{"d", "[", 
          RowBox[{"s", ",", "t"}], "]"}]}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "s"}], "]"}], 
         RowBox[{"d", "[", 
          RowBox[{"j", ",", "t"}], "]"}]}], "+", 
        RowBox[{"a3", " ", 
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "t"}], "]"}], 
         RowBox[{"d", "[", 
          RowBox[{"j", ",", "s"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"b1", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"b2", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"b3", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"b4", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"b5", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"b6", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"b7", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "+", 
           RowBox[{"b8", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "+", 
           RowBox[{"b9", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "+", 
           RowBox[{"b10", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"b11", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"b12", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c1", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"c2", " ", 
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"c3", " ", 
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"c4", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"c5", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"c6", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}],
         "+", 
        RowBox[{"d", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "j"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "s"}], "]"}], 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "t"}], "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}],
         "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"e1", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"e2", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}], "+", 
           RowBox[{"e3", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}], "+", 
           RowBox[{"e4", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], 
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f1", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"f2", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"f3", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"f4", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"f5", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"f6", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}], 
        "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"g1", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"g2", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"g3", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"g4", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}]}], ")"}], 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "3"}], ")"}]}]}],
         "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}]}], "+", 
           RowBox[{"h2", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}]}], "+", 
           RowBox[{"h3", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "+", 
           RowBox[{"h4", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}]}], "+", 
           RowBox[{"h5", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "+", 
           RowBox[{"h6", " ", 
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "o"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "o"}], "]"}]}], "]"}]}], "+", 
        RowBox[{"ii", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "j"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "s"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "t"}], "]"}], 
         RowBox[{
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "4"}], 
           ")"}]}]}]}], ")"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a2", "\[Rule]", "1"}], ",", 
       RowBox[{"b3", "\[Rule]", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"b5", "\[Rule]", 
        RowBox[{"-", "1"}]}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6179703517595673`*^9, 3.617970779129396*^9}, {
   3.617970879468876*^9, 3.617970919076379*^9}, {3.6179709519702663`*^9, 
   3.6179709533780193`*^9}, {3.617970984844159*^9, 3.61797114731628*^9}, {
   3.6179714109042788`*^9, 3.6179714542681723`*^9}, {3.617971514353078*^9, 
   3.617971601477254*^9}, {3.617971643385899*^9, 3.6179718972932*^9}, 
   3.6179719296959248`*^9, 3.617972009927199*^9, 3.617972050362486*^9, 
   3.6179724567357693`*^9, {3.617972660466942*^9, 3.617972672014579*^9}, 
   3.61797289536517*^9, {3.617972978809762*^9, 3.617972982014348*^9}, {
   3.617973026458253*^9, 3.6179730287227707`*^9}, 3.61803425058486*^9, {
   3.6180357071967497`*^9, 3.618035710039319*^9}, {3.618052871007208*^9, 
   3.618052921229148*^9}, {3.618052978179215*^9, 3.618053074353793*^9}, {
   3.618140015348394*^9, 3.6181400387410088`*^9}, {3.618140078679212*^9, 
   3.618140140134884*^9}, {3.618140224639729*^9, 3.618140275649692*^9}, {
   3.618140349871594*^9, 3.618140350074747*^9}, 3.618202878154153*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b9", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b12", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f4", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "d", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "ii", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.617970508644579*^9, 3.617970515674611*^9}, 
   3.617970610900194*^9, {3.617970667093309*^9, 3.617970684405377*^9}, 
   3.617970779487597*^9, {3.6179709094849358`*^9, 3.61797091948825*^9}, 
   3.61797095422296*^9, 3.6179710512162037`*^9, 3.617971151965066*^9, 
   3.617971456565495*^9, 3.617971618760309*^9, 3.617971806392809*^9, {
   3.617971884203683*^9, 3.6179718985356207`*^9}, 3.617971930558934*^9, {
   3.6179720251928453`*^9, 3.617972081120645*^9}, 3.617972457416106*^9, 
   3.617972673353109*^9, 3.617972896661525*^9, 3.617972982534219*^9, 
   3.617973029117887*^9, 3.618034252413721*^9, 3.6180357115866127`*^9, 
   3.618052872322629*^9, 3.618052923836216*^9, 3.618052979265397*^9, 
   3.61805307561588*^9, 3.618123157187961*^9, 3.618136390750071*^9, 
   3.6181402258941097`*^9, 3.618140276774337*^9, 3.6181403512717133`*^9, 
   3.6182022692458687`*^9, 3.618202878797084*^9, 3.618205477446751*^9, 
   3.618221103285145*^9, 3.619338030176828*^9}]
}, Open  ]],

Cell["Checking homogeneity...", "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QvfVSDy+I
/r1gtiiItmDYKbT7yyvHxetERUC0wO6utD1A+lKadAaIBgBU/s9r
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eij", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"i_", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"p", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{"P", " ", 
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"i", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"i_", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{"Q", " ", 
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"LorentzIndex", "[", 
          RowBox[{"i", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{"p", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"p", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"P", "^", "2"}], 
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}]}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{"p", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{"P", " ", "Q", " ", 
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"p", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], "}"}]}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.617972642115399*^9, 3.61797279957929*^9}, {
  3.617975080120081*^9, 3.61797508266891*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["P", "2"], " ", 
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "3"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "4"]}]], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["i",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["j",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["s",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"ii", " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"]}], "+", 
               RowBox[{"g2", " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"c5", " ", 
                SuperscriptBox["g", 
                 RowBox[{"s", "t"}]], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"g1", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"f1", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"], " ", 
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["g", 
                 RowBox[{"j", "t"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"c3", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"b8", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["g", 
                 RowBox[{"j", "s"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"c2", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"b7", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"g4", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"f2", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"b9", " ", 
                   SuperscriptBox["g", 
                    RowBox[{"s", "t"}]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"f3", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                    RowBox[{"e4", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], " ", 
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"i", "t"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["j",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"c4", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"b11", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"a3", " ", 
                   SuperscriptBox["g", 
                    RowBox[{"j", "s"}]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["j",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"b6", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                    RowBox[{"h4", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"i", "s"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["j",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"c1", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"b10", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["g", 
                    RowBox[{"j", "t"}]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["j",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h2", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
             "+", 
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"i", "j"}]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"c6", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"b4", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"a1", " ", 
                   SuperscriptBox["g", 
                    RowBox[{"s", "t"}]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"b1", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                    RowBox[{"h6", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["i",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"g3", " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                  RowBox[{"f5", " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "+", 
               RowBox[{
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"b12", " ", 
                   SuperscriptBox["g", 
                    RowBox[{"s", "t"}]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"f4", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                    RowBox[{"e3", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
            "+", 
            RowBox[{
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["g", 
                    RowBox[{"j", "t"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h5", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "-", 
                    RowBox[{
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}]}], ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox["g", 
                    RowBox[{"j", "s"}]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"b2", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                    RowBox[{"h3", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["j",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"f6", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                    RowBox[{"e2", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "+", 
                  RowBox[{
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"h1", " ", 
                    SuperscriptBox["g", 
                    RowBox[{"s", "t"}]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                    RowBox[{
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"e1", " ", 
                    SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"]}], "+", 
                    RowBox[{"d", " ", 
                    SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.617972653177929*^9, 3.617972675544368*^9}, {
   3.617972790858098*^9, 3.617972801154171*^9}, 3.617972899311665*^9, 
   3.617972984935429*^9, 3.617973033868379*^9, 3.617975084038159*^9, 
   3.618034263533247*^9, 3.618035717602991*^9, 3.618036368661537*^9, 
   3.618053084994061*^9, 3.6181231599773493`*^9, 3.618136395340186*^9, 
   3.618140284868827*^9, 3.618140356738557*^9, 3.618202272783174*^9, 
   3.6182028812048264`*^9, 3.6182054792843657`*^9, 3.61822110538923*^9, 
   3.619338032443331*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sys", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"eij", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "]"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"eij", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "j"}], "]"}]}], "]"}], "]"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{"Expand", "[", 
         RowBox[{"eij", " ", 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "]"}], "+", 
       RowBox[{"2", 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"j", ",", "t"}], "]"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}]}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{"Expand", "[", 
         RowBox[{"eij", " ", 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "j"}], "]"}]}], "]"}], "]"}], "+", 
       RowBox[{"2", 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}], 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "s"}], "]"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}]}], "\[Equal]", 
      "0"}]}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}]}], "\[Rule]", "0"}], "]"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.617972095948505*^9, 3.617972172277947*^9}, {
   3.617972202971814*^9, 3.6179723639304733`*^9}, {3.6179732932945538`*^9, 
   3.617973347814002*^9}, {3.617973419317361*^9, 3.617973443318619*^9}, {
   3.6179734784535437`*^9, 3.617973499082657*^9}, 3.617973584918683*^9, {
   3.617973710073709*^9, 3.617973725126054*^9}, {3.617973904712633*^9, 
   3.617973939428482*^9}, {3.618053094726465*^9, 3.618053095852097*^9}, {
   3.618140416485796*^9, 3.618140416771379*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b12", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b10", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b11", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c6", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]]}], "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b9", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b6", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b7", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b8", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c6", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]]}], "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["q", "s"], " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b9", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b8", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b7", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b12", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b10", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b11", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "ii", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "3"]]}], "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["q", "t"], " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b12", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b11", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b10", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b9", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b6", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c4", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c1", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b7", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b8", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f5", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "ii", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "3"]]}], "\[LongEqual]", "0"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.6179723054806337`*^9, 3.617972323398527*^9}, 
   3.617972366984592*^9, 3.6179724625613823`*^9, 3.617973065158647*^9, 
   3.617973588554257*^9, 3.617973726512703*^9, 3.6179739435576973`*^9, 
   3.6179756017261677`*^9, 3.618034276879684*^9, 3.618035720806094*^9, 
   3.6180363734625998`*^9, {3.618053092569376*^9, 3.618053098989853*^9}, 
   3.618123162897973*^9, 3.6181363997072783`*^9, 3.618140319878716*^9, 
   3.618140370651737*^9, 3.6181404184618397`*^9, 3.618202277609621*^9, 
   3.6182028876776876`*^9, 3.618221106632999*^9, 3.619338033631228*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"sys", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"g3", "\[Rule]", 
               RowBox[{
                RowBox[{"-", "c1"}], "-", "c4", "-", "c6"}]}], ",", 
              RowBox[{"f5", "\[Rule]", 
               RowBox[{
                RowBox[{"-", "b10"}], "-", "b4"}]}], ",", 
              RowBox[{"b12", "\[Rule]", 
               RowBox[{"-", "a1"}]}], ",", 
              RowBox[{"f4", "\[Rule]", 
               RowBox[{
                RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
              RowBox[{"h6", "\[Rule]", 
               RowBox[{"-", "e3"}]}], ",", 
              RowBox[{"b2", "\[Rule]", "a3"}], ",", 
              RowBox[{"f6", "\[Rule]", 
               RowBox[{"1", "-", "b6"}]}], ",", 
              RowBox[{"h2", "\[Rule]", 
               RowBox[{"-", "e2"}]}], ",", 
              RowBox[{"h4", "\[Rule]", 
               RowBox[{"-", "e1"}]}], ",", 
              RowBox[{"h5", "\[Rule]", "0"}], ",", 
              RowBox[{"d", "\[Rule]", "0"}], ",", 
              RowBox[{"h1", "\[Rule]", "0"}], ",", 
              RowBox[{"h3", "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a3", "\[Rule]", "0"}], ",", 
            RowBox[{"f2", "\[Rule]", 
             RowBox[{
              RowBox[{"-", "b7"}], "-", "b4"}]}], ",", 
            RowBox[{"f3", "\[Rule]", 
             RowBox[{
              RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
            RowBox[{"g4", "\[Rule]", 
             RowBox[{
              RowBox[{"-", "c2"}], "-", "c3", "-", "c6"}]}], ",", 
            RowBox[{"b9", "\[Rule]", 
             RowBox[{"-", "a1"}]}], ",", 
            RowBox[{"e4", "\[Rule]", "e3"}], ",", 
            RowBox[{"e2", "\[Rule]", 
             RowBox[{"b7", "-", "b6"}]}]}], "}"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"b6", "\[Rule]", "0"}], ",", 
          RowBox[{"b7", "\[Rule]", "0"}], ",", 
          RowBox[{"e1", "\[Rule]", "0"}], ",", 
          RowBox[{"g2", "\[Rule]", 
           RowBox[{"b10", "+", "b4", "-", "c4"}]}], ",", 
          RowBox[{"c5", "\[Rule]", "a1"}], ",", 
          RowBox[{"g1", "\[Rule]", 
           RowBox[{"b1", "+", "b11", "-", "c1"}]}], ",", 
          RowBox[{"b8", "\[Rule]", 
           RowBox[{"-", "1"}]}], ",", 
          RowBox[{"f1", "\[Rule]", 
           RowBox[{"1", "-", "e3"}]}], ",", 
          RowBox[{"c3", "\[Rule]", 
           RowBox[{"1", "-", "c2"}]}]}], "}"}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"b11", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b10"}], "-", "1"}]}], ",", 
        RowBox[{"ii", "\[Rule]", 
         RowBox[{"c1", "+", "c4", "+", "c6"}]}]}], "}"}]}], "//", "Expand"}], 
    "//", "Contract"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.618035736004798*^9, 3.6180362311031113`*^9}, {
  3.618036281194851*^9, 3.618036316493868*^9}, {3.6180364087518587`*^9, 
  3.6180364176091633`*^9}, {3.618053112701007*^9, 3.618053343361577*^9}, {
  3.6180533896005163`*^9, 3.618053577817658*^9}, {3.618053611709237*^9, 
  3.61805364646453*^9}, {3.618053677279689*^9, 3.618053707020729*^9}, {
  3.618202317720998*^9, 3.618202851443705*^9}, {3.618202896325378*^9, 
  3.618202908420046*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"c2", "-", "1"}], ")"}], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]]}], "-", 
       RowBox[{"c2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]]}]}], 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]], "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["i",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{"(", 
                RowBox[{"b10", "-", "c2", "-", "c4", "+", "1"}], ")"}], " ", 
               RowBox[{
                FormBox["p",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["q",
                 TraditionalForm]}]}], "+", 
              RowBox[{
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], "2"], " ", 
               RowBox[{"(", 
                RowBox[{"c1", "+", "c4", "-", "1"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{"b10", "+", "c1", "-", "c2"}], ")"}], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["g", 
                RowBox[{"i", "s"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"b10", "+", "1"}], ")"}], " ", 
                  SuperscriptBox[
                   FormBox["p",
                    TraditionalForm], 
                   FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], "+", 
                 RowBox[{"c1", " ", 
                  SuperscriptBox[
                   FormBox["p",
                    TraditionalForm], "2"], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["g", 
                RowBox[{"i", "t"}]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"c4", " ", 
                  SuperscriptBox[
                   FormBox["p",
                    TraditionalForm], "2"], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"b10", "+", "1"}], ")"}], " ", 
                  SuperscriptBox[
                   FormBox["p",
                    TraditionalForm], 
                   FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["i",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["s",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"b10", "+", "1"}], ")"}], " ", 
                  SuperscriptBox[
                   FormBox["p",
                    TraditionalForm], 
                   FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox["q",
                    TraditionalForm]}]}], "+", 
                 RowBox[{
                  SuperscriptBox[
                   FormBox["p",
                    TraditionalForm], "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"c1", "+", "c4", "-", "1"}], ")"}], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b10", "+", "1"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["s",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["p",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["q",
                 TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
     "\[LongEqual]", "0"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.618053120428934*^9, 3.61805313229114*^9}, {
   3.618053163478324*^9, 3.61805329687429*^9}, {3.618053329139673*^9, 
   3.618053345943322*^9}, {3.618053396658441*^9, 3.61805357906737*^9}, 
   3.6180536161886044`*^9, 3.61805364689266*^9, {3.618053688438396*^9, 
   3.618053707617134*^9}, 3.618136407173307*^9, 3.618140376566759*^9, 
   3.618140424188528*^9, {3.61820229835223*^9, 3.618202328322877*^9}, {
   3.6182023854036827`*^9, 3.618202649861964*^9}, {3.6182026926368237`*^9, 
   3.618202739458619*^9}, {3.6182027701459827`*^9, 3.618202852121522*^9}, {
   3.6182028917127132`*^9, 3.618202909297131*^9}, 3.6182211070336647`*^9, 
   3.6193380339550247`*^9}]
}, Open  ]],

Cell[TextData[{
 "If the ansatz is the most general then there is no such ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "ij"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAGIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QvfVSDy+I
/r1gtiiItmDYKbT7yyvHxetERUC0wO6utD1A+lKadAaIvqK788xjIM24P+o8
iAYApsjZ3w==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[TextData[{
 "Using the same ansatz can one complete the square in the Lagrangian?\n\n\
First, determine the coefficients in the ansatz so that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "i"], 
     SubscriptBox["e", "ij"]}], "=", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "j"], 
     SubscriptBox["e", "ij"]}], "=", "0"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAmIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QvfVSDy+I
/r1gtiiItmDYKbT7yyvHxetERUC0wO6utD1A+lKadAaIvqK788xjIM24P+o8
iP5TPWMV69dXjjN8Dq0B0f4b9m0F0Wq7tu8C0QAbFexD
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Filter", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"tmp", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"p", ",", "s"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "j"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "t"}], "]"}]}], "]"}]}], "]"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.618140655943206*^9, 3.618140692539877*^9}, 
   3.618140782476869*^9, {3.618140830210046*^9, 3.618140845580525*^9}, {
   3.6181409031468678`*^9, 3.618140921646873*^9}, {3.618140976958517*^9, 
   3.618140980207234*^9}, {3.618141018264008*^9, 3.618141118874613*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox[
    RowBox[{"Part", "::", "partd"}], "MessageName"], ":", 
   " ", "\<\"Part specification \[NoBreak]\\!\\(TraditionalForm\\`\\(True \
\[LeftDoubleBracket] 1 \[RightDoubleBracket]\\)\\)\[NoBreak] is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/partd\\\", ButtonNote -> \
\\\"Part::partd\\\"]\\)\"\>"}], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{3.618221107111609*^9, 3.619338034049317*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   StyleBox[
    RowBox[{"Part", "::", "partd"}], "MessageName"], ":", 
   " ", "\<\"Part specification \[NoBreak]\\!\\(TraditionalForm\\`\\(True \
\[LeftDoubleBracket] 1 \[RightDoubleBracket]\\)\\)\[NoBreak] is longer than \
depth of object. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\
\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/partd\\\", ButtonNote -> \
\\\"Part::partd\\\"]\\)\"\>"}], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{3.618221107111609*^9, 3.619338034085526*^9}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.618140665489922*^9, 3.61814069296933*^9}, {
   3.618140768131822*^9, 3.618140782744277*^9}, {3.618140813075902*^9, 
   3.618140873599121*^9}, {3.61814091015489*^9, 3.618140922103714*^9}, {
   3.618140980803342*^9, 3.6181411196127462`*^9}, 3.61820299267408*^9, 
   3.618221107157063*^9, 3.619338034090054*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"sys", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g3", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "c1"}], "-", "c4", "-", "c6"}]}], ",", 
        RowBox[{"g4", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "c2"}], "-", "c3", "-", "c6"}]}], ",", 
        RowBox[{"f4", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
        RowBox[{"f3", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
        RowBox[{"f6", "\[Rule]", 
         RowBox[{"1", "-", "b6"}]}], ",", 
        RowBox[{"f5", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b4"}], "-", "b10"}]}], ",", 
        RowBox[{"f2", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b4"}], "-", "b7"}]}], ",", 
        RowBox[{"h5", "\[Rule]", 
         RowBox[{"-", "e1"}]}], ",", 
        RowBox[{"h4", "\[Rule]", 
         RowBox[{"-", "e1"}]}], ",", 
        RowBox[{"h6", "\[Rule]", 
         RowBox[{"-", "e3"}]}], ",", 
        RowBox[{"h2", "\[Rule]", 
         RowBox[{"-", "e2"}]}], ",", 
        RowBox[{"h3", "\[Rule]", 
         RowBox[{"-", "e2"}]}], ",", 
        RowBox[{"h1", "\[Rule]", "0"}], ",", 
        RowBox[{"d", "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"b12", "\[Rule]", 
       RowBox[{"-", "a1"}]}], ",", 
      RowBox[{"b2", "\[Rule]", 
       RowBox[{"-", "a3"}]}], ",", 
      RowBox[{"e1", "\[Rule]", "0"}], ",", 
      RowBox[{"e2", "\[Rule]", "0"}], ",", 
      RowBox[{"b6", "\[Rule]", 
       RowBox[{"-", "a3"}]}], ",", 
      RowBox[{"e4", "\[Rule]", "e3"}], ",", 
      RowBox[{"b9", "\[Rule]", 
       RowBox[{"-", "a1"}]}]}], "}"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.618140598790771*^9, 3.618140652986001*^9}, {
  3.618140706652618*^9, 3.618140727106453*^9}, {3.618140762668045*^9, 
  3.618140794693933*^9}, {3.6181408513892927`*^9, 3.618140853974769*^9}, {
  3.61814098479492*^9, 3.6181409909177847`*^9}, {3.618141025892335*^9, 
  3.618141257306781*^9}, {3.618202981888029*^9, 3.618203234391654*^9}, {
  3.618203274352906*^9, 3.618203336632481*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}],
          TraditionalForm], "3"]}]], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["j",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"c5", "-", "a1"}], ")"}], " ", 
                SuperscriptBox["g", 
                 RowBox[{"s", "t"}]], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "b1"}], "-", "b11", "+", "c1", "+", "g1"}], 
                    ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}], " ", 
                   RowBox[{"(", 
                    RowBox[{"b10", "+", "b11", "+", "e3", "+", "f1"}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["s",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{"b10", "+", "b4", "-", "c4", "-", "g2"}], ")"}]}], 
               "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{"c1", "+", "c4", "+", "c6", "-", "ii"}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["g", 
                 RowBox[{"j", "s"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"a3", "+", "b7"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"c2", "-", "a3"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["g", 
                 RowBox[{"j", "t"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"b8", "+", "1"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"c3", "-", "1"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                SuperscriptBox["q", "s"], " ", 
                SuperscriptBox["g", 
                 RowBox[{"j", "t"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{"a3", "-", "c2", "-", "c3", "+", "1"}], ")"}]}], 
                  "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"a3", "+", "b7"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"b8", "+", "1"}], ")"}], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}],
          TraditionalForm], "3"]}]], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["i",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"c5", "-", "a1"}], ")"}], " ", 
                SuperscriptBox["g", 
                 RowBox[{"s", "t"}]], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "b1"}], "-", "b8", "+", "c2", "+", "g1"}], 
                    ")"}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}], " ", 
                   RowBox[{"(", 
                    RowBox[{"b7", "+", "b8", "+", "e3", "+", "f1"}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["s",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}], " ", 
                RowBox[{"(", 
                 RowBox[{"b4", "+", "b7", "-", "c3", "-", "g2"}], ")"}]}], 
               "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{"c2", "+", "c3", "+", "c6", "-", "ii"}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["g", 
                 RowBox[{"i", "t"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"a3", "+", "b11"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"c4", "-", "a3"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["s",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["g", 
                 RowBox[{"i", "s"}]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"b10", "+", "1"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"c1", "-", "1"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], "2"], " ", 
                SuperscriptBox["q", "t"], " ", 
                SuperscriptBox["g", 
                 RowBox[{"i", "s"}]]}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], "2"], " ", 
                   SuperscriptBox[
                    FormBox["q",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{"(", 
                    RowBox[{"a3", "-", "c1", "-", "c4", "+", "1"}], ")"}]}], 
                  "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"b10", "+", "1"}], ")"}], " ", 
                   SuperscriptBox[
                    FormBox["p",
                    TraditionalForm], 
                    FormBox[
                    FormBox["t",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["p",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox["q",
                    TraditionalForm]}]}]}], ")"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"a3", "+", "b11"}], ")"}], " ", 
                SuperscriptBox[
                 FormBox["p",
                  TraditionalForm], 
                 FormBox[
                  FormBox["s",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["t",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["p",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox["q",
                  TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
     "\[LongEqual]", "0"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.61820298886563*^9, 3.618203235768505*^9}, {
   3.6182032787149477`*^9, 3.618203337979007*^9}, 3.618221108236918*^9, 
   3.6193380351887693`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eijJ", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"eij", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "c1"}], "-", "c4", "-", "c6"}]}], ",", 
       RowBox[{"g4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "c2"}], "-", "c3", "-", "c6"}]}], ",", 
       RowBox[{"f4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
       RowBox[{"f3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
       RowBox[{"f6", "\[Rule]", 
        RowBox[{"1", "-", "b6"}]}], ",", 
       RowBox[{"f5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b4"}], "-", "b10"}]}], ",", 
       RowBox[{"f2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b4"}], "-", "b7"}]}], ",", 
       RowBox[{"h5", "\[Rule]", 
        RowBox[{"-", "e1"}]}], ",", 
       RowBox[{"h4", "\[Rule]", 
        RowBox[{"-", "e1"}]}], ",", 
       RowBox[{"h6", "\[Rule]", 
        RowBox[{"-", "e3"}]}], ",", 
       RowBox[{"h2", "\[Rule]", 
        RowBox[{"-", "e2"}]}], ",", 
       RowBox[{"h3", "\[Rule]", 
        RowBox[{"-", "e2"}]}], ",", 
       RowBox[{"h1", "\[Rule]", "0"}], ",", 
       RowBox[{"d", "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b12", "\[Rule]", 
      RowBox[{"-", "a1"}]}], ",", 
     RowBox[{"b2", "\[Rule]", 
      RowBox[{"-", "a3"}]}], ",", 
     RowBox[{"e1", "\[Rule]", "0"}], ",", 
     RowBox[{"e2", "\[Rule]", "0"}], ",", 
     RowBox[{"b6", "\[Rule]", 
      RowBox[{"-", "a3"}]}], ",", 
     RowBox[{"e4", "\[Rule]", "e3"}], ",", 
     RowBox[{"b9", "\[Rule]", 
      RowBox[{"-", "a1"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6181258719631977`*^9, 3.6181258831477222`*^9}, {
   3.618125953859033*^9, 3.61812597828318*^9}, 3.6181364766045218`*^9, 
   3.618140508460737*^9, 3.6181412817936573`*^9, 3.618203355980138*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b4"}], "-", "b7"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b10"}], "-", "b4"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b8"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b11"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"a3", "+", "1"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "c2"}], "-", "c3", "-", "c6"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "c1"}], "-", "c4", "-", "c6"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "ii", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6181258835271683`*^9, 3.6181259804411173`*^9, 
  3.618136478131229*^9, 3.61814051019172*^9, 3.618141284861121*^9, 
  3.618203356828607*^9, 3.6182211084678926`*^9, 3.6193380354208717`*^9}]
}, Open  ]],

Cell[TextData[{
 "Using the same ansatz can one complete the square in the Lagrangian?\n\n\
First, determine the coefficients in the ansatz so that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "i"], 
     SubscriptBox["e", "ij"]}], "=", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "j"], 
     SubscriptBox["e", "ij"]}], "=", "0"}], TraditionalForm]]],
 ".\nThen try to find coefficients so that the mixed terms (J e\
\[CloseCurlyQuote]) vanishes."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyU0og3EAx/FR26LUjEXmpUnLBTW1NoyeUVYTcRhzcMDWbkpZ6TEUF8xL
CdOohZOExmgj8nJQU5PX8ZhkSM9pYy4I/99z+PY5fGWtHQ2meB6PJyVBXbTt
vfiapc6qwjG4MKQbKSNGQo2cyUn+K8j/ObmFvSZtufCGpexrTAW89ynG4cDU
0QR8lhkEYqI1MshpUorUMH9OWwKze5SMgriUGOAsypN1l+Lnf9Fwst+vYIjt
uQ8aTp3tN3jHUp6zvj8453ZOdzEstUEdO2D1bb3NSvRr2H4YO2h3Q7v6jXOE
7ryAhrHTIDTS80+wNr3wFcpHoy2bHyzV5NKbYWgmnMYQUzJLM2CsUpIN77Po
HDj7IhKEiFt6VQL0nNuT4LfLKYEqnle8E2OpxVVJKhTtDJt3iedmqQVeFnhP
w8S4/eYA/KEdy/xPlnLUHK7AuvU9D5T7tn3Qknz8KCQahcYw/AckS/RL
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "4"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"eijJ", "[", 
            RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"x", ",", "m"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"y", ",", "n"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"x", ",", "i"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"y", ",", "j"}], "]"}], 
           RowBox[{"eijJ", "[", 
            RowBox[{"m", ",", "n", ",", "s", ",", "t"}], "]"}]}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "m"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "n"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "n"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "m"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "m"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "n"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{"x", ",", "s"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"y", ",", "t"}], "]"}]}]}], "//", "Expand"}], "//", 
     "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"x", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"y", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.61812766383427*^9, 3.618127816200135*^9}, {
   3.6181278590989847`*^9, 3.618127923576621*^9}, {3.618128673818131*^9, 
   3.618128706917452*^9}, 3.618135311614771*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "a3"}], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"t", "x"}]]}], "+", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "x"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "x"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "x"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   RowBox[{"a1", " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"x", "y"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"b4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"x", "y"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"b1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"x", "y"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "y"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"x", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.618127778917045*^9, 3.618127789062096*^9}, 
   3.6181278192217913`*^9, {3.618127865435725*^9, 3.618127927628908*^9}, {
   3.618128699464522*^9, 3.618128710424263*^9}, 3.618135332898191*^9, 
   3.618137231460053*^9, 3.618140531104244*^9, 3.6181413024044647`*^9, 
   3.618203379153846*^9, 3.618221112993438*^9, 3.619338040097794*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"tmp", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"b11", "\[Rule]", 
         RowBox[{"-", "a3"}]}], ",", 
        RowBox[{"b7", "\[Rule]", 
         RowBox[{"-", "a3"}]}], ",", 
        RowBox[{"a1", "\[Rule]", "0"}], ",", 
        RowBox[{"c2", "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a3", "\[Rule]", "0"}], ",", 
      RowBox[{"b8", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"b10", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"c1", "\[Rule]", "0"}], ",", 
      RowBox[{"b1", "\[Rule]", "0"}], ",", 
      RowBox[{"e3", "\[Rule]", "0"}], ",", 
      RowBox[{"c6", "\[Rule]", "0"}], ",", 
      RowBox[{"c4", "\[Rule]", 
       RowBox[{"1", "-", "c3"}]}], ",", 
      RowBox[{"b4", "\[Rule]", "0"}]}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.61814132036621*^9, 3.6181415026795588`*^9}, {
  3.618203408920825*^9, 3.618203578094624*^9}, {3.618203834196122*^9, 
  3.618203846077895*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["s",
       TraditionalForm],
      TraditionalForm]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"c3", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["x",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"t", "y"}]]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"c3", "-", "1"}], ")"}], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["y",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"t", "x"}]]}]}], ")"}]}], 
   RowBox[{
    FormBox["p",
     TraditionalForm], "\[CenterDot]", 
    FormBox["q",
     TraditionalForm]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.618141321321929*^9, {3.618141356058745*^9, 3.6181415030375834`*^9}, {
   3.618203412534965*^9, 3.618203579079021*^9}, {3.618203839998138*^9, 
   3.618203846529595*^9}, 3.618221113121935*^9, 3.619338040262814*^9}]
}, Open  ]],

Cell["\<\
This shows that it is not possible to complete the square (such that the \
mixed term vanishes).\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyU0og3EAx/FR26JWMxZ5bdJy8FJTa15GD8qKiAPm4MC2dlPKSo+XFRc2
rIQJJZwkhJFN5OWgpsjreEwypOe08biYt//vOXz7HL6KlrY6Y6RAIEgmQV2o
9T3vmqXOygMcnBvQ2YqIQX8Db4zEewWF38e3sMdYWiy+YSn7ClMC792qEdg3
duiAz4p6kYxoCfbzGtXSfJg5XVoAU7vUjIq4EH3Km5uh6CzEz/yi4ajVq2KI
hvQHLa+u+9d3x1Kus94/OL02Nd7BsNQ6deSEFbe13RaiV8taIbdvWIP2/Dde
G91+AeuHT3xQT888weqEnFeoHAo1b3ywVONspQn6JwLxDDE2uTARcmXyVHif
QqfByRepyE/crNREQde5XQLDs1NyqBFsyzwcS80vy+Og1DNo2iGem5LM8DJ7
+yRAjNhrOoXftHNR+MlSzqqDJVizuuuCSveWG5pjjh7FRL1YH4AORhTOIhZw
vz/wH7+V/nk=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[TextData[{
 "Now do it again but with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "s"], 
     SuperscriptBox["q", "t"], 
     SubscriptBox["J", "st"]}], "=", "0"}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyU0og3EAx/FR26JW87IIo0nLwUtNhHnpQZkm4oA5OGBrN6WseLwVF8xL
CRNKOEkIIyPyclBTW17HY5IhPaeNxwUb/99z+PY5fBWNLdX6YIFAICdBja/p
I+OGpZwlHg4uDGiG8ohedy1vmMR+DYW/Z3ewW19UIL5lKfMaUwgfbKpR2Ddx
MgZfFDWicKLJ28+rz5LmwOTZolwY35nFqIhLoQ7e9CRFuxo/+ZuG4712FUNs
TnzM59V0BVz3LGV19vzB2Y2ZyTaGpTapUwssvavqMhHt+Wwv5I6aN6A55513
iG69hDUj5y6oo+eeYUV02htUDvsatj5Zqm5ea4DuKU8UQ4yIU8dArlgWDx/k
dAKcfpWK3MRtbXYItF6YJfBnfkYGswW74XscSy2uyiKhdG/QsE+8MMQa4VXq
7rmHGHRY74C/tGVZ+MVSlvLjFVi5fmCFStuODRrDTp/ERJ1Y54FjjOgnhZjL
BfywI7OSSSX2l/nd8B/yLwej
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eij$", "=", 
  RowBox[{"eij", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "s"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618205643919593*^9, 3.618205652555293*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b9", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b12", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "h6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f4", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "d", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.618205654230371*^9, 3.618221113181542*^9, 
  3.619338040323818*^9}]
}, Open  ]],

Cell[TextData[{
 "In what follows one can use  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "s"], 
     SuperscriptBox["q", "t"], 
     SubscriptBox["J", "st"]}], "=", "0"}], TraditionalForm]]],
 " because it is always multiplied by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["J", "st"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVsoQ3EAx/EhW5TasNynSfJg1ERsLh2UueT2gHnwgC1vSlEcQ/GCuZQw
bUp4khBGRuTyoKbIfc4mGdJ5cjlK7v/fefj2efjKaxrKdJ4CgSCSBDUvta+J
Fyx1nOPm4FSPpi+N+Oyq4JX42c+h9/eBA7brsjJElyxlXGAyodOmHIRdI3tD
8F5eLvQnNj938+qSxakw1pKlgrK2ZEZJnPE94k2Ilreo8WM/aTjcaVcyxLqo
m3RejeH36pqlrMcdf9CyZB5tYlhqmdo3wVxHqaGZaE9nOyG3U7cEjalPvH10
4yksHzi8glp64g4WBcc/wpj+l+qVN5aqnCzQQ9eYO4ghBoSrQyGXLZVBZwQd
CccfxEIXcbUgxQdaT4x+8GvSLIUpgnX/DY6lpuelgVC80avfJJ7ow+rhmWL9
0E302K46gt+0adb7naVMhbtzsHhxywpjbGs2WC/ZvxURtSKtGw4xwq84oor7
/YGtScWMgtid9+OCXiX5AfFEu1oSCKdCeoOh4qNFBv8BwDYV0Q==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sys", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"eij$", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "]"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"Expand", "[", 
        RowBox[{"eij$", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "j"}], "]"}]}], "]"}], "]"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{"Expand", "[", 
         RowBox[{"eij$", " ", 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "]"}], "+", 
       RowBox[{"2", 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"j", ",", "t"}], "]"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}]}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{"Expand", "[", 
         RowBox[{"eij$", " ", 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "j"}], "]"}]}], "]"}], "]"}], "+", 
       RowBox[{"2", 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}], 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "s"}], "]"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}]}], "\[Equal]", 
      "0"}]}], "}"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}]}], "\[Rule]", "0"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.617972095948505*^9, 3.617972172277947*^9}, {
   3.617972202971814*^9, 3.6179723639304733`*^9}, {3.6179732932945538`*^9, 
   3.617973347814002*^9}, {3.617973419317361*^9, 3.617973443318619*^9}, {
   3.6179734784535437`*^9, 3.617973499082657*^9}, 3.617973584918683*^9, {
   3.617973710073709*^9, 3.617973725126054*^9}, {3.617973904712633*^9, 
   3.617973939428482*^9}, {3.618053094726465*^9, 3.618053095852097*^9}, {
   3.618140416485796*^9, 3.618140416771379*^9}, {3.618205504036622*^9, 
   3.618205514724372*^9}, {3.618205629183778*^9, 3.618205629906024*^9}, {
   3.618205662533259*^9, 3.618205672151761*^9}, {3.61820582451845*^9, 
   3.618205824840271*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b12", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b10", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b11", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]]}], "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b9", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "3"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b6", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b7", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b8", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]]}], "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["q", "s"], " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b9", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b8", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b7", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b12", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c3", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c2", " ", 
        SuperscriptBox["g", 
         RowBox[{"j", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b10", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b11", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["j",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]]}], "\[LongEqual]", "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["q", "t"], " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b12", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "a3", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b11", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h4", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b10", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b9", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c5", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"s", "t"}]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b6", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c4", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c1", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b7", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b8", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e4", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f5", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "b2", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e1", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f4", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "d", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "e3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h3", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h5", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "h6", " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], "2"],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "c2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "f3", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]], "+", 
      FractionBox[
       RowBox[{"2", " ", "g1", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["i",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]]}], 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]]}], "\[LongEqual]", "0"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.6179723054806337`*^9, 3.617972323398527*^9}, 
   3.617972366984592*^9, 3.6179724625613823`*^9, 3.617973065158647*^9, 
   3.617973588554257*^9, 3.617973726512703*^9, 3.6179739435576973`*^9, 
   3.6179756017261677`*^9, 3.618034276879684*^9, 3.618035720806094*^9, 
   3.6180363734625998`*^9, {3.618053092569376*^9, 3.618053098989853*^9}, 
   3.618123162897973*^9, 3.6181363997072783`*^9, 3.618140319878716*^9, 
   3.618140370651737*^9, 3.6181404184618397`*^9, 3.618202277609621*^9, 
   3.6182028876776876`*^9, 3.6182055174385157`*^9, 3.618205632103128*^9, 
   3.6182058318753357`*^9, 3.618221114141781*^9, 3.61933804134569*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"sys", "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"f5", "\[Rule]", 
                 RowBox[{
                  RowBox[{"-", "b10"}], "-", "b4"}]}], ",", 
                RowBox[{"f2", "\[Rule]", 
                 RowBox[{
                  RowBox[{"-", "b7"}], "-", "b4"}]}], ",", 
                RowBox[{"f4", "\[Rule]", 
                 RowBox[{
                  RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
                RowBox[{"f3", "\[Rule]", 
                 RowBox[{
                  RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
                RowBox[{"h6", "\[Rule]", 
                 RowBox[{"-", "e3"}]}], ",", 
                RowBox[{"h2", "\[Rule]", 
                 RowBox[{"-", "e2"}]}], ",", 
                RowBox[{"h4", "\[Rule]", 
                 RowBox[{"-", "e1"}]}], ",", 
                RowBox[{"h1", "\[Rule]", "0"}], ",", 
                RowBox[{"h3", "\[Rule]", "0"}], ",", 
                RowBox[{"h5", "\[Rule]", "0"}], ",", 
                RowBox[{"d", "\[Rule]", "0"}], ",", 
                RowBox[{"b12", "\[Rule]", 
                 RowBox[{"-", "a1"}]}], ",", 
                RowBox[{"b2", "\[Rule]", 
                 RowBox[{"-", "a3"}]}]}], "}"}]}], ")"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"e2", "\[Rule]", "0"}], ",", 
              RowBox[{"e1", "\[Rule]", "0"}], ",", 
              RowBox[{"e4", "\[Rule]", "e3"}], ",", 
              RowBox[{"b6", "\[Rule]", 
               RowBox[{"-", "a3"}]}], ",", 
              RowBox[{"b9", "\[Rule]", 
               RowBox[{"-", "a1"}]}]}], "}"}]}], ")"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"g1", "\[Rule]", 
             RowBox[{"b1", "+", "b11", "-", "c1"}]}], ",", 
            RowBox[{"g2", "\[Rule]", 
             RowBox[{"b4", "+", "b7", "-", "c3"}]}], ",", 
            RowBox[{"f1", "\[Rule]", 
             RowBox[{
              RowBox[{"-", "b10"}], "-", "b11", "-", "e3"}]}], ",", 
            RowBox[{"b8", "\[Rule]", 
             RowBox[{"-", "1"}]}], ",", 
            RowBox[{"c5", "\[Rule]", "a1"}], ",", 
            RowBox[{"b7", "\[Rule]", 
             RowBox[{"-", "a3"}]}]}], "}"}]}], ")"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"c3", "\[Rule]", "0"}], ",", 
          RowBox[{"c2", "\[Rule]", "a3"}], ",", 
          RowBox[{"c4", "\[Rule]", 
           RowBox[{"b10", "-", "b7"}]}], ",", 
          RowBox[{"b11", "\[Rule]", 
           RowBox[{"-", "a3"}]}]}], "}"}]}], ")"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"b10", "\[Rule]", 
         RowBox[{"-", "1"}]}], ",", 
        RowBox[{"c1", "\[Rule]", "1"}], ",", 
        RowBox[{"b7", "\[Rule]", 
         RowBox[{"-", "a3"}]}]}], "}"}]}], "//", "Expand"}], "//", 
    "Contract"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.618035736004798*^9, 3.6180362311031113`*^9}, {
  3.618036281194851*^9, 3.618036316493868*^9}, {3.6180364087518587`*^9, 
  3.6180364176091633`*^9}, {3.618053112701007*^9, 3.618053343361577*^9}, {
  3.6180533896005163`*^9, 3.618053577817658*^9}, {3.618053611709237*^9, 
  3.61805364646453*^9}, {3.618053677279689*^9, 3.618053707020729*^9}, {
  3.618202317720998*^9, 3.618202851443705*^9}, {3.618202896325378*^9, 
  3.618202908420046*^9}, {3.618206007715783*^9, 3.618206075256168*^9}, {
  3.61820613102344*^9, 3.618206438381789*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", "True", ",", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "t"}]]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"i", "s"}]]}]}], 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]], "\[LongEqual]", "0"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.618053120428934*^9, 3.61805313229114*^9}, {
   3.618053163478324*^9, 3.61805329687429*^9}, {3.618053329139673*^9, 
   3.618053345943322*^9}, {3.618053396658441*^9, 3.61805357906737*^9}, 
   3.6180536161886044`*^9, 3.61805364689266*^9, {3.618053688438396*^9, 
   3.618053707617134*^9}, 3.618136407173307*^9, 3.618140376566759*^9, 
   3.618140424188528*^9, {3.61820229835223*^9, 3.618202328322877*^9}, {
   3.6182023854036827`*^9, 3.618202649861964*^9}, {3.6182026926368237`*^9, 
   3.618202739458619*^9}, {3.6182027701459827`*^9, 3.618202852121522*^9}, {
   3.6182028917127132`*^9, 3.618202909297131*^9}, {3.6182060007572393`*^9, 
   3.618206077421238*^9}, {3.618206138020516*^9, 3.6182064387723083`*^9}, 
   3.618221114335935*^9, 3.619338041480978*^9}]
}, Open  ]],

Cell[TextData[{
 "If the ansatz is the most general then there is no such ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["e", "ij"], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAGIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QvfVSDy+I
/r1gtiiItmDYKbT7yyvHxetERUC0wO6utD1A+lKadAaIvqK788xjIM24P+o8
iAYApsjZ3w==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[TextData[{
 "Using the same ansatz can one complete the square in the Lagrangian?\n\n\
First, determine the coefficients in the ansatz so that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "i"], 
     SubscriptBox["e", "ij"]}], "=", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "j"], 
     SubscriptBox["e", "ij"]}], "=", "0"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAmIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRBdl+pkx379lWPP+tv2IPrOLqN+EN089fAEEP1EMYxNCEiXfWgB
06lmApYgWmOOkxWIlqsxu20EpJdwnQfT+iqKldYgeY1f1SB6csNpo9tAOkXp
ni2Y9qj9d+PWK8etF+r/g+g5m2ZPK739ynGz45EZINr9ZmBtGZA+bfuqAUR/
OZiyCUT3WL4A093VRZdBdFjfmRsgOrJ67iMQ7Seh9wxEq/V+jNvy+ZVjxALv
NBB9d/pj8dtAWljGWgpEf3EWlQPRd2Sr5UH0zKcCbHeB9DZvC04QvfVSDy+I
/r1gtiiItmDYKbT7yyvHxetERUC0wO6utD1A+lKadAaIvqK788xjIM24P+o8
iP5TPWMV69dXjjN8Dq0B0f4b9m0F0Wq7tu8C0QAbFexD
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"sys", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"f5", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b4"}], "-", "b10"}]}], ",", 
        RowBox[{"f4", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
        RowBox[{"f2", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b4"}], "-", "b7"}]}], ",", 
        RowBox[{"f3", "\[Rule]", 
         RowBox[{
          RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
        RowBox[{"h6", "\[Rule]", 
         RowBox[{"-", "e3"}]}], ",", 
        RowBox[{"h2", "\[Rule]", 
         RowBox[{"-", "e2"}]}], ",", 
        RowBox[{"h4", "\[Rule]", 
         RowBox[{"-", "e1"}]}], ",", 
        RowBox[{"h5", "\[Rule]", "0"}], ",", 
        RowBox[{"h1", "\[Rule]", "0"}], ",", 
        RowBox[{"h3", "\[Rule]", "0"}], ",", 
        RowBox[{"d", "\[Rule]", "0"}], ",", 
        RowBox[{"b12", "\[Rule]", 
         RowBox[{"-", "a1"}]}], ",", 
        RowBox[{"b2", "\[Rule]", 
         RowBox[{"-", "a3"}]}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"e2", "\[Rule]", "0"}], ",", 
      RowBox[{"e1", "\[Rule]", "0"}], ",", 
      RowBox[{"b6", "\[Rule]", 
       RowBox[{"-", "a3"}]}], ",", 
      RowBox[{"b9", "\[Rule]", 
       RowBox[{"-", "a1"}]}], ",", 
      RowBox[{"e4", "\[Rule]", "e3"}]}], "}"}]}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.618140598790771*^9, 3.618140652986001*^9}, {
  3.618140706652618*^9, 3.618140727106453*^9}, {3.618140762668045*^9, 
  3.618140794693933*^9}, {3.6181408513892927`*^9, 3.618140853974769*^9}, {
  3.61814098479492*^9, 3.6181409909177847`*^9}, {3.618141025892335*^9, 
  3.618141257306781*^9}, {3.618202981888029*^9, 3.618203234391654*^9}, {
  3.618203274352906*^9, 3.618203336632481*^9}, {3.618206481828422*^9, 
  3.618206606844318*^9}, {3.618206646257415*^9, 3.618206661290313*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["j",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b10", "+", "b4", "-", "c4", "-", "g2"}], ")"}], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a1", "-", "c5"}], ")"}], " ", 
            SuperscriptBox["g", 
             RowBox[{"s", "t"}]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b1", "+", "b11", "-", "c1", "-", "g1"}], ")"}], " ", 
               
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b10", "+", "b11", "+", "e3", "+", "f1"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["p",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["q",
                 TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox["j",
                TraditionalForm],
               TraditionalForm]]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"a3", "+", "b7"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["s",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b8", "+", "1"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["s",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["q", "s"], " ", 
            SuperscriptBox["g", 
             RowBox[{"j", "t"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{"c3", " ", 
            SuperscriptBox["g", 
             RowBox[{"j", "t"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["g", 
             RowBox[{"j", "t"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "-", 
           RowBox[{"a3", " ", 
            SuperscriptBox["g", 
             RowBox[{"j", "s"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{"c2", " ", 
            SuperscriptBox["g", 
             RowBox[{"j", "s"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{"b8", " ", 
            SuperscriptBox["g", 
             RowBox[{"j", "t"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], "+", 
           RowBox[{
            SuperscriptBox["g", 
             RowBox[{"j", "t"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], "+", 
           RowBox[{"a3", " ", 
            SuperscriptBox["g", 
             RowBox[{"j", "s"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], "+", 
           RowBox[{"b7", " ", 
            SuperscriptBox["g", 
             RowBox[{"j", "s"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "\[LongEqual]", 
     "0"}], ",", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], "2"], " ", 
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["i",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b4", "+", "b7", "-", "c3", "-", "g2"}], ")"}], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a1", "-", "c5"}], ")"}], " ", 
            SuperscriptBox["g", 
             RowBox[{"s", "t"}]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b1", "+", "b8", "-", "c2", "-", "g1"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], "2"]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b7", "+", "b8", "+", "e3", "+", "f1"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["p",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["q",
                 TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "-", 
        RowBox[{
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], 
              FormBox[
               FormBox["i",
                TraditionalForm],
               TraditionalForm]]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"b10", "+", "1"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["s",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"a3", "+", "b11"}], ")"}], " ", 
               SuperscriptBox[
                FormBox["p",
                 TraditionalForm], 
                FormBox[
                 FormBox["s",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["t",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["q", "t"], " ", 
            SuperscriptBox["g", 
             RowBox[{"i", "s"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "-", 
           RowBox[{"a3", " ", 
            SuperscriptBox["g", 
             RowBox[{"i", "t"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{"c4", " ", 
            SuperscriptBox["g", 
             RowBox[{"i", "t"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{"c1", " ", 
            SuperscriptBox["g", 
             RowBox[{"i", "s"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "-", 
           RowBox[{
            SuperscriptBox["g", 
             RowBox[{"i", "s"}]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], "2"]}], "+", 
           RowBox[{"a3", " ", 
            SuperscriptBox["g", 
             RowBox[{"i", "t"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], "+", 
           RowBox[{"b11", " ", 
            SuperscriptBox["g", 
             RowBox[{"i", "t"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], "+", 
           RowBox[{"b10", " ", 
            SuperscriptBox["g", 
             RowBox[{"i", "s"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}], "+", 
           RowBox[{
            SuperscriptBox["g", 
             RowBox[{"i", "s"}]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "\[LongEqual]", 
     "0"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.61820298886563*^9, 3.618203235768505*^9}, {
   3.6182032787149477`*^9, 3.618203337979007*^9}, {3.6182064861596746`*^9, 
   3.6182066001430197`*^9}, {3.618206642100512*^9, 3.618206662194683*^9}, 
   3.61822111474151*^9, 3.619338041909977*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eijJ", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"eij$", "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f5", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b4"}], "-", "b10"}]}], ",", 
       RowBox[{"f4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
       RowBox[{"f2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b4"}], "-", "b7"}]}], ",", 
       RowBox[{"f3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
       RowBox[{"h6", "\[Rule]", 
        RowBox[{"-", "e3"}]}], ",", 
       RowBox[{"h2", "\[Rule]", 
        RowBox[{"-", "e2"}]}], ",", 
       RowBox[{"h4", "\[Rule]", 
        RowBox[{"-", "e1"}]}], ",", 
       RowBox[{"h5", "\[Rule]", "0"}], ",", 
       RowBox[{"h1", "\[Rule]", "0"}], ",", 
       RowBox[{"h3", "\[Rule]", "0"}], ",", 
       RowBox[{"d", "\[Rule]", "0"}], ",", 
       RowBox[{"b12", "\[Rule]", 
        RowBox[{"-", "a1"}]}], ",", 
       RowBox[{"b2", "\[Rule]", 
        RowBox[{"-", "a3"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e2", "\[Rule]", "0"}], ",", 
     RowBox[{"e1", "\[Rule]", "0"}], ",", 
     RowBox[{"b6", "\[Rule]", 
      RowBox[{"-", "a3"}]}], ",", 
     RowBox[{"b9", "\[Rule]", 
      RowBox[{"-", "a1"}]}], ",", 
     RowBox[{"e4", "\[Rule]", "e3"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6181258719631977`*^9, 3.6181258831477222`*^9}, {
   3.618125953859033*^9, 3.61812597828318*^9}, 3.6181364766045218`*^9, 
   3.618140508460737*^9, 3.6181412817936573`*^9, 3.618203355980138*^9, {
   3.6182066788157*^9, 3.618206680986079*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b4"}], "-", "b7"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b10"}], "-", "b4"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b8"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b11"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6181258835271683`*^9, 3.6181259804411173`*^9, 
  3.618136478131229*^9, 3.61814051019172*^9, 3.618141284861121*^9, 
  3.618203356828607*^9, 3.618206684403655*^9, 3.6182211148107224`*^9, 
  3.6193380419812393`*^9}]
}, Open  ]],

Cell["\<\
Then try to find coefficients so that the mixed terms (J e\[CloseCurlyQuote]) \
vanishes.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyU0og3EAx/FRDKVmLPLaJLmgpuRt9EdZEXEYc3BgW25KWenxVlwwLyU8
MiUcJKExMiLsQFOTdx6TPEjPaWMuLPx/z+Hb5/BVNrbUGAIlEkk8DWq8TR9Z
1wI5K+V9cK5fM1hA9bhrRSPCnVcwyH98B7sMxYXSG4GYV7ki+GBXjcDe8aNR
+KLUBsupJk+fqCFblgvTLMV5MLEjm1NRF8JcopkpyvZ8/LRvBo71OFUcVZ/8
qBbVdP7e3gvEdtb9By3W6Yk2TiDrxMHCsrvqThPVqRZ6oO9Ab4Xm3HfRQab1
AmqHT2+hjpl5hpUxGW8wdcjbsPEpkLrZciN0T/LRHDUyPj8W+koUifAhgUmC
U6+yYDd1szwnFNrOzeHwZ3ZaAXMk2/Idn0DmVxRRULYzYNylnhvjmuFl+vYp
Tw3Yr3dBP8MuBX0JhK04XIZVa3s2mGrfssPmCMeTlKqT6ngY4mFPMqmLU5ei
/7zl/iE=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"1", "/", "4"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"eijJ", "[", 
            RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"x", ",", "m"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"y", ",", "n"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"x", ",", "i"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"y", ",", "j"}], "]"}], 
           RowBox[{"eijJ", "[", 
            RowBox[{"m", ",", "n", ",", "s", ",", "t"}], "]"}]}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "m"}], "]"}], 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "n"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "n"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "m"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "m"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "n"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{"x", ",", "s"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"y", ",", "t"}], "]"}]}]}], "//", "Expand"}], "//", 
     "Contract"}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"x", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"LorentzIndex", "[", 
         RowBox[{"y", ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.61812766383427*^9, 3.618127816200135*^9}, {
   3.6181278590989847`*^9, 3.618127923576621*^9}, {3.618128673818131*^9, 
   3.618128706917452*^9}, 3.618135311614771*^9, {3.618206974331002*^9, 
   3.6182069745120907`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "a3"}], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"t", "x"}]]}], "+", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "x"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "x"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "x"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   RowBox[{"a1", " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"x", "y"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"b4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"x", "y"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"b1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"x", "y"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "y"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.618127778917045*^9, 3.618127789062096*^9}, 
   3.6181278192217913`*^9, {3.618127865435725*^9, 3.618127927628908*^9}, {
   3.618128699464522*^9, 3.618128710424263*^9}, 3.618135332898191*^9, 
   3.618137231460053*^9, 3.618140531104244*^9, 3.6181413024044647`*^9, 
   3.618203379153846*^9, 3.61820672118414*^9, 3.618206978492188*^9, 
   3.618221117702471*^9, 3.619338044875697*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp2", "=", 
  RowBox[{
   RowBox[{"tmp", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a1", "\[Rule]", "0"}], ",", 
      RowBox[{"a3", "\[Rule]", "0"}], ",", 
      RowBox[{"c1", "\[Rule]", "0"}], ",", 
      RowBox[{"c2", "\[Rule]", "0"}], ",", 
      RowBox[{"b1", "\[Rule]", "0"}], ",", 
      RowBox[{"e3", "\[Rule]", "0"}], ",", 
      RowBox[{"b7", "\[Rule]", "0"}], ",", 
      RowBox[{"c3", "\[Rule]", "0"}], ",", 
      RowBox[{"c4", "\[Rule]", "0"}], ",", 
      RowBox[{"b11", "\[Rule]", "0"}], ",", 
      RowBox[{"b4", "\[Rule]", "0"}], ",", 
      RowBox[{"b10", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"b8", "\[Rule]", 
       RowBox[{"-", "1"}]}]}], "}"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.61814132036621*^9, 3.6181415026795588`*^9}, {
  3.618203408920825*^9, 3.618203578094624*^9}, {3.618203834196122*^9, 
  3.618203846077895*^9}, {3.618206731851019*^9, 3.618206736061873*^9}, {
  3.618206768398417*^9, 3.618206908848524*^9}, {3.6182069936967993`*^9, 
  3.618207142294099*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.618141321321929*^9, {3.618141356058745*^9, 3.6181415030375834`*^9}, {
   3.618203412534965*^9, 3.618203579079021*^9}, {3.618203839998138*^9, 
   3.618203846529595*^9}, 3.6182067368805113`*^9, {3.618206774904945*^9, 
   3.618206909474154*^9}, {3.61820698857224*^9, 3.6182071426518593`*^9}, 
   3.6182211177765503`*^9, 3.619338044983487*^9}]
}, Open  ]],

Cell[TextData[{
 "This shows that it is possible to complete the square (such that the mixed \
term vanishes) always using ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["q", "s"], 
     SuperscriptBox["q", "t"], 
     SubscriptBox["J", "st"]}], "=", "0"}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVsoQ3EAx/FD2aLUXBa5NkkemJqSu45LVkQ8YB48sC1voigdQ/HC5lLC
hBKe5BbmsomwBzVlzW0ckwzp5MHleGHG/3cevn0evrL6pkqNL0VR0SSofG/4
SL3kaHuhm4ezfUp9NvHNVS0YFGi7gH6e42vYqcnPFV9xtGGFzYO3ZsUQ7Bk9
GoaPsipRMLHtrVdQkybJgIlT+ZkwpiONVRDnA04FU+Jl7Vn4id8MHOm2KVii
Ou4uR1Cp8zpvONpk7/qDU2uTY60sR6/TViMsvq7QtRFtOVw35A/Ua9CQ8SKo
Z1rOYNXgiROqmOkHWBYuf4YJA+91G58cXTNTooWucXcYSwyJyoqAfIE0Bt5G
M7Fw4kkichE3S9L9oclhCIQ/M5NSmE7tBFt4jp5bloZCiaVfu0t0aCMb4Xny
zomb6LNfewo9jHHB74ujjaWHi7B8dc8EE8xbZtgYZL0XE1VilRsOs6KfJGIm
7/2FXnWzSU58XSrahv/+IQhD
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eijJ2", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"eijJ", "[", 
    RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "\[Rule]", "0"}], ",", 
     RowBox[{"a3", "\[Rule]", "0"}], ",", 
     RowBox[{"c1", "\[Rule]", "0"}], ",", 
     RowBox[{"c2", "\[Rule]", "0"}], ",", 
     RowBox[{"b1", "\[Rule]", "0"}], ",", 
     RowBox[{"e3", "\[Rule]", "0"}], ",", 
     RowBox[{"b7", "\[Rule]", "0"}], ",", 
     RowBox[{"c3", "\[Rule]", "0"}], ",", 
     RowBox[{"c4", "\[Rule]", "0"}], ",", 
     RowBox[{"b11", "\[Rule]", "0"}], ",", 
     RowBox[{"b4", "\[Rule]", "0"}], ",", 
     RowBox[{"b10", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"b8", "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618142041673979*^9, 3.618142045511858*^9}, {
  3.618203773641347*^9, 3.6182037789002523`*^9}, {3.618207177042581*^9, 
  3.618207185740521*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6181420464693832`*^9, 3.618203779967493*^9, 
  3.618207187352345*^9, 3.6182211178615627`*^9, 3.619338045034773*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"eijJ2", "[", 
      RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.6182072786382723`*^9, 3.618207360183135*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6182072921338263`*^9, 3.618207360557568*^9}, 
   3.61822111797478*^9, 3.619338045143845*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"eijJ2", "[", 
      RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "j"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.618207334371442*^9, 3.618207364242598*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.618207334763946*^9, 3.618207364572569*^9}, 
   3.618221118042642*^9, 3.619338045211331*^9}]
}, Open  ]],

Cell["Now compute the propagator:", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVsoQ3EAx/FRtig1l0Uu06Tlwa0puY2OS1ZEKMyDB7blTRSl41a8YC4l
TCjhSW5hLiPCHtSUuZuzSYZ08mAcLy7j/zsP3z4PX1l1XYnWUyAQSElQ5ap5
T7xiKWuOk4PT3aredOKbo5zXz9dyCb1+jmywTZuVIbpmKf0SkwntJsUA7Bw+
HISPsjKhP7HprYtXmyROgdETWalQ2pLEKIizPie88VGy5jT86C8aDnVYFAxR
E3mn5FW1um9uWcpobf+DEyvjI40MS61SZgPMsxW3NhEtSrYDcvuaFahPeeHt
pRvOYVn/8Q1U05MPsDA47hnK+1xVax8sVTGVr4OOUWcQQwwISwuBXLZECu3h
dAQcexILHcT1/GRvaDzT+8LvqXEJTBZs+W9zLDWzKAmE4u0e3Q7xTBdaCy9i
t46dRI+9yhP4QxvmvD5ZylBwMA+LlneNUG7aMMFaP/O9iKgWqZ1wkBF+xxBT
OfcvdGvqjXHE14XcTZjw8GuF9lL6FP4D2tASOg==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prop", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"-", "2"}], "I", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "4"}], 
         RowBox[{"eijJ2", "[", 
          RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
         RowBox[{"eijJ2", "[", 
          RowBox[{"m", ",", "n", ",", "x", ",", "y"}], "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Contract", "[", 
              RowBox[{
               RowBox[{"FVD", "[", 
                RowBox[{"p", ",", "i"}], "]"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "m"}], "]"}], 
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "n"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "n"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "m"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "m"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "n"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"eijJ2", "[", 
         RowBox[{"x", ",", "y", ",", "s", ",", "t"}], "]"}]}], ")"}]}], "]"}],
     "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "x"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "y"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618207645084536*^9, 3.618207783729149*^9}, {
  3.61820782433064*^9, 3.618207888276908*^9}, {3.618208005033499*^9, 
  3.6182080310950336`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "x"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"t", "y"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.618207758185719*^9, 3.618207785101149*^9}, {
   3.618207822268718*^9, 3.618207852282*^9}, {3.6182078929068127`*^9, 
   3.618207909942397*^9}, 3.618208046042719*^9, 3.6182211319927807`*^9, 
   3.6193380591831903`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{"prop", " ", 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "s"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.618207926951509*^9, 3.618207969127627*^9}, {
  3.618208078930172*^9, 3.618208079878354*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["t",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["x",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["y",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.618207969614715*^9, {3.618208061454146*^9, 3.618208081471128*^9}, 
   3.618221132147538*^9, 3.619338059303933*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{"prop", " ", 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{3.618208092506352*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["s",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["x",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["y",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.618208092851606*^9, 3.618221132229969*^9, 
  3.61933805939469*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{"prop", " ", 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "x"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{3.618208097059408*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["y",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["s",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["t",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.618208097651813*^9, 3.618221132312522*^9, 
  3.6193380594733047`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{"prop", " ", 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "y"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{3.618208102104808*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"2", " ", "\[ImaginaryI]", " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["x",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["s",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["t",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.618208102542142*^9, 3.618221132360509*^9, 
  3.6193380595196457`*^9}]
}, Open  ]],

Cell[TextData[{
 "Note that the propagator no longer depends on the free parameters ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["c", "5"], ",", 
    SubscriptBox["f", "1"], ",", 
    SubscriptBox["g", "1"], ",", 
    SubscriptBox["g", "2"]}], TraditionalForm]]],
 ".\nLet\[CloseCurlyQuote]s compare the propagator to the following \
factorization:"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVssW3EAx/FOoo0lkiqNxYxUBAljKmkoJX/XBiFITPfggbbxJiyTLGcu
ib2MGiGoIHF7EregLiXE5WFJJYptLqcV0RE58dDO2YtL7f87D998Hr6KqtpS
g49IJFLQoNZT/TfpN0fs2S4ejn3TtqdR3c73ggH+tl/Q9/HHKWwyZKZLjjli
mmUzoMOq7IStvTtd8I+iXCyjNri/ChpU0hQYM5SphmFfVKySOvFyXzAhUvE5
FT/mnoE9LTYlS9VHnGsEtY3ekzOOWOzNz3BofrDvE8uRBbJrhnmnJY0NVJuG
a4H8ln4emlJuBNuZ+iNY/n3vBOqY4UtY9Cr+GkZ1eCoX7zhSMVJghM5+VzBL
DQxNDYF8ljwMOt4w4XDgSip2UpcKkv2g5dDkDx9GBuUwWbQqW+M5Mj4jD4LS
tTbjOvXQ+LoG/ny7uueivtj8sA8fGfOk7z+OmAu3p2Dx3IYFRlmXrbAmYPdC
QtVJdC7YxYof4qhq3vsEvfo6Szz1djpnBb67fLJDRxlzAN0zsYkJ1CpZt2Bi
dLMK5o5+JFAT6smHpeqBQvgfc0Uo9Q==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prop", "-", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{"I", "/", 
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"x", ",", "s"}], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "x"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "s"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "x"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "s"}], "]"}]}]}], ")"}], "/", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"d", "[", 
          RowBox[{"y", ",", "t"}], "]"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "y"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "t"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "y"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}]}], ")"}]}], ")"}]}], 
    "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.618208377008198*^9, 3.618208573179347*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "\[ImaginaryI]", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["x",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["y",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6182085188242207`*^9, 3.6182085738915453`*^9}, 
   3.618221132482231*^9, 3.619338059646167*^9}]
}, Open  ]],

Cell[TextData[{
 "These terms vanish indeed when sandwiched between ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["J", "st"], 
    SubscriptBox["J", "xy"]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyU1Ik3EAx/EluGEgzNlIyowNUUGbbsHQ2Yy/vTimFCqs5qHD2oY3sZdR
PJkDvZizJFE3NNDyIKJL1Fnboqh2KCa4XC/as4W4jHjosNXTpc3l//ccvnwO
X4Wlq82WIxKJlDRoSF39ffIzRyJnEzx8PGAYPEVNxi8JFuSHP8HczLsteNfW
2CD5whHXU/Y0jAU0D2Df6Nth+F1hEsuojmS/oE0rrYMVk406WHJHy2qoMwfX
BatLFbfr8Sv+MXDEGdawVKvym17Q0JPd/MoRX6T3P5xcmhi7yXJkmYTcsGmr
tcdBDes5J+RfW5egq+6n4CBzLQpN99c2oZl5tAMvFKl+wLKh1JWVPxy5PNVs
h/HxxGGWWlhcfwTyZ+QlMHaMOQ49u1JxnLraXJsHfRuufJiempDDWpFfFuQ5
8sQrPwSlwXv2F9QN+9FO+PGEfy1BPfCqYx1mGPdc7l+OuFvezMOLiy99sCzw
LAA7C0LbEqpZYk7AYVacrqLq+OwezFq7fSrqr4Vzz2HNzl4ExtqZDzDprVRX
Uy2yh4Lq8l4tPD99nUB9ccoI23SeFjhrjN6AHe+Tt+A+U00yWA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Large z - behavior of 4 e amplitude for individual Feynman graphs\
\>", "Subsection",
 CellChangeTimes->{{3.6170117265241747`*^9, 3.617011751123253*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"serE", "=", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"amp4Eexchange", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "e"}], "]"}], "+", 
            RowBox[{"z", " ", 
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"LorentzIndex", "[", 
                RowBox[{"e", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"2", ",", "e"}], "]"}], "-", 
            RowBox[{"z", " ", 
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"LorentzIndex", "[", 
                RowBox[{"e", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
          RowBox[{"t", "\[Rule]", 
           RowBox[{"t", "+", 
            RowBox[{"2", "z", " ", 
             TagBox[
              StyleBox[
               RowBox[{"Pair", "[", 
                RowBox[{
                 RowBox[{"Momentum", "[", 
                  RowBox[{"q", ",", "D"}], "]"}], ",", 
                 RowBox[{"Momentum", "[", 
                  RowBox[{
                   RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
               ShowSpecialCharacters->False,
               ShowStringCharacters->True,
               NumberMarks->True],
              FullForm]}]}]}], ",", 
          RowBox[{"u", "\[Rule]", 
           RowBox[{"u", "-", 
            RowBox[{"2", "z", " ", 
             TagBox[
              StyleBox[
               RowBox[{"Pair", "[", 
                RowBox[{
                 RowBox[{"Momentum", "[", 
                  RowBox[{"q", ",", "D"}], "]"}], ",", 
                 RowBox[{"Momentum", "[", 
                  RowBox[{
                   RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
               ShowSpecialCharacters->False,
               ShowStringCharacters->True,
               NumberMarks->True],
              FullForm]}]}]}]}], "}"}]}], "//", "Expand"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
      "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61701183244963*^9, 3.617011833626677*^9}, {
  3.6170118662078047`*^9, 3.6170118793161592`*^9}, {3.617011950109686*^9, 
  3.6170119726715307`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          InterpretationBox[
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "8"]}], " ", "\[ImaginaryI]", " ", 
                SuperscriptBox["g", 
                 RowBox[{"a", "c"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"b", "h"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"d", "f"}]], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["e",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["g",
                   TraditionalForm],
                  TraditionalForm]]}], "-", 
               RowBox[{
                FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
                SuperscriptBox["g", 
                 RowBox[{"a", "c"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"b", "f"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"d", "h"}]], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["e",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox[
                 FormBox["q",
                  TraditionalForm], 
                 FormBox[
                  FormBox["g",
                   TraditionalForm],
                  TraditionalForm]]}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 SubsuperscriptBox["k", 
                  FormBox["2",
                   TraditionalForm], 
                  FormBox[
                   FormBox["b",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"d", "h"}]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["f",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["g",
                    TraditionalForm],
                   TraditionalForm]]}], 
                RowBox[{"8", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 SubsuperscriptBox["k", 
                  FormBox["3",
                   TraditionalForm], 
                  FormBox[
                   FormBox["b",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"d", "h"}]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["f",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["g",
                    TraditionalForm],
                   TraditionalForm]]}], 
                RowBox[{"8", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]], "+", 
               RowBox[{"\[LeftSkeleton]", "70", "\[RightSkeleton]"}], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "g"}]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"b", "d"}]], " ", 
                 SubsuperscriptBox["k", 
                  FormBox["3",
                   TraditionalForm], 
                  FormBox[
                   FormBox["c",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["f",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["h",
                    TraditionalForm],
                   TraditionalForm]]}], 
                RowBox[{"8", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]], "+", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "g"}]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"b", "d"}]], " ", 
                 SubsuperscriptBox["k", 
                  FormBox["4",
                   TraditionalForm], 
                  FormBox[
                   FormBox["c",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["f",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["h",
                    TraditionalForm],
                   TraditionalForm]]}], 
                RowBox[{"8", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]], "-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"b", "d"}]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["f",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SubsuperscriptBox["k", 
                  FormBox["1",
                   TraditionalForm], 
                  FormBox[
                   FormBox["g",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["h",
                    TraditionalForm],
                   TraditionalForm]]}], 
                RowBox[{"4", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]], "-", 
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 SuperscriptBox["g", 
                  RowBox[{"b", "d"}]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["e",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["f",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SubsuperscriptBox["k", 
                  FormBox["2",
                   TraditionalForm], 
                  FormBox[
                   FormBox["g",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["h",
                    TraditionalForm],
                   TraditionalForm]]}], 
                RowBox[{"4", " ", 
                 RowBox[{
                  FormBox["q",
                   TraditionalForm], "\[CenterDot]", 
                  FormBox[
                   SubscriptBox["k", "3"],
                   TraditionalForm]}]}]]}], ")"}], " ", 
             SuperscriptBox["z", "2"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"\[ImaginaryI]", " ", 
                 SuperscriptBox["g", 
                  RowBox[{"a", "c"}]], " ", 
                 RowBox[{"\[LeftSkeleton]", "5", "\[RightSkeleton]"}], " ", 
                 SuperscriptBox["t", "2"]}], 
                RowBox[{"16", " ", 
                 SuperscriptBox[
                  FormBox[
                   RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}],
                   TraditionalForm], "3"]}]], "-", 
               FractionBox[
                RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                RowBox[{"16", 
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]], "+", 
               RowBox[{"\[LeftSkeleton]", "621", "\[RightSkeleton]"}]}], 
              ")"}], " ", "z"}], "+", 
            RowBox[{"(", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ")"}], "+", 
            FractionBox[
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "z"], "+", 
            
            FractionBox[
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
             SuperscriptBox["z", "2"]], "+", 
            InterpretationBox[
             RowBox[{"O", "(", 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["1", "z"], ")"}], "3"], ")"}],
             SeriesData[$CellContext`z, 
              DirectedInfinity[1], {}, -2, 3, 1],
             Editable->False]}],
           SeriesData[$CellContext`z, 
            DirectedInfinity[1], {((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]), ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[3, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]], ((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]] + ((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]] + ((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 2]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 1], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 2], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 4]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[-1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + ((((((((Complex[0, 
                    Rational[1, 8]]/$CellContext`s) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`i, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`j, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`m, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`n, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 4], D]] + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]), (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[1, 32]] $CellContext`s^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) $CellContext`u) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]/HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) (HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 16]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
                    Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) (
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]/
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                 D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]), (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^5) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-6) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^5) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-6) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^4) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-5) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^4) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-4) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 128]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 128]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q,
                    D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`\
q, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-3) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s^2) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u^2) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^3) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s^2) $CellContext`t) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^3) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) $CellContext`u) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u^2) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 4], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 1], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 8]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 3], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 2], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`u^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 64]] $CellContext`s) $CellContext`t) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t^2) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 64]] $CellContext`t) $CellContext`u) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 32]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 4], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 2], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 1], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`u) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                  HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 3], D]]) 
                   HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[-1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2) + (((((((Complex[0, 
                    Rational[1, 16]] $CellContext`t) 
                    HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`b, D], 
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
                    
                    HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`d, D], 
                    HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 4], D]]) 
                 HighEnergyPhysics`FeynCalc`Pair`Pair[
                   
                   HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
                   HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                    Subscript[$CellContext`k, 1], D]]) 
                HighEnergyPhysics`FeynCalc`Pair`Pair[
                  
                  HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
                  HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                   Subscript[$CellContext`k, 2], D]]) 
               HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]) 
              HighEnergyPhysics`FeynCalc`Pair`Pair[
                 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                  D], 
                 HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                  Subscript[$CellContext`k, 3], D]]^(-2)}, -2, 3, 1],
           Editable->False],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 577, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 577, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 577, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[577]], TraditionalForm]], "Output",
 CellChangeTimes->{3.617011834809804*^9, 3.61701188703176*^9, 
  3.617011979240218*^9, 3.617340969201825*^9, 3.6182211388613586`*^9, 
  3.6193380667592907`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"serE2", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{"serE", " ", 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "a"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "b"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "c"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "d"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", 
      RowBox[{"-", 
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.617012046787016*^9, 3.617012056678337*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}],
         TraditionalForm], "2"]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", "t", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["3", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["f",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["g",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["h",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["t", "3"]}], 
         RowBox[{"64", " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}],
            TraditionalForm], "2"]}]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["t", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["t", "2"]}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["s", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "3"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["s", "2"], " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]]}], ")"}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {((((Complex[0, 
            Rational[-3, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-3, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 1], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + (((Complex[0, 
           Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2 + (((Complex[0, 
           Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2, 0, ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`t^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`u^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`t^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`u^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
              Rational[-1, 64]] $CellContext`s^2) $CellContext`t) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`t^3) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-1, 64]] $CellContext`s^2) $CellContext`u) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-3, 64]] $CellContext`t^2) $CellContext`u) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-3, 64]] $CellContext`t) $CellContext`u^2) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`u^3) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + (((Complex[0, 
           Rational[-1, 8]] $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2 + (((Complex[0, 
           Rational[-1, 8]] $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2}, 0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.617012193042787*^9, 3.617341104508608*^9, 
  3.618221275334495*^9, 3.619338206150231*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"serE3", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"serE2", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"kc", "[", 
              RowBox[{"2", ",", "e"}], "]"}]}], "-", 
            RowBox[{"kc", "[", 
             RowBox[{"3", ",", "e"}], "]"}], "-", 
            RowBox[{"kc", "[", 
             RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], ")"}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{"u", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "s"}], "-", "t"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.617012545941008*^9, 3.617012613799839*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["g", 
                RowBox[{"f", "h"}]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"4", " ", 
                   SubsuperscriptBox["k", 
                    FormBox["3",
                    TraditionalForm], 
                    FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                   RowBox[{
                    FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                    FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}]}], "-", 
                 RowBox[{"3", " ", "s", " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "-", 
              RowBox[{"4", " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}]}], "+", 
           RowBox[{"2", " ", 
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["e",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}], "+", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"64", " ", 
       SuperscriptBox["z", "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}],
         TraditionalForm], "2"]}]], 
     RowBox[{"\[ImaginaryI]", " ", "s", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "s", " ", 
                  SubsuperscriptBox["k", 
                   FormBox["3",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["s", "2"], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["k", 
                   FormBox["3",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}], "+", 
                 RowBox[{"2", " ", "s", " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", "s", " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["g", 
                RowBox[{"f", "h"}]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}]}], "+", 
           RowBox[{
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["e",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["g", 
                RowBox[{"f", "h"}]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["k", 
                 FormBox["3",
                  TraditionalForm], 
                 FormBox[
                  FormBox["h",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], "-", 
              RowBox[{"2", " ", "s", " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
    
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {Complex[0, 
       Rational[-1, 16]] ((((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) ((2 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) + 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] (((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]])
            HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) ((2 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 4], D]]) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] ((((-4) HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
              
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
               D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]] + 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] (((-3) $CellContext`s) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] - (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]])))), 0, ((Complex[0, 
         Rational[1, 64]] $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2)) (((2 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) (
         HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]])) ((2 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) ((2 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 4], D]]) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] (((-2) $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] - (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]])) + 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] (((-HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) ((2 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 4], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
              
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
               D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]])) ((2 $CellContext`s) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] + (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]]) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] (((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]]) ((2 $CellContext`s) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] + (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) + 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] ((2 $CellContext`s^2) HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] + ((4 $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]))))}, 0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.617012552011237*^9, {3.617012582069496*^9, 3.617012614257457*^9}, 
   3.61734110495172*^9, 3.618221275552071*^9, 3.619338206613796*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ser\[CurlyPhi]", "=", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"amp4VARPHIexchange", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "e"}], "]"}], "+", 
            RowBox[{"z", " ", 
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"LorentzIndex", "[", 
                RowBox[{"e", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"2", ",", "e"}], "]"}], "-", 
            RowBox[{"z", " ", 
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"LorentzIndex", "[", 
                RowBox[{"e", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
          RowBox[{"t", "\[Rule]", 
           RowBox[{"t", "+", 
            RowBox[{"2", "z", " ", 
             TagBox[
              StyleBox[
               RowBox[{"Pair", "[", 
                RowBox[{
                 RowBox[{"Momentum", "[", 
                  RowBox[{"q", ",", "D"}], "]"}], ",", 
                 RowBox[{"Momentum", "[", 
                  RowBox[{
                   RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
               ShowSpecialCharacters->False,
               ShowStringCharacters->True,
               NumberMarks->True],
              FullForm]}]}]}], ",", 
          RowBox[{"u", "\[Rule]", 
           RowBox[{"u", "-", 
            RowBox[{"2", "z", " ", 
             TagBox[
              StyleBox[
               RowBox[{"Pair", "[", 
                RowBox[{
                 RowBox[{"Momentum", "[", 
                  RowBox[{"q", ",", "D"}], "]"}], ",", 
                 RowBox[{"Momentum", "[", 
                  RowBox[{
                   RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
               ShowSpecialCharacters->False,
               ShowStringCharacters->True,
               NumberMarks->True],
              FullForm]}]}]}]}], "}"}]}], "//", "Expand"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
      "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61701183244963*^9, 3.617011833626677*^9}, {
  3.6170118662078047`*^9, 3.6170119068375807`*^9}, {3.617011980423023*^9, 
  3.617011986937934*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"s", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]]}], "+", 
       RowBox[{"t", " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]]}], "+", 
       RowBox[{"u", " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]]}]}], ")"}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, -1, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {Complex[0, 
       Rational[1, 8]] ((((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]), Complex[0, 
       Rational[-1, 
        16]] (((($CellContext`u HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]] + ((($CellContext`t HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]] + ((($CellContext`s HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]])}, -1, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.617011907707981*^9, 3.61701198847157*^9, 
  3.617341105098336*^9, 3.6182212756043463`*^9, 3.6193382067217417`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ser\[CurlyPhi]2", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{"ser\[CurlyPhi]", " ", 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "a"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "b"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "c"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "d"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", 
      RowBox[{"-", 
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.617012046787016*^9, 3.617012056678337*^9}, {
  3.6170120932081738`*^9, 3.6170120952001333`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"t", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], "+", 
        RowBox[{"u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}]}], ")"}]}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {Complex[0, 
       Rational[-1, 
        16]] (((($CellContext`t HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + ((($CellContext`u HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]])}, 
    0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.6170121933290358`*^9, 3.617341105171072*^9, 
  3.618221275678113*^9, 3.619338206796064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ser\[CurlyPhi]3", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ser\[CurlyPhi]2", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"kc", "[", 
              RowBox[{"2", ",", "e"}], "]"}]}], "-", 
            RowBox[{"kc", "[", 
             RowBox[{"3", ",", "e"}], "]"}], "-", 
            RowBox[{"kc", "[", 
             RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], ")"}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{"u", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "s"}], "-", "t"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6170126324046926`*^9, 3.6170126337049437`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "s", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["h",
        TraditionalForm],
       TraditionalForm]]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {((((Complex[0, 
           Rational[1, 16]] $CellContext`s) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
     HighEnergyPhysics`FeynCalc`Pair`Pair[
       HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
        D], 
       HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]}, 0, 
    3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.617012634185752*^9, 3.6173411052113047`*^9, 
  3.618221275731316*^9, 3.619338206863538*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"serVertex", "=", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"verEEEEonshell", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "e"}], "]"}], "+", 
            RowBox[{"z", " ", 
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"LorentzIndex", "[", 
                RowBox[{"e", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"2", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"2", ",", "e"}], "]"}], "-", 
            RowBox[{"z", " ", 
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"LorentzIndex", "[", 
                RowBox[{"e", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}]}], ",", 
          RowBox[{"t", "\[Rule]", 
           RowBox[{"t", "+", 
            RowBox[{"2", "z", " ", 
             TagBox[
              StyleBox[
               RowBox[{"Pair", "[", 
                RowBox[{
                 RowBox[{"Momentum", "[", 
                  RowBox[{"q", ",", "D"}], "]"}], ",", 
                 RowBox[{"Momentum", "[", 
                  RowBox[{
                   RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
               ShowSpecialCharacters->False,
               ShowStringCharacters->True,
               NumberMarks->True],
              FullForm]}]}]}], ",", 
          RowBox[{"u", "\[Rule]", 
           RowBox[{"u", "-", 
            RowBox[{"2", "z", " ", 
             TagBox[
              StyleBox[
               RowBox[{"Pair", "[", 
                RowBox[{
                 RowBox[{"Momentum", "[", 
                  RowBox[{"q", ",", "D"}], "]"}], ",", 
                 RowBox[{"Momentum", "[", 
                  RowBox[{
                   RowBox[{"Subscript", "[", 
                    RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
               ShowSpecialCharacters->False,
               ShowStringCharacters->True,
               NumberMarks->True],
              FullForm]}]}]}]}], "}"}]}], "//", "Expand"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"b", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"c", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"d", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
      "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61701183244963*^9, 3.617011833626677*^9}, {
  3.6170118662078047`*^9, 3.617011931660791*^9}, {3.6170119939677467`*^9, 
  3.617011996474819*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "c"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "f"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"d", "h"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["g", 
         RowBox[{"a", "e"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"b", "d"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"c", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}]}], ")"}], " ", "z"}], "+", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "f"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "s", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "t", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["b",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"d", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["a",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["c",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "c"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "f"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["d",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "g"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "e"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"a", "e"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"b", "d"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"c", "g"}]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, -2, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {Complex[0, 
       Rational[1, 8]] ((((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - ((((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - ((((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]), 
     Complex[0, 
       Rational[-1, 8]] ((((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]] 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]] 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]] + (((
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]] + (((
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] - (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]] + (((
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] - (((
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], 
         D]] + (((HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], 
          D]] + ((((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]] - ((((2 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], 
         D]] + ((((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`a, D], 
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]] - ((((2 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]), ((((Complex[0, 
            Rational[1, 8]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`s) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`s) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`s) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`s) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`b,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 4], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
c, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`d,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
a, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
b, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
d, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`c,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 4], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]}, -2, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.6170119330204887`*^9, 3.6170119973360767`*^9, 
  3.6173411053365307`*^9, 3.6182212759231462`*^9, 3.6193382070436153`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"serVertex2", "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{"serVertex", " ", 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "a"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "b"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "c"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "d"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", "0"}], ",", 
     RowBox[{
      TagBox[
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
       FullForm], "\[Rule]", 
      RowBox[{"-", 
       StyleBox[
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{
            RowBox[{"Subscript", "[", 
             RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True]}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.617012046787016*^9, 3.617012056678337*^9}, {
  3.6170120932081738`*^9, 3.6170121186318607`*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"f", "h"}]], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}],
         TraditionalForm], "2"]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox["g", 
        RowBox[{"e", "g"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}],
         TraditionalForm], "2"]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", "t", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", "u", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {((((Complex[0, 
            Rational[1, 4]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 4]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 1], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + (((Complex[0, 
           Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2 + (((Complex[0, 
           Rational[1, 4]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2}, 0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.617012194108461*^9, 3.617341106091741*^9, 
  3.618221276599874*^9, 3.619338207817934*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"serE2", "+", "ser\[CurlyPhi]2", "+", "serVertex2"}], ")"}], "/.", 
  
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     TagBox[
      StyleBox[
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}]}], "]"}],
       ShowSpecialCharacters->False,
       ShowStringCharacters->True,
       NumberMarks->True],
      FullForm], "\[Rule]", "0"}], ",", 
    RowBox[{
     TagBox[
      StyleBox[
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}]}], "]"}],
       ShowSpecialCharacters->False,
       ShowStringCharacters->True,
       NumberMarks->True],
      FullForm], "\[Rule]", "0"}], ",", 
    RowBox[{
     TagBox[
      StyleBox[
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "2"}], "]"}], ",", "D"}], "]"}]}], "]"}],
       ShowSpecialCharacters->False,
       ShowStringCharacters->True,
       NumberMarks->True],
      FullForm], "\[Rule]", "0"}], ",", 
    RowBox[{
     TagBox[
      StyleBox[
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}]}], "]"}],
       ShowSpecialCharacters->False,
       ShowStringCharacters->True,
       NumberMarks->True],
      FullForm], "\[Rule]", 
     RowBox[{"-", 
      StyleBox[
       RowBox[{"Pair", "[", 
        RowBox[{
         RowBox[{"Momentum", "[", 
          RowBox[{"q", ",", "D"}], "]"}], ",", 
         RowBox[{"Momentum", "[", 
          RowBox[{
           RowBox[{"Subscript", "[", 
            RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}]}], "]"}],
       ShowSpecialCharacters->False,
       ShowStringCharacters->True,
       NumberMarks->True]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.617012431250011*^9, 3.617012458977242*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["4",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["1",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["2",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SubsuperscriptBox["k", 
        FormBox["3",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}]}], "-", 
      RowBox[{
       FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"t", " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["f",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["g",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["h",
             TraditionalForm],
            TraditionalForm]]}], "+", 
         RowBox[{"u", " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["f",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["g",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["h",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "t", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}], "+", 
      RowBox[{
       FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["e",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["f",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["g",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["h",
          TraditionalForm],
         TraditionalForm]]}]}], ")"}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["z", "2"]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["e",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["f",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["g",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["h",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox["t", "3"]}], 
         RowBox[{"64", " ", 
          SuperscriptBox[
           FormBox[
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}],
            TraditionalForm], "2"]}]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["t", "2"]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["t", "2"]}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox["t", "2"]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", "t"}], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"32", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["s", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]], " ", "t"}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       RowBox[{
        FractionBox["1", "8"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["q",
            TraditionalForm], "\[CenterDot]", 
           FormBox[
            SubscriptBox["k", "3"],
            TraditionalForm]}],
          TraditionalForm], "2"]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", 
        SuperscriptBox["u", "2"], " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "s", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "-", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "32"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["g", 
         RowBox[{"f", "h"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "-", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", "\[ImaginaryI]", " ", "u", " ", 
        SuperscriptBox["g", 
         RowBox[{"e", "g"}]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}]}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["4",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["1",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["2",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "2"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "s", " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SubsuperscriptBox["k", 
          FormBox["3",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["u", "3"], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SuperscriptBox["s", "2"], " ", "u", " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["f",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["g",
            TraditionalForm],
           TraditionalForm]], " ", 
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["h",
            TraditionalForm],
           TraditionalForm]]}], 
        RowBox[{"64", " ", 
         SuperscriptBox[
          FormBox[
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}],
           TraditionalForm], "2"]}]]}], ")"}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + 
     Complex[0, 
        Rational[-1, 
         16]] (((($CellContext`t HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]])
            HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D], 
          
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
           D]] + ((($CellContext`u HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`e, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]])
            HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D], 
          
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
           D]]) + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 1], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 2], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 8]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]], 0, ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`t^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`u^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`t^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`s) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + (((
         Complex[0, 
           Rational[-1, 32]] $CellContext`u^2) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
         D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 1], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 2], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 32]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
         D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((((Complex[0, 
              Rational[-1, 64]] $CellContext`s^2) $CellContext`t) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`t^3) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-1, 64]] $CellContext`s^2) $CellContext`u) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-3, 64]] $CellContext`t^2) $CellContext`u) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + ((((((Complex[0, 
              Rational[-3, 64]] $CellContext`t) $CellContext`u^2) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`u^3) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[-1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`t^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[-1, 64]] $CellContext`s) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + (((((Complex[0, 
             Rational[1, 32]] $CellContext`t) $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 64]] $CellContext`u^2) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) (
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]/
       HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]]) + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 1], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 2], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 1], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 2], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 4], D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 1], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[-1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 2], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`t) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + ((((Complex[0, 
            Rational[1, 16]] $CellContext`u) 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f,
            D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
       HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]) 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
        HighEnergyPhysics`FeynCalc`Momentum`Momentum[
         Subscript[$CellContext`k, 3], D]] + (((Complex[0, 
           Rational[-1, 8]] $CellContext`t) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2 + (((Complex[0, 
           Rational[-1, 8]] $CellContext`u) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e,
            D], 
          
          HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`g,
            D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`f, 
          D], 
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`h, 
          D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^2}, 0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6170124391513777`*^9, 3.617012459696177*^9}, 
   3.617341106316626*^9, 3.618221276812798*^9, 3.619338207955205*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"serVertex3", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"serVertex2", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"1", ",", "e_"}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"kc", "[", 
              RowBox[{"2", ",", "e"}], "]"}]}], "-", 
            RowBox[{"kc", "[", 
             RowBox[{"3", ",", "e"}], "]"}], "-", 
            RowBox[{"kc", "[", 
             RowBox[{"4", ",", "e"}], "]"}]}]}], "}"}]}], ")"}], "//", 
       "Simplify"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{"u", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "s"}], "-", "t"}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            FormBox["q",
             TraditionalForm], 
            FormBox[
             FormBox["g",
              TraditionalForm],
             TraditionalForm]], " ", 
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]], " ", 
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "3"],
                TraditionalForm]}]}], "+", 
             RowBox[{
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["f",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["h",
                 TraditionalForm],
                TraditionalForm]]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            FormBox["q",
             TraditionalForm], 
            FormBox[
             FormBox["f",
              TraditionalForm],
             TraditionalForm]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["g",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                  SubsuperscriptBox["k", 
                   FormBox["3",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}]}], "-", 
                RowBox[{"s", " ", 
                 SuperscriptBox[
                  FormBox["q",
                   TraditionalForm], 
                  FormBox[
                   FormBox["h",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}]}], "-", 
             RowBox[{
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["g",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["h",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{
               FormBox["q",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "3"],
                TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{
         FormBox["q",
          TraditionalForm], "\[CenterDot]", 
         FormBox[
          SubscriptBox["k", "3"],
          TraditionalForm]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["g", 
            RowBox[{"e", "g"}]], " ", 
           RowBox[{
            FormBox["q",
             TraditionalForm], "\[CenterDot]", 
            FormBox[
             SubscriptBox["k", "3"],
             TraditionalForm]}]}], "+", 
          RowBox[{
           SubsuperscriptBox["k", 
            FormBox["4",
             TraditionalForm], 
            FormBox[
             FormBox["e",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox["q",
             TraditionalForm], 
            FormBox[
             FormBox["g",
              TraditionalForm],
             TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 0, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {Complex[0, 
       Rational[1, 4]] (((HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
h, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]]) 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
          HighEnergyPhysics`FeynCalc`Momentum`Momentum[
           Subscript[$CellContext`k, 3], D]]) (
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 4], D]] 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) + 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] ((
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) (
          HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 4], D]] 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] (((-HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
              
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
               D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]] + 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] ((-$CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] - HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]] 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]]))))}, 0, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.617012693709156*^9, 3.6173411066602173`*^9, 
  3.618221276923435*^9, 3.619338208340733*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"serE3", "+", "ser\[CurlyPhi]3", "+", "serVertex3"}]], "Input",
 CellChangeTimes->{{3.617012711648978*^9, 3.617012713696011*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"64", " ", 
       SuperscriptBox["z", "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}],
         TraditionalForm], "2"]}]], 
     RowBox[{"\[ImaginaryI]", " ", "s", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["e",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "s", " ", 
                  SubsuperscriptBox["k", 
                   FormBox["3",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["s", "2"], " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", 
                  SubsuperscriptBox["k", 
                   FormBox["3",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                  RowBox[{
                   FormBox["q",
                    TraditionalForm], "\[CenterDot]", 
                   FormBox[
                    SubscriptBox["k", "3"],
                    TraditionalForm]}]}], "+", 
                 RowBox[{"2", " ", "s", " ", 
                  SuperscriptBox[
                   FormBox["q",
                    TraditionalForm], 
                   FormBox[
                    FormBox["h",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", "s", " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["g", 
                RowBox[{"f", "h"}]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          FormBox["q",
           TraditionalForm], "\[CenterDot]", 
          FormBox[
           SubscriptBox["k", "3"],
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["g", 
             RowBox[{"e", "g"}]], " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}]}], "+", 
           RowBox[{
            SubsuperscriptBox["k", 
             FormBox["4",
              TraditionalForm], 
             FormBox[
              FormBox["e",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["g",
               TraditionalForm],
              TraditionalForm]]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             FormBox["q",
              TraditionalForm], "\[CenterDot]", 
             FormBox[
              SubscriptBox["k", "3"],
              TraditionalForm]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               SuperscriptBox["g", 
                RowBox[{"f", "h"}]], " ", 
               RowBox[{
                FormBox["q",
                 TraditionalForm], "\[CenterDot]", 
                FormBox[
                 SubscriptBox["k", "3"],
                 TraditionalForm]}]}], "+", 
              RowBox[{"2", " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["f",
               TraditionalForm],
              TraditionalForm]], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"4", " ", 
                SubsuperscriptBox["k", 
                 FormBox["3",
                  TraditionalForm], 
                 FormBox[
                  FormBox["h",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}]}], "-", 
              RowBox[{"2", " ", "s", " ", 
               SuperscriptBox[
                FormBox["q",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
    
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["1", "z"], ")"}], "3"], ")"}],
     SeriesData[$CellContext`z, 
      DirectedInfinity[1], {}, 2, 3, 1],
     Editable->False]}],
   SeriesData[$CellContext`z, 
    DirectedInfinity[1], {((Complex[0, 
         Rational[1, 64]] $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[
          Subscript[$CellContext`k, 3], D]]^(-2)) (((2 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[
            Subscript[$CellContext`k, 3], D]]) (
         HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 4], D]] 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D]] + 
         HighEnergyPhysics`FeynCalc`Pair`Pair[
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
e, D], 
            
            HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
g, D]] HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]])) ((2 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]]) ((2 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 4], D]]) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] (((-2) $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] - (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
            HighEnergyPhysics`FeynCalc`Momentum`Momentum[
             Subscript[$CellContext`k, 3], D]])) + 
      HighEnergyPhysics`FeynCalc`Pair`Pair[
         HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`e, 
          D], 
         HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
          D]] (((-HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) ((2 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 4], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
              
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
               D]] + (2 HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`f, D], 
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D]]) HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]])) ((2 $CellContext`s) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] + (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
              
              HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]]) 
           HighEnergyPhysics`FeynCalc`Pair`Pair[
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[
              Subscript[$CellContext`k, 3], D]]) + 
        HighEnergyPhysics`FeynCalc`Pair`Pair[
           
           HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$CellContext`\
f, D], 
           
           HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
            D]] (((2 HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) 
            HighEnergyPhysics`FeynCalc`Pair`Pair[
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, D], 
              HighEnergyPhysics`FeynCalc`Momentum`Momentum[
               Subscript[$CellContext`k, 3], D]]) ((2 $CellContext`s) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] + (4 HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]) + 
          HighEnergyPhysics`FeynCalc`Pair`Pair[
             
             HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`g, D], 
             
             HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
              D]] ((2 $CellContext`s^2) HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D]] + ((4 $CellContext`s) HighEnergyPhysics`FeynCalc`Pair`Pair[
                
                HighEnergyPhysics`FeynCalc`LorentzIndex`LorentzIndex[$\
CellContext`h, D], 
                HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                 Subscript[$CellContext`k, 3], D]]) 
             HighEnergyPhysics`FeynCalc`Pair`Pair[
               
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[$CellContext`q, 
                D], 
               HighEnergyPhysics`FeynCalc`Momentum`Momentum[
                Subscript[$CellContext`k, 3], D]]))))}, 2, 3, 1],
   Editable->False], TraditionalForm]], "Output",
 CellChangeTimes->{3.617012714360427*^9, 3.617341106749305*^9, 
  3.618221276983316*^9, 3.619338208469489*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Brute-force propagator ansatz in q-light-cone gauge", "Subsection",
 CellChangeTimes->{{3.6175115845088453`*^9, 3.617511624543292*^9}, {
  3.619158391344123*^9, 3.619158433741346*^9}}],

Cell["\<\
In what follows I try to find a propagator which is transversal to q and \
yields an amplitude that agrees with the original computation.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVtIk2EAh/EluGEgzNlITI3JMEHzsGDodNVrHoaKkoE5L7qwbXgXmkny
aUpGUE7zgDrRwFJIIpesljqjqLwoJjgPmfZtEa4iXrzY7NMgdfb+v4uH38Wj
qrlWYQ6TSCRqFjQEr26fWaPEk+8X4ON7ho5cZsB3WTQq0v0Zhu9/3IC3zHln
ZV8osT7nz0GvS/MAtvd/6IY/VJVSBbMxcEfUrJVnw+SRPB1MaNbyGub40UXR
dLWqKQc/+R8H+9rcGp5pSvymFzW0hNa/UuL0tB7CEcfwwA2ekhdk3gaLNi62
NDLdetoGhXcmB7Rm/xbt4OpXYGXXwjo0cg83YVlM2i+Y1Bm88vIPJVWjJRbo
G/Qf55nRcTmxULigTIDeeO4kHPopl/qYr0qyIqBz2RoJ90aHlTBLMquYEygZ
syuPQfncfctr5rLlRC1cPT274GceeVu9CPc529PwHUpspe+fwfKpN06Y5Jp2
wdqo+e8yplFm9MNuXrqXytQJoQMYMtU505hbkwUzMGPzwAO9l7glGLCnZKYz
axS9opmnWrWw8NF1AvVxwWJYoRsqhRPFKw2w+lPgJrRPNdw+3KVE/STlLpRO
96ym/qXkvNC+Bv8D5hpFtQ==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eijst", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "j"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"s", ",", "t"}], "]"}]}], "+", 
       RowBox[{"a2", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "s"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"j", ",", "t"}], "]"}]}], "+", 
       RowBox[{"a3", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "t"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"j", ",", "s"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b7", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b8", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b9", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b10", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"b11", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"b12", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"c2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"c3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"c4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"c5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"c6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}], 
       "+", 
       RowBox[{"d", " ", 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "j"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "s"}], "]"}], 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "t"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"e1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}], 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"f2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"f3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"f4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"f5", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"f6", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"g1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "3"}], ")"}]}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "+", 
          RowBox[{"h4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "+", 
          RowBox[{"h6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "o"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "o"}], "]"}]}], "]"}]}], "+", 
       RowBox[{"ii", " ", 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "j"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}], 
        RowBox[{
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "4"}], 
          ")"}]}]}]}], ")"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6179703517595673`*^9, 3.617970779129396*^9}, {
   3.617970879468876*^9, 3.617970919076379*^9}, {3.6179709519702663`*^9, 
   3.6179709533780193`*^9}, {3.617970984844159*^9, 3.61797114731628*^9}, {
   3.6179714109042788`*^9, 3.6179714542681723`*^9}, {3.617971514353078*^9, 
   3.617971601477254*^9}, {3.617971643385899*^9, 3.6179718972932*^9}, 
   3.6179719296959248`*^9, 3.617972009927199*^9, 3.617972050362486*^9, 
   3.6179724567357693`*^9, {3.617972660466942*^9, 3.617972672014579*^9}, 
   3.61797289536517*^9, {3.617972978809762*^9, 3.617972982014348*^9}, {
   3.617973026458253*^9, 3.6179730287227707`*^9}, 3.61803425058486*^9, {
   3.6180357071967497`*^9, 3.618035710039319*^9}, {3.618052871007208*^9, 
   3.618052921229148*^9}, {3.618052978179215*^9, 3.618053074353793*^9}, {
   3.618140015348394*^9, 3.6181400387410088`*^9}, {3.618140078679212*^9, 
   3.618140140134884*^9}, {3.618140224639729*^9, 3.618140275649692*^9}, {
   3.618140349871594*^9, 3.618140350074747*^9}, 3.618202878154153*^9, {
   3.618735662852004*^9, 3.618735698391954*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b9", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b12", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f4", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"d", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"ii", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619158512030223*^9, 3.619338208897195*^9}]
}, Closed]],

Cell[TextData[{
 "Starting with the most generic ansatz with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["q", "2"], "=", "0"}], TraditionalForm]]],
 " we first restrict the coefficients such that the would-be propagator \
becomes q-transversal."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVtIk2EAh/GVuKEkzOVQzIyF2UDzsGDobMlrp6FiqGDNCy90G96JZVJ9
mVIi1FaKUU20sAMoolOsWU6pPFwoE5xaHvo2CVcRL11s9VWQOn3/38XD7+JR
VdaUmPdKJJIjLGgIVv06vkyJ57RfgM/vGKwnmAHfBdHoKPcnGL41swZvmvNO
ylYosQ3yudDr0rTC2w+n2uBXVZlUwawPNIuatfJsqO7K08HEG1pew3wZOS+a
nqS6loOv/s/BB01uDc80HV7XixoaQqufKXF6Gndg13Dnoys8Ja/ItB2eWytu
qGe69bQJChOmYWjL/iFq5S4twbL7c6vQyD3ZgEVxad9h8r1gxevflFzsLrBA
32N/LM/cn5ATD4VTykToPcgdgh3f5FIfc6QgKwI6F21RcLO7UwmzJKOKMYGS
Fw5lDJSP3bWMMxctB6rhx2Ojc37mnvfl83CLs/eF/6HEXjjZD88PvXPCZNcb
F6yOnv4iYxplRj9s46WbqUydENqGIVOtM435c+DMW5ixse2B3lJuAQYcKZnp
zEpFu2jm0UYtPPvsMoH6hGA+LNF1FMLe/KU6WD4buAodQ3W3dv5SktST0gKL
IsKs8OmH6+1wRBO5T/2PkuLcVtFdeQ9Mtw==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sysqtransv", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{"Expand", "[", 
            RowBox[{
             RowBox[{"eijst", "[", 
              RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "]"}], "\[Equal]", 
          "0"}], ",", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{"Expand", "[", 
            RowBox[{
             RowBox[{"eijst", "[", 
              RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "j"}], "]"}]}], "]"}], "]"}], "\[Equal]", 
          "0"}]}], "}"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
        "}"}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "c1"}], "-", "c4", "-", "c6"}]}], ",", 
       RowBox[{"g4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "c2"}], "-", "c3", "-", "c6"}]}], ",", 
       RowBox[{"h5", "\[Rule]", 
        RowBox[{"-", "e1"}]}], ",", 
       RowBox[{"h4", "\[Rule]", 
        RowBox[{"-", "e1"}]}], ",", 
       RowBox[{"h2", "\[Rule]", 
        RowBox[{"-", "e2"}]}], ",", 
       RowBox[{"h3", "\[Rule]", 
        RowBox[{"-", "e2"}]}], ",", 
       RowBox[{"d", "\[Rule]", "0"}], ",", 
       RowBox[{"h1", "\[Rule]", "0"}], ",", 
       RowBox[{"b12", "\[Rule]", 
        RowBox[{"-", "a1"}]}], ",", 
       RowBox[{"b9", "\[Rule]", 
        RowBox[{"-", "a1"}]}], ",", 
       RowBox[{"b5", "\[Rule]", 
        RowBox[{"-", "a2"}]}], ",", 
       RowBox[{"b3", "\[Rule]", 
        RowBox[{"-", "a2"}]}], ",", 
       RowBox[{"b6", "\[Rule]", 
        RowBox[{"-", "a3"}]}], ",", 
       RowBox[{"b2", "\[Rule]", 
        RowBox[{"-", "a3"}]}], ",", 
       RowBox[{"h6", "\[Rule]", 
        RowBox[{"-", "e3"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e1", "\[Rule]", "0"}], ",", 
     RowBox[{"e2", "\[Rule]", "0"}], ",", 
     RowBox[{"e4", "\[Rule]", "e3"}], ",", 
     RowBox[{"f6", "\[Rule]", 
      RowBox[{"a2", "+", "a3"}]}], ",", 
     RowBox[{"f2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b4"}], "-", "b7"}]}], ",", 
     RowBox[{"f3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
     RowBox[{"f4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
     RowBox[{"f5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b4"}], "-", "b10"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618736039868785*^9, 3.6187361229945707`*^9}, {
  3.618736172901292*^9, 3.6187362638114233`*^9}, {3.618736373365267*^9, 
  3.6187365127096252`*^9}, {3.618736543974063*^9, 3.618736704892205*^9}, {
  3.618736805831768*^9, 3.618736808003583*^9}, {3.618740688101403*^9, 
  3.618740700612451*^9}, {3.618907256931685*^9, 3.618907258880978*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619159224269464*^9, 3.6193382099981613`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eijst2", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"eijst", "[", 
      RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "c1"}], "-", "c4", "-", "c6"}]}], ",", 
       RowBox[{"g4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "c2"}], "-", "c3", "-", "c6"}]}], ",", 
       RowBox[{"h5", "\[Rule]", 
        RowBox[{"-", "e1"}]}], ",", 
       RowBox[{"h4", "\[Rule]", 
        RowBox[{"-", "e1"}]}], ",", 
       RowBox[{"h2", "\[Rule]", 
        RowBox[{"-", "e2"}]}], ",", 
       RowBox[{"h3", "\[Rule]", 
        RowBox[{"-", "e2"}]}], ",", 
       RowBox[{"d", "\[Rule]", "0"}], ",", 
       RowBox[{"h1", "\[Rule]", "0"}], ",", 
       RowBox[{"b12", "\[Rule]", 
        RowBox[{"-", "a1"}]}], ",", 
       RowBox[{"b9", "\[Rule]", 
        RowBox[{"-", "a1"}]}], ",", 
       RowBox[{"b5", "\[Rule]", 
        RowBox[{"-", "a2"}]}], ",", 
       RowBox[{"b3", "\[Rule]", 
        RowBox[{"-", "a2"}]}], ",", 
       RowBox[{"b6", "\[Rule]", 
        RowBox[{"-", "a3"}]}], ",", 
       RowBox[{"b2", "\[Rule]", 
        RowBox[{"-", "a3"}]}], ",", 
       RowBox[{"h6", "\[Rule]", 
        RowBox[{"-", "e3"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"e1", "\[Rule]", "0"}], ",", 
     RowBox[{"e2", "\[Rule]", "0"}], ",", 
     RowBox[{"e4", "\[Rule]", "e3"}], ",", 
     RowBox[{"f6", "\[Rule]", 
      RowBox[{"a2", "+", "a3"}]}], ",", 
     RowBox[{"f2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b4"}], "-", "b7"}]}], ",", 
     RowBox[{"f3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b8"}]}], ",", 
     RowBox[{"f4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b11"}]}], ",", 
     RowBox[{"f5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b4"}], "-", "b10"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.619159282490859*^9, 3.619159293119597*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b4"}], "-", "b7"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b10"}], "-", "b4"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b8"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b1"}], "-", "b11"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"a2", "+", "a3"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "c2"}], "-", "c3", "-", "c6"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "c1"}], "-", "c4", "-", "c6"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"ii", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619159251566111*^9, 3.6191592955001*^9, 
  3.6193382101242437`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$s$qlightcone", "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{"Expand", "[", 
       RowBox[{
        RowBox[{"verEEEonshellmn", "[", 
         RowBox[{
         "1", ",", "2", ",", "a", ",", "b", ",", "c", ",", "d", ",", "i", ",",
           "j"}], "]"}], 
        RowBox[{"I", "/", "s"}], " ", 
        RowBox[{"eijst2", "[", 
         RowBox[{"i", ",", "j", ",", "m", ",", "n"}], "]"}]}], "]"}], "]"}], 
     RowBox[{"verEEEonshellmn", "[", 
      RowBox[{
      "3", ",", "4", ",", "e", ",", "f", ",", "g", ",", "h", ",", "m", ",", 
       "n"}], "]"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6191586105167093`*^9, 3.6191586956884623`*^9}, {
   3.619158758800352*^9, 3.619158791431305*^9}, 3.619158829569809*^9, {
   3.619158891466893*^9, 3.6191589137009993`*^9}, 3.6191592987897177`*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
              SubsuperscriptBox["k", 
               FormBox["3",
                TraditionalForm], 
               FormBox[
                FormBox["a",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "d"}]], " ", 
              SubsuperscriptBox["k", 
               FormBox["1",
                TraditionalForm], 
               FormBox[
                FormBox["c",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SubsuperscriptBox["k", 
               FormBox["4",
                TraditionalForm], 
               FormBox[
                FormBox["e",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox["q",
                TraditionalForm], 
               FormBox[
                FormBox["g",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{
               FormBox["p",
                TraditionalForm], "\[CenterDot]", 
               FormBox[
                SubscriptBox["k", "1"],
                TraditionalForm]}], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]]}], 
             RowBox[{"16", " ", "s", " ", 
              SuperscriptBox[
               FormBox["p",
                TraditionalForm], "2"], " ", 
              RowBox[{
               FormBox["p",
                TraditionalForm], "\[CenterDot]", 
               FormBox["q",
                TraditionalForm]}]}]]}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "1"],
               TraditionalForm]}], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]]}], 
            RowBox[{"16", " ", "s", " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"], " ", 
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}]], "+", 
           RowBox[{"\[LeftSkeleton]", "11753", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"]}], 
            RowBox[{"4", " ", "s", " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["p",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["q",
                 TraditionalForm]}],
               TraditionalForm], "4"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["p",
               TraditionalForm], "2"]}], 
            RowBox[{"4", " ", "s", " ", 
             SuperscriptBox[
              FormBox[
               RowBox[{
                FormBox["p",
                 TraditionalForm], "\[CenterDot]", 
                FormBox["q",
                 TraditionalForm]}],
               TraditionalForm], "4"]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 591, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 591, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 591, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[591]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619158927625312*^9, 3.619159045972019*^9, 
  3.619164400012473*^9, 3.6193436100838118`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$channel$s$qlightcone", "]"}]], "Input",
 CellChangeTimes->{{3.619164899154457*^9, 3.61916490327566*^9}}],

Cell[BoxData[
 FormBox["7832", TraditionalForm]], "Output",
 CellChangeTimes->{3.619164903565008*^9, 3.619343610358467*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$s$qlightcone2", "=", 
  RowBox[{"(", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Expand", "[", 
       RowBox[{"amp4$channel$s$qlightcone", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           TagBox[
            StyleBox[
             RowBox[{"Pair", "[", 
              RowBox[{
               RowBox[{"LorentzIndex", "[", 
                RowBox[{"i_", ",", "D"}], "]"}], ",", 
               RowBox[{"Momentum", "[", 
                RowBox[{"p", ",", "D"}], "]"}]}], "]"}],
             ShowSpecialCharacters->False,
             ShowStringCharacters->True,
             NumberMarks->True],
            FullForm], "\[Rule]", 
           RowBox[{
            RowBox[{"kc", "[", 
             RowBox[{"1", ",", "i"}], "]"}], "+", 
            RowBox[{"kc", "[", 
             RowBox[{"2", ",", "i"}], "]"}]}]}], ",", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "s"}], ",", 
          
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"1", ",", "1"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"2", ",", "2"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"3", ",", "3"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"4", ",", "4"}], "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"1", ",", "2"}], "]"}], "\[Rule]", 
           RowBox[{"s", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"1", ",", "3"}], "]"}], "\[Rule]", 
           RowBox[{"t", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"1", ",", "4"}], "]"}], "\[Rule]", 
           RowBox[{"u", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"2", ",", "3"}], "]"}], "\[Rule]", 
           RowBox[{"u", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"2", ",", "4"}], "]"}], "\[Rule]", 
           RowBox[{"t", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"kdotk", "[", 
            RowBox[{"3", ",", "4"}], "]"}], "\[Rule]", 
           RowBox[{"s", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"1", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"s", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"2", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"s", "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"3", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"-", "s"}], "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"k", "[", 
              RowBox[{"4", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"-", "s"}], "/", "2"}]}], ",", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"1", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"k", "[", 
               RowBox[{"2", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}]}], "]"}]}]}], "}"}]}], "]"}], 
      ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "a"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"1", ",", "b"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "c"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"2", ",", "d"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "e"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"3", ",", "f"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "g"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"kc", "[", 
         RowBox[{"4", ",", "h"}], "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"u", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "s"}], "-", "t"}]}]}], "}"}]}], "]"}], ")"}]}]], "Input",\

 CellChangeTimes->{{3.6191656122096243`*^9, 3.61916564237514*^9}, {
   3.619165676610173*^9, 3.619165743961191*^9}, {3.6191657834457397`*^9, 
   3.619165815425336*^9}, {3.61916587222291*^9, 3.61916591413142*^9}, {
   3.6191660769595213`*^9, 3.61916608341346*^9}, {3.619167582682519*^9, 
   3.619167600980507*^9}, {3.619168307043331*^9, 3.619168371151874*^9}, {
   3.6191685562246103`*^9, 3.619168624693404*^9}, {3.619168685255995*^9, 
   3.619168705264616*^9}, {3.619168754080185*^9, 3.6191687587288647`*^9}, {
   3.619169017918638*^9, 3.619169031188429*^9}, {3.619169716211131*^9, 
   3.619169730751359*^9}, {3.619169997610572*^9, 3.619170058225854*^9}, {
   3.619170121159585*^9, 3.619170152894397*^9}, {3.6191712472416353`*^9, 
   3.6191712579579077`*^9}, {3.619171344427948*^9, 3.6191713467031803`*^9}, 
   3.619171574203698*^9, {3.619171605906993*^9, 3.619171608467396*^9}, {
   3.619172362177244*^9, 3.619172381689616*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "a2", " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "c"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "d"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"e", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"f", "h"}]], " ", 
              SuperscriptBox["t", "2"]}], 
             RowBox[{"16", " ", 
              SuperscriptBox["s", "2"]}]]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", 
             SuperscriptBox["t", "2"]}], 
            RowBox[{"16", " ", 
             SuperscriptBox["s", "2"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "a2", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", "t"}], 
            RowBox[{"16", " ", "s"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"e", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"f", "h"}]], " ", "t"}], 
            RowBox[{"16", " ", "s"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "5962", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "d"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "1"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}]}], 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "1"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}]}], ")"}], "4"]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 593, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 593, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 593, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[593]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619165648462133*^9, {3.619165686713313*^9, 3.619165715508296*^9}, 
   3.619165749251423*^9, 3.619165829988497*^9, 3.6191659198562937`*^9, 
   3.619166104609767*^9, {3.6191683586069*^9, 3.619168376925633*^9}, 
   3.619168730265052*^9, 3.619168763051399*^9, 3.619169034691967*^9, 
   3.619169736699572*^9, 3.6191698448656683`*^9, 3.619170069660615*^9, 
   3.6191701631660337`*^9, 3.6191712610817633`*^9, 3.61917135058843*^9, 
   3.619172425043133*^9, 3.61934361373954*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$channel$s$qlightcone2", "]"}]], "Input",
 CellChangeTimes->{{3.619165684728129*^9, 3.619165691903471*^9}}],

Cell[BoxData[
 FormBox["3970", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6191656923399*^9, 3.6191657160996113`*^9}, 
   3.619165753707761*^9, 3.619165832483568*^9, 3.619165922515695*^9, 
   3.619166107689883*^9, 3.619168379392227*^9, 3.619168733172193*^9, 
   3.619168775865438*^9, 3.619169040094017*^9, 3.619169740302381*^9, 
   3.6191698598381577`*^9, 3.6191700697428923`*^9, 3.619170166162208*^9, 
   3.619171262258973*^9, 3.619171356226891*^9, 3.6191724304725037`*^9, 
   3.619343613952866*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$t$qlightcone2", "=", 
  RowBox[{"amp4$channel$s$qlightcone2", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "i_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "i"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"4", ",", "i_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "i"}], "]"}]}], ",", 
     RowBox[{"a", "\[Rule]", "g"}], ",", 
     RowBox[{"g", "\[Rule]", "a"}], ",", 
     RowBox[{"b", "\[Rule]", "h"}], ",", 
     RowBox[{"h", "\[Rule]", "b"}], ",", 
     RowBox[{"s", "\[Rule]", "t"}], ",", 
     RowBox[{"t", "\[Rule]", "s"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "4"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{3.619172940281189*^9, 3.619173074812904*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"\[LeftSkeleton]", "5964", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"\[LeftSkeleton]", "8", "\[RightSkeleton]"}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "4"]}]], 
           "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "4"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}], ")"}], "4"]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "4"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}], ")"}], "4"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "f"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "h"}]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "1"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "4"],
               TraditionalForm]}]}], 
            RowBox[{"4", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "4"],
                  TraditionalForm]}]}], ")"}], "4"]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 595, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 595, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 595, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[595]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6191730977751207`*^9, 3.6193436165799522`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$channel$u$qlightcone2", "=", 
  RowBox[{"amp4$channel$s$qlightcone2", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "i_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "i"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"kc", "[", 
       RowBox[{"3", ",", "i_"}], "]"}], "\[Rule]", 
      RowBox[{"kc", "[", 
       RowBox[{"1", ",", "i"}], "]"}]}], ",", 
     RowBox[{"a", "\[Rule]", "e"}], ",", 
     RowBox[{"e", "\[Rule]", "a"}], ",", 
     RowBox[{"b", "\[Rule]", "f"}], ",", 
     RowBox[{"f", "\[Rule]", "b"}], ",", 
     RowBox[{"s", "\[Rule]", "u"}], ",", 
     RowBox[{"u", "\[Rule]", "s"}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "3"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", 
      RowBox[{"Pair", "[", 
       RowBox[{
        RowBox[{"Momentum", "[", 
         RowBox[{
          RowBox[{"Subscript", "[", 
           RowBox[{"k", ",", "1"}], "]"}], ",", "D"}], "]"}], ",", 
        RowBox[{"Momentum", "[", 
         RowBox[{"q", ",", "D"}], "]"}]}], "]"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.619171362881373*^9, 3.619171366944336*^9}, {
  3.619172467092548*^9, 3.61917252143215*^9}, {3.6191725757255373`*^9, 
  3.619172611972721*^9}, {3.619172756347651*^9, 3.619172858056435*^9}, {
  3.619173004146475*^9, 3.619173072557034*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"\[ImaginaryI]", " ", "a2", " ", 
              SuperscriptBox["g", 
               RowBox[{"a", "g"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"b", "h"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"c", "e"}]], " ", 
              SuperscriptBox["g", 
               RowBox[{"d", "f"}]], " ", 
              SuperscriptBox["t", "2"]}], 
             RowBox[{"16", " ", 
              SuperscriptBox["u", "2"]}]]}], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox["t", "2"]}], 
            RowBox[{"16", " ", 
             SuperscriptBox["u", "2"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "a2", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", "t"}], 
            RowBox[{"16", " ", "u"}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], " ", 
             SuperscriptBox["g", 
              RowBox[{
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", "t"}], 
            RowBox[{"16", " ", "u"}]], "+", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], "+", 
           RowBox[{"\[LeftSkeleton]", "5955", "\[RightSkeleton]"}], "+", 
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", 
             RowBox[{"\[LeftSkeleton]", "8", "\[RightSkeleton]"}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "4"]}]], 
           "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "h"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "1"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}], ")"}], "4"]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["4",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "1"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}], ")"}], "4"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "ii", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "g"}]], " ", 
             SuperscriptBox[
              FormBox["q",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"c", "e"}]], " ", 
             SuperscriptBox["g", 
              RowBox[{"d", "f"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "1"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "2"],
               TraditionalForm]}], " ", 
             RowBox[{
              FormBox["q",
               TraditionalForm], "\[CenterDot]", 
              FormBox[
               SubscriptBox["k", "3"],
               TraditionalForm]}]}], 
            RowBox[{"8", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "2"],
                  TraditionalForm]}], "+", 
                RowBox[{
                 FormBox["q",
                  TraditionalForm], "\[CenterDot]", 
                 FormBox[
                  SubscriptBox["k", "3"],
                  TraditionalForm]}]}], ")"}], "4"]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 596, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 596, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 596, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[596]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619172785210476*^9, {3.619172847848062*^9, 3.6191728616643867`*^9}, 
   3.61917313082509*^9, 3.619343619380013*^9}]
}, Open  ]],

Cell["\<\
We now also add the varphi exchange diagrams. The most general ansatz for the \
varphi propagator is but a constant \[Lambda] times the original one.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, {3.619242739991846*^9, 3.619242809730998*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2", "=", 
  RowBox[{
  "amp4$channel$s$qlightcone2", "+", "amp4$channel$t$qlightcone2", "+", 
   "amp4$channel$u$qlightcone2", "+", 
   RowBox[{"\[Lambda]", " ", "amp4VARPHIexchange"}]}]}]], "Input",
 CellChangeTimes->{{3.619173163230035*^9, 3.61917317837074*^9}, 
   3.619173294402172*^9, {3.6192427123169928`*^9, 3.619242719109085*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"\[LeftSkeleton]", "17906", "\[RightSkeleton]"}], "+", 
           FractionBox[
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
            RowBox[{"4", " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "d"}]], " ", 
             SubsuperscriptBox["k", 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", 
             SuperscriptBox["s", "3"]}]], "-", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["a",
                TraditionalForm],
               TraditionalForm]], " ", 
             SuperscriptBox["g", 
              RowBox[{"b", "c"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", 
             SuperscriptBox["s", "3"]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "c"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["b",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", 
             SuperscriptBox["s", "3"]}]], "+", 
           FractionBox[
            RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
             SuperscriptBox["g", 
              RowBox[{"a", "b"}]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["c",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["1",
               TraditionalForm], 
              FormBox[
               FormBox["d",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["e",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["2",
               TraditionalForm], 
              FormBox[
               FormBox["f",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["g",
                TraditionalForm],
               TraditionalForm]], " ", 
             SubsuperscriptBox["k", 
              FormBox["3",
               TraditionalForm], 
              FormBox[
               FormBox["h",
                TraditionalForm],
               TraditionalForm]]}], 
            RowBox[{"4", " ", 
             SuperscriptBox["s", "3"]}]]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 597, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 597, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 597, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[597]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6191731868018713`*^9, 3.619173301976391*^9, 
  3.619242824256777*^9, 3.619343626795972*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$qlightcone2", "]"}]], "Input",
 CellChangeTimes->{{3.619173193503137*^9, 3.6191731947643414`*^9}, 
   3.619173302125641*^9}],

Cell[BoxData[
 FormBox["11911", TraditionalForm]], "Output",
 CellChangeTimes->{3.6191731950469713`*^9, 3.6191733026875277`*^9, 
  3.619242826427909*^9, 3.619343627034563*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical analysis of most general q-light-cone propagator", \
"Subsection",
 CellChangeTimes->{{3.612085834165001*^9, 3.612085844526819*^9}, {
  3.612086484467353*^9, 3.612086497855007*^9}, {3.614577753311775*^9, 
  3.61457775350277*^9}, {3.619251617251955*^9, 3.619251628468852*^9}}],

Cell["First need 4 light-like momenta adding up to zero.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}, {3.6120866065182667`*^9, 3.612086606758206*^9}, {
   3.612505924058659*^9, 3.612505936532402*^9}, {3.612684208346747*^9, 
   3.6126842128136387`*^9}, {3.619173534353448*^9, 3.61917353448518*^9}, {
   3.6192428328385477`*^9, 3.619242834469954*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}, {3.612086612732903*^9, 
   3.612086614349341*^9}, {3.612505939428406*^9, 3.6125059543631077`*^9}, {
   3.61268421467281*^9, 3.612684221598008*^9}, {3.619173536026105*^9, 
   3.6191735361820107`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{"k31", ",", "k32", ",", "k33", ",", "k34"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9, {
   3.61208661791853*^9, 3.612086618148158*^9}, {3.612086936652397*^9, 
   3.612086944450577*^9}, 3.619173550969096*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k4", "=", 
   RowBox[{"{", 
    RowBox[{"k41", ",", "k42", ",", "k43", ",", "k44"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}, {3.612086632200843*^9, 3.612086646982294*^9}, 
   3.6191735537450657`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.612086707631708*^9, 3.612086713887814*^9}, 
   3.6191735610392447`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kinsys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4"}], "\[Equal]", "0"}]}], 
    "}"}]}], ";", 
  RowBox[{"kinsys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612258217072095*^9, 3.612258219089881*^9}, {
  3.612258263321577*^9, 3.612258271721939*^9}, {3.612505966669755*^9, 
  3.612505985721085*^9}, {3.6191735688138533`*^9, 3.619173572268476*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k31", "2"]}], "+", 
         SuperscriptBox["k32", "2"], "+", 
         SuperscriptBox["k33", "2"], "+", 
         SuperscriptBox["k34", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k41", "2"]}], "+", 
         SuperscriptBox["k42", "2"], "+", 
         SuperscriptBox["k43", "2"], "+", 
         SuperscriptBox["k44", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"k31", "+", "k41", "+", "2"}], ",", 
          RowBox[{"k32", "+", "k42"}], ",", 
          RowBox[{"k33", "+", "k43"}], ",", 
          RowBox[{"k34", "+", "k44"}]}], "}"}], "\[LongEqual]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612258223332856*^9, 3.612258277667809*^9, 3.612505994584982*^9, 
   3.6126800091197*^9, 3.6126842296073713`*^9, 3.614415251319221*^9, 
   3.614416681331402*^9, 3.614506889916788*^9, 3.6145783531107807`*^9, 
   3.61493838358314*^9, 3.615634944521681*^9, 3.6157167540016603`*^9, 
   3.6162157977373037`*^9, 3.617337299458859*^9, 3.617339456664722*^9, 
   3.618218573787261*^9, {3.619173572887054*^9, 3.619173586936594*^9}, 
   3.619242838388041*^9, 3.6193436271101513`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"FindInstance", "[", 
   RowBox[{"kinsys", ",", 
    RowBox[{"Join", "[", 
     RowBox[{"k4", ",", "k3"}], "]"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086667146719*^9, 3.612086669789753*^9}, {
   3.61208672018432*^9, 3.6120867609601393`*^9}, {3.612086820399687*^9, 
   3.61208684701149*^9}, {3.6120868882347116`*^9, 3.612086911234775*^9}, {
   3.612086947214334*^9, 3.612086966920597*^9}, {3.612087130200302*^9, 
   3.612087138062559*^9}, {3.612257132872628*^9, 3.6122571670798407`*^9}, 
   3.612257397692018*^9, {3.61225751058984*^9, 3.612257511578771*^9}, {
   3.6122576055168962`*^9, 3.612257613202684*^9}, 3.612257694530752*^9, {
   3.612258060499379*^9, 3.612258062723226*^9}, {3.612258192623537*^9, 
   3.612258193411767*^9}, 3.612258282749514*^9, {3.6125060012757797`*^9, 
   3.612506003735097*^9}, {3.612680017069385*^9, 3.6126800172139387`*^9}, 
   3.612684254591062*^9, 3.6145769005945463`*^9, 3.614576952464837*^9, {
   3.6145770875853148`*^9, 3.614577088568757*^9}, {3.6191736130014772`*^9, 
   3.6191736131373873`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k41", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k42", "\[Rule]", "0"}], ",", 
     RowBox[{"k43", "\[Rule]", "0"}], ",", 
     RowBox[{"k44", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k31", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k32", "\[Rule]", "0"}], ",", 
     RowBox[{"k33", "\[Rule]", "0"}], ",", 
     RowBox[{"k34", "\[Rule]", "1"}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.612086762118141*^9, 3.612086780893147*^9}, {
   3.612086823214789*^9, 3.612086847939478*^9}, {3.61208688888518*^9, 
   3.612086911822865*^9}, {3.612086954278853*^9, 3.612086967359386*^9}, {
   3.612087131307373*^9, 3.6120871383511143`*^9}, 3.612257142281363*^9, 
   3.612257394237977*^9, {3.6122575076936417`*^9, 3.612257512163836*^9}, {
   3.6122576069012537`*^9, 3.612257627804504*^9}, {3.612257690411792*^9, 
   3.612257695104991*^9}, 3.612258189484466*^9, 3.61225822195914*^9, 
   3.612258276336063*^9, 3.612259320778799*^9, 3.612511330729707*^9, 
   3.6126803950144*^9, {3.6126842499610157`*^9, 3.612684258655238*^9}, 
   3.6144152518055267`*^9, 3.614416681520438*^9, 3.6145068908943377`*^9, 
   3.614576906819211*^9, 3.614576960270529*^9, 3.614577089264464*^9, 
   3.6145783532449417`*^9, 3.614938384517983*^9, 3.615634945242508*^9, 
   3.615716763753829*^9, 3.616215797986451*^9, 3.617337299646379*^9, 
   3.617339456758937*^9, 3.618218573949119*^9, 3.619173619583102*^9, 
   3.619242840164323*^9, 3.619343627163353*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k3", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086972550753*^9, 3.612086977276445*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "1"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.612086977587695*^9, 3.6122575146527653`*^9, 
  3.612257696324094*^9, 3.612684263546081*^9, 3.6144152519329348`*^9, 
  3.6144166815767603`*^9, 3.614506890949765*^9, 3.614578353276498*^9, 
  3.614938384565001*^9, 3.615634945289898*^9, 3.615716766074543*^9, 
  3.616215798017215*^9, 3.617337299676415*^9, 3.617339456797743*^9, 
  3.618218573984281*^9, 3.619173630677906*^9, 3.619242841374653*^9, 
  3.619343627209127*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k3", ",", "k3"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122571125898314`*^9, 3.612257119072855*^9}, {
  3.612257544299827*^9, 3.612257553190195*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6122571193226643`*^9, 3.612257515599658*^9, {3.612257545928628*^9, 
   3.612257553598151*^9}, 3.612257697150077*^9, 3.612684265607835*^9, 
   3.6144152519576693`*^9, 3.614416681638151*^9, 3.614506890967968*^9, 
   3.61457835328469*^9, 3.614938384605798*^9, 3.615634945325961*^9, 
   3.615716767074236*^9, 3.616215798046818*^9, 3.617337299711178*^9, 
   3.617339456832644*^9, 3.618218574015799*^9, 3.6191736350394297`*^9, 
   3.6192428424830933`*^9, 3.619343627215727*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086983780642*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
    RowBox[{"-", "1"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086984684704*^9, 3.612257555469883*^9, 
  3.612257697740192*^9, 3.612684268914393*^9, 3.614415251973494*^9, 
  3.6144166816980267`*^9, 3.614506890983892*^9, 3.614578353290989*^9, 
  3.614938384647709*^9, 3.615634945363903*^9, 3.6157167682912292`*^9, 
  3.616215798191144*^9, 3.617337299746804*^9, 3.617339456867691*^9, 
  3.6182185740487432`*^9, 3.619173636567751*^9, 3.61924284322722*^9, 
  3.619343627221695*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k4", ",", "k4"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122575625202703`*^9, 3.612257564202305*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.612257565498811*^9, 3.612257698283271*^9, 
  3.6126842714539623`*^9, 3.614415251992217*^9, 3.614416681767228*^9, 
  3.614506890999983*^9, 3.614578353295656*^9, 3.614938384652294*^9, 
  3.615634945401319*^9, 3.615716769807744*^9, 3.616215798222134*^9, 
  3.617337299789431*^9, 3.617339456902569*^9, 3.618218574055382*^9, 
  3.6192428439067097`*^9, 3.619343627227079*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
     RowBox[{"t", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"u", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k4"}], "]"}]}]}]}], "}"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.612087426835834*^9, 3.612087432664119*^9}, {
   3.612258338518701*^9, 3.612258339672268*^9}, 3.6145769704085627`*^9, 
   3.614577080572277*^9, {3.619173653576743*^9, 3.619173663300818*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"t", "\[Rule]", "2"}], ",", 
    RowBox[{"u", "\[Rule]", "2"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612087439480166*^9, 3.612257591558383*^9, 3.612257700130177*^9, 
   3.612258340118903*^9, 3.6126842783468533`*^9, 3.614415252427136*^9, 
   3.614416681890109*^9, 3.6145068911892233`*^9, {3.6145769429963827`*^9, 
   3.614576970611363*^9}, 3.614578353362673*^9, 3.614938384741045*^9, 
   3.61563494553862*^9, 3.615716776067073*^9, 3.616215798269853*^9, 
   3.617337299947012*^9, 3.617339456954917*^9, 3.618218574108639*^9, 
   3.6191736638778257`*^9, 3.6192428449891157`*^9, 3.619343627270199*^9}]
}, Open  ]],

Cell[TextData[{
 "This is to check that the kinematical configuration is not singular (i.e. \
all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "ij"], "\[NotEqual]", "0"}], TraditionalForm]]],
 ")."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EA0ACNrNIA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"qq", "=", 
   RowBox[{"{", 
    RowBox[{"q1", ",", "q2", ",", "q3", ",", "q4"}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.619245750462315*^9, 3.6192457583034897`*^9}, {
  3.61925359622964*^9, 3.619253624137032*^9}, {3.6192536823679132`*^9, 
  3.619253690597275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solsQ", "=", 
   RowBox[{"FindInstance", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "qq"}], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k2"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k3"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k4"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{"q3", "\[NotEqual]", "0"}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "qq", ",", "100"}], "]"}]}], 
  ";", 
  RowBox[{"solsQ", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619245735712246*^9, 3.619245843386804*^9}, {
   3.619245898655726*^9, 3.619245907321413*^9}, {3.619246907400166*^9, 
   3.619246907649767*^9}, {3.6192471569505043`*^9, 3.619247157251212*^9}, {
   3.619247302920272*^9, 3.619247327249937*^9}, {3.619247363111875*^9, 
   3.619247380569146*^9}, 3.619250174378536*^9, {3.619252969898986*^9, 
   3.619252989345154*^9}, {3.6192534788689737`*^9, 3.619253483581024*^9}, 
   3.619253561288389*^9, {3.6192536348760147`*^9, 3.619253659843577*^9}, {
   3.619253696488311*^9, 3.619253696662755*^9}, 3.619253796719205*^9, {
   3.619259185839983*^9, 3.619259186016962*^9}, {3.619259675735292*^9, 
   3.619259676084115*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7673", "5"]}], "-", 
        FractionBox[
         RowBox[{"4241", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "552"}], "+", 
        FractionBox[
         RowBox[{"879", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["18583", "10"]}], "+", 
        FractionBox[
         RowBox[{"10259", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "25976313"}], "+", 
          FractionBox[
           RowBox[{"330511929", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["4593", "5"], "-", 
        FractionBox[
         RowBox[{"16989", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["16649", "10"]}], "+", 
        RowBox[{"54", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4577", "2"]}], "+", 
        FractionBox[
         RowBox[{"413", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1004182075"}], "-", 
          RowBox[{"256334968", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3093", "2"], "+", 
        FractionBox[
         RowBox[{"7861", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["11268", "5"], "-", 
        RowBox[{"1180", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["89", "10"]}], "+", 
        FractionBox[
         RowBox[{"9803", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "280555467"}], "+", 
          RowBox[{"1019875994", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3229", "2"], "-", 
        FractionBox[
         RowBox[{"19097", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["4", "5"], "+", 
        FractionBox[
         RowBox[{"11493", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["18359", "10"]}], "-", 
        FractionBox[
         RowBox[{"2429", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "303098239"}], "-", 
          RowBox[{"706014040", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6451", "5"], "-", 
        FractionBox[
         RowBox[{"4236", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["7447", "10"], "-", 
        FractionBox[
         RowBox[{"10451", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8528", "5"]}], "-", 
        FractionBox[
         RowBox[{"3487", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"49343662", "-", 
          RowBox[{"6561411", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1249", "5"]}], "+", 
        FractionBox[
         RowBox[{"19129", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5794", "5"]}], "-", 
        FractionBox[
         RowBox[{"10821", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1253"}], "-", 
        FractionBox[
         RowBox[{"22251", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "38760239"}], "-", 
          RowBox[{"903966040", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10441", "5"]}], "-", 
        FractionBox[
         RowBox[{"343", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1052"}], "+", 
        FractionBox[
         RowBox[{"20809", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1511", "10"]}], "+", 
        FractionBox[
         RowBox[{"3102", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["14", "5"]}], " ", 
        SqrtBox[
         RowBox[{"1012931", "+", 
          RowBox[{"618903", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9428", "5"]}], "+", 
        FractionBox[
         RowBox[{"1963", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["13577", "10"], "+", 
        FractionBox[
         RowBox[{"12113", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["407", "10"]}], "-", 
        RowBox[{"1776", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["528975679", "2"], "-", 
          RowBox[{"205086689", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2873", "5"]}], "+", 
        FractionBox[
         RowBox[{"7236", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"545", "-", 
        FractionBox[
         RowBox[{"2871", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15397", "10"]}], "-", 
        FractionBox[
         RowBox[{"10614", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"40406171", "-", 
          RowBox[{"757419456", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4721", "10"]}], "-", 
        FractionBox[
         RowBox[{"4226", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6334", "5"]}], "+", 
        FractionBox[
         RowBox[{"10301", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["831", "5"]}], "+", 
        RowBox[{"1564", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"456663073", "+", 
          RowBox[{"653763416", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6129", "10"]}], "-", 
        FractionBox[
         RowBox[{"3166", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"609", "+", 
        FractionBox[
         RowBox[{"3531", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19289", "10"]}], "+", 
        FractionBox[
         RowBox[{"3807", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"519865", "+", 
          RowBox[{"725934726", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19059", "10"]}], "+", 
        FractionBox[
         RowBox[{"4112", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4773", "5"]}], "-", 
        RowBox[{"538", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7387", "10"]}], "+", 
        FractionBox[
         RowBox[{"17437", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"482910789", "-", 
          RowBox[{"158583154", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2099", "10"]}], "-", 
        FractionBox[
         RowBox[{"18679", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["3694", "5"], "+", 
        FractionBox[
         RowBox[{"6197", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["10029", "10"], "+", 
        FractionBox[
         RowBox[{"2423", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "85045115"}], "-", 
          RowBox[{"38329959", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3287", "2"], "+", 
        FractionBox[
         RowBox[{"2917", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["5231", "5"], "-", 
        FractionBox[
         RowBox[{"5722", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4071", "5"]}], "-", 
        FractionBox[
         RowBox[{"12302", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"154490836", "+", 
          FractionBox[
           RowBox[{"159105835", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["11798", "5"], "+", 
        FractionBox[
         RowBox[{"7331", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["2437", "5"], "-", 
        FractionBox[
         RowBox[{"11444", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["583", "5"], "-", 
        FractionBox[
         RowBox[{"959", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"250673112", "+", 
          RowBox[{"142828291", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2139", "2"]}], "+", 
        FractionBox[
         RowBox[{"20407", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10389", "10"]}], "-", 
        FractionBox[
         RowBox[{"1223", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["3329", "10"], "-", 
        FractionBox[
         RowBox[{"527", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "418469541"}], "-", 
          RowBox[{"454899692", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11329", "10"]}], "+", 
        FractionBox[
         RowBox[{"13257", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["345", "2"]}], "+", 
        FractionBox[
         RowBox[{"3757", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["23147", "10"], "-", 
        RowBox[{"1892", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "214079593"}], "+", 
          RowBox[{"588467024", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["12089", "5"], "+", 
        FractionBox[
         RowBox[{"18749", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5701", "10"]}], "+", 
        FractionBox[
         RowBox[{"3195", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6192", "5"], "+", 
        FractionBox[
         RowBox[{"1957", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"76554075", "+", 
          FractionBox[
           RowBox[{"520151309", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3367", "10"], "-", 
        FractionBox[
         RowBox[{"6298", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "2057"}], "+", 
        FractionBox[
         RowBox[{"857", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2753", "2"]}], "-", 
        RowBox[{"152", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "756877803"}], "-", 
          RowBox[{"91410084", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11948", "5"]}], "+", 
        FractionBox[
         RowBox[{"8709", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1683", "10"], "-", 
        FractionBox[
         RowBox[{"6513", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["621", "2"]}], "-", 
        FractionBox[
         RowBox[{"5179", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["90331459", "5"], "-", 
          FractionBox[
           RowBox[{"164151426", " ", "\[ImaginaryI]"}], "5"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["695", "2"], "+", 
        FractionBox[
         RowBox[{"7129", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19331", "10"]}], "-", 
        FractionBox[
         RowBox[{"2472", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["5227", "5"], "+", 
        FractionBox[
         RowBox[{"9929", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "63851329"}], "-", 
          RowBox[{"126810723", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2057", "5"], "+", 
        FractionBox[
         RowBox[{"1401", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2269", "10"]}], "-", 
        FractionBox[
         RowBox[{"2571", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["11239", "10"], "+", 
        FractionBox[
         RowBox[{"8972", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["106047945", "2"], "-", 
          FractionBox[
           RowBox[{"201742501", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["4649", "5"], "-", 
        FractionBox[
         RowBox[{"19113", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19043", "10"]}], "-", 
        FractionBox[
         RowBox[{"2098", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["5876", "5"], "-", 
        FractionBox[
         RowBox[{"8689", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "686494181"}], "-", 
          RowBox[{"311007948", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"2219", "+", 
        FractionBox[
         RowBox[{"2873", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3079", "10"]}], "+", 
        FractionBox[
         RowBox[{"9136", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["21", "2"]}], "-", 
        FractionBox[
         RowBox[{"2747", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["406969169", "2"], "+", 
          RowBox[{"91593179", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["5923", "5"], "+", 
        FractionBox[
         RowBox[{"5079", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4403", "5"]}], "-", 
        FractionBox[
         RowBox[{"1273", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6297", "10"]}], "-", 
        FractionBox[
         RowBox[{"12691", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"21872126", "+", 
          FractionBox[
           RowBox[{"17996365", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["421", "2"], "-", 
        FractionBox[
         RowBox[{"23361", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["17401", "10"]}], "+", 
        FractionBox[
         RowBox[{"20797", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["2855", "2"], "-", 
        FractionBox[
         RowBox[{"1721", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "135328622"}], "+", 
          FractionBox[
           RowBox[{"435550067", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["8296", "5"], "+", 
        FractionBox[
         RowBox[{"9313", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"1766", "-", 
        FractionBox[
         RowBox[{"787", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["5949", "5"], "+", 
        FractionBox[
         RowBox[{"23223", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["14860269", "2"], "+", 
          RowBox[{"51113719", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["12277", "10"], "+", 
        FractionBox[
         RowBox[{"10064", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11243", "5"]}], "+", 
        FractionBox[
         RowBox[{"2289", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10098", "5"]}], "-", 
        FractionBox[
         RowBox[{"7173", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["478431515", "2"]}], "+", 
          RowBox[{"4425047", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7829", "10"]}], "+", 
        FractionBox[
         RowBox[{"4949", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2517", "10"]}], "-", 
        RowBox[{"1804", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["10159", "5"], "+", 
        RowBox[{"371", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "29156969"}], "-", 
          RowBox[{"99138951", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["20621", "10"]}], "-", 
        FractionBox[
         RowBox[{"6759", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["8529", "5"], "-", 
        FractionBox[
         RowBox[{"3226", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4449", "2"]}], "+", 
        FractionBox[
         RowBox[{"3317", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "490695279"}], "+", 
          RowBox[{"925199118", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["115", "2"]}], "-", 
        FractionBox[
         RowBox[{"11697", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4876", "5"]}], "+", 
        FractionBox[
         RowBox[{"5358", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["16131", "10"]}], "+", 
        FractionBox[
         RowBox[{"11876", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"187190311", "+", 
          RowBox[{"988743438", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["20339", "10"], "-", 
        FractionBox[
         RowBox[{"2356", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4967", "10"]}], "-", 
        FractionBox[
         RowBox[{"18313", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["9636", "5"], "+", 
        FractionBox[
         RowBox[{"23481", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["441057117", "2"], "-", 
          FractionBox[
           RowBox[{"639323871", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3597", "10"], "+", 
        FractionBox[
         RowBox[{"24657", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["7019", "5"], "+", 
        FractionBox[
         RowBox[{"12997", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["13303", "10"], "+", 
        FractionBox[
         RowBox[{"11661", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "64056700"}], "-", 
          FractionBox[
           RowBox[{"404013223", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3419", "10"], "+", 
        FractionBox[
         RowBox[{"21307", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["21223", "10"], "-", 
        FractionBox[
         RowBox[{"3691", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1789", "5"]}], "-", 
        FractionBox[
         RowBox[{"22317", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "88243522"}], "+", 
          FractionBox[
           RowBox[{"149666593", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["24641", "10"]}], "+", 
        FractionBox[
         RowBox[{"2469", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"1071", "-", 
        FractionBox[
         RowBox[{"1843", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6899", "10"], "-", 
        FractionBox[
         RowBox[{"2726", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"101780021", "-", 
          FractionBox[
           RowBox[{"167887147", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8854", "5"]}], "+", 
        FractionBox[
         RowBox[{"12388", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4011", "10"]}], "+", 
        FractionBox[
         RowBox[{"7249", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["10353", "10"], "+", 
        FractionBox[
         RowBox[{"1857", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "71197604"}], "-", 
          RowBox[{"252892637", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3953", "10"], "-", 
        FractionBox[
         RowBox[{"1571", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["18449", "10"]}], "-", 
        FractionBox[
         RowBox[{"11851", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["20331", "10"]}], "-", 
        RowBox[{"1686", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"98083287", "-", 
          RowBox[{"1584958368", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12791", "10"]}], "+", 
        RowBox[{"215", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1002", "5"]}], "-", 
        FractionBox[
         RowBox[{"15341", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["10808", "5"], "+", 
        RowBox[{"2205", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["204634245", "2"], "-", 
          RowBox[{"267438407", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5324", "5"]}], "+", 
        FractionBox[
         RowBox[{"7723", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5547", "5"]}], "-", 
        RowBox[{"1760", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "864"}], "+", 
        FractionBox[
         RowBox[{"5476", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"285715043", "-", 
          RowBox[{"365727248", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9673", "10"]}], "+", 
        RowBox[{"848", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["7519", "5"], "-", 
        FractionBox[
         RowBox[{"5251", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1794", "5"]}], "+", 
        RowBox[{"1541", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["23841221", "2"], "+", 
          RowBox[{"26114289", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2398", "5"]}], "+", 
        FractionBox[
         RowBox[{"16869", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1836"}], "-", 
        FractionBox[
         RowBox[{"19593", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], "+", 
        FractionBox[
         RowBox[{"10972", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"66693409", "-", 
          RowBox[{"220293658", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6573", "10"], "-", 
        FractionBox[
         RowBox[{"6833", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19667", "10"]}], "-", 
        FractionBox[
         RowBox[{"6344", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["10943", "5"], "-", 
        RowBox[{"613", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "202695217"}], "-", 
          RowBox[{"102600167", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["1817", "10"], "+", 
        FractionBox[
         RowBox[{"4979", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["20899", "10"]}], "-", 
        FractionBox[
         RowBox[{"12537", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["20057", "10"]}], "+", 
        FractionBox[
         RowBox[{"3777", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "763469627"}], "-", 
          RowBox[{"336323576", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3977", "2"]}], "+", 
        RowBox[{"261", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"2037", "-", 
        FractionBox[
         RowBox[{"22309", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["3518", "5"], "+", 
        FractionBox[
         RowBox[{"5519", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["271843927", "2"], "+", 
          RowBox[{"162435556", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4193", "10"]}], "-", 
        FractionBox[
         RowBox[{"17921", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "522"}], "+", 
        FractionBox[
         RowBox[{"24611", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1955", "2"]}], "+", 
        FractionBox[
         RowBox[{"3278", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"55575610", "+", 
          FractionBox[
           RowBox[{"267697073", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["16453", "10"]}], "+", 
        FractionBox[
         RowBox[{"9006", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["35", "2"], "+", 
        FractionBox[
         RowBox[{"20341", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["16873", "10"], "-", 
        FractionBox[
         RowBox[{"13387", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"254508361", "-", 
          RowBox[{"148064520", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7989", "5"]}], "-", 
        FractionBox[
         RowBox[{"4027", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["13409", "10"], "-", 
        FractionBox[
         RowBox[{"3794", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["2157", "10"], "+", 
        FractionBox[
         RowBox[{"8973", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["192806149", "2"], "+", 
          RowBox[{"95862391", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2953", "10"]}], "-", 
        FractionBox[
         RowBox[{"3091", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"2402", "+", 
        FractionBox[
         RowBox[{"4704", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4696", "5"], "-", 
        FractionBox[
         RowBox[{"5733", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "168831815"}], "-", 
          FractionBox[
           RowBox[{"72652873", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["594", "5"], "+", 
        FractionBox[
         RowBox[{"4989", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["3879", "5"], "-", 
        FractionBox[
         RowBox[{"4976", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15579", "10"]}], "+", 
        FractionBox[
         RowBox[{"517", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "75432838"}], "+", 
          FractionBox[
           RowBox[{"97115823", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"887", "-", 
        FractionBox[
         RowBox[{"7764", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["16901", "10"], "+", 
        FractionBox[
         RowBox[{"3977", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1074", "5"], "+", 
        RowBox[{"400", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "10321591"}], "-", 
          FractionBox[
           RowBox[{"482401745", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["158", "5"], "-", 
        FractionBox[
         RowBox[{"2109", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5089", "10"]}], "+", 
        FractionBox[
         RowBox[{"11321", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6359", "5"]}], "+", 
        FractionBox[
         RowBox[{"4639", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"22252855", "+", 
          RowBox[{"349887458", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["7", "5"], "-", 
        FractionBox[
         RowBox[{"12192", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["18113", "10"]}], "+", 
        FractionBox[
         RowBox[{"1971", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10539", "10"]}], "+", 
        FractionBox[
         RowBox[{"16707", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["37536093", "5"]}], "+", 
         FractionBox[
          RowBox[{"21143442", " ", "\[ImaginaryI]"}], "5"]}]]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["4768", "5"], "-", 
        FractionBox[
         RowBox[{"2334", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5706", "5"]}], "+", 
        FractionBox[
         RowBox[{"24233", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11553", "10"]}], "+", 
        FractionBox[
         RowBox[{"13641", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"578754689", "+", 
          RowBox[{"779254842", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7311", "10"]}], "+", 
        FractionBox[
         RowBox[{"11762", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12322", "5"]}], "+", 
        FractionBox[
         RowBox[{"5901", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5488", "5"]}], "-", 
        FractionBox[
         RowBox[{"12296", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["294069451", "2"]}], "-", 
          RowBox[{"148240756", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6041", "5"]}], "-", 
        FractionBox[
         RowBox[{"2719", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10284", "5"]}], "+", 
        FractionBox[
         RowBox[{"5623", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1187", "10"], "+", 
        FractionBox[
         RowBox[{"3669", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "60197535"}], "+", 
          FractionBox[
           RowBox[{"144149719", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8267", "5"]}], "-", 
        FractionBox[
         RowBox[{"23523", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["575", "2"]}], "-", 
        FractionBox[
         RowBox[{"21133", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["321", "5"], "+", 
        FractionBox[
         RowBox[{"13237", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"83296424", "+", 
          FractionBox[
           RowBox[{"319673753", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["23329", "10"]}], "+", 
        FractionBox[
         RowBox[{"2587", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["8159", "10"], "-", 
        FractionBox[
         RowBox[{"8287", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{"334", "-", 
        FractionBox[
         RowBox[{"193", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"143484465", "-", 
          FractionBox[
           RowBox[{"165888729", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6409", "5"], "+", 
        FractionBox[
         RowBox[{"12819", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "910"}], "-", 
        FractionBox[
         RowBox[{"4933", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1233", "10"], "+", 
        FractionBox[
         RowBox[{"567", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["7133993", "2"], "+", 
          RowBox[{"36567560", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["668", "5"], "+", 
        FractionBox[
         RowBox[{"2073", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8621", "10"]}], "+", 
        FractionBox[
         RowBox[{"141", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1490"}], "+", 
        RowBox[{"2434", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"294088551", "+", 
          RowBox[{"743026666", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5511", "10"]}], "-", 
        FractionBox[
         RowBox[{"5606", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["6451", "5"], "+", 
        FractionBox[
         RowBox[{"2403", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["831", "10"]}], "-", 
        FractionBox[
         RowBox[{"12461", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["18573379", "2"], "-", 
          FractionBox[
           RowBox[{"103583289", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4416", "5"]}], "+", 
        FractionBox[
         RowBox[{"19981", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["6719", "10"], "+", 
        FractionBox[
         RowBox[{"7127", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1299"}], "+", 
        FractionBox[
         RowBox[{"11338", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["91128147", "2"], "+", 
          RowBox[{"11158211", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["611", "2"]}], "+", 
        FractionBox[
         RowBox[{"3801", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1882"}], "+", 
        FractionBox[
         RowBox[{"8617", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4417", "2"], "-", 
        FractionBox[
         RowBox[{"4682", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "809101373"}], "+", 
          RowBox[{"946175090", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"1244", "-", 
        FractionBox[
         RowBox[{"1426", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8969", "10"]}], "-", 
        FractionBox[
         RowBox[{"6082", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6293", "10"], "+", 
        FractionBox[
         RowBox[{"19451", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"552879183", "-", 
          RowBox[{"533965878", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9817", "5"]}], "-", 
        FractionBox[
         RowBox[{"3501", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3335", "2"]}], "+", 
        RowBox[{"121", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["20979", "10"]}], "-", 
        FractionBox[
         RowBox[{"19573", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["19814659", "2"], "-", 
          FractionBox[
           RowBox[{"321706583", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2001", "5"], "-", 
        FractionBox[
         RowBox[{"1329", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["596", "5"], "-", 
        FractionBox[
         RowBox[{"2547", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["10123", "5"], "+", 
        FractionBox[
         RowBox[{"3521", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["113896337", "2"]}], "-", 
          RowBox[{"33371681", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8252", "5"]}], "-", 
        FractionBox[
         RowBox[{"10254", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["11241", "5"], "+", 
        FractionBox[
         RowBox[{"16367", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["321", "2"]}], "+", 
        FractionBox[
         RowBox[{"5104", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "71032611"}], "-", 
          RowBox[{"6557511", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"2039", "+", 
        RowBox[{"2424", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5677", "5"]}], "-", 
        FractionBox[
         RowBox[{"12096", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6988", "5"], "+", 
        FractionBox[
         RowBox[{"1661", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"25055289", "+", 
          RowBox[{"86574680", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8309", "10"]}], "+", 
        FractionBox[
         RowBox[{"9547", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10979", "5"]}], "-", 
        FractionBox[
         RowBox[{"4725", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9811", "5"]}], "-", 
        FractionBox[
         RowBox[{"6099", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "182350547"}], "-", 
          RowBox[{"1674865858", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"1859", "+", 
        FractionBox[
         RowBox[{"9937", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["6443", "10"], "+", 
        FractionBox[
         RowBox[{"1593", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6009", "5"]}], "+", 
        FractionBox[
         RowBox[{"11781", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"65783186", "+", 
          FractionBox[
           RowBox[{"274994393", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11456", "5"]}], "-", 
        FractionBox[
         RowBox[{"3587", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["18991", "10"], "+", 
        FractionBox[
         RowBox[{"2631", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["11701", "10"], "+", 
        FractionBox[
         RowBox[{"10414", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["73225891", "2"], "+", 
          FractionBox[
           RowBox[{"117252971", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["7733", "5"], "-", 
        FractionBox[
         RowBox[{"7299", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1193", "2"]}], "+", 
        FractionBox[
         RowBox[{"4461", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "2297"}], "-", 
        FractionBox[
         RowBox[{"4239", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "499236931"}], "-", 
          RowBox[{"593065266", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6613", "10"]}], "-", 
        FractionBox[
         RowBox[{"9509", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4041", "10"]}], "-", 
        FractionBox[
         RowBox[{"4607", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4173", "10"], "-", 
        FractionBox[
         RowBox[{"13771", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "19289482"}], "+", 
          FractionBox[
           RowBox[{"145998643", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"2307", "-", 
        FractionBox[
         RowBox[{"19543", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1787", "10"], "-", 
        FractionBox[
         RowBox[{"4021", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6823", "5"], "-", 
        FractionBox[
         RowBox[{"2223", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"92510530", "-", 
          FractionBox[
           RowBox[{"384594317", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2193", "10"]}], "+", 
        FractionBox[
         RowBox[{"6467", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12131", "5"]}], "+", 
        FractionBox[
         RowBox[{"14077", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4869", "2"]}], "-", 
        FractionBox[
         RowBox[{"863", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "254298876"}], "+", 
          FractionBox[
           RowBox[{"285334573", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4479", "5"]}], "+", 
        FractionBox[
         RowBox[{"2367", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["21401", "10"]}], "+", 
        RowBox[{"937", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "2287"}], "-", 
        FractionBox[
         RowBox[{"3963", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "110693392"}], "-", 
          RowBox[{"147524426", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["16243", "10"], "+", 
        FractionBox[
         RowBox[{"5411", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["13973", "10"], "-", 
        FractionBox[
         RowBox[{"14551", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["8957", "10"], "-", 
        RowBox[{"613", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"30138822", "+", 
          FractionBox[
           RowBox[{"434009279", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3684", "5"]}], "+", 
        FractionBox[
         RowBox[{"291", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["2917", "2"], "-", 
        FractionBox[
         RowBox[{"9382", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5911", "5"]}], "-", 
        FractionBox[
         RowBox[{"22131", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"135833912", "+", 
          RowBox[{"3876041", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["12849", "10"], "+", 
        FractionBox[
         RowBox[{"19419", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5091", "10"]}], "+", 
        FractionBox[
         RowBox[{"12121", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9453", "10"]}], "+", 
        FractionBox[
         RowBox[{"5986", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "37030825"}], "+", 
          RowBox[{"848788116", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["737", "10"], "-", 
        FractionBox[
         RowBox[{"20881", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4276", "5"]}], "+", 
        FractionBox[
         RowBox[{"3711", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["3601", "10"], "+", 
        FractionBox[
         RowBox[{"4493", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "157101823"}], "+", 
          RowBox[{"254227540", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4227", "10"]}], "+", 
        FractionBox[
         RowBox[{"6696", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["18327", "10"], "-", 
        FractionBox[
         RowBox[{"387", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6386", "5"]}], "+", 
        FractionBox[
         RowBox[{"14273", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["228306375", "2"]}], "+", 
          FractionBox[
           RowBox[{"132779321", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6803", "10"], "-", 
        RowBox[{"1928", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["688", "5"]}], "+", 
        FractionBox[
         RowBox[{"6557", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["14171", "10"]}], "-", 
        RowBox[{"14", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "485134359"}], "-", 
          RowBox[{"248246696", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["5713", "5"], "+", 
        FractionBox[
         RowBox[{"5636", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["779", "2"], "+", 
        FractionBox[
         RowBox[{"9757", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["15723", "10"], "+", 
        FractionBox[
         RowBox[{"7637", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{"-", 
        SqrtBox[
         RowBox[{
          FractionBox["35520301", "10"], "-", 
          FractionBox[
           RowBox[{"18736626", " ", "\[ImaginaryI]"}], "5"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2844", "5"], "+", 
        FractionBox[
         RowBox[{"2093", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["8057", "5"], "+", 
        RowBox[{"1272", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6364", "5"], "+", 
        FractionBox[
         RowBox[{"4863", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "78344673"}], "-", 
          RowBox[{"103670712", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["18267", "10"], "+", 
        RowBox[{"1910", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "181"}], "-", 
        FractionBox[
         RowBox[{"4299", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["929", "2"]}], "+", 
        FractionBox[
         RowBox[{"9489", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["26271843", "2"], "+", 
          FractionBox[
           RowBox[{"385194915", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["9961", "5"], "+", 
        FractionBox[
         RowBox[{"3716", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15187", "10"]}], "+", 
        FractionBox[
         RowBox[{"10801", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9554", "5"]}], "+", 
        FractionBox[
         RowBox[{"863", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "136702803"}], "+", 
          RowBox[{"657170590", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["23093", "10"], "-", 
        FractionBox[
         RowBox[{"713", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8812", "5"]}], "-", 
        FractionBox[
         RowBox[{"18693", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1499"}], "+", 
        RowBox[{"1501", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["285338023", "2"], "-", 
          RowBox[{"68688075", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["10353", "10"], "+", 
        FractionBox[
         RowBox[{"1097", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1949", "2"], "-", 
        FractionBox[
         RowBox[{"7878", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2873", "10"]}], "-", 
        FractionBox[
         RowBox[{"1579", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"62474149", "+", 
          FractionBox[
           RowBox[{"171720235", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19203", "10"]}], "+", 
        FractionBox[
         RowBox[{"1319", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10741", "5"]}], "+", 
        FractionBox[
         RowBox[{"2045", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["9251", "10"], "+", 
        FractionBox[
         RowBox[{"23059", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"456226229", "-", 
          RowBox[{"37988232", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7739", "10"]}], "+", 
        FractionBox[
         RowBox[{"4334", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["12769", "10"], "+", 
        FractionBox[
         RowBox[{"3306", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["9137", "10"], "+", 
        RowBox[{"1554", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"23435911", "-", 
          RowBox[{"586998520", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["1387", "2"], "-", 
        FractionBox[
         RowBox[{"8889", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["17327", "10"], "-", 
        FractionBox[
         RowBox[{"6827", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["11171", "10"], "+", 
        FractionBox[
         RowBox[{"1671", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "109185372"}], "+", 
          FractionBox[
           RowBox[{"19958723", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2001", "10"], "+", 
        FractionBox[
         RowBox[{"11587", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["17981", "10"]}], "+", 
        FractionBox[
         RowBox[{"10716", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["13329", "10"], "+", 
        RowBox[{"1316", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["641527", "2"], "+", 
          FractionBox[
           RowBox[{"233144739", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2791", "10"], "-", 
        FractionBox[
         RowBox[{"2123", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"2007", "+", 
        FractionBox[
         RowBox[{"8303", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["322", "5"]}], "+", 
        FractionBox[
         RowBox[{"9602", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"37796341", "-", 
          RowBox[{"320398254", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["13307", "10"], "-", 
        FractionBox[
         RowBox[{"11583", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5251", "5"]}], "+", 
        FractionBox[
         RowBox[{"6117", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7783", "10"]}], "-", 
        FractionBox[
         RowBox[{"18401", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"90077706", "-", 
          RowBox[{"84434248", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1973", "10"]}], "+", 
        FractionBox[
         RowBox[{"19401", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["12909", "10"], "+", 
        FractionBox[
         RowBox[{"4581", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["19277", "10"], "-", 
        FractionBox[
         RowBox[{"7878", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["128302797", "5"]}], "+", 
          FractionBox[
           RowBox[{"82525644", " ", "\[ImaginaryI]"}], "5"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5683", "10"]}], "-", 
        FractionBox[
         RowBox[{"1931", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["3127", "2"], "+", 
        FractionBox[
         RowBox[{"5534", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["7211", "5"], "-", 
        FractionBox[
         RowBox[{"679", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "299534793"}], "-", 
          RowBox[{"284978462", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3919", "2"]}], "+", 
        FractionBox[
         RowBox[{"5727", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["2931", "10"], "-", 
        RowBox[{"1900", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10521", "5"]}], "+", 
        FractionBox[
         RowBox[{"12601", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"321198585", "+", 
          RowBox[{"192796224", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7694", "5"]}], "+", 
        FractionBox[
         RowBox[{"21497", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["16263", "10"], "+", 
        FractionBox[
         RowBox[{"288", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1952", "5"], "+", 
        RowBox[{"1973", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["57726087", "2"]}], "-", 
          RowBox[{"208594622", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["7882", "5"], "+", 
        FractionBox[
         RowBox[{"8267", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["13071", "10"]}], "+", 
        FractionBox[
         RowBox[{"12428", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["23611", "10"], "-", 
        FractionBox[
         RowBox[{"10067", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "34034597"}], "+", 
          RowBox[{"1646453378", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"598", "-", 
        FractionBox[
         RowBox[{"12351", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19201", "10"]}], "+", 
        FractionBox[
         RowBox[{"4573", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4635", "2"], "+", 
        FractionBox[
         RowBox[{"6531", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1288659257"}], "-", 
          RowBox[{"725247274", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2107", "10"], "+", 
        FractionBox[
         RowBox[{"23711", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["17559", "10"], "+", 
        FractionBox[
         RowBox[{"3583", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["14431", "10"]}], "-", 
        FractionBox[
         RowBox[{"3439", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "185392592"}], "-", 
          FractionBox[
           RowBox[{"314238617", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619247306337376*^9, 3.6192473275798597`*^9}, {
   3.619247366761524*^9, 3.6192473862009478`*^9}, 3.619250189167459*^9, 
   3.619253006482288*^9, 3.619253501155623*^9, 3.619253562818247*^9, {
   3.619253636647204*^9, 3.6192536606192513`*^9}, 3.619253714663269*^9, 
   3.619253798174103*^9, 3.619259192689518*^9, 3.619259679665366*^9, 
   3.619343628769216*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"qq", ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k2"}], ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k3"}], ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k4"}], ",", "qq"}], "]"}]}], "}"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"solsQ", "[", 
       RowBox[{"[", "20", "]"}], "]"}]}], "]"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.6191737450948343`*^9, 3.619173797754238*^9}, {
  3.6191738286543903`*^9, 3.6191738320823097`*^9}, {3.619245862668565*^9, 
  3.6192458852495947`*^9}, {3.619245916409066*^9, 3.619245923800671*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"0"},
      {
       RowBox[{
        FractionBox["23896", "5"], "-", 
        FractionBox[
         RowBox[{"17418", " ", "\[ImaginaryI]"}], "5"]}]},
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1683", "10"], "-", 
          FractionBox[
           RowBox[{"6513", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["90331459", "5"], "-", 
           FractionBox[
            RowBox[{"164151426", " ", "\[ImaginaryI]"}], "5"]}]]}]}]},
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1683", "10"], "-", 
          FractionBox[
           RowBox[{"6513", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["90331459", "5"], "-", 
           FractionBox[
            RowBox[{"164151426", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619245867709139*^9, 3.6192459244387503`*^9}, 
   3.6192469121346416`*^9, {3.619247376009243*^9, 3.619247390701576*^9}, 
   3.619253029812439*^9, 3.6192538056839447`*^9, 3.6192592221682997`*^9, 
   3.619259691088504*^9, 3.6193436293231564`*^9}]
}, Open  ]],

Cell["\<\
So we found a light-like q that leads to non-singular terms in the \
propagators.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules0", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
       RowBox[{"u", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"1", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"2", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"3", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"4", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "qq"}], "]"}]}]}], "}"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"solsQ", "[", 
        RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"iq", ",", "1", ",", 
      RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619243019476788*^9, 3.619243024257585*^9}, {
   3.61924594137394*^9, 3.619246017843701*^9}, 3.619251664736548*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4913", "5"], "+", 
        RowBox[{"1024", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10433", "5"], "+", 
        FractionBox[
         RowBox[{"3362", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7673", "5"]}], "-", 
          FractionBox[
           RowBox[{"4241", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "25976313"}], "+", 
           FractionBox[
            RowBox[{"330511929", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7673", "5"]}], "-", 
          FractionBox[
           RowBox[{"4241", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "25976313"}], "+", 
           FractionBox[
            RowBox[{"330511929", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5167", "2"]}], "+", 
        FractionBox[
         RowBox[{"17529", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7463", "10"], "+", 
        FractionBox[
         RowBox[{"16449", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4593", "5"], "-", 
          FractionBox[
           RowBox[{"16989", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1004182075"}], "-", 
           RowBox[{"256334968", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4593", "5"], "-", 
          FractionBox[
           RowBox[{"16989", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1004182075"}], "-", 
           RowBox[{"256334968", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7071", "10"], "-", 
        FractionBox[
         RowBox[{"13761", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["38001", "10"]}], "-", 
        FractionBox[
         RowBox[{"1961", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3093", "2"], "+", 
          FractionBox[
           RowBox[{"7861", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "280555467"}], "+", 
           RowBox[{"1019875994", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3093", "2"], "+", 
          FractionBox[
           RowBox[{"7861", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "280555467"}], "+", 
           RowBox[{"1019875994", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["16137", "10"]}], "+", 
        RowBox[{"3059", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["16153", "10"]}], "+", 
        FractionBox[
         RowBox[{"3802", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3229", "2"], "-", 
          FractionBox[
           RowBox[{"19097", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "303098239"}], "-", 
           RowBox[{"706014040", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3229", "2"], "-", 
          FractionBox[
           RowBox[{"19097", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "303098239"}], "-", 
           RowBox[{"706014040", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1091", "2"]}], "-", 
        RowBox[{"1243", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["20349", "10"]}], "+", 
        FractionBox[
         RowBox[{"14687", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6451", "5"], "-", 
          FractionBox[
           RowBox[{"4236", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"49343662", "-", 
           RowBox[{"6561411", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6451", "5"], "-", 
          FractionBox[
           RowBox[{"4236", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"49343662", "-", 
           RowBox[{"6561411", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "909"}], "-", 
        RowBox[{"2995", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7043", "5"], "-", 
        FractionBox[
         RowBox[{"4154", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1249", "5"]}], "+", 
          FractionBox[
           RowBox[{"19129", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "38760239"}], "-", 
           RowBox[{"903966040", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1249", "5"]}], "+", 
          FractionBox[
           RowBox[{"19129", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "38760239"}], "-", 
           RowBox[{"903966040", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5181", "5"], "+", 
        FractionBox[
         RowBox[{"4299", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["15701", "5"], "-", 
        FractionBox[
         RowBox[{"20123", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["10441", "5"]}], "-", 
          FractionBox[
           RowBox[{"343", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["14", "5"], " ", 
         SqrtBox[
          RowBox[{"1012931", "+", 
           RowBox[{"618903", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["10441", "5"]}], "-", 
          FractionBox[
           RowBox[{"343", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["14", "5"], " ", 
         SqrtBox[
          RowBox[{"1012931", "+", 
           RowBox[{"618903", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["32433", "10"], "+", 
        RowBox[{"2030", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5279", "10"], "-", 
        FractionBox[
         RowBox[{"14076", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["9428", "5"]}], "+", 
          FractionBox[
           RowBox[{"1963", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["528975679", "2"], "-", 
           RowBox[{"205086689", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["9428", "5"]}], "+", 
          FractionBox[
           RowBox[{"1963", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["528975679", "2"], "-", 
           RowBox[{"205086689", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5598", "5"], "-", 
        FractionBox[
         RowBox[{"10107", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["148", "5"], "-", 
        RowBox[{"873", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2873", "5"]}], "+", 
          FractionBox[
           RowBox[{"7236", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"40406171", "-", 
           RowBox[{"757419456", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2873", "5"]}], "+", 
          FractionBox[
           RowBox[{"7236", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"40406171", "-", 
           RowBox[{"757419456", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7947", "10"]}], "+", 
        FractionBox[
         RowBox[{"14527", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["17389", "10"], "-", 
        RowBox[{"1215", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4721", "10"]}], "-", 
          FractionBox[
           RowBox[{"4226", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"456663073", "+", 
           RowBox[{"653763416", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4721", "10"]}], "-", 
          FractionBox[
           RowBox[{"4226", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"456663073", "+", 
           RowBox[{"653763416", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["12219", "10"], "+", 
        FractionBox[
         RowBox[{"6697", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["39", "10"], "-", 
        RowBox[{"73", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["6129", "10"]}], "-", 
          FractionBox[
           RowBox[{"3166", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"519865", "+", 
           RowBox[{"725934726", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["6129", "10"]}], "-", 
          FractionBox[
           RowBox[{"3166", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"519865", "+", 
           RowBox[{"725934726", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["9513", "10"], "-", 
        FractionBox[
         RowBox[{"6802", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5721", "2"], "-", 
        FractionBox[
         RowBox[{"1422", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["19059", "10"]}], "+", 
          FractionBox[
           RowBox[{"4112", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"482910789", "-", 
           RowBox[{"158583154", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["19059", "10"]}], "+", 
          FractionBox[
           RowBox[{"4112", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"482910789", "-", 
           RowBox[{"158583154", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["9487", "10"], "+", 
        FractionBox[
         RowBox[{"31073", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5289", "10"]}], "+", 
        FractionBox[
         RowBox[{"1257", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2099", "10"]}], "-", 
          FractionBox[
           RowBox[{"18679", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "85045115"}], "-", 
           RowBox[{"38329959", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2099", "10"]}], "-", 
          FractionBox[
           RowBox[{"18679", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "85045115"}], "-", 
           RowBox[{"38329959", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5973", "10"]}], "-", 
        FractionBox[
         RowBox[{"26029", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["26897", "10"]}], "-", 
        FractionBox[
         RowBox[{"3141", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3287", "2"], "+", 
          FractionBox[
           RowBox[{"2917", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"154490836", "+", 
           FractionBox[
            RowBox[{"159105835", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3287", "2"], "+", 
          FractionBox[
           RowBox[{"2917", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"154490836", "+", 
           FractionBox[
            RowBox[{"159105835", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9361", "5"]}], "-", 
        FractionBox[
         RowBox[{"30219", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "2847"}], "+", 
        FractionBox[
         RowBox[{"15557", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["11798", "5"], "+", 
          FractionBox[
           RowBox[{"7331", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"250673112", "+", 
           RowBox[{"142828291", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["11798", "5"], "+", 
          FractionBox[
           RowBox[{"7331", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"250673112", "+", 
           RowBox[{"142828291", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["153", "5"], "-", 
        RowBox[{"2163", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10542", "5"], "-", 
        FractionBox[
         RowBox[{"9592", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2139", "2"]}], "+", 
          FractionBox[
           RowBox[{"20407", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "418469541"}], "-", 
           RowBox[{"454899692", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2139", "2"]}], "+", 
          FractionBox[
           RowBox[{"20407", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "418469541"}], "-", 
           RowBox[{"454899692", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4802", "5"], "-", 
        RowBox[{"950", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["6527", "5"], "-", 
        FractionBox[
         RowBox[{"8507", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["11329", "10"]}], "+", 
          FractionBox[
           RowBox[{"13257", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "214079593"}], "+", 
           RowBox[{"588467024", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["11329", "10"]}], "+", 
          FractionBox[
           RowBox[{"13257", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "214079593"}], "+", 
           RowBox[{"588467024", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["29879", "10"]}], "-", 
        FractionBox[
         RowBox[{"1387", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["18477", "10"]}], "-", 
        FractionBox[
         RowBox[{"17362", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["12089", "5"], "+", 
          FractionBox[
           RowBox[{"18749", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"76554075", "+", 
           FractionBox[
            RowBox[{"520151309", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["12089", "5"], "+", 
          FractionBox[
           RowBox[{"18749", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"76554075", "+", 
           FractionBox[
            RowBox[{"520151309", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["23937", "10"]}], "+", 
        FractionBox[
         RowBox[{"13453", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["17203", "10"], "+", 
        FractionBox[
         RowBox[{"11739", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3367", "10"], "-", 
          FractionBox[
           RowBox[{"6298", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "756877803"}], "-", 
           RowBox[{"91410084", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3367", "10"], "-", 
          FractionBox[
           RowBox[{"6298", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "756877803"}], "-", 
           RowBox[{"91410084", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["25579", "10"], "-", 
        FractionBox[
         RowBox[{"15222", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["22213", "10"], "-", 
        FractionBox[
         RowBox[{"2196", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["11948", "5"]}], "+", 
          FractionBox[
           RowBox[{"8709", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["90331459", "5"], "-", 
           FractionBox[
            RowBox[{"164151426", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["11948", "5"]}], "+", 
          FractionBox[
           RowBox[{"8709", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["90331459", "5"], "-", 
           FractionBox[
            RowBox[{"164151426", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11403", "5"]}], "-", 
        FractionBox[
         RowBox[{"9601", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7928", "5"], "-", 
        FractionBox[
         RowBox[{"4657", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["695", "2"], "+", 
          FractionBox[
           RowBox[{"7129", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "63851329"}], "-", 
           RowBox[{"126810723", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["695", "2"], "+", 
          FractionBox[
           RowBox[{"7129", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "63851329"}], "-", 
           RowBox[{"126810723", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6383", "10"]}], "-", 
        FractionBox[
         RowBox[{"1986", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["369", "2"]}], "+", 
        RowBox[{"117", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2057", "5"], "+", 
          FractionBox[
           RowBox[{"1401", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["106047945", "2"], "-", 
           FractionBox[
            RowBox[{"201742501", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2057", "5"], "+", 
          FractionBox[
           RowBox[{"1401", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["106047945", "2"], "-", 
           FractionBox[
            RowBox[{"201742501", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["28341", "10"]}], "+", 
        FractionBox[
         RowBox[{"14917", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1949", "2"], "+", 
        FractionBox[
         RowBox[{"23309", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4649", "5"], "-", 
          FractionBox[
           RowBox[{"19113", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "686494181"}], "-", 
           RowBox[{"311007948", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4649", "5"], "-", 
          FractionBox[
           RowBox[{"19113", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "686494181"}], "-", 
           RowBox[{"311007948", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["25269", "10"]}], "+", 
        FractionBox[
         RowBox[{"6263", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["19111", "10"]}], "-", 
        FractionBox[
         RowBox[{"12009", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2219", "+", 
          FractionBox[
           RowBox[{"2873", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["406969169", "2"], "+", 
           RowBox[{"91593179", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2219", "+", 
          FractionBox[
           RowBox[{"2873", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["406969169", "2"], "+", 
           RowBox[{"91593179", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10326", "5"]}], "-", 
        FractionBox[
         RowBox[{"6352", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "304"}], "-", 
        FractionBox[
         RowBox[{"3806", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["5923", "5"], "+", 
          FractionBox[
           RowBox[{"5079", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"21872126", "+", 
           FractionBox[
            RowBox[{"17996365", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["5923", "5"], "+", 
          FractionBox[
           RowBox[{"5079", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"21872126", "+", 
           FractionBox[
            RowBox[{"17996365", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9753", "5"]}], "+", 
        FractionBox[
         RowBox[{"22079", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7648", "5"], "+", 
        FractionBox[
         RowBox[{"1282", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["421", "2"], "-", 
          FractionBox[
           RowBox[{"23361", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "135328622"}], "+", 
           FractionBox[
            RowBox[{"435550067", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["421", "2"], "-", 
          FractionBox[
           RowBox[{"23361", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "135328622"}], "+", 
           FractionBox[
            RowBox[{"435550067", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["534", "5"], "-", 
        FractionBox[
         RowBox[{"22561", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["17126", "5"]}], "-", 
        FractionBox[
         RowBox[{"14691", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["8296", "5"], "+", 
          FractionBox[
           RowBox[{"9313", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["14860269", "2"], "+", 
           RowBox[{"51113719", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["8296", "5"], "+", 
          FractionBox[
           RowBox[{"9313", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["14860269", "2"], "+", 
           RowBox[{"51113719", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["34763", "10"]}], "-", 
        FractionBox[
         RowBox[{"17839", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10209", "10"], "-", 
        FractionBox[
         RowBox[{"22417", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["12277", "10"], "+", 
          FractionBox[
           RowBox[{"10064", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["478431515", "2"]}], "+", 
           RowBox[{"4425047", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["12277", "10"], "+", 
          FractionBox[
           RowBox[{"10064", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["478431515", "2"]}], "+", 
           RowBox[{"4425047", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2656", "5"], "-", 
        FractionBox[
         RowBox[{"13969", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5173", "5"], "+", 
        FractionBox[
         RowBox[{"4071", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7829", "10"]}], "+", 
          FractionBox[
           RowBox[{"4949", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "29156969"}], "-", 
           RowBox[{"99138951", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7829", "10"]}], "+", 
          FractionBox[
           RowBox[{"4949", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "29156969"}], "-", 
           RowBox[{"99138951", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["37679", "10"], "+", 
        FractionBox[
         RowBox[{"3533", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["3563", "10"], "+", 
        RowBox[{"1997", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["20621", "10"]}], "-", 
          FractionBox[
           RowBox[{"6759", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "490695279"}], "+", 
           RowBox[{"925199118", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["20621", "10"]}], "-", 
          FractionBox[
           RowBox[{"6759", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "490695279"}], "+", 
           RowBox[{"925199118", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9177", "10"]}], "+", 
        FractionBox[
         RowBox[{"22413", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10327", "10"], "+", 
        FractionBox[
         RowBox[{"981", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["115", "2"]}], "-", 
          FractionBox[
           RowBox[{"11697", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"187190311", "+", 
           RowBox[{"988743438", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["115", "2"]}], "-", 
          FractionBox[
           RowBox[{"11697", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"187190311", "+", 
           RowBox[{"988743438", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12653", "5"]}], "-", 
        FractionBox[
         RowBox[{"13601", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7686", "5"]}], "+", 
        FractionBox[
         RowBox[{"4605", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["20339", "10"], "-", 
          FractionBox[
           RowBox[{"2356", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["441057117", "2"], "-", 
           FractionBox[
            RowBox[{"639323871", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["20339", "10"], "-", 
          FractionBox[
           RowBox[{"2356", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["441057117", "2"], "-", 
           FractionBox[
            RowBox[{"639323871", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10441", "10"], "-", 
        RowBox[{"1166", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3527", "2"]}], "-", 
        FractionBox[
         RowBox[{"18827", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3597", "10"], "+", 
          FractionBox[
           RowBox[{"24657", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "64056700"}], "-", 
           FractionBox[
            RowBox[{"404013223", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3597", "10"], "+", 
          FractionBox[
           RowBox[{"24657", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "64056700"}], "-", 
           FractionBox[
            RowBox[{"404013223", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8902", "5"], "-", 
        FractionBox[
         RowBox[{"28689", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12321", "5"]}], "-", 
        FractionBox[
         RowBox[{"2785", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3419", "10"], "+", 
          FractionBox[
           RowBox[{"21307", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "88243522"}], "+", 
           FractionBox[
            RowBox[{"149666593", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3419", "10"], "+", 
          FractionBox[
           RowBox[{"21307", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "88243522"}], "+", 
           FractionBox[
            RowBox[{"149666593", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["35351", "10"], "-", 
        RowBox[{"2156", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["13931", "10"], "-", 
        RowBox[{"313", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["24641", "10"]}], "+", 
          FractionBox[
           RowBox[{"2469", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"101780021", "-", 
           FractionBox[
            RowBox[{"167887147", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["24641", "10"]}], "+", 
          FractionBox[
           RowBox[{"2469", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"101780021", "-", 
           FractionBox[
            RowBox[{"167887147", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["13697", "10"], "-", 
        FractionBox[
         RowBox[{"17527", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["21719", "10"], "-", 
        FractionBox[
         RowBox[{"6405", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8854", "5"]}], "+", 
          FractionBox[
           RowBox[{"12388", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "71197604"}], "-", 
           RowBox[{"252892637", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8854", "5"]}], "+", 
          FractionBox[
           RowBox[{"12388", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "71197604"}], "-", 
           RowBox[{"252892637", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11201", "5"]}], "-", 
        RowBox[{"2056", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7248", "5"], "+", 
        FractionBox[
         RowBox[{"13422", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3953", "10"], "-", 
          FractionBox[
           RowBox[{"1571", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"98083287", "-", 
           RowBox[{"1584958368", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3953", "10"], "-", 
          FractionBox[
           RowBox[{"1571", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"98083287", "-", 
           RowBox[{"1584958368", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10787", "10"], "-", 
        FractionBox[
         RowBox[{"17491", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2959", "2"], "+", 
        FractionBox[
         RowBox[{"13191", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["12791", "10"]}], "+", 
          RowBox[{"215", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["204634245", "2"], "-", 
           RowBox[{"267438407", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["12791", "10"]}], "+", 
          RowBox[{"215", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["204634245", "2"], "-", 
           RowBox[{"267438407", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["223", "5"]}], "-", 
        FractionBox[
         RowBox[{"25323", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10871", "5"], "+", 
        FractionBox[
         RowBox[{"9877", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["5324", "5"]}], "+", 
          FractionBox[
           RowBox[{"7723", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"285715043", "-", 
           RowBox[{"365727248", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["5324", "5"]}], "+", 
          FractionBox[
           RowBox[{"7723", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"285715043", "-", 
           RowBox[{"365727248", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["24711", "10"], "-", 
        FractionBox[
         RowBox[{"13731", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1073", "2"]}], "-", 
        FractionBox[
         RowBox[{"3229", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["9673", "10"]}], "+", 
          RowBox[{"848", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["23841221", "2"], "+", 
           RowBox[{"26114289", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["9673", "10"]}], "+", 
          RowBox[{"848", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["23841221", "2"], "+", 
           RowBox[{"26114289", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6782", "5"]}], "-", 
        FractionBox[
         RowBox[{"18231", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["11578", "5"], "+", 
        FractionBox[
         RowBox[{"1362", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2398", "5"]}], "+", 
          FractionBox[
           RowBox[{"16869", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"66693409", "-", 
           RowBox[{"220293658", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2398", "5"]}], "+", 
          FractionBox[
           RowBox[{"16869", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"66693409", "-", 
           RowBox[{"220293658", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "2624"}], "+", 
        FractionBox[
         RowBox[{"489", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["6547", "5"], "+", 
        FractionBox[
         RowBox[{"13177", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6573", "10"], "-", 
          FractionBox[
           RowBox[{"6833", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "202695217"}], "-", 
           RowBox[{"102600167", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6573", "10"], "-", 
          FractionBox[
           RowBox[{"6833", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "202695217"}], "-", 
           RowBox[{"102600167", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["11358", "5"]}], "-", 
        FractionBox[
         RowBox[{"4499", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["9541", "5"], "+", 
        FractionBox[
         RowBox[{"2579", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1817", "10"], "+", 
          FractionBox[
           RowBox[{"4979", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "763469627"}], "-", 
           RowBox[{"336323576", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1817", "10"], "+", 
          FractionBox[
           RowBox[{"4979", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "763469627"}], "-", 
           RowBox[{"336323576", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8051", "2"], "-", 
        FractionBox[
         RowBox[{"24919", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["97", "2"]}], "+", 
        FractionBox[
         RowBox[{"19699", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3977", "2"]}], "+", 
          RowBox[{"261", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["271843927", "2"], "+", 
           RowBox[{"162435556", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3977", "2"]}], "+", 
          RowBox[{"261", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["271843927", "2"], "+", 
           RowBox[{"162435556", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1027", "10"]}], "+", 
        FractionBox[
         RowBox[{"21266", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["9413", "10"], "-", 
        RowBox[{"669", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4193", "10"]}], "-", 
          FractionBox[
           RowBox[{"17921", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"55575610", "+", 
           FractionBox[
            RowBox[{"267697073", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4193", "10"]}], "-", 
          FractionBox[
           RowBox[{"17921", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"55575610", "+", 
           FractionBox[
            RowBox[{"267697073", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8314", "5"], "+", 
        FractionBox[
         RowBox[{"2329", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8139", "5"], "-", 
        FractionBox[
         RowBox[{"38353", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["16453", "10"]}], "+", 
          FractionBox[
           RowBox[{"9006", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"254508361", "-", 
           RowBox[{"148064520", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["16453", "10"]}], "+", 
          FractionBox[
           RowBox[{"9006", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"254508361", "-", 
           RowBox[{"148064520", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["29387", "10"], "+", 
        FractionBox[
         RowBox[{"233", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2569", "10"], "+", 
        FractionBox[
         RowBox[{"7821", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7989", "5"]}], "-", 
          FractionBox[
           RowBox[{"4027", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["192806149", "2"], "+", 
           RowBox[{"95862391", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7989", "5"]}], "-", 
          FractionBox[
           RowBox[{"4027", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["192806149", "2"], "+", 
           RowBox[{"95862391", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["26973", "10"], "+", 
        FractionBox[
         RowBox[{"24863", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["21067", "10"]}], "+", 
        FractionBox[
         RowBox[{"6047", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2953", "10"]}], "-", 
          FractionBox[
           RowBox[{"3091", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "168831815"}], "-", 
           FractionBox[
            RowBox[{"72652873", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2953", "10"]}], "-", 
          FractionBox[
           RowBox[{"3091", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "168831815"}], "-", 
           FractionBox[
            RowBox[{"72652873", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"657", "-", 
        RowBox[{"1993", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4473", "5"]}], "-", 
        FractionBox[
         RowBox[{"13", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["594", "5"], "+", 
          FractionBox[
           RowBox[{"4989", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75432838"}], "+", 
           FractionBox[
            RowBox[{"97115823", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["594", "5"], "+", 
          FractionBox[
           RowBox[{"4989", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "75432838"}], "+", 
           FractionBox[
            RowBox[{"97115823", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8031", "10"], "+", 
        FractionBox[
         RowBox[{"35413", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["25771", "10"]}], "-", 
        FractionBox[
         RowBox[{"4357", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"887", "-", 
          FractionBox[
           RowBox[{"7764", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "10321591"}], "-", 
           FractionBox[
            RowBox[{"482401745", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"887", "-", 
          FractionBox[
           RowBox[{"7764", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "10321591"}], "-", 
           FractionBox[
            RowBox[{"482401745", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1081", "2"]}], "+", 
        RowBox[{"1343", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4773", "10"], "-", 
        FractionBox[
         RowBox[{"4606", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["158", "5"], "-", 
          FractionBox[
           RowBox[{"2109", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"22252855", "+", 
           RowBox[{"349887458", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["158", "5"], "-", 
          FractionBox[
           RowBox[{"2109", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"22252855", "+", 
           RowBox[{"349887458", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["18127", "10"]}], "+", 
        FractionBox[
         RowBox[{"5271", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["18099", "10"], "+", 
        FractionBox[
         RowBox[{"22413", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["7", "5"], "-", 
          FractionBox[
           RowBox[{"12192", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["37536093", "5"]}], "+", 
          FractionBox[
           RowBox[{"21143442", " ", "\[ImaginaryI]"}], "5"]}]]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["7", "5"], "-", 
          FractionBox[
           RowBox[{"12192", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["37536093", "5"]}], "+", 
          FractionBox[
           RowBox[{"21143442", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10474", "5"]}], "+", 
        FractionBox[
         RowBox[{"28901", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["938", "5"], "-", 
        FractionBox[
         RowBox[{"3913", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4768", "5"], "-", 
          FractionBox[
           RowBox[{"2334", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"578754689", "+", 
           RowBox[{"779254842", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4768", "5"], "-", 
          FractionBox[
           RowBox[{"2334", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"578754689", "+", 
           RowBox[{"779254842", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["17333", "10"]}], "-", 
        FractionBox[
         RowBox[{"17623", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["6391", "2"], "-", 
        FractionBox[
         RowBox[{"5885", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7311", "10"]}], "+", 
          FractionBox[
           RowBox[{"11762", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["294069451", "2"]}], "-", 
           RowBox[{"148240756", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7311", "10"]}], "+", 
          FractionBox[
           RowBox[{"11762", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["294069451", "2"]}], "-", 
           RowBox[{"148240756", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4243", "5"]}], "+", 
        FractionBox[
         RowBox[{"4171", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"3265", "-", 
        FractionBox[
         RowBox[{"1452", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["6041", "5"]}], "-", 
          FractionBox[
           RowBox[{"2719", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "60197535"}], "+", 
           FractionBox[
            RowBox[{"144149719", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["6041", "5"]}], "-", 
          FractionBox[
           RowBox[{"2719", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "60197535"}], "+", 
           FractionBox[
            RowBox[{"144149719", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["13659", "10"], "+", 
        RowBox[{"239", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["19409", "10"], "+", 
        FractionBox[
         RowBox[{"22328", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8267", "5"]}], "-", 
          FractionBox[
           RowBox[{"23523", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"83296424", "+", 
           FractionBox[
            RowBox[{"319673753", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8267", "5"]}], "-", 
          FractionBox[
           RowBox[{"23523", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"83296424", "+", 
           FractionBox[
            RowBox[{"319673753", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["15744", "5"], "-", 
        FractionBox[
         RowBox[{"29509", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"1517", "+", 
        FractionBox[
         RowBox[{"3639", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["23329", "10"]}], "+", 
          FractionBox[
           RowBox[{"2587", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"143484465", "-", 
           FractionBox[
            RowBox[{"165888729", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["23329", "10"]}], "+", 
          FractionBox[
           RowBox[{"2587", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"143484465", "-", 
           FractionBox[
            RowBox[{"165888729", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10959", "5"]}], "-", 
        FractionBox[
         RowBox[{"4537", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1859", "5"]}], "-", 
        FractionBox[
         RowBox[{"2953", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6409", "5"], "+", 
          FractionBox[
           RowBox[{"12819", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["7133993", "2"], "+", 
           RowBox[{"36567560", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6409", "5"], "+", 
          FractionBox[
           RowBox[{"12819", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["7133993", "2"], "+", 
           RowBox[{"36567560", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9957", "10"]}], "-", 
        FractionBox[
         RowBox[{"684", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1457", "2"], "-", 
        FractionBox[
         RowBox[{"1389", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["668", "5"], "+", 
          FractionBox[
           RowBox[{"2073", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"294088551", "+", 
           RowBox[{"743026666", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["668", "5"], "+", 
          FractionBox[
           RowBox[{"2073", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"294088551", "+", 
           RowBox[{"743026666", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["18413", "10"], "+", 
        FractionBox[
         RowBox[{"23227", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7391", "10"]}], "-", 
        FractionBox[
         RowBox[{"803", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["5511", "10"]}], "-", 
          FractionBox[
           RowBox[{"5606", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["18573379", "2"], "-", 
           FractionBox[
            RowBox[{"103583289", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["5511", "10"]}], "-", 
          FractionBox[
           RowBox[{"5606", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["18573379", "2"], "-", 
           FractionBox[
            RowBox[{"103583289", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["15551", "10"], "-", 
        FractionBox[
         RowBox[{"5727", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2113", "10"], "-", 
        FractionBox[
         RowBox[{"6847", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4416", "5"]}], "+", 
          FractionBox[
           RowBox[{"19981", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["91128147", "2"], "+", 
           RowBox[{"11158211", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4416", "5"]}], "+", 
          FractionBox[
           RowBox[{"19981", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["91128147", "2"], "+", 
           RowBox[{"11158211", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3153", "2"]}], "-", 
        FractionBox[
         RowBox[{"1771", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4375", "2"], "-", 
        FractionBox[
         RowBox[{"36239", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["611", "2"]}], "+", 
          FractionBox[
           RowBox[{"3801", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "809101373"}], "+", 
           RowBox[{"946175090", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["611", "2"]}], "+", 
          FractionBox[
           RowBox[{"3801", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "809101373"}], "+", 
           RowBox[{"946175090", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["21409", "10"]}], "-", 
        FractionBox[
         RowBox[{"4656", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3471", "10"]}], "+", 
        FractionBox[
         RowBox[{"7508", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1244", "-", 
          FractionBox[
           RowBox[{"1426", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"552879183", "-", 
           RowBox[{"533965878", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1244", "-", 
          FractionBox[
           RowBox[{"1426", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"552879183", "-", 
           RowBox[{"533965878", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2959", "10"], "+", 
        FractionBox[
         RowBox[{"4711", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["36309", "10"], "+", 
        FractionBox[
         RowBox[{"2291", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["9817", "5"]}], "-", 
          FractionBox[
           RowBox[{"3501", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["19814659", "2"], "-", 
           FractionBox[
            RowBox[{"321706583", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["9817", "5"]}], "-", 
          FractionBox[
           RowBox[{"3501", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["19814659", "2"], "-", 
           FractionBox[
            RowBox[{"321706583", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "281"}], "-", 
        FractionBox[
         RowBox[{"10077", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2597", "5"]}], "+", 
        FractionBox[
         RowBox[{"15393", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2001", "5"], "-", 
          FractionBox[
           RowBox[{"1329", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["113896337", "2"]}], "-", 
           RowBox[{"33371681", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2001", "5"], "-", 
          FractionBox[
           RowBox[{"1329", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["113896337", "2"]}], "-", 
           RowBox[{"33371681", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["19493", "5"], "+", 
        FractionBox[
         RowBox[{"7375", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2989", "5"]}], "+", 
        FractionBox[
         RowBox[{"4141", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8252", "5"]}], "-", 
          FractionBox[
           RowBox[{"10254", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "71032611"}], "-", 
           RowBox[{"6557511", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8252", "5"]}], "-", 
          FractionBox[
           RowBox[{"10254", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "71032611"}], "-", 
           RowBox[{"6557511", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15872", "5"]}], "-", 
        FractionBox[
         RowBox[{"24216", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4518", "5"]}], "-", 
        FractionBox[
         RowBox[{"24", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2039", "+", 
          RowBox[{"2424", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"25055289", "+", 
           RowBox[{"86574680", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2039", "+", 
          RowBox[{"2424", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"25055289", "+", 
           RowBox[{"86574680", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["13649", "10"]}], "-", 
        FractionBox[
         RowBox[{"16586", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["30267", "10"], "+", 
        FractionBox[
         RowBox[{"7039", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8309", "10"]}], "+", 
          FractionBox[
           RowBox[{"9547", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "182350547"}], "-", 
           RowBox[{"1674865858", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8309", "10"]}], "+", 
          FractionBox[
           RowBox[{"9547", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "182350547"}], "-", 
           RowBox[{"1674865858", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12147", "10"]}], "-", 
        FractionBox[
         RowBox[{"986", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["25033", "10"]}], "-", 
        FractionBox[
         RowBox[{"8951", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1859", "+", 
          FractionBox[
           RowBox[{"9937", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"65783186", "+", 
           FractionBox[
            RowBox[{"274994393", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1859", "+", 
          FractionBox[
           RowBox[{"9937", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"65783186", "+", 
           FractionBox[
            RowBox[{"274994393", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["41903", "10"], "+", 
        FractionBox[
         RowBox[{"10283", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["3921", "10"], "+", 
        FractionBox[
         RowBox[{"7652", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["11456", "5"]}], "-", 
          FractionBox[
           RowBox[{"3587", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["73225891", "2"], "+", 
           FractionBox[
            RowBox[{"117252971", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["11456", "5"]}], "-", 
          FractionBox[
           RowBox[{"3587", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["73225891", "2"], "+", 
           FractionBox[
            RowBox[{"117252971", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["21431", "10"]}], "+", 
        FractionBox[
         RowBox[{"19059", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9501", "10"]}], "+", 
        FractionBox[
         RowBox[{"10137", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["7733", "5"], "-", 
          FractionBox[
           RowBox[{"7299", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "499236931"}], "-", 
           RowBox[{"593065266", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["7733", "5"], "-", 
          FractionBox[
           RowBox[{"7299", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "499236931"}], "-", 
           RowBox[{"593065266", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1286", "5"], "+", 
        FractionBox[
         RowBox[{"4902", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5327", "5"], "+", 
        FractionBox[
         RowBox[{"14116", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["6613", "10"]}], "-", 
          FractionBox[
           RowBox[{"9509", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "19289482"}], "+", 
           FractionBox[
            RowBox[{"145998643", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["6613", "10"]}], "-", 
          FractionBox[
           RowBox[{"9509", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "19289482"}], "+", 
           FractionBox[
            RowBox[{"145998643", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["21283", "10"]}], "-", 
        FractionBox[
         RowBox[{"281", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["24857", "10"]}], "+", 
        FractionBox[
         RowBox[{"19824", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2307", "-", 
          FractionBox[
           RowBox[{"19543", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"92510530", "-", 
           FractionBox[
            RowBox[{"384594317", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2307", "-", 
          FractionBox[
           RowBox[{"19543", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"92510530", "-", 
           FractionBox[
            RowBox[{"384594317", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["22069", "10"]}], "+", 
        RowBox[{"761", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5291", "2"], "-", 
        FractionBox[
         RowBox[{"10272", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2193", "10"]}], "+", 
          FractionBox[
           RowBox[{"6467", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254298876"}], "+", 
           FractionBox[
            RowBox[{"285334573", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2193", "10"]}], "+", 
          FractionBox[
           RowBox[{"6467", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254298876"}], "+", 
           FractionBox[
            RowBox[{"285334573", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12443", "10"]}], "+", 
        FractionBox[
         RowBox[{"2318", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["30359", "10"], "-", 
        FractionBox[
         RowBox[{"7052", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4479", "5"]}], "+", 
          FractionBox[
           RowBox[{"2367", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "110693392"}], "-", 
           RowBox[{"147524426", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4479", "5"]}], "+", 
          FractionBox[
           RowBox[{"2367", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "110693392"}], "-", 
           RowBox[{"147524426", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "227"}], "-", 
        FractionBox[
         RowBox[{"25373", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15108", "5"]}], "+", 
        FractionBox[
         RowBox[{"3729", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["16243", "10"], "+", 
          FractionBox[
           RowBox[{"5411", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"30138822", "+", 
           FractionBox[
            RowBox[{"434009279", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["16243", "10"], "+", 
          FractionBox[
           RowBox[{"5411", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"30138822", "+", 
           FractionBox[
            RowBox[{"434009279", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["21953", "10"], "-", 
        FractionBox[
         RowBox[{"9673", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7217", "10"]}], "+", 
        FractionBox[
         RowBox[{"9091", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3684", "5"]}], "+", 
          FractionBox[
           RowBox[{"291", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"135833912", "+", 
           RowBox[{"3876041", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3684", "5"]}], "+", 
          FractionBox[
           RowBox[{"291", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"135833912", "+", 
           RowBox[{"3876041", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1794"}], "-", 
        FractionBox[
         RowBox[{"3649", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3879", "5"]}], "-", 
        RowBox[{"3154", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["12849", "10"], "+", 
          FractionBox[
           RowBox[{"19419", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "37030825"}], "+", 
           RowBox[{"848788116", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["12849", "10"], "+", 
          FractionBox[
           RowBox[{"19419", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "37030825"}], "+", 
           RowBox[{"848788116", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9289", "10"]}], "+", 
        FractionBox[
         RowBox[{"19718", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1563", "2"], "+", 
        FractionBox[
         RowBox[{"1163", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["737", "10"], "-", 
          FractionBox[
           RowBox[{"20881", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "157101823"}], "+", 
           RowBox[{"254227540", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["737", "10"], "-", 
          FractionBox[
           RowBox[{"20881", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "157101823"}], "+", 
           RowBox[{"254227540", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["11277", "5"], "-", 
        FractionBox[
         RowBox[{"13779", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1410"}], "-", 
        FractionBox[
         RowBox[{"2601", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4227", "10"]}], "+", 
          FractionBox[
           RowBox[{"6696", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["228306375", "2"]}], "+", 
           FractionBox[
            RowBox[{"132779321", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4227", "10"]}], "+", 
          FractionBox[
           RowBox[{"6696", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["228306375", "2"]}], "+", 
           FractionBox[
            RowBox[{"132779321", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8179", "10"]}], "+", 
        FractionBox[
         RowBox[{"25837", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5427", "10"]}], "+", 
        FractionBox[
         RowBox[{"12723", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6803", "10"], "-", 
          RowBox[{"1928", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "485134359"}], "-", 
           RowBox[{"248246696", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6803", "10"], "-", 
          RowBox[{"1928", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "485134359"}], "-", 
           RowBox[{"248246696", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7531", "10"]}], "+", 
        FractionBox[
         RowBox[{"4121", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15321", "10"]}], "-", 
        FractionBox[
         RowBox[{"15393", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["5713", "5"], "+", 
          FractionBox[
           RowBox[{"5636", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        SqrtBox[
         RowBox[{
          FractionBox["35520301", "10"], "-", 
          FractionBox[
           RowBox[{"18736626", " ", "\[ImaginaryI]"}], "5"]}]]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["5713", "5"], "+", 
          FractionBox[
           RowBox[{"5636", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        SqrtBox[
         RowBox[{
          FractionBox["35520301", "10"], "-", 
          FractionBox[
           RowBox[{"18736626", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5213", "5"], "+", 
        FractionBox[
         RowBox[{"451", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10901", "5"]}], "-", 
        FractionBox[
         RowBox[{"4637", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2844", "5"], "+", 
          FractionBox[
           RowBox[{"2093", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "78344673"}], "-", 
           RowBox[{"103670712", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2844", "5"], "+", 
          FractionBox[
           RowBox[{"2093", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "78344673"}], "-", 
           RowBox[{"103670712", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["20077", "10"]}], "-", 
        FractionBox[
         RowBox[{"23399", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["16457", "10"]}], "-", 
        FractionBox[
         RowBox[{"14801", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["18267", "10"], "+", 
          RowBox[{"1910", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["26271843", "2"], "+", 
           FractionBox[
            RowBox[{"385194915", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["18267", "10"], "+", 
          RowBox[{"1910", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["26271843", "2"], "+", 
           FractionBox[
            RowBox[{"385194915", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["35109", "10"]}], "+", 
        FractionBox[
         RowBox[{"3369", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["947", "2"]}], "-", 
        FractionBox[
         RowBox[{"18233", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["9961", "5"], "+", 
          FractionBox[
           RowBox[{"3716", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "136702803"}], "+", 
           RowBox[{"657170590", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["9961", "5"], "+", 
          FractionBox[
           RowBox[{"3716", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "136702803"}], "+", 
           RowBox[{"657170590", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["40717", "10"]}], "-", 
        FractionBox[
         RowBox[{"17267", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5469", "10"]}], "+", 
        FractionBox[
         RowBox[{"20119", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["23093", "10"], "-", 
          FractionBox[
           RowBox[{"713", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["285338023", "2"], "-", 
           RowBox[{"68688075", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["23093", "10"], "-", 
          FractionBox[
           RowBox[{"713", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["285338023", "2"], "-", 
           RowBox[{"68688075", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["304", "5"]}], "-", 
        RowBox[{"1795", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10049", "5"]}], "+", 
        FractionBox[
         RowBox[{"6781", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["10353", "10"], "+", 
          FractionBox[
           RowBox[{"1097", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"62474149", "+", 
           FractionBox[
            RowBox[{"171720235", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["10353", "10"], "+", 
          FractionBox[
           RowBox[{"1097", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"62474149", "+", 
           FractionBox[
            RowBox[{"171720235", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2279", "10"]}], "+", 
        FractionBox[
         RowBox[{"4453", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8137", "2"], "-", 
        FractionBox[
         RowBox[{"5772", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["19203", "10"]}], "+", 
          FractionBox[
           RowBox[{"1319", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"456226229", "-", 
           RowBox[{"37988232", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["19203", "10"]}], "+", 
          FractionBox[
           RowBox[{"1319", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"456226229", "-", 
           RowBox[{"37988232", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10254", "5"], "-", 
        FractionBox[
         RowBox[{"1028", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "503"}], "-", 
        RowBox[{"1528", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7739", "10"]}], "+", 
          FractionBox[
           RowBox[{"4334", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"23435911", "-", 
           RowBox[{"586998520", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7739", "10"]}], "+", 
          FractionBox[
           RowBox[{"4334", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"23435911", "-", 
           RowBox[{"586998520", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5196", "5"], "+", 
        FractionBox[
         RowBox[{"2062", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12131", "5"]}], "+", 
        FractionBox[
         RowBox[{"15716", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1387", "2"], "-", 
          FractionBox[
           RowBox[{"8889", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "109185372"}], "+", 
           FractionBox[
            RowBox[{"19958723", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1387", "2"], "-", 
          FractionBox[
           RowBox[{"8889", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "109185372"}], "+", 
           FractionBox[
            RowBox[{"19958723", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9991", "5"]}], "+", 
        FractionBox[
         RowBox[{"1969", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"1598", "-", 
        FractionBox[
         RowBox[{"33019", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2001", "10"], "+", 
          FractionBox[
           RowBox[{"11587", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["641527", "2"], "+", 
           FractionBox[
            RowBox[{"233144739", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2001", "10"], "+", 
          FractionBox[
           RowBox[{"11587", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["641527", "2"], "+", 
           FractionBox[
            RowBox[{"233144739", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["17279", "10"], "+", 
        FractionBox[
         RowBox[{"5213", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["22861", "10"]}], "-", 
        RowBox[{"618", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2791", "10"], "-", 
          FractionBox[
           RowBox[{"2123", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"37796341", "-", 
           RowBox[{"320398254", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2791", "10"], "-", 
          FractionBox[
           RowBox[{"2123", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"37796341", "-", 
           RowBox[{"320398254", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["23809", "10"]}], "+", 
        FractionBox[
         RowBox[{"23817", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["561", "2"]}], "-", 
        FractionBox[
         RowBox[{"651", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["13307", "10"], "-", 
          FractionBox[
           RowBox[{"11583", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"90077706", "-", 
           RowBox[{"84434248", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["13307", "10"], "-", 
          FractionBox[
           RowBox[{"11583", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"90077706", "-", 
           RowBox[{"84434248", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7441", "5"], "-", 
        RowBox[{"1482", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5468", "5"]}], "-", 
        FractionBox[
         RowBox[{"11991", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1973", "10"]}], "+", 
          FractionBox[
           RowBox[{"19401", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["128302797", "5"]}], "+", 
           FractionBox[
            RowBox[{"82525644", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1973", "10"]}], "+", 
          FractionBox[
           RowBox[{"19401", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["128302797", "5"]}], "+", 
           FractionBox[
            RowBox[{"82525644", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10659", "5"], "+", 
        FractionBox[
         RowBox[{"12999", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4976", "5"]}], "-", 
        FractionBox[
         RowBox[{"9137", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["5683", "10"]}], "-", 
          FractionBox[
           RowBox[{"1931", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "299534793"}], "-", 
           RowBox[{"284978462", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["5683", "10"]}], "-", 
          FractionBox[
           RowBox[{"1931", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "299534793"}], "-", 
           RowBox[{"284978462", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["11263", "5"], "-", 
        FractionBox[
         RowBox[{"15227", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8332", "5"], "+", 
        FractionBox[
         RowBox[{"3773", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3919", "2"]}], "+", 
          FractionBox[
           RowBox[{"5727", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"321198585", "+", 
           RowBox[{"192796224", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3919", "2"]}], "+", 
          FractionBox[
           RowBox[{"5727", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"321198585", "+", 
           RowBox[{"192796224", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["31651", "10"], "-", 
        FractionBox[
         RowBox[{"20921", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["175", "2"]}], "-", 
        FractionBox[
         RowBox[{"22073", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7694", "5"]}], "+", 
          FractionBox[
           RowBox[{"21497", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["57726087", "2"]}], "-", 
           RowBox[{"208594622", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7694", "5"]}], "+", 
          FractionBox[
           RowBox[{"21497", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["57726087", "2"]}], "-", 
           RowBox[{"208594622", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5767", "2"]}], "+", 
        FractionBox[
         RowBox[{"4161", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2693", "10"]}], "-", 
        RowBox[{"4139", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["7882", "5"], "+", 
          FractionBox[
           RowBox[{"8267", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "34034597"}], "+", 
           RowBox[{"1646453378", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["7882", "5"], "+", 
          FractionBox[
           RowBox[{"8267", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "34034597"}], "+", 
           RowBox[{"1646453378", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["25181", "10"]}], "+", 
        FractionBox[
         RowBox[{"5855", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["13221", "10"], "+", 
        FractionBox[
         RowBox[{"20129", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"598", "-", 
          FractionBox[
           RowBox[{"12351", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1288659257"}], "-", 
           RowBox[{"725247274", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"598", "-", 
          FractionBox[
           RowBox[{"12351", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1288659257"}], "-", 
           RowBox[{"725247274", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7726", "5"], "-", 
        FractionBox[
         RowBox[{"2898", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9833", "5"]}], "-", 
        FractionBox[
         RowBox[{"20813", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2107", "10"], "+", 
          FractionBox[
           RowBox[{"23711", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "185392592"}], "-", 
           FractionBox[
            RowBox[{"314238617", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2107", "10"], "+", 
          FractionBox[
           RowBox[{"23711", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "185392592"}], "-", 
           FractionBox[
            RowBox[{"314238617", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619251667731608*^9, 3.6192530358732567`*^9, 
  3.619253808214054*^9, 3.619259226480626*^9, 3.619259694413026*^9, 
  3.619343630253477*^9}]
}, Open  ]],

Cell["Now choose random polarizations:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}, {3.619235593173221*^9, 3.619235598976385*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi1", "=", 
   RowBox[{"{", 
    RowBox[{"xix1", ",", "xix2", ",", "xix3", ",", "xix4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043270708568*^9, 3.6040432967635603`*^9}, 
   3.604043499802985*^9, 3.604301554870967*^9, {3.6043021515175753`*^9, 
   3.604302152636281*^9}, {3.612166399986412*^9, 3.612166401456052*^9}, {
   3.615717383769212*^9, 3.61571738455131*^9}, 3.619235607803103*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi2", "=", 
   RowBox[{"{", 
    RowBox[{"xiy1", ",", "xiy2", ",", "xiy3", ",", "xiy4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.6040433084930897`*^9, 
   3.6040433346916733`*^9}, 3.604043502795218*^9, {3.612166409439506*^9, 
   3.612166414318565*^9}, 3.619235609169167*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{"xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9, {3.612166418225318*^9, 
   3.6121664207438507`*^9}, 3.61923561085168*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi4", "=", 
   RowBox[{"{", 
    RowBox[{"xiu1", ",", "xiu2", ",", "xiu3", ",", "xiu4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.6040433145245943`*^9, 
   3.604043314748054*^9}, {3.6040433534274893`*^9, 3.604043369394578*^9}, 
   3.60404350847479*^9, {3.61216642588039*^9, 3.612166429007922*^9}, 
   3.6192356125390587`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et1", "=", 
   RowBox[{"{", 
    RowBox[{"etx1", ",", "etx2", ",", "etx3", ",", "etx4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, {3.6040433875103607`*^9, 3.604043405643474*^9}, 
   3.604043511306425*^9, 3.604301558638516*^9, {3.604302156974309*^9, 
   3.604302158069281*^9}, {3.612166432744034*^9, 3.6121664410321913`*^9}, 
   3.619235615211533*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et2", "=", 
   RowBox[{"{", 
    RowBox[{"ety1", ",", "ety2", ",", "ety3", ",", "ety4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.604043389260811*^9, 
   3.6040434154828787`*^9}, 3.6040435138414288`*^9, {3.61216644492061*^9, 
   3.612166446303801*^9}, 3.6192356168433237`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{"etz1", ",", "etz2", ",", "etz3", ",", "etz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9, {3.612166449248323*^9, 
   3.6121664509560738`*^9}, 3.619235618371313*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et4", "=", 
   RowBox[{"{", 
    RowBox[{"etu1", ",", "etu2", ",", "etu3", ",", "etu4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.604043392149412*^9, 
   3.604043392255167*^9}, {3.6040434286448727`*^9, 3.604043435995811*^9}, 
   3.604043520033565*^9, {3.612166453399662*^9, 3.6121664555841017`*^9}, 
   3.6192356200145407`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "xi1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "et1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "xi2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "et2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "xi4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "et4"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     
     RowBox[{"sols", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.61216653422339*^9, 3.612166556960194*^9}, {
   3.612166600729034*^9, 3.6121666133164167`*^9}, {3.612258455793024*^9, 
   3.612258468175284*^9}, 3.6192356384135313`*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[LongEqual]", "xix2"}]},
      {
       RowBox[{"etx1", "\[LongEqual]", "etx2"}]},
      {
       RowBox[{
        RowBox[{"xiy1", "+", "xiy2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"ety1", "+", "ety2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"xiz1", "+", "xiz4"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"etz1", "+", "etz4"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{"xiu1", "\[LongEqual]", "xiu4"}]},
      {
       RowBox[{"etu1", "\[LongEqual]", "etu4"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166557730864*^9, 3.612166613587278*^9, 3.612257786626362*^9, {
   3.612258449865247*^9, 3.6122584694730263`*^9}, 3.612684401222273*^9, 
   3.6144153037766237`*^9, 3.614416733198262*^9, 3.614506942881184*^9, 
   3.6145770516151667`*^9, 3.614578403574582*^9, 3.6149384370663424`*^9, 
   3.615634998183165*^9, 3.6157168339297047`*^9, 3.61571741922215*^9, 
   3.6157966523647614`*^9, 3.6162158522704887`*^9, 3.6173373519442377`*^9, 
   3.6173395085025463`*^9, 3.618218625975627*^9, 3.619235639546756*^9, 
   3.619242887012747*^9, 3.6192436415076227`*^9, 3.6192530487462673`*^9, 
   3.619343630583494*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "=", 
   RowBox[{
    RowBox[{"FindInstance", "[", 
     RowBox[{"conditions", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
       "xi1", ",", "xi2", ",", "xi3", ",", "xi4", ",", "et1", ",", "et2", ",",
         "et3", ",", "et4"}], "]"}], ",", "2"}], "]"}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.612166575888966*^9, 3.612166576370742*^9}, {3.6121666241502*^9, 
   3.612166629642056*^9}, 3.6122577970426483`*^9, {3.6122584771168823`*^9, 
   3.612258481721101*^9}, 3.615716743846897*^9, {3.619235681872355*^9, 
   3.619235715558448*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.615716687944995*^9, 3.6157166901908703`*^9}, 
   3.615796959672283*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[Rule]", 
        RowBox[{
         FractionBox["19", "5"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{"xix2", "\[Rule]", 
        RowBox[{
         FractionBox["19", "5"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{"xix3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xix4", "\[Rule]", 
        RowBox[{
         FractionBox["1", "5"], "-", 
         FractionBox[
          RowBox[{"15", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiy1", "\[Rule]", 
        RowBox[{"8", "+", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiy2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "8"}], "-", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiy3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["19", "2"]}], "+", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiy4", "\[Rule]", 
        RowBox[{
         FractionBox["27", "5"], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiz1", "\[Rule]", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiz2", "\[Rule]", 
        RowBox[{
         FractionBox["8", "5"], "+", 
         FractionBox[
          RowBox[{"53", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz3", "\[Rule]", 
        RowBox[{"7", "-", 
         FractionBox[
          RowBox[{"39", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu1", "\[Rule]", 
        RowBox[{
         FractionBox["3", "10"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}]}]},
      {
       RowBox[{"xiu2", "\[Rule]", 
        RowBox[{
         FractionBox["13", "2"], "+", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["67", "10"]}], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiu4", "\[Rule]", 
        RowBox[{
         FractionBox["3", "10"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}]}]},
      {
       RowBox[{"etx1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["46", "5"]}], "-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["46", "5"]}], "-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx3", "\[Rule]", 
        RowBox[{"7", "+", 
         FractionBox[
          RowBox[{"37", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx4", "\[Rule]", 
        RowBox[{
         FractionBox["49", "5"], "-", 
         FractionBox[
          RowBox[{"47", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety1", "\[Rule]", 
        RowBox[{
         FractionBox["51", "10"], "+", 
         FractionBox[
          RowBox[{"19", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["51", "10"]}], "-", 
         FractionBox[
          RowBox[{"19", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["57", "10"]}], "-", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["15", "2"]}], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etz1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["13", "5"]}], "-", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etz2", "\[Rule]", 
        RowBox[{
         FractionBox["79", "10"], "+", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["19", "2"]}], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz4", "\[Rule]", 
        RowBox[{
         FractionBox["13", "5"], "+", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etu1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["11", "5"]}], "+", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], "+", 
         RowBox[{"5", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu3", "\[Rule]", 
        RowBox[{
         FractionBox["19", "2"], "+", 
         FractionBox[
          RowBox[{"33", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["11", "5"]}], "+", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]"}], "5"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.615716686264927*^9, 3.615716690541438*^9}, 
   3.615716837926202*^9, 3.6157969736709547`*^9, 3.616215854088387*^9, 
   3.617337353622591*^9, 3.617339509744925*^9, 3.6182186276162148`*^9, {
   3.6192356917235203`*^9, 3.619235718040629*^9}, 3.619242890133157*^9, 
   3.619243645459914*^9, 3.6192530517234907`*^9, 3.619343630684009*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"leg2k", "[", "l_", "]"}], "=", 
  RowBox[{"Switch", "[", 
   RowBox[{
   "l", ",", "1", ",", "k1", ",", "2", ",", "k2", ",", "3", ",", "k3", ",", 
    "4", ",", "k4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619236521062236*^9, 3.6192365496795073`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Switch", "[", 
   RowBox[{
   "l", ",", "\[IndentingNewLine]", "1", ",", "k1", ",", 
    "\[IndentingNewLine]", "2", ",", "k2", ",", "\[IndentingNewLine]", "3", 
    ",", "k3", ",", "\[IndentingNewLine]", "4", ",", "k4"}], "]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6192365504484243`*^9, 3.6192429019015207`*^9, 
  3.619243648336986*^9, 3.61925305403577*^9, 3.619343630733646*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ind2pols", "[", "i_", "]"}], "=", 
  RowBox[{"Switch", "[", 
   RowBox[{
   "i", ",", "a", ",", "xi1", ",", "b", ",", "et1", ",", "c", ",", "xi2", ",",
     "d", ",", "et2", ",", "e", ",", "xi3", ",", "f", ",", "et3", ",", "g", 
    ",", "xi4", ",", "h", ",", "et4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619236308508829*^9, 3.619236416287768*^9}, {
  3.6192374423377123`*^9, 3.6192374951804256`*^9}, {3.619237584106935*^9, 
  3.619237607040175*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Switch", "[", 
   RowBox[{
   "i", ",", "\[IndentingNewLine]", "a", ",", "xi1", ",", 
    "\[IndentingNewLine]", "b", ",", "et1", ",", "\[IndentingNewLine]", "c", 
    ",", "xi2", ",", "\[IndentingNewLine]", "d", ",", "et2", ",", 
    "\[IndentingNewLine]", "e", ",", "xi3", ",", "\[IndentingNewLine]", "f", 
    ",", "et3", ",", "\[IndentingNewLine]", "g", ",", "xi4", ",", 
    "\[IndentingNewLine]", "h", ",", "et4"}], "]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619236347953261*^9, 3.619236359045373*^9}, 
   3.6192364172726183`*^9, 3.619237449695252*^9, 3.619237495854807*^9, 
   3.619237607542542*^9, 3.6192429044198847`*^9, 3.619243650338719*^9, 
   3.6192530555236893`*^9, 3.619343630779799*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"indices", "=", 
  RowBox[{"{", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
    "h"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619239158604762*^9, 3.619239170171886*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
    "h"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619239171626947*^9, 3.6192429065479813`*^9, 
  3.619243651783976*^9, 3.6192530569798813`*^9, 3.619343630790625*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"leg", ",", 
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind", "]"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{
             RowBox[{"leg2k", "[", "leg", "]"}], ",", 
             RowBox[{"ind2pols", "[", 
              RowBox[{"indices", "[", 
               RowBox[{"[", "ind", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"leg", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ind", ",", "1", ",", "8"}], "}"}]}], "]"}], ")"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"rules1", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619239137912868*^9, 3.619239142802182*^9}, {
  3.619239181944091*^9, 3.619239373739903*^9}, {3.6192394261171017`*^9, 
  3.619239427997581*^9}, {3.619239473148394*^9, 3.619239479671443*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["38", "5"]}], "-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"4", "-", 
         FractionBox[
          RowBox[{"73", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["18", "5"], "+", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["92", "5"], "+", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["3", "5"], "-", 
         FractionBox[
          RowBox[{"59", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "19"}], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "16"}], "-", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["67", "5"], "+", 
         FractionBox[
          RowBox[{"91", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["13", "5"], "+", 
         FractionBox[
          RowBox[{"63", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["51", "5"]}], "-", 
         FractionBox[
          RowBox[{"19", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["12", "5"]}], "+", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["63", "5"], "+", 
         FractionBox[
          RowBox[{"13", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["3", "5"], "+", 
         FractionBox[
          RowBox[{"69", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["13", "5"]}], "-", 
         FractionBox[
          RowBox[{"37", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"2", "-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["21", "2"], "+", 
         FractionBox[
          RowBox[{"13", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["53", "10"]}], "-", 
         FractionBox[
          RowBox[{"47", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["26", "5"]}], "-", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["31", "5"], "+", 
         FractionBox[
          RowBox[{"27", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["34", "5"]}], "-", 
         FractionBox[
          RowBox[{"37", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["3", "5"], "+", "\[ImaginaryI]"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["21", "10"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["23", "10"], "-", 
         FractionBox[
          RowBox[{"49", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["22", "5"]}], "+", 
         FractionBox[
          RowBox[{"48", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.61923921283426*^9, 3.6192392238744507`*^9}, {
   3.619239296819813*^9, 3.6192393414974527`*^9}, 3.619239373991585*^9, 
   3.619239428356347*^9, 3.619239480439577*^9, 3.619242908197208*^9, 
   3.619243653772341*^9, 3.619253058148912*^9, 3.6193436308378563`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k3", ",", "et4"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239396112124*^9, 3.619239462797274*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["22", "5"]}], "+", 
   FractionBox[
    RowBox[{"48", " ", "\[ImaginaryI]"}], "5"]}], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.6192394091672373`*^9, 3.6192394630970716`*^9}, 
   3.6192429108792257`*^9, 3.619243657538933*^9, 3.61925306056183*^9, 
   3.619343630892432*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{
              RowBox[{"indices", "[", 
               RowBox[{"[", "ind", "]"}], "]"}], ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", " ", 
          RowBox[{"min", "[", 
           RowBox[{"qq", ",", 
            RowBox[{"ind2pols", "[", 
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ind", ",", "1", ",", "8"}], "}"}]}], "]"}], ")"}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"sols", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"sols$pol", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"solsQ", "[", 
         RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"rules2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619239498168215*^9, 3.61923950278657*^9}, {
  3.619239533212517*^9, 3.619239653462655*^9}, {3.619246060578376*^9, 
  3.619246065085746*^9}, {3.6192460967103662`*^9, 3.619246105142829*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          TagBox[
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
           Function[BoxForm`e$, 
            TableForm[BoxForm`e$]]],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 631, 23719710895012768101, 
            5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 631, 23719710895012768101, 
            5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 631, 23719710895012768101, 
            Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[631]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619239655223105*^9, 3.619242912013666*^9, 
  3.619243658775285*^9, 3.619246111099959*^9, 3.619246943666779*^9, 
  3.619247189962232*^9, 3.619247409699597*^9, 3.61925020872122*^9, 
  3.6192530627606363`*^9, 3.619253819672687*^9, 3.619259231805781*^9, 
  3.619259714922319*^9, 3.6192597910059633`*^9, 3.6193436333112383`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"qq", ",", "et2"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"solsQ", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239664221813*^9, 3.6192396792379*^9}, {
  3.619253086407671*^9, 3.6192530905073223`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["696396", "25"], "+", 
     FractionBox[
      RowBox[{"792753", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["3", "2"], "+", 
      FractionBox[
       RowBox[{"7", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "25976313"}], "+", 
      FractionBox[
       RowBox[{"330511929", " ", "\[ImaginaryI]"}], "2"]}]]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619239666472765*^9, 3.619239679962988*^9}, 
   3.619242914306307*^9, 3.6192436608671427`*^9, {3.619253066756884*^9, 
   3.619253090890196*^9}, 3.6192592368026037`*^9, 3.6193436335131197`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules3", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind1", "]"}], "]"}], ",", "D"}], "]"}], ",", 
           RowBox[{"LorentzIndex", "[", 
            RowBox[{
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind2", "]"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
         "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"ind2pols", "[", 
            RowBox[{"indices", "[", 
             RowBox[{"[", "ind1", "]"}], "]"}], "]"}], ",", 
           RowBox[{"ind2pols", "[", 
            RowBox[{"indices", "[", 
             RowBox[{"[", "ind2", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ind2", ",", 
          RowBox[{"ind1", "+", "1"}], ",", "8"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ind1", ",", "1", ",", "8"}], "}"}]}], "]"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"sols$pol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239941847797*^9, 3.6192399886826353`*^9}, 
   3.619240025873451*^9, {3.61924005782653*^9, 3.6192400996716957`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "b"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["7017", "100"]}], "-", 
      FractionBox[
       RowBox[{"2391", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["551", "50"]}], "-", 
      FractionBox[
       RowBox[{"6147", " ", "\[ImaginaryI]"}], "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "d"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1271", "100"]}], "+", 
      FractionBox[
       RowBox[{"6359", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["531", "50"]}], "+", 
      FractionBox[
       RowBox[{"1454", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "f"}]], "\[Rule]", 
     RowBox[{
      FractionBox["8339", "100"], "-", 
      FractionBox[
       RowBox[{"138", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["5399", "100"], "+", 
      FractionBox[
       RowBox[{"251", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["121", "50"]}], "+", 
      FractionBox[
       RowBox[{"91", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "c"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2599", "25"], "+", 
      FractionBox[
       RowBox[{"2393", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2957", "100"], "-", 
      FractionBox[
       RowBox[{"2049", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "e"}]], "\[Rule]", 
     RowBox[{
      FractionBox["3917", "50"], "-", 
      FractionBox[
       RowBox[{"483", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2571", "20"]}], "-", 
      FractionBox[
       RowBox[{"1433", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["9319", "100"]}], "-", 
      FractionBox[
       RowBox[{"8047", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["21", "50"]}], "+", 
      FractionBox[
       RowBox[{"4238", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "d"}]], "\[Rule]", 
     RowBox[{
      FractionBox["3311", "100"], "+", 
      FractionBox[
       RowBox[{"4519", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["5709", "100"]}], "+", 
      FractionBox[
       RowBox[{"1147", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "f"}]], "\[Rule]", 
     RowBox[{
      FractionBox["4793", "50"], "-", 
      FractionBox[
       RowBox[{"9651", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1969", "50"], "-", 
      FractionBox[
       RowBox[{"9207", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["3083", "100"]}], "-", 
      FractionBox[
       RowBox[{"311", " ", "\[ImaginaryI]"}], "4"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["3377", "50"]}], "-", 
      FractionBox[
       RowBox[{"3339", " ", "\[ImaginaryI]"}], "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1013", "50"], "+", 
      FractionBox[
       RowBox[{"1413", " ", "\[ImaginaryI]"}], "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["633", "100"], "+", 
      FractionBox[
       RowBox[{"351", " ", "\[ImaginaryI]"}], "20"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "h"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1172", "25"], "-", 
      FractionBox[
       RowBox[{"4771", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["4099", "50"]}], "+", 
      FractionBox[
       RowBox[{"2267", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["5683", "100"]}], "+", 
      FractionBox[
       RowBox[{"1589", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "h"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2731", "50"], "-", 
      FractionBox["\[ImaginaryI]", "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"f", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["4893", "50"], "+", 
      FractionBox[
       RowBox[{"6499", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"f", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["3544", "25"]}], "+", 
      FractionBox[
       RowBox[{"26", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"g", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1958", "25"]}], "-", 
      FractionBox[
       RowBox[{"1489", " ", "\[ImaginaryI]"}], "100"]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.61924010032931*^9, 3.619242915317422*^9, 
  3.619243662861741*^9, 3.619247195513521*^9, 3.61925310552606*^9, 
  3.619343633581479*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"xi1", ",", "et2"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61924014756181*^9, 3.619240162565056*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1271", "100"]}], "+", 
   FractionBox[
    RowBox[{"6359", " ", "\[ImaginaryI]"}], "100"]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619240158523693*^9, 3.619240163202877*^9}, 
   3.61924291753172*^9, 3.61924366653813*^9, 3.619253108251897*^9, 
   3.61934363362945*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$num", "=", 
  RowBox[{"N", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"amp4$qlightcone2", "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"rules0", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], ",", "rules1", ",", 
        RowBox[{"rules2", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], ",", "rules3"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.619174090652886*^9, 3.6191740932519493`*^9}, {
   3.6191741401679697`*^9, 3.6191741406610947`*^9}, {3.61923575463708*^9, 
   3.6192357570857067`*^9}, {3.619236448618927*^9, 3.619236504574319*^9}, {
   3.619236563719427*^9, 3.619236567088612*^9}, {3.619236864755721*^9, 
   3.619236867380209*^9}, {3.61923695240946*^9, 3.619236981307167*^9}, {
   3.6192370158471622`*^9, 3.6192370436549377`*^9}, {3.619237081637163*^9, 
   3.6192370857360153`*^9}, {3.619237181822341*^9, 3.619237222082407*^9}, 
   3.619237292907866*^9, {3.6192377416628027`*^9, 3.619237776673604*^9}, {
   3.619237877858811*^9, 3.619238191513442*^9}, {3.619238234861478*^9, 
   3.61923835670647*^9}, {3.619240181475733*^9, 3.619240188813858*^9}, {
   3.6192461927732477`*^9, 3.6192462234944773`*^9}, {3.619246283517706*^9, 
   3.6192462902520113`*^9}, 3.619246408486841*^9, {3.619246958317753*^9, 
   3.61924696063234*^9}, {3.619247426612483*^9, 3.619247427423375*^9}, 
   3.619259918646023*^9}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1.797120214937119`*^7", "+", 
                RowBox[{"981200.1207617493`", " ", "\[ImaginaryI]"}]}], ")"}],
               " ", "a1"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2.6197715003099274`*^7", "-", 
                RowBox[{"877332.1270018369`", " ", "\[ImaginaryI]"}]}], ")"}],
               " ", "a2"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1.7733697692196093`*^7", "-", 
                RowBox[{"1.1726481673418082`*^7", " ", "\[ImaginaryI]"}]}], 
               ")"}], " ", "a3"}], "+", 
             RowBox[{"\[LeftSkeleton]", "25", "\[RightSkeleton]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3.333397109930266`*^7", "-", 
                RowBox[{"6.826559324130945`*^7", " ", "\[ImaginaryI]"}]}], 
               ")"}], " ", "ii"}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3.89708504248637`*^6", "-", 
                RowBox[{"1.279552166703696`*^7", " ", "\[ImaginaryI]"}]}], 
               ")"}], " ", "\[Lambda]"}]}], ",", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ",", 
            RowBox[{"\[LeftSkeleton]", "96", "\[RightSkeleton]"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1.797120214937119`*^7", "+", 
                RowBox[{
                 RowBox[{"\[LeftSkeleton]", "18", "\[RightSkeleton]"}], " ", 
                 "\[ImaginaryI]"}]}], ")"}], " ", "a1"}], "+", 
             RowBox[{"\[LeftSkeleton]", "29", "\[RightSkeleton]"}]}], ",", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], "}"}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 635, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 635, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 635, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[635]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619236713396962*^9, 3.619236880539884*^9, 3.619237000579589*^9, 
   3.619237048379258*^9, 3.61923709189137*^9, 3.6192372281109953`*^9, 
   3.6192372963930597`*^9, 3.619237786267847*^9, {3.619237908284073*^9, 
   3.619238012603725*^9}, 3.61923807139123*^9, 3.619238141755127*^9, 
   3.619238228754908*^9, 3.619238263802507*^9, {3.619238301836074*^9, 
   3.619238359174882*^9}, 3.6192401896951847`*^9, 3.6192429198033333`*^9, 
   3.619243668751142*^9, 3.61924623881572*^9, {3.61924640579837*^9, 
   3.619246412663979*^9}, 3.6192469862046127`*^9, 3.6192472491922073`*^9, 
   3.6192474671861477`*^9, 3.619250329849607*^9, 3.619253124165639*^9, 
   3.6192544141567593`*^9, 3.619259600225254*^9, 3.619259870585545*^9, 
   3.619259916232139*^9, 3.61925997003017*^9, 3.619343683831526*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$num", "[", 
  RowBox[{"[", "10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.619246246845746*^9, 3.619246247318962*^9}, {
  3.619246445896468*^9, 3.619246449407371*^9}, {3.61924699790209*^9, 
  3.61924700749713*^9}, {3.6192472050257587`*^9, 3.619247205197611*^9}, {
  3.6192474889175587`*^9, 3.619247495105204*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"301564.3008025042`", "\[VeryThinSpace]", "-", 
      RowBox[{"552787.6465217145`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b11"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"73018.52803221345`", "\[VeryThinSpace]", "+", 
      RowBox[{"1.0482543034295212`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b7"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.797120214937119`*^7", "+", 
      RowBox[{"981200.1207617493`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.348349674148161`*^6", "+", 
      RowBox[{"1.90391992858754`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a2"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.1156676367550194`*^6", "+", 
      RowBox[{"8.945229617828706`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a3"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.2365389177169204`*^6", "+", 
      RowBox[{"224437.144927131`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.7541525334655046`*^6", "-", 
      RowBox[{"1.4621279875555297`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b10"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7.43862054221677`*^6", "-", 
      RowBox[{"2.2718368439101703`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b4"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.520663807979312`*^6", "-", 
      RowBox[{"1.2661907283730932`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b8"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.856934071025507`*^7", "+", 
      RowBox[{"1.5300931320016645`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.6586220303300396`*^6", "-", 
      RowBox[{"6.940387083274059`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c2"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.302355758987235`*^6", "-", 
      RowBox[{"3.9874171444925174`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c3"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.3082046328333946`*^7", "+", 
      RowBox[{"468297.4124957118`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c4"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4.555173223366084`*^7", "+", 
      RowBox[{"7.47621691437012`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c5"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"8.86362430300998`*^6", "+", 
      RowBox[{"1.4758569444648065`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c6"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.345611665372184`*^6", "-", 
      RowBox[{"6.819922063203526`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "e3"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.3333909258945052`*^7", "+", 
      RowBox[{"3.765867002127607`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "f1"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.6613378046484292`*^7", "+", 
      RowBox[{"3.3438259122835904`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "g1"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.2318355214042842`*^7", "+", 
      RowBox[{"1.9428202157213733`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "g2"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.72131378948395`*^8", "-", 
      RowBox[{"1.1458382277943747`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "ii"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.89708504248637`*^6", "-", 
      RowBox[{"1.279552166703696`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "\[Lambda]"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619246247927534*^9, {3.619246431180839*^9, 3.619246449750126*^9}, {
   3.619246999551182*^9, 3.6192470082780323`*^9}, 3.619247249301611*^9, {
   3.619247474848068*^9, 3.6192474954243193`*^9}, 3.619253143481003*^9, 
   3.619254507782629*^9, 3.619343684071299*^9}]
}, Open  ]],

Cell[TextData[{
 "Compare this to the numerically evaluated original ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "4"], TraditionalForm]]],
 "-amplitude:"
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.619174112444458*^9, {3.619242955678088*^9, 
   3.619242977714387*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4num", "=", 
  RowBox[{"amp4", "/.", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"rules0", "[", 
      RowBox[{"[", "9", "]"}], "]"}], ",", "rules1", ",", "rules3"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.619243050186409*^9, 3.6192431000563173`*^9}, {
  3.6192467286478443`*^9, 3.6192467330975037`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["388899869243533", "200000000"]}], "-", 
   FractionBox[
    RowBox[{"392690892808709", " ", "\[ImaginaryI]"}], "200000000"]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619243053214594*^9, 3.61924310115626*^9}, 
   3.619243677202939*^9, {3.619246729606061*^9, 3.619246733653371*^9}, 
   3.619247012573942*^9, 3.619247502133204*^9, 3.619250329939883*^9, 
   3.6192531477574863`*^9, 3.61925451665207*^9, 3.61934368413831*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"amp4$qlightcone2$num", "[", 
       RowBox[{"[", "iq", "]"}], "]"}], "\[Equal]", "amp4num"}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.619250913836196*^9, 3.619250917128471*^9}, {
  3.619250966223983*^9, 3.619250966383337*^9}, {3.619253158121739*^9, 
  3.6192531625368967`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"res", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{"N", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"amp4$qlightcone2$num", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], "\[Equal]", "amp4num"}], ",", 
       RowBox[{"{", 
        RowBox[{"iq", ",", "1", ",", 
         RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}], "]"}], 
    "]"}]}], ";", "res"}]], "Input",
 CellChangeTimes->{{3.6192467473225307`*^9, 3.619246866471874*^9}, 
   3.619247017893632*^9, {3.619247506253628*^9, 3.619247534126361*^9}, {
   3.619253207399193*^9, 3.619253211985969*^9}, {3.6192532731859713`*^9, 
   3.619253274389608*^9}, {3.619259606803865*^9, 3.619259635510037*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.5024398185101`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.5762639276850472`", " ", "\[ImaginaryI]"}]}], ")"}], " ",
         "a3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.33139135644699086`", "\[VeryThinSpace]", "-", 
          RowBox[{"0.3975851611250566`", " ", "\[ImaginaryI]"}]}], ")"}], " ",
         "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.1774485006311431`", "\[VeryThinSpace]", "-", 
          RowBox[{"0.721689848541325`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
        "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"0.11382672170269978`", "\[VeryThinSpace]", "+", 
         RowBox[{"0.10304083475171052`", " ", "\[ImaginaryI]"}]}], ")"}]}]}], 
     ",", 
     RowBox[{"a2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "0.9999999999999999`"}], "+", 
          RowBox[{"2.8189256484623115`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "a3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"7.844110671679769`*^-17", "-", 
          RowBox[{"1.0485778144171603`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"7.275466981003935`*^-18", "-", 
          RowBox[{"8.802438182152924`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"8.871058468154136`*^-19", "+", 
         RowBox[{"2.186171156783871`*^-18", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"b1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4.0027432223053234`*^-18"}], "-", 
          RowBox[{"6.873942727081843`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5.4115940235514364`*^-17", "-", 
          RowBox[{"7.101471230166793`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"7.605956937720794`*^-18", "+", 
         RowBox[{"1.6804434306694044`*^-17", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"b10", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"9.264723899635043`*^-17", "+", 
          RowBox[{"5.2798710914725346`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4.5973987632723574`*^-17", "+", 
          RowBox[{"3.13106320463853`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"1.0201939228929622`*^-17", "-", 
         RowBox[{"5.289132804886906`*^-18", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"b11", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5.070696838897727`*^-17"}], "+", 
          RowBox[{"2.624917871468261`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.765734494764509`*^-16", "+", 
          RowBox[{"1.9671080902750958`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"2.0893041885433104`*^-17", "-", 
         RowBox[{"3.017818706632462`*^-17", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"b4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1.524261049596467`*^-16"}], "-", 
          RowBox[{"5.1177264169757713`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5.3796877534610756`*^-17", "+", 
          RowBox[{"7.55655752747769`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"1.9016222074884942`*^-17", "-", 
         RowBox[{"2.3716314579133203`*^-18", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"b7", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2.303913796538216`*^-17"}], "-", 
          RowBox[{"1.906098499114697`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.8259935691108698`*^-16", "-", 
          RowBox[{"1.1540080154547055`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"1.5808698087915845`*^-17", "-", 
         RowBox[{"3.4334715248039997`*^-17", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"b8", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5.889943353134156`*^-17"}], "-", 
          RowBox[{"1.0548583357716764`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"7.488885726727345`*^-17", "+", 
          RowBox[{"4.3624342521689236`*^-18", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"8.137419574138356`*^-18", "-", 
         RowBox[{"1.318962317341575`*^-17", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"c1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.0025711540040573`*^-17", "+", 
          RowBox[{"2.816925145646445`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.587506957389413`*^-18", "-", 
          RowBox[{"5.407697692145501`*^-19", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"2.5348739059716517`*^-19", "-", 
         RowBox[{"7.053673858554192`*^-19", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"c2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.902714289154546`*^-17", "+", 
          RowBox[{"1.5973766439618928`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.1570788565463982`*^-18", "-", 
          RowBox[{"2.5096160959727723`*^-18", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"3.4286474716880334`*^-19", "+", 
         RowBox[{"4.565099478523468`*^-19", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"c3", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3.572404398446854`*^-19"}], "+", 
          RowBox[{"9.415320268395618`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5.256523324781768`*^-18", "+", 
          RowBox[{"3.002625443142489`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"1.061478209827182`*^-18", "-", 
         RowBox[{"6.613609755724448`*^-19", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"c4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.6298023401519138`*^-17", "-", 
          RowBox[{"2.4900106132979937`*^-18", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.22434529760422`*^-18", "+", 
          RowBox[{"4.555806281597297`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"9.484750253094245`*^-19", "+", 
         RowBox[{"2.2414808794135397`*^-19", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"c5", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4.330700911284188`*^-19"}], "+", 
          RowBox[{"2.821699671684537`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.3639283979523895`*^-17", "+", 
          RowBox[{"4.511908174974307`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"2.1579968018050315`*^-18", "-", 
         RowBox[{"2.0376308422631738`*^-18", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"c6", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1.3008010506462155`*^-17"}], "-", 
          RowBox[{"1.5759984718548483`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4.865411126849709`*^-18", "+", 
          RowBox[{"4.099503159400248`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"1.2225738262613485`*^-18", "-", 
         RowBox[{"4.826747442523754`*^-19", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"f1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.691685200167022`*^-17", "+", 
          RowBox[{"1.1225484852089402`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"4.680861990875758`*^-18", "-", 
         RowBox[{"3.7935764784979354`*^-18", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"g1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.0144970037173458`*^-19", "-", 
          RowBox[{"1.1430930300268649`*^-18", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"1.979057149972847`*^-19", "+", 
         RowBox[{"1.3054759551030102`*^-19", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"g2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5.903471192476088`*^-19", "+", 
          RowBox[{"5.323424915302823`*^-19", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "+", 
       RowBox[{"(", 
        RowBox[{"1.5469261136181957`*^-19", "-", 
         RowBox[{"5.514035506361225`*^-20", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}], ",", 
     RowBox[{"ii", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4.5774884150489315`*^-20"}], "+", 
          RowBox[{"1.4164238071292744`*^-20", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "-", 
       RowBox[{"(", 
        RowBox[{"1.913477530422575`*^-21", "-", 
         RowBox[{"9.712542924902363`*^-21", " ", "\[ImaginaryI]"}]}], 
        ")"}]}]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619246819393581*^9, 3.619246866953732*^9}, 
   3.619247019824709*^9, 3.619247250482655*^9, {3.619247510261654*^9, 
   3.6192475345179462`*^9}, 3.619250330200377*^9, 3.619253165768021*^9, 
   3.619253212558496*^9, 3.619253274954056*^9, 3.619259157627931*^9, {
   3.619259620338154*^9, 3.6192596363980207`*^9}, 3.619259755507863*^9, 
   3.619259971173687*^9, 3.61934368526867*^9}]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.619174112444458*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
   3.604652950305522*^9}, 3.604653026772519*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Numerical analysis of most general q-light-cone propagator with Ward identity\
\
\>", "Subsection",
 CellChangeTimes->{{3.612085834165001*^9, 3.612085844526819*^9}, {
  3.612086484467353*^9, 3.612086497855007*^9}, {3.614577753311775*^9, 
  3.61457775350277*^9}, {3.619251617251955*^9, 3.619251628468852*^9}, {
  3.6194118106691017`*^9, 3.619411813186904*^9}}],

Cell[CellGroupData[{

Cell["First kinematical configuration", "Subsubsection",
 CellChangeTimes->{{3.619426499642606*^9, 3.619426531438857*^9}}],

Cell["First need 4 light-like momenta adding up to zero.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}, {3.6120866065182667`*^9, 3.612086606758206*^9}, {
   3.612505924058659*^9, 3.612505936532402*^9}, {3.612684208346747*^9, 
   3.6126842128136387`*^9}, {3.619173534353448*^9, 3.61917353448518*^9}, {
   3.6192428328385477`*^9, 3.619242834469954*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}, {3.612086612732903*^9, 
   3.612086614349341*^9}, {3.612505939428406*^9, 3.6125059543631077`*^9}, {
   3.61268421467281*^9, 3.612684221598008*^9}, {3.619173536026105*^9, 
   3.6191735361820107`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{"k31", ",", "k32", ",", "k33", ",", "k34"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9, {
   3.61208661791853*^9, 3.612086618148158*^9}, {3.612086936652397*^9, 
   3.612086944450577*^9}, 3.619173550969096*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k4", "=", 
   RowBox[{"{", 
    RowBox[{"k41", ",", "k42", ",", "k43", ",", "k44"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}, {3.612086632200843*^9, 3.612086646982294*^9}, 
   3.6191735537450657`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.612086707631708*^9, 3.612086713887814*^9}, 
   3.6191735610392447`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kinsys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4"}], "\[Equal]", "0"}]}], 
    "}"}]}], ";", 
  RowBox[{"kinsys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612258217072095*^9, 3.612258219089881*^9}, {
  3.612258263321577*^9, 3.612258271721939*^9}, {3.612505966669755*^9, 
  3.612505985721085*^9}, {3.6191735688138533`*^9, 3.619173572268476*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k31", "2"]}], "+", 
         SuperscriptBox["k32", "2"], "+", 
         SuperscriptBox["k33", "2"], "+", 
         SuperscriptBox["k34", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k41", "2"]}], "+", 
         SuperscriptBox["k42", "2"], "+", 
         SuperscriptBox["k43", "2"], "+", 
         SuperscriptBox["k44", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"k31", "+", "k41", "+", "2"}], ",", 
          RowBox[{"k32", "+", "k42"}], ",", 
          RowBox[{"k33", "+", "k43"}], ",", 
          RowBox[{"k34", "+", "k44"}]}], "}"}], "\[LongEqual]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612258223332856*^9, 3.612258277667809*^9, 3.612505994584982*^9, 
   3.6126800091197*^9, 3.6126842296073713`*^9, 3.614415251319221*^9, 
   3.614416681331402*^9, 3.614506889916788*^9, 3.6145783531107807`*^9, 
   3.61493838358314*^9, 3.615634944521681*^9, 3.6157167540016603`*^9, 
   3.6162157977373037`*^9, 3.617337299458859*^9, 3.617339456664722*^9, 
   3.618218573787261*^9, {3.619173572887054*^9, 3.619173586936594*^9}, 
   3.619242838388041*^9, 3.6193436271101513`*^9, 3.619411834288629*^9, 
   3.619412717518421*^9, 3.6194144187326727`*^9, 3.6194153087505503`*^9, 
   3.619419019310787*^9, 3.619422172653228*^9, 3.619426791790433*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"FindInstance", "[", 
   RowBox[{"kinsys", ",", 
    RowBox[{"Join", "[", 
     RowBox[{"k4", ",", "k3"}], "]"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086667146719*^9, 3.612086669789753*^9}, {
   3.61208672018432*^9, 3.6120867609601393`*^9}, {3.612086820399687*^9, 
   3.61208684701149*^9}, {3.6120868882347116`*^9, 3.612086911234775*^9}, {
   3.612086947214334*^9, 3.612086966920597*^9}, {3.612087130200302*^9, 
   3.612087138062559*^9}, {3.612257132872628*^9, 3.6122571670798407`*^9}, 
   3.612257397692018*^9, {3.61225751058984*^9, 3.612257511578771*^9}, {
   3.6122576055168962`*^9, 3.612257613202684*^9}, 3.612257694530752*^9, {
   3.612258060499379*^9, 3.612258062723226*^9}, {3.612258192623537*^9, 
   3.612258193411767*^9}, 3.612258282749514*^9, {3.6125060012757797`*^9, 
   3.612506003735097*^9}, {3.612680017069385*^9, 3.6126800172139387`*^9}, 
   3.612684254591062*^9, 3.6145769005945463`*^9, 3.614576952464837*^9, {
   3.6145770875853148`*^9, 3.614577088568757*^9}, {3.6191736130014772`*^9, 
   3.6191736131373873`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"k41", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k42", "\[Rule]", "0"}], ",", 
     RowBox[{"k43", "\[Rule]", "0"}], ",", 
     RowBox[{"k44", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k31", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"k32", "\[Rule]", "0"}], ",", 
     RowBox[{"k33", "\[Rule]", "0"}], ",", 
     RowBox[{"k34", "\[Rule]", "1"}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.612086762118141*^9, 3.612086780893147*^9}, {
   3.612086823214789*^9, 3.612086847939478*^9}, {3.61208688888518*^9, 
   3.612086911822865*^9}, {3.612086954278853*^9, 3.612086967359386*^9}, {
   3.612087131307373*^9, 3.6120871383511143`*^9}, 3.612257142281363*^9, 
   3.612257394237977*^9, {3.6122575076936417`*^9, 3.612257512163836*^9}, {
   3.6122576069012537`*^9, 3.612257627804504*^9}, {3.612257690411792*^9, 
   3.612257695104991*^9}, 3.612258189484466*^9, 3.61225822195914*^9, 
   3.612258276336063*^9, 3.612259320778799*^9, 3.612511330729707*^9, 
   3.6126803950144*^9, {3.6126842499610157`*^9, 3.612684258655238*^9}, 
   3.6144152518055267`*^9, 3.614416681520438*^9, 3.6145068908943377`*^9, 
   3.614576906819211*^9, 3.614576960270529*^9, 3.614577089264464*^9, 
   3.6145783532449417`*^9, 3.614938384517983*^9, 3.615634945242508*^9, 
   3.615716763753829*^9, 3.616215797986451*^9, 3.617337299646379*^9, 
   3.617339456758937*^9, 3.618218573949119*^9, 3.619173619583102*^9, 
   3.619242840164323*^9, 3.619343627163353*^9, 3.619411842939118*^9, 
   3.619412717583315*^9, 3.619414418766119*^9, 3.61941530879943*^9, 
   3.619419020880562*^9, 3.6194221728038893`*^9, 3.6194267918659782`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k3", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086972550753*^9, 3.612086977276445*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", "1"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.612086977587695*^9, 3.6122575146527653`*^9, 
  3.612257696324094*^9, 3.612684263546081*^9, 3.6144152519329348`*^9, 
  3.6144166815767603`*^9, 3.614506890949765*^9, 3.614578353276498*^9, 
  3.614938384565001*^9, 3.615634945289898*^9, 3.615716766074543*^9, 
  3.616215798017215*^9, 3.617337299676415*^9, 3.617339456797743*^9, 
  3.618218573984281*^9, 3.619173630677906*^9, 3.619242841374653*^9, 
  3.619343627209127*^9, 3.61941184560463*^9, 3.619412717642727*^9, 
  3.6194144188001947`*^9, 3.619415308839137*^9, 3.619419021034181*^9, 
  3.619422172870103*^9, 3.619426791888362*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k3", ",", "k3"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122571125898314`*^9, 3.612257119072855*^9}, {
  3.612257544299827*^9, 3.612257553190195*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6122571193226643`*^9, 3.612257515599658*^9, {3.612257545928628*^9, 
   3.612257553598151*^9}, 3.612257697150077*^9, 3.612684265607835*^9, 
   3.6144152519576693`*^9, 3.614416681638151*^9, 3.614506890967968*^9, 
   3.61457835328469*^9, 3.614938384605798*^9, 3.615634945325961*^9, 
   3.615716767074236*^9, 3.616215798046818*^9, 3.617337299711178*^9, 
   3.617339456832644*^9, 3.618218574015799*^9, 3.6191736350394297`*^9, 
   3.6192428424830933`*^9, 3.619343627215727*^9, 3.61941184687271*^9, 
   3.619412717696143*^9, 3.6194144188087997`*^9, 3.619415308899968*^9, 
   3.619419021180119*^9, 3.6194221729470654`*^9, 3.619426791895362*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086983780642*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", "0", ",", "0", ",", 
    RowBox[{"-", "1"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.612086984684704*^9, 3.612257555469883*^9, 
  3.612257697740192*^9, 3.612684268914393*^9, 3.614415251973494*^9, 
  3.6144166816980267`*^9, 3.614506890983892*^9, 3.614578353290989*^9, 
  3.614938384647709*^9, 3.615634945363903*^9, 3.6157167682912292`*^9, 
  3.616215798191144*^9, 3.617337299746804*^9, 3.617339456867691*^9, 
  3.6182185740487432`*^9, 3.619173636567751*^9, 3.61924284322722*^9, 
  3.619343627221695*^9, 3.619411848922373*^9, 3.6194127177368402`*^9, 
  3.619414418815596*^9, 3.6194153089619102`*^9, 3.61941902126154*^9, 
  3.619422173010064*^9, 3.6194267919019423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k4", ",", "k4"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122575625202703`*^9, 3.612257564202305*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.612257565498811*^9, 3.612257698283271*^9, 
  3.6126842714539623`*^9, 3.614415251992217*^9, 3.614416681767228*^9, 
  3.614506890999983*^9, 3.614578353295656*^9, 3.614938384652294*^9, 
  3.615634945401319*^9, 3.615716769807744*^9, 3.616215798222134*^9, 
  3.617337299789431*^9, 3.617339456902569*^9, 3.618218574055382*^9, 
  3.6192428439067097`*^9, 3.619343627227079*^9, 3.619411850482154*^9, 
  3.619412717775824*^9, 3.619414418821764*^9, 3.619415309003797*^9, 
  3.619419021335904*^9, 3.619422173059569*^9, 3.619426791908618*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
     RowBox[{"t", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"u", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k4"}], "]"}]}]}]}], "}"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.612087426835834*^9, 3.612087432664119*^9}, {
   3.612258338518701*^9, 3.612258339672268*^9}, 3.6145769704085627`*^9, 
   3.614577080572277*^9, {3.619173653576743*^9, 3.619173663300818*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"t", "\[Rule]", "2"}], ",", 
    RowBox[{"u", "\[Rule]", "2"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612087439480166*^9, 3.612257591558383*^9, 3.612257700130177*^9, 
   3.612258340118903*^9, 3.6126842783468533`*^9, 3.614415252427136*^9, 
   3.614416681890109*^9, 3.6145068911892233`*^9, {3.6145769429963827`*^9, 
   3.614576970611363*^9}, 3.614578353362673*^9, 3.614938384741045*^9, 
   3.61563494553862*^9, 3.615716776067073*^9, 3.616215798269853*^9, 
   3.617337299947012*^9, 3.617339456954917*^9, 3.618218574108639*^9, 
   3.6191736638778257`*^9, 3.6192428449891157`*^9, 3.619343627270199*^9, 
   3.619411852210965*^9, 3.619412717816416*^9, 3.619414418855288*^9, 
   3.619415309046014*^9, 3.619419021449251*^9, 3.61942217309978*^9, 
   3.619426791960037*^9}]
}, Open  ]],

Cell[TextData[{
 "This is to check that the kinematical configuration is not singular (i.e. \
all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "ij"], "\[NotEqual]", "0"}], TraditionalForm]]],
 ")."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EA0ACNrNIA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"qq", "=", 
   RowBox[{"{", 
    RowBox[{"q1", ",", "q2", ",", "q3", ",", "q4"}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.619245750462315*^9, 3.6192457583034897`*^9}, {
  3.61925359622964*^9, 3.619253624137032*^9}, {3.6192536823679132`*^9, 
  3.619253690597275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solsQ", "=", 
   RowBox[{"FindInstance", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "qq"}], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k2"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k3"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k4"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{"q3", "\[NotEqual]", "0"}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "qq", ",", "40"}], "]"}]}], ";", 
  RowBox[{"solsQ", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619245735712246*^9, 3.619245843386804*^9}, {
   3.619245898655726*^9, 3.619245907321413*^9}, {3.619246907400166*^9, 
   3.619246907649767*^9}, {3.6192471569505043`*^9, 3.619247157251212*^9}, {
   3.619247302920272*^9, 3.619247327249937*^9}, {3.619247363111875*^9, 
   3.619247380569146*^9}, 3.619250174378536*^9, {3.619252969898986*^9, 
   3.619252989345154*^9}, {3.6192534788689737`*^9, 3.619253483581024*^9}, 
   3.619253561288389*^9, {3.6192536348760147`*^9, 3.619253659843577*^9}, {
   3.619253696488311*^9, 3.619253696662755*^9}, 3.619253796719205*^9, {
   3.619259185839983*^9, 3.619259186016962*^9}, {3.619259675735292*^9, 
   3.619259676084115*^9}, {3.619411868929187*^9, 3.619411869159006*^9}, 
   3.619414412353684*^9, 3.619415301351286*^9, {3.619419007538918*^9, 
   3.619419007730249*^9}, {3.619422167668703*^9, 3.619422167946136*^9}, {
   3.619426784399118*^9, 3.619426784589344*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["529", "2"]}], "+", 
        FractionBox[
         RowBox[{"3721", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1447", "10"]}], "-", 
        FractionBox[
         RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6829", "10"]}], "-", 
        FractionBox[
         RowBox[{"7607", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "39248715"}], "-", 
          RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1457", "2"]}], "+", 
        RowBox[{"977", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1091", "2"], "+", 
        FractionBox[
         RowBox[{"7691", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8869", "10"]}], "+", 
        FractionBox[
         RowBox[{"6147", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "53860771"}], "-", 
          RowBox[{"117222224", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6603", "10"], "+", 
        FractionBox[
         RowBox[{"673", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4642", "5"]}], "-", 
        FractionBox[
         RowBox[{"7149", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["113", "2"], "+", 
        FractionBox[
         RowBox[{"788", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"2556694", "-", 
          FractionBox[
           RowBox[{"62817937", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3061", "10"], "-", 
        FractionBox[
         RowBox[{"6737", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["2799", "5"], "-", 
        FractionBox[
         RowBox[{"6579", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4531", "5"]}], "-", 
        FractionBox[
         RowBox[{"4527", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["42848963", "2"]}], "-", 
          FractionBox[
           RowBox[{"24816389", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1593", "2"]}], "+", 
        FractionBox[
         RowBox[{"1334", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3961", "5"]}], "+", 
        FractionBox[
         RowBox[{"6559", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1209", "2"]}], "+", 
        FractionBox[
         RowBox[{"2533", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"25707729", "+", 
          RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1934", "5"]}], "-", 
        FractionBox[
         RowBox[{"4921", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4419", "10"]}], "+", 
        FractionBox[
         RowBox[{"9831", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1827", "2"]}], "-", 
        FractionBox[
         RowBox[{"3863", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "659273"}], "+", 
          RowBox[{"54378224", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3378", "5"]}], "-", 
        FractionBox[
         RowBox[{"8619", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1169", "10"]}], "-", 
        FractionBox[
         RowBox[{"2709", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["357", "10"], "-", 
        FractionBox[
         RowBox[{"4874", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"94240593", "+", 
          RowBox[{"110752716", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4177", "5"]}], "+", 
        FractionBox[
         RowBox[{"1629", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["462", "5"]}], "-", 
        FractionBox[
         RowBox[{"184", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["199", "5"], "-", 
        FractionBox[
         RowBox[{"567", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"3857491", "-", 
          RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2606", "5"], "+", 
        FractionBox[
         RowBox[{"1363", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["768", "5"]}], "-", 
        FractionBox[
         RowBox[{"1166", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1997", "2"], "+", 
        FractionBox[
         RowBox[{"1807", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "63826433"}], "-", 
          RowBox[{"50919660", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["4979", "5"], "+", 
        FractionBox[
         RowBox[{"8653", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["2341", "10"], "-", 
        FractionBox[
         RowBox[{"3764", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3127", "10"]}], "-", 
        FractionBox[
         RowBox[{"8073", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["65436529", "2"], "+", 
          FractionBox[
           RowBox[{"78545351", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2796", "5"], "-", 
        FractionBox[
         RowBox[{"4514", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["651", "10"]}], "-", 
        FractionBox[
         RowBox[{"2479", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1467", "5"], "-", 
        FractionBox[
         RowBox[{"1824", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "9953283"}], "-", 
          FractionBox[
           RowBox[{"41395173", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["829", "2"], "-", 
        FractionBox[
         RowBox[{"4348", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1763", "5"], "+", 
        RowBox[{"62", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["5339", "10"], "+", 
        FractionBox[
         RowBox[{"857", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "80631363"}], "-", 
          RowBox[{"122217310", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7409", "10"]}], "-", 
        FractionBox[
         RowBox[{"4866", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["177", "2"]}], "-", 
        FractionBox[
         RowBox[{"7597", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4242", "5"], "-", 
        RowBox[{"312", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "45131215"}], "+", 
          RowBox[{"183702246", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4303", "5"]}], "+", 
        FractionBox[
         RowBox[{"4997", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2632", "5"]}], "-", 
        FractionBox[
         RowBox[{"1349", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6293", "10"], "+", 
        FractionBox[
         RowBox[{"1437", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["1339619", "2"]}], "-", 
          RowBox[{"37646268", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["888", "5"], "-", 
        FractionBox[
         RowBox[{"9979", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["3631", "10"], "-", 
        FractionBox[
         RowBox[{"3413", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1943", "2"], "-", 
        FractionBox[
         RowBox[{"7069", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["53713307", "2"]}], "+", 
          FractionBox[
           RowBox[{"75737837", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["242", "5"], "+", 
        FractionBox[
         RowBox[{"797", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"275", "+", 
        FractionBox[
         RowBox[{"2789", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1205", "2"], "-", 
        FractionBox[
         RowBox[{"2849", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1480995"}], "+", 
          RowBox[{"13716098", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["49", "2"], "+", 
        FractionBox[
         RowBox[{"1435", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["9043", "10"], "+", 
        FractionBox[
         RowBox[{"448", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["2727", "10"], "+", 
        FractionBox[
         RowBox[{"2677", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "132663833"}], "-", 
          RowBox[{"27289664", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["567", "5"], "+", 
        FractionBox[
         RowBox[{"1611", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["6939", "10"], "-", 
        FractionBox[
         RowBox[{"4506", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1472", "5"], "-", 
        FractionBox[
         RowBox[{"3663", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["13794847", "5"], "+", 
          FractionBox[
           RowBox[{"35102304", " ", "\[ImaginaryI]"}], "5"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3979", "10"]}], "+", 
        FractionBox[
         RowBox[{"2457", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["863", "10"], "+", 
        RowBox[{"297", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3209", "5"]}], "-", 
        FractionBox[
         RowBox[{"145", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "5698344"}], "-", 
          FractionBox[
           RowBox[{"16992563", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["1672", "5"], "+", 
        FractionBox[
         RowBox[{"5687", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "184"}], "-", 
        FractionBox[
         RowBox[{"8527", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5253", "10"]}], "+", 
        FractionBox[
         RowBox[{"3617", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"72901243", "+", 
          RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["27", "10"]}], "-", 
        FractionBox[
         RowBox[{"5137", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["6669", "10"], "-", 
        RowBox[{"919", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["713", "10"], "+", 
        FractionBox[
         RowBox[{"7341", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"66974411", "+", 
          RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3128", "5"], "+", 
        FractionBox[
         RowBox[{"3576", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8859", "10"]}], "+", 
        FractionBox[
         RowBox[{"1467", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["529", "10"]}], "+", 
        FractionBox[
         RowBox[{"3631", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "35886557"}], "+", 
          RowBox[{"123161326", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3869", "5"], "-", 
        FractionBox[
         RowBox[{"3039", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["86", "5"]}], "+", 
        FractionBox[
         RowBox[{"5527", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1889", "10"]}], "+", 
        RowBox[{"451", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"97931047", "-", 
          RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2561", "5"]}], "+", 
        FractionBox[
         RowBox[{"1335", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7933", "10"]}], "+", 
        FractionBox[
         RowBox[{"3659", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3217", "5"]}], "-", 
        FractionBox[
         RowBox[{"2691", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "61854981"}], "+", 
          RowBox[{"13100900", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["9009", "10"], "-", 
        FractionBox[
         RowBox[{"5249", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3399", "5"]}], "-", 
        FractionBox[
         RowBox[{"8991", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1085", "2"], "+", 
        FractionBox[
         RowBox[{"793", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"15330032", "-", 
          FractionBox[
           RowBox[{"117013109", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["837", "2"], "+", 
        FractionBox[
         RowBox[{"3956", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2943", "5"]}], "+", 
        FractionBox[
         RowBox[{"4664", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "425"}], "+", 
        FractionBox[
         RowBox[{"251", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["5359215", "2"]}], "+", 
          RowBox[{"44541539", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6859", "10"], "-", 
        FractionBox[
         RowBox[{"1121", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["877", "5"]}], "+", 
        FractionBox[
         RowBox[{"6871", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["872", "5"], "+", 
        FractionBox[
         RowBox[{"4433", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["80858931", "2"], "-", 
          RowBox[{"9394224", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2618", "5"], "+", 
        FractionBox[
         RowBox[{"7807", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1471", "10"], "+", 
        FractionBox[
         RowBox[{"2501", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["8377", "10"], "-", 
        FractionBox[
         RowBox[{"1109", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["47348499", "2"]}], "+", 
          FractionBox[
           RowBox[{"55778667", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["747", "10"], "+", 
        FractionBox[
         RowBox[{"3479", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "605"}], "-", 
        FractionBox[
         RowBox[{"1513", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1627", "10"], "-", 
        FractionBox[
         RowBox[{"1273", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["14127815", "2"]}], "-", 
          FractionBox[
           RowBox[{"38499453", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3357", "10"], "+", 
        FractionBox[
         RowBox[{"3556", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2109", "10"]}], "+", 
        FractionBox[
         RowBox[{"673", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1739", "10"]}], "-", 
        RowBox[{"83", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "8692743"}], "+", 
          FractionBox[
           RowBox[{"29528399", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2422", "5"], "-", 
        FractionBox[
         RowBox[{"839", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"169", "-", 
        RowBox[{"102", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["9163", "10"], "+", 
        FractionBox[
         RowBox[{"4022", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["7602011", "2"]}], "-", 
          RowBox[{"46151976", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["171", "5"]}], "+", 
        FractionBox[
         RowBox[{"9369", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8957", "10"]}], "+", 
        FractionBox[
         RowBox[{"2987", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1343", "10"]}], "-", 
        RowBox[{"128", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "132365619"}], "+", 
          RowBox[{"97171760", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "745"}], "-", 
        FractionBox[
         RowBox[{"1283", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3117", "10"]}], "+", 
        FractionBox[
         RowBox[{"7363", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1171", "10"], "-", 
        FractionBox[
         RowBox[{"7701", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"116782515", "+", 
          RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["5809", "10"], "-", 
        FractionBox[
         RowBox[{"1749", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9209", "10"]}], "+", 
        RowBox[{"205", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3697", "10"]}], "+", 
        FractionBox[
         RowBox[{"2551", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "130493933"}], "-", 
          RowBox[{"44980416", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2104", "5"]}], "-", 
        FractionBox[
         RowBox[{"4916", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6199", "10"]}], "+", 
        FractionBox[
         RowBox[{"4183", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6583", "10"], "+", 
        FractionBox[
         RowBox[{"1943", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "12211434"}], "+", 
          RowBox[{"1674814", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4954", "5"]}], "-", 
        FractionBox[
         RowBox[{"1201", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1949", "10"]}], "-", 
        FractionBox[
         RowBox[{"2692", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4669", "5"], "+", 
        FractionBox[
         RowBox[{"6823", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"46652379", "-", 
          RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2687", "5"], "-", 
        FractionBox[
         RowBox[{"7103", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["239", "2"], "+", 
        FractionBox[
         RowBox[{"9633", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1676", "5"], "-", 
        FractionBox[
         RowBox[{"4116", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"126323851", "-", 
          RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"829", "-", 
        FractionBox[
         RowBox[{"3603", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["3637", "5"], "-", 
        FractionBox[
         RowBox[{"7841", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["9067", "10"], "-", 
        FractionBox[
         RowBox[{"3163", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"22120483", "+", 
          RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2058", "5"], "+", 
        FractionBox[
         RowBox[{"2792", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4309", "10"]}], "-", 
        FractionBox[
         RowBox[{"4141", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["5821", "10"], "-", 
        FractionBox[
         RowBox[{"1953", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["8578619", "2"], "+", 
          RowBox[{"5016716", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3393", "5"]}], "-", 
        RowBox[{"751", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4239", "10"]}], "+", 
        FractionBox[
         RowBox[{"1561", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["777", "2"]}], "+", 
        FractionBox[
         RowBox[{"4069", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "17109005"}], "+", 
          RowBox[{"160010166", " ", "\[ImaginaryI]"}]}]]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619247306337376*^9, 3.6192473275798597`*^9}, {
   3.619247366761524*^9, 3.6192473862009478`*^9}, 3.619250189167459*^9, 
   3.619253006482288*^9, 3.619253501155623*^9, 3.619253562818247*^9, {
   3.619253636647204*^9, 3.6192536606192513`*^9}, 3.619253714663269*^9, 
   3.619253798174103*^9, 3.619259192689518*^9, 3.619259679665366*^9, 
   3.619343628769216*^9, {3.61941186770128*^9, 3.619411869795827*^9}, 
   3.619412717990695*^9, 3.619414425743634*^9, 3.619415316499393*^9, 
   3.619419029729253*^9, {3.619422172023136*^9, 3.619422175309548*^9}, 
   3.6194267926867332`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"qq", ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k2"}], ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k3"}], ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k4"}], ",", "qq"}], "]"}]}], "}"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"solsQ", "[", 
       RowBox[{"[", "10", "]"}], "]"}]}], "]"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.6191737450948343`*^9, 3.619173797754238*^9}, {
  3.6191738286543903`*^9, 3.6191738320823097`*^9}, {3.619245862668565*^9, 
  3.6192458852495947`*^9}, {3.619245916409066*^9, 3.619245923800671*^9}, {
  3.619411876427549*^9, 3.619411876569488*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"0"},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox["9958", "5"]}], "-", 
        FractionBox[
         RowBox[{"8653", " ", "\[ImaginaryI]"}], "5"]}]},
      {
       RowBox[{
        FractionBox["1", "10"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2341", "-", 
            RowBox[{"7528", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
          SqrtBox[
           RowBox[{"130873058", "+", 
            RowBox[{"157090702", " ", "\[ImaginaryI]"}]}]]}], ")"}]}]},
      {
       RowBox[{
        FractionBox["1", "10"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2341", "-", 
            RowBox[{"7528", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
          SqrtBox[
           RowBox[{"130873058", "+", 
            RowBox[{"157090702", " ", "\[ImaginaryI]"}]}]]}], ")"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619245867709139*^9, 3.6192459244387503`*^9}, 
   3.6192469121346416`*^9, {3.619247376009243*^9, 3.619247390701576*^9}, 
   3.619253029812439*^9, 3.6192538056839447`*^9, 3.6192592221682997`*^9, 
   3.619259691088504*^9, 3.6193436293231564`*^9, 3.619411877276538*^9, 
   3.6194127180281563`*^9, 3.61941442596553*^9, 3.619415316772113*^9, 
   3.61941904197148*^9, 3.6194221756500473`*^9, 3.619426793925027*^9}]
}, Open  ]],

Cell["\<\
So we found a light-like q that leads to non-singular terms in the \
propagators.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules0", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
       RowBox[{"u", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"1", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"2", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"3", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"4", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "qq"}], "]"}]}]}], "}"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"solsQ", "[", 
        RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"iq", ",", "1", ",", 
      RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619243019476788*^9, 3.619243024257585*^9}, {
   3.61924594137394*^9, 3.619246017843701*^9}, 3.619251664736548*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["599", "5"], "-", 
        FractionBox[
         RowBox[{"7477", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2046", "5"], "-", 
        FractionBox[
         RowBox[{"7407", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["529", "2"]}], "+", 
          FractionBox[
           RowBox[{"3721", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "39248715"}], "-", 
           RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["529", "2"]}], "+", 
          FractionBox[
           RowBox[{"3721", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "39248715"}], "-", 
           RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"1274", "-", 
        FractionBox[
         RowBox[{"2079", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"183", "-", 
        FractionBox[
         RowBox[{"17461", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1457", "2"]}], "+", 
          RowBox[{"977", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "53860771"}], "-", 
           RowBox[{"117222224", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1457", "2"]}], "+", 
          RowBox[{"977", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "53860771"}], "-", 
           RowBox[{"117222224", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15887", "10"]}], "-", 
        FractionBox[
         RowBox[{"3911", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2681", "10"], "+", 
        FractionBox[
         RowBox[{"3238", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6603", "10"], "+", 
          FractionBox[
           RowBox[{"673", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"2556694", "-", 
           FractionBox[
            RowBox[{"62817937", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6603", "10"], "+", 
          FractionBox[
           RowBox[{"673", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"2556694", "-", 
           FractionBox[
            RowBox[{"62817937", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2537", "10"], "+", 
        FractionBox[
         RowBox[{"79", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8659", "10"]}], "+", 
        FractionBox[
         RowBox[{"6658", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3061", "10"], "-", 
          FractionBox[
           RowBox[{"6737", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["42848963", "2"]}], "-", 
           FractionBox[
            RowBox[{"24816389", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3061", "10"], "-", 
          FractionBox[
           RowBox[{"6737", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["42848963", "2"]}], "-", 
           FractionBox[
            RowBox[{"24816389", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["43", "10"], "+", 
        FractionBox[
         RowBox[{"3891", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["15887", "10"], "-", 
        FractionBox[
         RowBox[{"9227", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1593", "2"]}], "+", 
          FractionBox[
           RowBox[{"1334", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"25707729", "+", 
           RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1593", "2"]}], "+", 
          FractionBox[
           RowBox[{"1334", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"25707729", "+", 
           RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["551", "10"]}], "+", 
        FractionBox[
         RowBox[{"7376", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8287", "10"], "-", 
        RowBox[{"491", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1934", "5"]}], "-", 
          FractionBox[
           RowBox[{"4921", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "659273"}], "+", 
           RowBox[{"54378224", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1934", "5"]}], "-", 
          FractionBox[
           RowBox[{"4921", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "659273"}], "+", 
           RowBox[{"54378224", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5587", "10"], "+", 
        FractionBox[
         RowBox[{"3201", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1585", "2"], "+", 
        FractionBox[
         RowBox[{"14037", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3378", "5"]}], "-", 
          FractionBox[
           RowBox[{"8619", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"94240593", "+", 
           RowBox[{"110752716", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3378", "5"]}], "-", 
          FractionBox[
           RowBox[{"8619", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"94240593", "+", 
           RowBox[{"110752716", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"743", "-", 
        FractionBox[
         RowBox[{"8513", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4639", "5"], "-", 
        FractionBox[
         RowBox[{"7777", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4177", "5"]}], "+", 
          FractionBox[
           RowBox[{"1629", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"3857491", "-", 
           RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4177", "5"]}], "+", 
          FractionBox[
           RowBox[{"1629", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"3857491", "-", 
           RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3374", "5"]}], "-", 
        FractionBox[
         RowBox[{"2529", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1838", "5"]}], "-", 
        FractionBox[
         RowBox[{"197", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2606", "5"], "+", 
          FractionBox[
           RowBox[{"1363", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "63826433"}], "-", 
           RowBox[{"50919660", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2606", "5"], "+", 
          FractionBox[
           RowBox[{"1363", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "63826433"}], "-", 
           RowBox[{"50919660", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7617", "10"]}], "-", 
        FractionBox[
         RowBox[{"16181", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12299", "10"]}], "-", 
        FractionBox[
         RowBox[{"225", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4979", "5"], "+", 
          FractionBox[
           RowBox[{"8653", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["65436529", "2"], "+", 
           FractionBox[
            RowBox[{"78545351", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["4979", "5"], "+", 
          FractionBox[
           RowBox[{"8653", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["65436529", "2"], "+", 
           FractionBox[
            RowBox[{"78545351", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6243", "10"]}], "+", 
        FractionBox[
         RowBox[{"6549", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4941", "10"]}], "+", 
        FractionBox[
         RowBox[{"11507", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2796", "5"], "-", 
          FractionBox[
           RowBox[{"4514", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "9953283"}], "-", 
           FractionBox[
            RowBox[{"41395173", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2796", "5"], "-", 
          FractionBox[
           RowBox[{"4514", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "9953283"}], "-", 
           FractionBox[
            RowBox[{"41395173", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["619", "10"]}], "+", 
        FractionBox[
         RowBox[{"4658", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7671", "10"]}], "+", 
        FractionBox[
         RowBox[{"4038", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["829", "2"], "-", 
          FractionBox[
           RowBox[{"4348", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "80631363"}], "-", 
           RowBox[{"122217310", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["829", "2"], "-", 
          FractionBox[
           RowBox[{"4348", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "80631363"}], "-", 
           RowBox[{"122217310", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["3262", "5"], "+", 
        FractionBox[
         RowBox[{"427", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4147", "5"], "+", 
        FractionBox[
         RowBox[{"17329", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7409", "10"]}], "-", 
          FractionBox[
           RowBox[{"4866", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "45131215"}], "+", 
           RowBox[{"183702246", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["7409", "10"]}], "-", 
          FractionBox[
           RowBox[{"4866", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "45131215"}], "+", 
           RowBox[{"183702246", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1671", "5"], "-", 
        FractionBox[
         RowBox[{"1539", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"1387", "-", 
        FractionBox[
         RowBox[{"2299", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4303", "5"]}], "+", 
          FractionBox[
           RowBox[{"4997", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["1339619", "2"]}], "-", 
           RowBox[{"37646268", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4303", "5"]}], "+", 
          FractionBox[
           RowBox[{"4997", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["1339619", "2"]}], "-", 
           RowBox[{"37646268", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["371", "2"], "+", 
        FractionBox[
         RowBox[{"3153", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5407", "10"]}], "+", 
        FractionBox[
         RowBox[{"3361", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["888", "5"], "-", 
          FractionBox[
           RowBox[{"9979", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["53713307", "2"]}], "+", 
           FractionBox[
            RowBox[{"75737837", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["888", "5"], "-", 
          FractionBox[
           RowBox[{"9979", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["53713307", "2"]}], "+", 
           FractionBox[
            RowBox[{"75737837", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1133", "5"], "+", 
        FractionBox[
         RowBox[{"239", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1617", "5"]}], "-", 
        FractionBox[
         RowBox[{"4383", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["242", "5"], "+", 
          FractionBox[
           RowBox[{"797", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1480995"}], "+", 
           RowBox[{"13716098", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["242", "5"], "+", 
          FractionBox[
           RowBox[{"797", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1480995"}], "+", 
           RowBox[{"13716098", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4399", "5"], "-", 
        FractionBox[
         RowBox[{"6279", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4644", "5"]}], "-", 
        FractionBox[
         RowBox[{"8071", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["49", "2"], "+", 
          FractionBox[
           RowBox[{"1435", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "132663833"}], "-", 
           RowBox[{"27289664", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["49", "2"], "+", 
          FractionBox[
           RowBox[{"1435", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "132663833"}], "-", 
           RowBox[{"27289664", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1161", "2"], "-", 
        FractionBox[
         RowBox[{"6117", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8073", "10"]}], "+", 
        RowBox[{"579", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["567", "5"], "+", 
          FractionBox[
           RowBox[{"1611", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["13794847", "5"], "+", 
           FractionBox[
            RowBox[{"35102304", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["567", "5"], "+", 
          FractionBox[
           RowBox[{"1611", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["13794847", "5"], "+", 
           FractionBox[
            RowBox[{"35102304", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2421", "5"], "+", 
        FractionBox[
         RowBox[{"513", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1558", "5"], "-", 
        FractionBox[
         RowBox[{"5427", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3979", "10"]}], "+", 
          FractionBox[
           RowBox[{"2457", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "5698344"}], "-", 
           FractionBox[
            RowBox[{"16992563", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3979", "10"]}], "+", 
          FractionBox[
           RowBox[{"2457", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "5698344"}], "-", 
           FractionBox[
            RowBox[{"16992563", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2592", "5"]}], "-", 
        FractionBox[
         RowBox[{"7107", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["752", "5"]}], "+", 
        RowBox[{"284", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1672", "5"], "+", 
          FractionBox[
           RowBox[{"5687", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"72901243", "+", 
           RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1672", "5"], "+", 
          FractionBox[
           RowBox[{"5687", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"72901243", "+", 
           RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["3348", "5"], "-", 
        FractionBox[
         RowBox[{"4053", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3321", "5"]}], "+", 
        FractionBox[
         RowBox[{"14327", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["27", "10"]}], "-", 
          FractionBox[
           RowBox[{"5137", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"66974411", "+", 
           RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["27", "10"]}], "-", 
          FractionBox[
           RowBox[{"5137", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"66974411", "+", 
           RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3023", "2"]}], "-", 
        FractionBox[
         RowBox[{"1137", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2603", "10"], "-", 
        FractionBox[
         RowBox[{"8619", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3128", "5"], "+", 
          FractionBox[
           RowBox[{"3576", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "35886557"}], "+", 
           RowBox[{"123161326", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3128", "5"], "+", 
          FractionBox[
           RowBox[{"3576", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "35886557"}], "+", 
           RowBox[{"123161326", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "791"}], "+", 
        FractionBox[
         RowBox[{"4283", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3783", "5"]}], "-", 
        FractionBox[
         RowBox[{"1244", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3869", "5"], "-", 
          FractionBox[
           RowBox[{"3039", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"97931047", "-", 
           RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3869", "5"], "-", 
          FractionBox[
           RowBox[{"3039", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"97931047", "-", 
           RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2811", "10"]}], "+", 
        FractionBox[
         RowBox[{"643", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2611", "2"], "-", 
        FractionBox[
         RowBox[{"13993", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2561", "5"]}], "+", 
          FractionBox[
           RowBox[{"1335", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "61854981"}], "+", 
           RowBox[{"13100900", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2561", "5"]}], "+", 
          FractionBox[
           RowBox[{"1335", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "61854981"}], "+", 
           RowBox[{"13100900", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15807", "10"]}], "-", 
        FractionBox[
         RowBox[{"1871", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2211", "10"]}], "+", 
        RowBox[{"1424", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["9009", "10"], "-", 
          FractionBox[
           RowBox[{"5249", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"15330032", "-", 
           FractionBox[
            RowBox[{"117013109", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["9009", "10"], "-", 
          FractionBox[
           RowBox[{"5249", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{"15330032", "-", 
           FractionBox[
            RowBox[{"117013109", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10071", "10"]}], "+", 
        FractionBox[
         RowBox[{"708", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1701", "10"], "-", 
        RowBox[{"1724", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["837", "2"], "+", 
          FractionBox[
           RowBox[{"3956", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["5359215", "2"]}], "+", 
           RowBox[{"44541539", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["837", "2"], "+", 
          FractionBox[
           RowBox[{"3956", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["5359215", "2"]}], "+", 
           RowBox[{"44541539", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8613", "10"]}], "+", 
        FractionBox[
         RowBox[{"9113", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1021", "2"]}], "-", 
        FractionBox[
         RowBox[{"4629", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6859", "10"], "-", 
          FractionBox[
           RowBox[{"1121", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["80858931", "2"], "-", 
           RowBox[{"9394224", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["6859", "10"], "-", 
          FractionBox[
           RowBox[{"1121", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["80858931", "2"], "-", 
           RowBox[{"9394224", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["753", "2"]}], "-", 
        FractionBox[
         RowBox[{"2653", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6707", "10"]}], "-", 
        FractionBox[
         RowBox[{"5154", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2618", "5"], "+", 
          FractionBox[
           RowBox[{"7807", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["47348499", "2"]}], "+", 
           FractionBox[
            RowBox[{"55778667", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2618", "5"], "+", 
          FractionBox[
           RowBox[{"7807", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["47348499", "2"]}], "+", 
           FractionBox[
            RowBox[{"55778667", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6797", "10"]}], "-", 
        FractionBox[
         RowBox[{"14523", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5303", "10"], "+", 
        FractionBox[
         RowBox[{"607", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["747", "10"], "+", 
          FractionBox[
           RowBox[{"3479", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["14127815", "2"]}], "-", 
           FractionBox[
            RowBox[{"38499453", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["747", "10"], "+", 
          FractionBox[
           RowBox[{"3479", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["14127815", "2"]}], "-", 
           FractionBox[
            RowBox[{"38499453", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2733", "5"]}], "-", 
        FractionBox[
         RowBox[{"3747", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["624", "5"]}], "-", 
        FractionBox[
         RowBox[{"10477", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3357", "10"], "+", 
          FractionBox[
           RowBox[{"3556", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "8692743"}], "+", 
           FractionBox[
            RowBox[{"29528399", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["3357", "10"], "+", 
          FractionBox[
           RowBox[{"3556", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "8692743"}], "+", 
           FractionBox[
            RowBox[{"29528399", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1577", "5"]}], "+", 
        FractionBox[
         RowBox[{"635", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3267", "5"]}], "+", 
        FractionBox[
         RowBox[{"1043", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2422", "5"], "-", 
          FractionBox[
           RowBox[{"839", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["7602011", "2"]}], "-", 
           RowBox[{"46151976", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2422", "5"], "-", 
          FractionBox[
           RowBox[{"839", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["7602011", "2"]}], "-", 
           RowBox[{"46151976", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1723", "2"]}], "-", 
        FractionBox[
         RowBox[{"679", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["9299", "10"], "-", 
        FractionBox[
         RowBox[{"15343", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["171", "5"]}], "+", 
          FractionBox[
           RowBox[{"9369", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "132365619"}], "+", 
           RowBox[{"97171760", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["171", "5"]}], "+", 
          FractionBox[
           RowBox[{"9369", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "132365619"}], "+", 
           RowBox[{"97171760", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4333", "10"], "+", 
        FractionBox[
         RowBox[{"6889", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10567", "10"], "-", 
        FractionBox[
         RowBox[{"474", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "745"}], "-", 
          FractionBox[
           RowBox[{"1283", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"116782515", "+", 
           RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "745"}], "-", 
          FractionBox[
           RowBox[{"1283", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"116782515", "+", 
           RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7509", "5"]}], "+", 
        FractionBox[
         RowBox[{"2159", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"340", "+", 
        FractionBox[
         RowBox[{"1339", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["5809", "10"], "-", 
          FractionBox[
           RowBox[{"1749", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "130493933"}], "-", 
           RowBox[{"44980416", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["5809", "10"], "-", 
          FractionBox[
           RowBox[{"1749", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "130493933"}], "-", 
           RowBox[{"44980416", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1991", "10"]}], "+", 
        FractionBox[
         RowBox[{"2803", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10407", "10"], "+", 
        FractionBox[
         RowBox[{"5649", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2104", "5"]}], "-", 
          FractionBox[
           RowBox[{"4916", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "12211434"}], "+", 
           RowBox[{"1674814", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["2104", "5"]}], "-", 
          FractionBox[
           RowBox[{"4916", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "12211434"}], "+", 
           RowBox[{"1674814", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7959", "10"], "+", 
        FractionBox[
         RowBox[{"621", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["11857", "10"], "+", 
        FractionBox[
         RowBox[{"11389", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4954", "5"]}], "-", 
          FractionBox[
           RowBox[{"1201", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"46652379", "-", 
           RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4954", "5"]}], "-", 
          FractionBox[
           RowBox[{"1201", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"46652379", "-", 
           RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4179", "10"]}], "+", 
        FractionBox[
         RowBox[{"8368", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6569", "10"]}], "-", 
        RowBox[{"253", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2687", "5"], "-", 
          FractionBox[
           RowBox[{"7103", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"126323851", "-", 
           RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2687", "5"], "-", 
          FractionBox[
           RowBox[{"7103", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"126323851", "-", 
           RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["508", "5"]}], "-", 
        FractionBox[
         RowBox[{"2119", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7782", "5"]}], "+", 
        FractionBox[
         RowBox[{"5722", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"829", "-", 
          FractionBox[
           RowBox[{"3603", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"22120483", "+", 
           RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"829", "-", 
          FractionBox[
           RowBox[{"3603", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{"22120483", "+", 
           RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1685", "2"]}], "-", 
        FractionBox[
         RowBox[{"6933", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["193", "10"], "+", 
        FractionBox[
         RowBox[{"1349", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2058", "5"], "+", 
          FractionBox[
           RowBox[{"2792", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["8578619", "2"], "+", 
           RowBox[{"5016716", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["2058", "5"], "+", 
          FractionBox[
           RowBox[{"2792", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["8578619", "2"], "+", 
           RowBox[{"5016716", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", "2"}], ",", 
      RowBox[{"u", "\[Rule]", "2"}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2547", "10"], "+", 
        FractionBox[
         RowBox[{"5316", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2205", "2"], "+", 
        FractionBox[
         RowBox[{"2194", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3393", "5"]}], "-", 
          RowBox[{"751", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "17109005"}], "+", 
           RowBox[{"160010166", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["3393", "5"]}], "-", 
          RowBox[{"751", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "17109005"}], "+", 
           RowBox[{"160010166", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}]}], 
   "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619251667731608*^9, 3.6192530358732567`*^9, 
  3.619253808214054*^9, 3.619259226480626*^9, 3.619259694413026*^9, 
  3.619343630253477*^9, 3.619411889898546*^9, 3.619412718158453*^9, 
  3.6194144269751167`*^9, 3.619415318677949*^9, 3.6194190445058327`*^9, 
  3.6194221771857853`*^9, 3.6194268009098797`*^9}]
}, Open  ]],

Cell["Now choose random polarizations:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}, {3.619235593173221*^9, 3.619235598976385*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi1", "=", 
   RowBox[{"{", 
    RowBox[{"xix1", ",", "xix2", ",", "xix3", ",", "xix4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043270708568*^9, 3.6040432967635603`*^9}, 
   3.604043499802985*^9, 3.604301554870967*^9, {3.6043021515175753`*^9, 
   3.604302152636281*^9}, {3.612166399986412*^9, 3.612166401456052*^9}, {
   3.615717383769212*^9, 3.61571738455131*^9}, 3.619235607803103*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi2", "=", 
   RowBox[{"{", 
    RowBox[{"xiy1", ",", "xiy2", ",", "xiy3", ",", "xiy4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.6040433084930897`*^9, 
   3.6040433346916733`*^9}, 3.604043502795218*^9, {3.612166409439506*^9, 
   3.612166414318565*^9}, 3.619235609169167*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{"xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9, {3.612166418225318*^9, 
   3.6121664207438507`*^9}, 3.61923561085168*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi4", "=", 
   RowBox[{"{", 
    RowBox[{"xiu1", ",", "xiu2", ",", "xiu3", ",", "xiu4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.6040433145245943`*^9, 
   3.604043314748054*^9}, {3.6040433534274893`*^9, 3.604043369394578*^9}, 
   3.60404350847479*^9, {3.61216642588039*^9, 3.612166429007922*^9}, 
   3.6192356125390587`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et1", "=", 
   RowBox[{"{", 
    RowBox[{"etx1", ",", "etx2", ",", "etx3", ",", "etx4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, {3.6040433875103607`*^9, 3.604043405643474*^9}, 
   3.604043511306425*^9, 3.604301558638516*^9, {3.604302156974309*^9, 
   3.604302158069281*^9}, {3.612166432744034*^9, 3.6121664410321913`*^9}, 
   3.619235615211533*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et2", "=", 
   RowBox[{"{", 
    RowBox[{"ety1", ",", "ety2", ",", "ety3", ",", "ety4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.604043389260811*^9, 
   3.6040434154828787`*^9}, 3.6040435138414288`*^9, {3.61216644492061*^9, 
   3.612166446303801*^9}, 3.6192356168433237`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{"etz1", ",", "etz2", ",", "etz3", ",", "etz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9, {3.612166449248323*^9, 
   3.6121664509560738`*^9}, 3.619235618371313*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et4", "=", 
   RowBox[{"{", 
    RowBox[{"etu1", ",", "etu2", ",", "etu3", ",", "etu4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.604043392149412*^9, 
   3.604043392255167*^9}, {3.6040434286448727`*^9, 3.604043435995811*^9}, 
   3.604043520033565*^9, {3.612166453399662*^9, 3.6121664555841017`*^9}, 
   3.6192356200145407`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "xi1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "et1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "xi2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "et2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "xi4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "et4"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     
     RowBox[{"sols", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.61216653422339*^9, 3.612166556960194*^9}, {
   3.612166600729034*^9, 3.6121666133164167`*^9}, {3.612258455793024*^9, 
   3.612258468175284*^9}, 3.6192356384135313`*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[LongEqual]", "xix2"}]},
      {
       RowBox[{"etx1", "\[LongEqual]", "etx2"}]},
      {
       RowBox[{
        RowBox[{"xiy1", "+", "xiy2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"ety1", "+", "ety2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"xiz1", "+", "xiz4"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"etz1", "+", "etz4"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{"xiu1", "\[LongEqual]", "xiu4"}]},
      {
       RowBox[{"etu1", "\[LongEqual]", "etu4"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166557730864*^9, 3.612166613587278*^9, 3.612257786626362*^9, {
   3.612258449865247*^9, 3.6122584694730263`*^9}, 3.612684401222273*^9, 
   3.6144153037766237`*^9, 3.614416733198262*^9, 3.614506942881184*^9, 
   3.6145770516151667`*^9, 3.614578403574582*^9, 3.6149384370663424`*^9, 
   3.615634998183165*^9, 3.6157168339297047`*^9, 3.61571741922215*^9, 
   3.6157966523647614`*^9, 3.6162158522704887`*^9, 3.6173373519442377`*^9, 
   3.6173395085025463`*^9, 3.618218625975627*^9, 3.619235639546756*^9, 
   3.619242887012747*^9, 3.6192436415076227`*^9, 3.6192530487462673`*^9, 
   3.619343630583494*^9, 3.6194119064607563`*^9, 3.6194127182382793`*^9, 
   3.619414427181924*^9, 3.6194153188634443`*^9, 3.619419046651602*^9, 
   3.619422177818959*^9, 3.619426801014042*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "=", 
   RowBox[{
    RowBox[{"FindInstance", "[", 
     RowBox[{"conditions", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
       "xi1", ",", "xi2", ",", "xi3", ",", "xi4", ",", "et1", ",", "et2", ",",
         "et3", ",", "et4"}], "]"}], ",", "2"}], "]"}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.612166575888966*^9, 3.612166576370742*^9}, {3.6121666241502*^9, 
   3.612166629642056*^9}, 3.6122577970426483`*^9, {3.6122584771168823`*^9, 
   3.612258481721101*^9}, 3.615716743846897*^9, {3.619235681872355*^9, 
   3.619235715558448*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.615716687944995*^9, 3.6157166901908703`*^9}, 
   3.615796959672283*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[Rule]", 
        RowBox[{
         FractionBox["19", "5"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{"xix2", "\[Rule]", 
        RowBox[{
         FractionBox["19", "5"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{"xix3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xix4", "\[Rule]", 
        RowBox[{
         FractionBox["1", "5"], "-", 
         FractionBox[
          RowBox[{"15", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xiy1", "\[Rule]", 
        RowBox[{"8", "+", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiy2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "8"}], "-", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiy3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["19", "2"]}], "+", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiy4", "\[Rule]", 
        RowBox[{
         FractionBox["27", "5"], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiz1", "\[Rule]", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiz2", "\[Rule]", 
        RowBox[{
         FractionBox["8", "5"], "+", 
         FractionBox[
          RowBox[{"53", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz3", "\[Rule]", 
        RowBox[{"7", "-", 
         FractionBox[
          RowBox[{"39", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox[
          RowBox[{"8", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu1", "\[Rule]", 
        RowBox[{
         FractionBox["3", "10"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}]}]},
      {
       RowBox[{"xiu2", "\[Rule]", 
        RowBox[{
         FractionBox["13", "2"], "+", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["67", "10"]}], "-", 
         FractionBox[
          RowBox[{"3", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiu4", "\[Rule]", 
        RowBox[{
         FractionBox["3", "10"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}]}]},
      {
       RowBox[{"etx1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["46", "5"]}], "-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["46", "5"]}], "-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx3", "\[Rule]", 
        RowBox[{"7", "+", 
         FractionBox[
          RowBox[{"37", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx4", "\[Rule]", 
        RowBox[{
         FractionBox["49", "5"], "-", 
         FractionBox[
          RowBox[{"47", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety1", "\[Rule]", 
        RowBox[{
         FractionBox["51", "10"], "+", 
         FractionBox[
          RowBox[{"19", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["51", "10"]}], "-", 
         FractionBox[
          RowBox[{"19", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["57", "10"]}], "-", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["15", "2"]}], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etz1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["13", "5"]}], "-", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etz2", "\[Rule]", 
        RowBox[{
         FractionBox["79", "10"], "+", 
         FractionBox[
          RowBox[{"28", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["19", "2"]}], "+", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz4", "\[Rule]", 
        RowBox[{
         FractionBox["13", "5"], "+", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etu1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["11", "5"]}], "+", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], "+", 
         RowBox[{"5", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etu3", "\[Rule]", 
        RowBox[{
         FractionBox["19", "2"], "+", 
         FractionBox[
          RowBox[{"33", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["11", "5"]}], "+", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]"}], "5"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.615716686264927*^9, 3.615716690541438*^9}, 
   3.615716837926202*^9, 3.6157969736709547`*^9, 3.616215854088387*^9, 
   3.617337353622591*^9, 3.617339509744925*^9, 3.6182186276162148`*^9, {
   3.6192356917235203`*^9, 3.619235718040629*^9}, 3.619242890133157*^9, 
   3.619243645459914*^9, 3.6192530517234907`*^9, 3.619343630684009*^9, 
   3.61941191005159*^9, 3.619412718328298*^9, 3.619414427263516*^9, 
   3.619415318955674*^9, 3.619419047458848*^9, 3.619422178175963*^9, 
   3.619426801113048*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"leg2k", "[", "l_", "]"}], "=", 
  RowBox[{"Switch", "[", 
   RowBox[{
   "l", ",", "1", ",", "k1", ",", "2", ",", "k2", ",", "3", ",", "k3", ",", 
    "4", ",", "k4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619236521062236*^9, 3.6192365496795073`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Switch", "[", 
   RowBox[{
   "l", ",", "\[IndentingNewLine]", "1", ",", "k1", ",", 
    "\[IndentingNewLine]", "2", ",", "k2", ",", "\[IndentingNewLine]", "3", 
    ",", "k3", ",", "\[IndentingNewLine]", "4", ",", "k4"}], "]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6192365504484243`*^9, 3.6192429019015207`*^9, 
  3.619243648336986*^9, 3.61925305403577*^9, 3.619343630733646*^9, 
  3.619411913551228*^9, 3.6194127183671503`*^9, 3.619414427316038*^9, 
  3.619415318982546*^9, 3.619419047660269*^9, 3.619422178254744*^9, 
  3.61942680114047*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ind2pols", "[", "i_", "]"}], "=", 
  RowBox[{"Switch", "[", 
   RowBox[{
   "i", ",", "a", ",", "xi1", ",", "b", ",", "et1", ",", "c", ",", "xi2", ",",
     "d", ",", "et2", ",", "e", ",", "xi3", ",", "f", ",", "et3", ",", "g", 
    ",", "xi4", ",", "h", ",", "et4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619236308508829*^9, 3.619236416287768*^9}, {
  3.6192374423377123`*^9, 3.6192374951804256`*^9}, {3.619237584106935*^9, 
  3.619237607040175*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Switch", "[", 
   RowBox[{
   "i", ",", "\[IndentingNewLine]", "a", ",", "xi1", ",", 
    "\[IndentingNewLine]", "b", ",", "et1", ",", "\[IndentingNewLine]", "c", 
    ",", "xi2", ",", "\[IndentingNewLine]", "d", ",", "et2", ",", 
    "\[IndentingNewLine]", "e", ",", "xi3", ",", "\[IndentingNewLine]", "f", 
    ",", "et3", ",", "\[IndentingNewLine]", "g", ",", "xi4", ",", 
    "\[IndentingNewLine]", "h", ",", "et4"}], "]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619236347953261*^9, 3.619236359045373*^9}, 
   3.6192364172726183`*^9, 3.619237449695252*^9, 3.619237495854807*^9, 
   3.619237607542542*^9, 3.6192429044198847`*^9, 3.619243650338719*^9, 
   3.6192530555236893`*^9, 3.619343630779799*^9, 3.619411914442868*^9, 
   3.619412718400263*^9, 3.619414427367017*^9, 3.619415319009656*^9, 
   3.6194190478606663`*^9, 3.619422178308936*^9, 3.619426801166912*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"indices", "=", 
  RowBox[{"{", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
    "h"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619239158604762*^9, 3.619239170171886*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
    "h"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619239171626947*^9, 3.6192429065479813`*^9, 3.619243651783976*^9, 
   3.6192530569798813`*^9, 3.619343630790625*^9, {3.6194119156498213`*^9, 
   3.619411936843273*^9}, 3.619412718439302*^9, 3.619414427431369*^9, 
   3.619415319031279*^9, 3.619419047962557*^9, 3.619422178358959*^9, 
   3.619426801191538*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"leg", ",", 
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind", "]"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{
             RowBox[{"leg2k", "[", "leg", "]"}], ",", 
             RowBox[{"ind2pols", "[", 
              RowBox[{"indices", "[", 
               RowBox[{"[", "ind", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"leg", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ind", ",", "1", ",", "8"}], "}"}]}], "]"}], ")"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"rules1", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619239137912868*^9, 3.619239142802182*^9}, {
  3.619239181944091*^9, 3.619239373739903*^9}, {3.6192394261171017`*^9, 
  3.619239427997581*^9}, {3.619239473148394*^9, 3.619239479671443*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["38", "5"]}], "-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"4", "-", 
         FractionBox[
          RowBox[{"73", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["18", "5"], "+", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["92", "5"], "+", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["3", "5"], "-", 
         FractionBox[
          RowBox[{"59", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "19"}], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "16"}], "-", 
         FractionBox[
          RowBox[{"77", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["67", "5"], "+", 
         FractionBox[
          RowBox[{"91", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["13", "5"], "+", 
         FractionBox[
          RowBox[{"63", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["51", "5"]}], "-", 
         FractionBox[
          RowBox[{"19", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["12", "5"]}], "+", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["63", "5"], "+", 
         FractionBox[
          RowBox[{"13", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["3", "5"], "+", 
         FractionBox[
          RowBox[{"69", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["13", "5"]}], "-", 
         FractionBox[
          RowBox[{"37", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"2", "-", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["21", "2"], "+", 
         FractionBox[
          RowBox[{"13", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["53", "10"]}], "-", 
         FractionBox[
          RowBox[{"47", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["26", "5"]}], "-", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["31", "5"], "+", 
         FractionBox[
          RowBox[{"27", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["34", "5"]}], "-", 
         FractionBox[
          RowBox[{"37", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["3", "5"], "+", "\[ImaginaryI]"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["21", "10"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["23", "10"], "-", 
         FractionBox[
          RowBox[{"49", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["22", "5"]}], "+", 
         FractionBox[
          RowBox[{"48", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.61923921283426*^9, 3.6192392238744507`*^9}, {
   3.619239296819813*^9, 3.6192393414974527`*^9}, 3.619239373991585*^9, 
   3.619239428356347*^9, 3.619239480439577*^9, 3.619242908197208*^9, 
   3.619243653772341*^9, 3.619253058148912*^9, 3.6193436308378563`*^9, 
   3.619412718504106*^9, 3.6194144275242243`*^9, 3.61941531906747*^9, 
   3.6194190481522017`*^9, 3.619422178443902*^9, 3.6194268012261667`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k3", ",", "et4"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239396112124*^9, 3.619239462797274*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["22", "5"]}], "+", 
   FractionBox[
    RowBox[{"48", " ", "\[ImaginaryI]"}], "5"]}], TraditionalForm]], "Output",\

 CellChangeTimes->{{3.6192394091672373`*^9, 3.6192394630970716`*^9}, 
   3.6192429108792257`*^9, 3.619243657538933*^9, 3.61925306056183*^9, 
   3.619343630892432*^9, 3.6194127185438004`*^9, 3.619414427582204*^9, 
   3.619415319087006*^9, 3.619419048276211*^9, 3.619422178516365*^9, 
   3.6194268012514153`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{
              RowBox[{"indices", "[", 
               RowBox[{"[", "ind", "]"}], "]"}], ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", " ", 
          RowBox[{"min", "[", 
           RowBox[{"qq", ",", 
            RowBox[{"ind2pols", "[", 
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ind", ",", "1", ",", "8"}], "}"}]}], "]"}], ")"}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"sols", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"sols$pol", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"solsQ", "[", 
         RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"rules2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619239498168215*^9, 3.61923950278657*^9}, {
  3.619239533212517*^9, 3.619239653462655*^9}, {3.619246060578376*^9, 
  3.619246065085746*^9}, {3.6192460967103662`*^9, 3.619246105142829*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          TagBox[
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
           Function[BoxForm`e$, 
            TableForm[BoxForm`e$]]],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 1243, 23719710895012768101, 
            5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 1243, 23719710895012768101, 
            5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 1243, 23719710895012768101, 
            Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[1243]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619239655223105*^9, 3.619242912013666*^9, 
  3.619243658775285*^9, 3.619246111099959*^9, 3.619246943666779*^9, 
  3.619247189962232*^9, 3.619247409699597*^9, 3.61925020872122*^9, 
  3.6192530627606363`*^9, 3.619253819672687*^9, 3.619259231805781*^9, 
  3.619259714922319*^9, 3.6192597910059633`*^9, 3.6193436333112383`*^9, 
  3.619412547566163*^9, 3.619412718821464*^9, 3.6194144304394007`*^9, 
  3.6194153240745573`*^9, 3.619419051850832*^9, 3.619422181693461*^9, 
  3.619426802277384*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"qq", ",", "et2"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"solsQ", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239664221813*^9, 3.6192396792379*^9}, {
  3.619253086407671*^9, 3.6192530905073223`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["152939", "100"], "+", 
     FractionBox[
      RowBox[{"659423", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["3", "4"], "+", 
      FractionBox[
       RowBox[{"7", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "39248715"}], "-", 
      RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619239666472765*^9, 3.619239679962988*^9}, 
   3.619242914306307*^9, 3.6192436608671427`*^9, {3.619253066756884*^9, 
   3.619253090890196*^9}, 3.6192592368026037`*^9, 3.6193436335131197`*^9, 
   3.6194127188890676`*^9, 3.619414430523732*^9, 3.619415324149371*^9, 
   3.619419052005918*^9, 3.61942218183997*^9, 3.619426802331985*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules3", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind1", "]"}], "]"}], ",", "D"}], "]"}], ",", 
           RowBox[{"LorentzIndex", "[", 
            RowBox[{
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind2", "]"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
         "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"ind2pols", "[", 
            RowBox[{"indices", "[", 
             RowBox[{"[", "ind1", "]"}], "]"}], "]"}], ",", 
           RowBox[{"ind2pols", "[", 
            RowBox[{"indices", "[", 
             RowBox[{"[", "ind2", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ind2", ",", 
          RowBox[{"ind1", "+", "1"}], ",", "8"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ind1", ",", "1", ",", "8"}], "}"}]}], "]"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"sols$pol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239941847797*^9, 3.6192399886826353`*^9}, 
   3.619240025873451*^9, {3.61924005782653*^9, 3.6192400996716957`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "b"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["7017", "100"]}], "-", 
      FractionBox[
       RowBox[{"2391", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["551", "50"]}], "-", 
      FractionBox[
       RowBox[{"6147", " ", "\[ImaginaryI]"}], "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "d"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1271", "100"]}], "+", 
      FractionBox[
       RowBox[{"6359", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["531", "50"]}], "+", 
      FractionBox[
       RowBox[{"1454", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "f"}]], "\[Rule]", 
     RowBox[{
      FractionBox["8339", "100"], "-", 
      FractionBox[
       RowBox[{"138", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["5399", "100"], "+", 
      FractionBox[
       RowBox[{"251", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["121", "50"]}], "+", 
      FractionBox[
       RowBox[{"91", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "c"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2599", "25"], "+", 
      FractionBox[
       RowBox[{"2393", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2957", "100"], "-", 
      FractionBox[
       RowBox[{"2049", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "e"}]], "\[Rule]", 
     RowBox[{
      FractionBox["3917", "50"], "-", 
      FractionBox[
       RowBox[{"483", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2571", "20"]}], "-", 
      FractionBox[
       RowBox[{"1433", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["9319", "100"]}], "-", 
      FractionBox[
       RowBox[{"8047", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["21", "50"]}], "+", 
      FractionBox[
       RowBox[{"4238", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "d"}]], "\[Rule]", 
     RowBox[{
      FractionBox["3311", "100"], "+", 
      FractionBox[
       RowBox[{"4519", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["5709", "100"]}], "+", 
      FractionBox[
       RowBox[{"1147", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "f"}]], "\[Rule]", 
     RowBox[{
      FractionBox["4793", "50"], "-", 
      FractionBox[
       RowBox[{"9651", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1969", "50"], "-", 
      FractionBox[
       RowBox[{"9207", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["3083", "100"]}], "-", 
      FractionBox[
       RowBox[{"311", " ", "\[ImaginaryI]"}], "4"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["3377", "50"]}], "-", 
      FractionBox[
       RowBox[{"3339", " ", "\[ImaginaryI]"}], "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1013", "50"], "+", 
      FractionBox[
       RowBox[{"1413", " ", "\[ImaginaryI]"}], "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["633", "100"], "+", 
      FractionBox[
       RowBox[{"351", " ", "\[ImaginaryI]"}], "20"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "h"}]], "\[Rule]", 
     RowBox[{
      FractionBox["1172", "25"], "-", 
      FractionBox[
       RowBox[{"4771", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["4099", "50"]}], "+", 
      FractionBox[
       RowBox[{"2267", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["5683", "100"]}], "+", 
      FractionBox[
       RowBox[{"1589", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "h"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2731", "50"], "-", 
      FractionBox["\[ImaginaryI]", "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"f", "g"}]], "\[Rule]", 
     RowBox[{
      FractionBox["4893", "50"], "+", 
      FractionBox[
       RowBox[{"6499", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"f", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["3544", "25"]}], "+", 
      FractionBox[
       RowBox[{"26", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"g", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1958", "25"]}], "-", 
      FractionBox[
       RowBox[{"1489", " ", "\[ImaginaryI]"}], "100"]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.61924010032931*^9, 3.619242915317422*^9, 
  3.619243662861741*^9, 3.619247195513521*^9, 3.61925310552606*^9, 
  3.619343633581479*^9, 3.6194127189564962`*^9, 3.619414430602275*^9, 
  3.619415324225881*^9, 3.619419052085876*^9, 3.6194221819369383`*^9, 
  3.619426802403808*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"xi1", ",", "et2"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61924014756181*^9, 3.619240162565056*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1271", "100"]}], "+", 
   FractionBox[
    RowBox[{"6359", " ", "\[ImaginaryI]"}], "100"]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619240158523693*^9, 3.619240163202877*^9}, 
   3.61924291753172*^9, 3.61924366653813*^9, 3.619253108251897*^9, 
   3.61934363362945*^9, 3.619412718995681*^9, 3.619414430667799*^9, 
   3.6194153242803783`*^9, 3.619419052229499*^9, 3.619422181990479*^9, 
   3.619426802445356*^9}]
}, Open  ]],

Cell[TextData[{
 "Before choosing polarizations we contract the index a into ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 "in order to check the Ward identity."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}, {3.619235593173221*^9, 3.619235598976385*^9}, {
   3.619411957188622*^9, 3.619412060723302*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesward1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"leg", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"leg2k", "[", "leg", "]"}], ",", 
           RowBox[{"leg2k", "[", "1", "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"leg", ",", "1", ",", "4"}], "}"}]}], "]"}], ")"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"rulesward1", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619412156842771*^9, 3.619412191524993*^9}, {
  3.619412224880752*^9, 3.619412263898706*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"-", "2"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "1"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "1"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619412196401766*^9, 3.6194122656343946`*^9}, 
   3.619412719030764*^9, 3.6194144307165117`*^9, 3.619415324329966*^9, 
   3.619419052290638*^9, 3.619422182062059*^9, 3.619426802474309*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k1", ",", "k4"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619412278062975*^9, 3.619412296012594*^9}}],

Cell[BoxData[
 FormBox["1", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6194122847719707`*^9, 3.619412296204054*^9}, 
   3.619412719069291*^9, 3.6194144307238827`*^9, 3.6194153243830233`*^9, 
   3.619419052322007*^9, 3.619422182101104*^9, 3.619426802498228*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesward2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", " ", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", 
          RowBox[{"ind2pols", "[", "a", "]"}]}], "]"}]}], ")"}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"sols", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"sols$pol", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"solsQ", "[", 
         RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"rulesward2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619412453834653*^9, 3.619412593462965*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["212461", "50"], "-", 
           FractionBox[
            RowBox[{"29699", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "39248715"}], "-", 
            RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["384637", "50"], "-", 
           FractionBox[
            RowBox[{"40583", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "53860771"}], "-", 
            RowBox[{"117222224", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["314787", "50"]}], "-", 
           FractionBox[
            RowBox[{"38527", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"2556694", "-", 
            FractionBox[
             RowBox[{"62817937", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["256447", "50"], "+", 
           FractionBox[
            RowBox[{"41707", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["42848963", "2"]}], "-", 
            FractionBox[
             RowBox[{"24816389", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["8743", "5"], "-", 
           FractionBox[
            RowBox[{"31809", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"25707729", "+", 
            RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["180657", "50"], "+", 
           FractionBox[
            RowBox[{"302187", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "659273"}], "+", 
            RowBox[{"54378224", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3086", "+", 
           FractionBox[
            RowBox[{"131754", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"94240593", "+", 
            RowBox[{"110752716", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["148527", "50"], "-", 
           FractionBox[
            RowBox[{"129249", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"3857491", "-", 
            RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["172269", "25"]}], "-", 
           FractionBox[
            RowBox[{"11522", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "63826433"}], "-", 
            RowBox[{"50919660", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["8782", "25"]}], "-", 
           FractionBox[
            RowBox[{"86179", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["65436529", "2"], "+", 
            FractionBox[
             RowBox[{"78545351", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["80979", "25"]}], "+", 
           FractionBox[
            RowBox[{"104376", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "9953283"}], "-", 
            FractionBox[
             RowBox[{"41395173", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["153567", "50"]}], "+", 
           FractionBox[
            RowBox[{"122719", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "80631363"}], "-", 
            RowBox[{"122217310", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["29139", "50"]}], "+", 
           FractionBox[
            RowBox[{"160393", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "45131215"}], "+", 
            RowBox[{"183702246", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["71911", "50"]}], "-", 
           FractionBox[
            RowBox[{"32517", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["1339619", "2"]}], "-", 
            RowBox[{"37646268", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["59897", "25"]}], "+", 
           FractionBox[
            RowBox[{"130716", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["53713307", "2"]}], "+", 
            FractionBox[
             RowBox[{"75737837", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["44453", "50"]}], "+", 
           FractionBox[
            RowBox[{"175081", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1480995"}], "+", 
            RowBox[{"13716098", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["102839", "50"], "-", 
           FractionBox[
            RowBox[{"147681", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "132663833"}], "-", 
            RowBox[{"27289664", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["21521", "10"], "-", 
           FractionBox[
            RowBox[{"62457", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "10"], "-", 
            FractionBox[
             RowBox[{"15", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["13794847", "5"], "+", 
            FractionBox[
             RowBox[{"35102304", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["44839", "10"], "-", 
           FractionBox[
            RowBox[{"9419", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "5698344"}], "-", 
            FractionBox[
             RowBox[{"16992563", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["11313", "25"]}], "-", 
           FractionBox[
            RowBox[{"225724", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"72901243", "+", 
            RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["72971", "50"], "-", 
           FractionBox[
            RowBox[{"212853", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"66974411", "+", 
            RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["157246", "25"]}], "-", 
           FractionBox[
            RowBox[{"135772", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "35886557"}], "+", 
            RowBox[{"123161326", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["74068", "25"]}], "+", 
           FractionBox[
            RowBox[{"5331", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"97931047", "-", 
            RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["45387", "25"], "+", 
           FractionBox[
            RowBox[{"12311", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "61854981"}], "+", 
            RowBox[{"13100900", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["414607", "50"]}], "-", 
           FractionBox[
            RowBox[{"3443", " ", "\[ImaginaryI]"}], "2"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"15330032", "-", 
            FractionBox[
             RowBox[{"117013109", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["109271", "50"]}], "-", 
           FractionBox[
            RowBox[{"13687", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["5359215", "2"]}], "+", 
            RowBox[{"44541539", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["130418", "25"]}], "-", 
           FractionBox[
            RowBox[{"1161", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["80858931", "2"], "-", 
            RowBox[{"9394224", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["220461", "50"]}], "-", 
           FractionBox[
            RowBox[{"9957", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["47348499", "2"]}], "+", 
            FractionBox[
             RowBox[{"55778667", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["69761", "25"]}], "-", 
           FractionBox[
            RowBox[{"123756", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["14127815", "2"]}], "-", 
            FractionBox[
             RowBox[{"38499453", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["60347", "50"]}], "-", 
           FractionBox[
            RowBox[{"70493", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "8692743"}], "+", 
            FractionBox[
             RowBox[{"29528399", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["11785", "2"]}], "-", 
           FractionBox[
            RowBox[{"48731", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["7602011", "2"]}], "-", 
            RowBox[{"46151976", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2515"}], "-", 
           FractionBox[
            RowBox[{"27789", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "132365619"}], "+", 
            RowBox[{"97171760", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["18267", "10"], "+", 
           FractionBox[
            RowBox[{"427161", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"116782515", "+", 
            RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["237503", "50"]}], "+", 
           FractionBox[
            RowBox[{"23377", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "130493933"}], "-", 
            RowBox[{"44980416", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["120897", "25"]}], "+", 
           FractionBox[
            RowBox[{"54746", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["2", "25"], "-", 
            RowBox[{"3", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["6105717", "2"]}], "+", 
            FractionBox[
             RowBox[{"837407", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["38549", "25"]}], "-", 
           FractionBox[
            RowBox[{"30337", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"46652379", "-", 
            RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["22757", "10"]}], "+", 
           FractionBox[
            RowBox[{"498557", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"126323851", "-", 
            RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3169"}], "+", 
           FractionBox[
            RowBox[{"49692", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"22120483", "+", 
            RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["239193", "50"]}], "-", 
           FractionBox[
            RowBox[{"158833", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "25"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "2"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["8578619", "2"], "+", 
            RowBox[{"5016716", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["91047", "50"], "+", 
           FractionBox[
            RowBox[{"19973", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "50"], "-", 
            FractionBox[
             RowBox[{"3", " ", "\[ImaginaryI]"}], "4"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "17109005"}], "+", 
            RowBox[{"160010166", " ", "\[ImaginaryI]"}]}]]}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619412496418803*^9, 3.61941255225438*^9, {3.6194125834607363`*^9, 
   3.6194125943428373`*^9}, 3.619412719110879*^9, 3.619414431064124*^9, 
   3.61941532503345*^9, 3.619419053613039*^9, 3.619422182656433*^9, 
   3.619426802651812*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rulesward3", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dc", "[", 
      RowBox[{"a", ",", 
       RowBox[{"indices", "[", 
        RowBox[{"[", "ind", "]"}], "]"}]}], "]"}], "\[Rule]", 
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", 
       RowBox[{"indices", "[", 
        RowBox[{"[", "ind", "]"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"ind", ",", "2", ",", "8"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619412313576882*^9, 3.619412402678738*^9}, 
   3.6194124360974817`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "b"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "d"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "f"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "h"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["h",
        TraditionalForm],
       TraditionalForm]]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619412403806982*^9, 3.6194124466630287`*^9, 
  3.619412719167528*^9, 3.6194144311622543`*^9, 3.619415325227663*^9, 
  3.619419053864347*^9, 3.619422182830111*^9, 3.6194268026772423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$ward", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"amp4$qlightcone2", "/.", 
     RowBox[{"Join", "[", 
      RowBox[{"rulesward1", ",", 
       RowBox[{"{", 
        RowBox[{"rulesward2", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], "}"}], ",", "rulesward3"}], "]"}]}],
     ",", 
    RowBox[{"{", 
     RowBox[{"iq", ",", "1", ",", 
      RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619412063800127*^9, 3.619412070470079*^9}, {
  3.619412610431522*^9, 3.619412618367523*^9}, {3.6194129261265993`*^9, 
  3.6194129692352467`*^9}, {3.619413016601595*^9, 3.619413027674564*^9}, {
  3.619413131136685*^9, 3.619413134234509*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"\[LeftSkeleton]", "16515", "\[RightSkeleton]"}], "+", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], " ", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
              RowBox[{"4", " ", 
               SuperscriptBox["s", "3"]}]], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                 TraditionalForm]], " ", 
               SuperscriptBox["g", 
                RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["s", "3"]}]], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SuperscriptBox["g", 
                RowBox[{"b", "d"}]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["c",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["e",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["s", "3"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SuperscriptBox["g", 
                RowBox[{"b", "c"}]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["d",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["e",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["s", "3"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["b",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["c",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["d",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["e",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"4", " ", 
               SuperscriptBox["s", "3"]}]]}], ",", 
            RowBox[{
             RowBox[{"\[LeftSkeleton]", "16522", "\[RightSkeleton]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], " ", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
              RowBox[{"4", " ", 
               SuperscriptBox["s", "3"]}]]}], ",", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ",", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ",", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ",", 
            RowBox[{"\[LeftSkeleton]", "31", "\[RightSkeleton]"}], ",", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ",", 
            RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], ",", 
            RowBox[{
             RowBox[{"\[LeftSkeleton]", "16521", "\[RightSkeleton]"}], "+", 
             RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"\[LeftSkeleton]", "7", "\[RightSkeleton]"}], " ", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
              RowBox[{"4", " ", 
               SuperscriptBox["s", "3"]}]]}], ",", 
            RowBox[{
             RowBox[{"\[LeftSkeleton]", "16521", "\[RightSkeleton]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"\[LeftSkeleton]", "6", "\[RightSkeleton]"}], " ", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["s", "3"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["b",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["c",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"4", " ", 
               SuperscriptBox["s", "3"]}]]}]}], "}"}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1251, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1251, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1251, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[1251]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619412726823831*^9, 3.619413101047892*^9, 
  3.6194132063152122`*^9, 3.619415157101575*^9, 3.619418408999012*^9, 
  3.619419815331244*^9, 3.6194229249271183`*^9, 3.619427100769333*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Filter", "[", 
    RowBox[{
     RowBox[{"amp4$qlightcone2$ward", "[", 
      RowBox[{"[", "iq", "]"}], "]"}], ",", 
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"a", ",", "D"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"iq", ",", "1", ",", 
     RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619412776495097*^9, 3.619412795255933*^9}, {
  3.6194132140187483`*^9, 3.619413236804791*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6194127966598873`*^9, 3.619413240947672*^9, 
  3.619415192171403*^9, 3.619418645277316*^9, 3.6194198597523623`*^9, 
  3.619422960083191*^9, 3.619427114704173*^9}]
}, Open  ]],

Cell["\<\
Now all indices a have gone. We can therefore savely apply the original rules \
for the contractions into polarizations.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}, {3.619235593173221*^9, 3.619235598976385*^9}, {
   3.619411957188622*^9, 3.619412060723302*^9}, {3.619412811354751*^9, 
   3.6194128551686296`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$ward2", "=", 
  RowBox[{"N", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"amp4$qlightcone2$ward", "[", 
       RowBox[{"[", "iq", "]"}], "]"}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"rules0", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], ",", "rules1", ",", 
        RowBox[{"rules2", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], ",", "rules3"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.619174090652886*^9, 3.6191740932519493`*^9}, {
   3.6191741401679697`*^9, 3.6191741406610947`*^9}, {3.61923575463708*^9, 
   3.6192357570857067`*^9}, {3.619236448618927*^9, 3.619236504574319*^9}, {
   3.619236563719427*^9, 3.619236567088612*^9}, {3.619236864755721*^9, 
   3.619236867380209*^9}, {3.61923695240946*^9, 3.619236981307167*^9}, {
   3.6192370158471622`*^9, 3.6192370436549377`*^9}, {3.619237081637163*^9, 
   3.6192370857360153`*^9}, {3.619237181822341*^9, 3.619237222082407*^9}, 
   3.619237292907866*^9, {3.6192377416628027`*^9, 3.619237776673604*^9}, {
   3.619237877858811*^9, 3.619238191513442*^9}, {3.619238234861478*^9, 
   3.61923835670647*^9}, {3.619240181475733*^9, 3.619240188813858*^9}, {
   3.6192461927732477`*^9, 3.6192462234944773`*^9}, {3.619246283517706*^9, 
   3.6192462902520113`*^9}, 3.619246408486841*^9, {3.619246958317753*^9, 
   3.61924696063234*^9}, {3.619247426612483*^9, 3.619247427423375*^9}, 
   3.619259918646023*^9, {3.6194126257666893`*^9, 3.6194126279267187`*^9}, {
   3.619413263733199*^9, 3.61941326610187*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.9248495208139922`*^6", "-", 
        RowBox[{"2.901609623557738`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.2404421982773095`*^6", "-", 
        RowBox[{"5.846336164631487`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.25507494890779`*^6", "-", 
        RowBox[{"827784.8737676461`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0685284785984913`*^6", "-", 
        RowBox[{"1.0357229430288851`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"299760.3421372047`", "\[VeryThinSpace]", "+", 
        RowBox[{"191095.5871524415`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7939458427792385`*^7", "-", 
        RowBox[{"2.3891861426035814`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.535974775144815`*^6", "-", 
        RowBox[{"9.383854174786389`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"918860.071275467`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.656391956786986`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0607170240751961`*^6", "-", 
        RowBox[{"5.095520719071757`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.581644134862979`*^6", "-", 
        RowBox[{"1.4034194052383741`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.545517720901604`*^7", "-", 
        RowBox[{"1.3628916720026037`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.949728919285718`*^6", "-", 
        RowBox[{"376734.9662665259`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3114548141409416`*^7", "-", 
        RowBox[{"1.5193086315653404`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.324776046860317`*^7", "-", 
        RowBox[{"3.46771741697262`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.13961283230544`*^6", "-", 
        RowBox[{"7.067883972453207`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.595783035597999`*^6", "-", 
        RowBox[{"6.987017881585723`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7219373714091063`*^7", "-", 
        RowBox[{"9.12961424223362`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.748962941415725`*^7", "+", 
        RowBox[{"4.065124901273926`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.459420313716885`*^6", "-", 
        RowBox[{"1.8954156433620173`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.775012991180202`*^6", "-", 
        RowBox[{"4.840142184435768`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"587720.7960558294`", "\[VeryThinSpace]", "+", 
        RowBox[{"934259.806112923`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5002010788271725`*^6", "-", 
        RowBox[{"4.58502850987996`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"742061.3772126419`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.2335194476156766`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3935108934867132`*^7", "-", 
        RowBox[{"8.948025591046529`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.080052353005258`*^6", "-", 
        RowBox[{"4.5879969055610765`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.990165834262596`*^6", "+", 
        RowBox[{"318863.45295898966`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8391952212772751`*^6", "+", 
        RowBox[{"2.9659721236951267`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2665547191952`*^6", "-", 
        RowBox[{"2.2983476279846914`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6715610083260216`*^7", "+", 
        RowBox[{"4.216357047193646`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.813622729893908`*^6", "+", 
        RowBox[{"1.3195648132450376`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1180528857732877`*^7", "-", 
        RowBox[{"1.406022684709815`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.103129215245612`*^6", "+", 
        RowBox[{"3.898040834842997`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.927402237022625`*^6", "-", 
        RowBox[{"3.931214743498557`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.789709211850492`*^6", "+", 
        RowBox[{"4.062209155138471`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.699336014973156`*^6", "+", 
        RowBox[{"2.3516546960885927`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2255143583297998`*^7", "-", 
        RowBox[{"1.7073681985678416`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.3339553499`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5749151938481431`*^7", "+", 
        RowBox[{"6.618958557979744`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.506474461594475`*^7", "+", 
        RowBox[{"3.674232016905993`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"932976.9517983261`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.547775630762367`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.122946423836172`*^6", "+", 
        RowBox[{"2.5728626710682577`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"380827.0642879074`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.162999640356569`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9475200105109088`*^7", "+", 
        RowBox[{"1.665596313033946`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.566888270294668`*^6", "+", 
        RowBox[{"1.2641909418769944`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"771472.467843385`", "\[VeryThinSpace]", "+", 
        RowBox[{"560602.6749898288`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.765074017124138`*^6", "+", 
        RowBox[{"3.4674358494769456`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.704924488239612`*^6", "+", 
        RowBox[{"6.947407403928462`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1440395632179335`*^7", "+", 
        RowBox[{"1.2605629293901693`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5535775278956706`*^7", "+", 
        RowBox[{"1.2511305059391495`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.362902160865802`*^7", "+", 
        RowBox[{"2.1386701593046904`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4825634446649905`*^7", "+", 
        RowBox[{"2.1990173436647348`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4223285321178515`*^7", "+", 
        RowBox[{"8.476222102370452`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4746225099751238`*^7", "+", 
        RowBox[{"9.686031522948988`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0809929648244074`*^7", "+", 
        RowBox[{"3.577935021678388`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.655926190827888`*^7", "-", 
        RowBox[{"5.4301594635349184`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764614`*^6"}], "-", 
        RowBox[{"432555.3339553501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.8525196864876226`*^7", "+", 
        RowBox[{"5.296965391597552`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.784078954233954`*^7", "+", 
        RowBox[{"5.002492737490177`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77120.83317045681`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.184018120130403`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9554934599965118`*^7", "+", 
        RowBox[{"1.3156449398389652`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5453255246282425`*^6", "+", 
        RowBox[{"1.8068775985210182`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.305542588641475`*^7", "+", 
        RowBox[{"6.445074840082961`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.133570235186375`*^7", "+", 
        RowBox[{"5.279819505367368`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.752793896567274`*^6", "+", 
        RowBox[{"741049.1317249525`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7638495165766552`*^7", "+", 
        RowBox[{"4.954246938648683`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.698074034368874`*^7", "+", 
        RowBox[{"4.24315657988255`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.9831311370910305`*^8", "-", 
        RowBox[{"2.269325635413279`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1381839337723489`*^8", "+", 
        RowBox[{"3.0505975524701774`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.527645568425951`*^7", "+", 
        RowBox[{"9.598670166280704`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0809191721446306`*^7", "+", 
        RowBox[{"1.8099826395093042`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119985`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.402534921556383`*^6", "+", 
        RowBox[{"6.358961493422879`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.208310910482901`*^7", "+", 
        RowBox[{"1.9880127394831207`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.162988725265749`*^8", "-", 
        RowBox[{"5.210460143419819`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2953822579407742`*^9", "+", 
        RowBox[{"1.262202257345078`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1291172509652786`*^6", "+", 
        RowBox[{"604888.4480486885`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8135245735019594`*^6", "+", 
        RowBox[{"3.5496149891224396`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7692582756170917`*^6", "-", 
        RowBox[{"73961.74966000707`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"401758.3122586999`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.2204145013583858`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"404471.7044798117`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.0115373173861403`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.188198149852055`*^7", "-", 
        RowBox[{"2.8853521145931132`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4430142875515781`*^6", "+", 
        RowBox[{"8.539532797393743`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"671824.0799438303`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.2585699221288804`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.403992304462086`*^6", "-", 
        RowBox[{"7.359464148364259`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.251584716783914`*^6", "-", 
        RowBox[{"6.088191858649274`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.431294457904175`*^6", "-", 
        RowBox[{"3.1452457244826473`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.194817093527071`*^6", "-", 
        RowBox[{"1.702474746220871`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3928252647865102`*^7", "+", 
        RowBox[{"3.230925833010919`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.310664548596111`*^7", "-", 
        RowBox[{"9.046092826302925`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.260171753456343`*^6", "+", 
        RowBox[{"1.2402300912430298`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.136319414772958`*^6", "+", 
        RowBox[{"1.3769998821816128`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.7830688354573846`*^6", "-", 
        RowBox[{"7.65541303691203`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0223464979333527`*^7", "-", 
        RowBox[{"3.785509868090609`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.33395535004`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.880048193532951`*^6", "-", 
        RowBox[{"411995.28898786684`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1956408709962694`*^6", "-", 
        RowBox[{"3.3567218300616164`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"934407.6133774881`", "\[VeryThinSpace]", "-", 
        RowBox[{"596122.1112257787`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.361676039985425`*^6", "-", 
        RowBox[{"7.390176626075`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"340449.4771711413`", "\[VeryThinSpace]", "+", 
        RowBox[{"979787.3052237933`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8297019597969793`*^7", "-", 
        RowBox[{"6.896897201045323`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9687897427454656`*^6", "-", 
        RowBox[{"4.640041229645032`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"54393.17745301954`", "\[VeryThinSpace]", "-", 
        RowBox[{"204173.64147997717`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.273006075747534`*^6", "-", 
        RowBox[{"2.563578890053693`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1007875552536575`*^6", "-", 
        RowBox[{"211538.05151395453`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.835906507851658`*^6", "+", 
        RowBox[{"1.1096007821429338`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.103076101775034`*^6", "-", 
        RowBox[{"2.038108903414839`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1219458697330877`*^7", "-", 
        RowBox[{"7.840309736705497`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.735599828778919`*^6", "-", 
        RowBox[{"3.0261115251669697`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.396451155698708`*^7", "-", 
        RowBox[{"4.841527924781887`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4368507444844544`*^7", "-", 
        RowBox[{"4.1378020454567745`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2109981146181857`*^7", "+", 
        RowBox[{"1.0137534187839558`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2588265399352416`*^7", "+", 
        RowBox[{"2.0518496437921725`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.842841596777965`*^7", "+", 
        RowBox[{"1.5302071958193399`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7744008645242974`*^7", "+", 
        RowBox[{"1.235734541711965`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"659271.8617247525`", "\[VeryThinSpace]", "+", 
        RowBox[{"4.2419692552124`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0397751979158763`*^7", "+", 
        RowBox[{"1.2737261798090113`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.28309365996099`*^6", "+", 
        RowBox[{"2.9002964125499413`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.974457296784621`*^7", "+", 
        RowBox[{"2.538053478003522`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.148334516173154`*^6", "+", 
        RowBox[{"4.223960684476176`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.267401228042897`*^6", "+", 
        RowBox[{"3.0213475364442053`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5042582393937252`*^7", "+", 
        RowBox[{"2.2689431388962984`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2187877172270559`*^7", "+", 
        RowBox[{"7.951970051111139`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.0631239670207396`*^7", "+", 
        RowBox[{"2.444725236429207`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.680789322470263`*^7", "+", 
        RowBox[{"1.6045256453555375`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"885378.4231227869`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.1512499300747242`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.426016632075657`*^7", "+", 
        RowBox[{"3.423329542654893`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.24606020090366`*^6", "-", 
        RowBox[{"4.296568796414426`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6196092557685355`*^7", "+", 
        RowBox[{"1.8900009580498353`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.604481427883746`*^8", "+", 
        RowBox[{"4.0184697982436605`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5570841993389937`*^8", "+", 
        RowBox[{"1.0449706630693993`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.3339553499`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4074692256347332`*^6", "+", 
        RowBox[{"5.965537769081029`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.091876548171414`*^6", "+", 
        RowBox[{"8.91026431015478`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2331574445955222`*^6", "-", 
        RowBox[{"987629.4789248314`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8803993736445624`*^6", "-", 
        RowBox[{"7.355812362275398`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"621736.5913719512`", "\[VeryThinSpace]", "+", 
        RowBox[{"195294.1386271519`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.28583888477891`*^7", "-", 
        RowBox[{"1.992236269578567`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.217876387540032`*^6", "-", 
        RowBox[{"7.237336693448716`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"183892.24034231063`", "\[VeryThinSpace]", "-", 
        RowBox[{"295270.43168693397`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.760715144185289`*^6", "+", 
        RowBox[{"1.3944033989705779`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.341699544456819`*^6", "+", 
        RowBox[{"1.3621003593553118`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"535072.0604204051`", "\[VeryThinSpace]", "+", 
        RowBox[{"6.716357185010191`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.843327028957397`*^6", "+", 
        RowBox[{"1.881945964534647`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.788199367652109`*^6", "+", 
        RowBox[{"2.026204231769689`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5221702531219836`*^7", "+", 
        RowBox[{"6.894707769126688`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"938175.0406599585`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.0212344124732642`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"226632.16520221997`", "\[VeryThinSpace]", "+", 
        RowBox[{"672082.7452521224`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.854163942010714`*^6", "-", 
        RowBox[{"6.339648462258282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2044111826929476`*^7", "-", 
        RowBox[{"3.678882815985214`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.3339553499`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.359687805060258`*^6", "-", 
        RowBox[{"522396.60444201063`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.6752804825235773`*^6", "-", 
        RowBox[{"3.4671231455157604`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2819482717874185`*^6", "+", 
        RowBox[{"101702.21193689236`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.342015436115633`*^6", "+", 
        RowBox[{"4.368961275210358`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.716837642941676`*^6", "+", 
        RowBox[{"635670.2017739681`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.142849925627265`*^6", "+", 
        RowBox[{"4.002608366463257`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.998317584617797`*^6", "-", 
        RowBox[{"120666.93885946681`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.668064704552232`*^6", "+", 
        RowBox[{"2.131749113193173`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.608376760716742`*^6", "-", 
        RowBox[{"1.0256300783591976`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.078606892819074`*^6", "-", 
        RowBox[{"5.456692196399641`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3038405173042174`*^7", "-", 
        RowBox[{"7.201326022773747`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1539506583907403`*^7", "-", 
        RowBox[{"1.3373582067164756`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.446065206285216`*^6", "+", 
        RowBox[{"5.079770423418565`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.488848693130651`*^6", "-", 
        RowBox[{"1.3808571508392172`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5094257921198704`*^6", "-", 
        RowBox[{"1.0098845593062346`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.093667713541222`*^6", "-", 
        RowBox[{"4.6783722071467545`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.699821848422926`*^7", "-", 
        RowBox[{"2.135434476009664`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.523850353980832`*^6", "+", 
        RowBox[{"5.205604023643481`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.3339553499`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.94879045118645`*^6", "-", 
        RowBox[{"3.5003100722915577`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.264383128649769`*^6", "-", 
        RowBox[{"6.445036613365309`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4110062110644607`*^6", "+", 
        RowBox[{"867866.8262564332`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.560021801969369`*^6", "-", 
        RowBox[{"4.561748664681161`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"770203.0155108545`", "\[VeryThinSpace]", "+", 
        RowBox[{"306185.5299740446`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2964735343289284`*^7", "-", 
        RowBox[{"1.2213532587412968`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"997821.2935051566`", "\[VeryThinSpace]", "-", 
        RowBox[{"4.839623311225794`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"568178.1736123527`", "\[VeryThinSpace]", "-", 
        RowBox[{"719767.8929066337`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3280698101330772`*^6", "-", 
        RowBox[{"1.664079697815606`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"287118.0333253518`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.8321857353920396`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4479212367158096`*^7", "-", 
        RowBox[{"1.483549383868262`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7293119711498227`*^6", "-", 
        RowBox[{"5.633573756495974`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0434961315458356`*^6", "+", 
        RowBox[{"9.728099924039954`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.7121372356898896`*^6", "+", 
        RowBox[{"549021.9432098251`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119991`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.160749023947148`*^6", "+", 
        RowBox[{"5.120003084656319`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5193418209303862`*^6", "+", 
        RowBox[{"4.794608083392687`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.074144015834728`*^6", "+", 
        RowBox[{"7.08166387152197`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.265820799414344`*^6", "+", 
        RowBox[{"2.25220142661741`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.509679474229291`*^6", "-", 
        RowBox[{"7.468202283128371`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"825272.1516926084`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.041292882420212`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.22359426788698`*^6", "-", 
        RowBox[{"1.2884751529234177`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"870702.0547025595`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.461457598500533`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"38900.44905936008`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.241650654766252`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.974127761119185`*^7", "-", 
        RowBox[{"1.7385052025986955`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.497054741839434`*^6", "-", 
        RowBox[{"5.901791976364203`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3177897408399177`*^6", "+", 
        RowBox[{"286634.1582382045`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.357270536116114`*^6", "+", 
        RowBox[{"4.1688297209807886`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.651860001980017`*^6", "+", 
        RowBox[{"2.3931317103141015`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.459888054251244`*^6", "-", 
        RowBox[{"1.6265232373450952`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.5744006072953865`*^6", "+", 
        RowBox[{"2.0589975370270338`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.223245274639983`*^6", "-", 
        RowBox[{"5.181401488047573`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8670350508344274`*^7", "-", 
        RowBox[{"3.292513318851798`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4768787397853872`*^6", "-", 
        RowBox[{"1.4670134205367398`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.246160725533009`*^6", "-", 
        RowBox[{"892586.2471834718`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.000348240592831`*^6", "+", 
        RowBox[{"4.356904144432781`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1468035874840063`*^8", "+", 
        RowBox[{"6.933229089851417`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.747941240205595`*^7", "+", 
        RowBox[{"5.071901231838778`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6795005079519264`*^7", "+", 
        RowBox[{"2.127174690765027`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"827791.4158127881`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.459682656208642`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.39893015019332`*^6", "+", 
        RowBox[{"6.170211004746737`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.470127382890434`*^6", "+", 
        RowBox[{"2.113547950295867`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3265650725346204`*^7", "+", 
        RowBox[{"1.289000574831737`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.730138293583505`*^6", "+", 
        RowBox[{"609224.6747800764`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.00012895515416`*^6", "+", 
        RowBox[{"1.1288618824292673`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3412391045349535`*^7", "+", 
        RowBox[{"9.072093560761102`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.46734343790083`*^6", "+", 
        RowBox[{"463962.9866865836`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3463285060455132`*^7", "-", 
        RowBox[{"5.410752734611427`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.5851990263891324`*^7", "-", 
        RowBox[{"7.318357426752024`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.158224398379685`*^6", "-", 
        RowBox[{"2.375949684516042`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8382576326781087`*^7", "+", 
        RowBox[{"1.0256222272526294`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119991`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.214171416851177`*^6", "-", 
        RowBox[{"1.3972405480572102`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6170892726615947`*^6", "+", 
        RowBox[{"2.606807312089812`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.801215081072804`*^7", "-", 
        RowBox[{"2.3033241591416795`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.325809125819044`*^7", "-", 
        RowBox[{"2.8904914991939347`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764621`*^6"}], "-", 
        RowBox[{"432555.33395535004`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.277355520008486`*^6", "+", 
        RowBox[{"2.8267755477276454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.592948197471805`*^6", "-", 
        RowBox[{"117950.9933461044`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7478192876144485`*^6", "-", 
        RowBox[{"125444.77812787278`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.629303753824485`*^6", "-", 
        RowBox[{"8.343639361855449`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"427182.2604990715`", "\[VeryThinSpace]", "+", 
        RowBox[{"61347.841365827015`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8066295893433254`*^7", "-", 
        RowBox[{"1.763299657661508`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.590812628465433`*^6", "-", 
        RowBox[{"6.129276631029127`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"952047.5265477378`", "\[VeryThinSpace]", "-", 
        RowBox[{"845665.8545915969`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"439445.847672116`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.0216878317561056`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5758490005951636`*^6", "+", 
        RowBox[{"5.476600210254369`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.274015946799025`*^6", "-", 
        RowBox[{"3.7754787254827976`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5489517445376873`*^7", "-", 
        RowBox[{"7.588154410370737`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.235395387368379`*^6", "+", 
        RowBox[{"2.007001658933019`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.093487424880982`*^7", "-", 
        RowBox[{"6.1565678257166624`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.95839604348919`*^6", "+", 
        RowBox[{"7.816233583225673`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.491022915714271`*^6", "+", 
        RowBox[{"1.5229650160117153`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.9205950125667825`*^6", "-", 
        RowBox[{"1.709316299456628`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2234470932108063`*^8", "+", 
        RowBox[{"4.564351117660108`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.946034805640351`*^6", "+", 
        RowBox[{"2.0083383300033952`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.630442128177033`*^6", "+", 
        RowBox[{"4.9530648710771445`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5301115812361687`*^6", "-", 
        RowBox[{"1.0704284115528737`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8796104935628115`*^6", "-", 
        RowBox[{"5.35593987761482`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"988222.0885534273`", "\[VeryThinSpace]", "-", 
        RowBox[{"276517.2425241088`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.350175982258457`*^7", "-", 
        RowBox[{"1.2026798464103855`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6904574261094825`*^6", "-", 
        RowBox[{"4.272698100244993`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"204325.9534348559`", "\[VeryThinSpace]", "+", 
        RowBox[{"268345.1609237294`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.1728302698126715`*^6", "+", 
        RowBox[{"2.063694877798197`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.3666617151414305`*^6", "+", 
        RowBox[{"399461.92202824354`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.748245673933954`*^6", "-", 
        RowBox[{"5.344553016363181`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4735443326785993`*^6", "+", 
        RowBox[{"1.255464070459736`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.349518416634591`*^6", "+", 
        RowBox[{"1.8248351941782665`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.336742937000579`*^7", "+", 
        RowBox[{"1.1577000393515877`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1253760106401746`*^6", "+", 
        RowBox[{"1.0101968469517576`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.244122870744315`*^6", "+", 
        RowBox[{"1.7690041274594087`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.432701511208438`*^6", "-", 
        RowBox[{"6.93944919116607`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.113421012034984`*^6", "-", 
        RowBox[{"2.729708565929088`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.850834792500354`*^6", "+", 
        RowBox[{"855484.2392328298`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.166427469963672`*^6", "-", 
        RowBox[{"2.089242301840919`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8902227829460665`*^6", "+", 
        RowBox[{"48905.56946935196`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"636941.609347607`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.0475266388018947`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"701386.3274063703`", "\[VeryThinSpace]", "+", 
        RowBox[{"162721.30588269746`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6930891173067324`*^7", "-", 
        RowBox[{"2.5215936272544395`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"895220.7726750681`", "\[VeryThinSpace]", "-", 
        RowBox[{"7.8262206370393`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"457819.676649329`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.414344519360339`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0456693953717807`*^6", "-", 
        RowBox[{"8.548610444281768`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6883188830769937`*^6", "+", 
        RowBox[{"6.47006465339673`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"282361.87464921176`", "\[VeryThinSpace]", "-", 
        RowBox[{"6.210561217860103`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4187925771691892`*^7", "+", 
        RowBox[{"9.46124198755163`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6361845143863812`*^7", "+", 
        RowBox[{"8.371729535649192`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.587818262521151`*^7", "-", 
        RowBox[{"5.485973851821339`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5828931942836825`*^7", "+", 
        RowBox[{"4.099829341836065`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0193214458846238`*^7", "+", 
        RowBox[{"1.0682255536640644`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.351129319091812`*^6", "-", 
        RowBox[{"2.8589405776918948`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2092462328337044`*^8", "+", 
        RowBox[{"1.7954602975312537`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.3339553501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.297886449088421`*^6", "-", 
        RowBox[{"3.33948349983622`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.613479126551744`*^6", "-", 
        RowBox[{"3.6339561539435945`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6456453315328127`*^6", "+", 
        RowBox[{"512281.7388721355`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.483768163256545`*^7", "-", 
        RowBox[{"2.303078308076602`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"219981.28656738997`", "\[VeryThinSpace]", "-", 
        RowBox[{"496588.97991758096`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.337520180510807`*^7", "-", 
        RowBox[{"5.491361720777197`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1705485799592186`*^7", "-", 
        RowBox[{"2.4397335598899394`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0805001170317107`*^6", "-", 
        RowBox[{"5.982432761279753`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9284882287425846`*^6", "+", 
        RowBox[{"9.729772926433235`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5273753534688063`*^7", "-", 
        RowBox[{"2.797420454752296`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.3039825468852884`*^8", "-", 
        RowBox[{"1.7935996605908906`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"380660.9674591273`", "\[VeryThinSpace]", "-", 
        RowBox[{"429059.6246703565`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.766633607548927`*^7", "-", 
        RowBox[{"2.538731190360299`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.683053015805393`*^6", "+", 
        RowBox[{"5.777370091503397`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.6075512002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4675387594049372`*^7", "-", 
        RowBox[{"1.18543779234137`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.272526674696371`*^7", "-", 
        RowBox[{"1.113561425964843`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5912473898234087`*^8", "+", 
        RowBox[{"2.1235642034429953`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9171954750863314`*^8", "+", 
        RowBox[{"3.881272798368158`*^9", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535004`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"418657.6102452688`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.5640969723584694`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"265749.71229141206`", "\[VeryThinSpace]", "+", 
        RowBox[{"5.50882351343222`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2460857380683967`*^6", "+", 
        RowBox[{"316947.6339851114`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.589933499070794`*^6", "-", 
        RowBox[{"7.932748464734011`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"471106.48619310674`", "\[VeryThinSpace]", "-", 
        RowBox[{"842798.0522770376`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6481190985847283`*^7", "-", 
        RowBox[{"1.4654165022706676`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7105910706900717`*^6", "-", 
        RowBox[{"5.947347302749096`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"420222.50248617353`", "\[VeryThinSpace]", "-", 
        RowBox[{"741637.3446207878`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.908635495074884`*^6", "+", 
        RowBox[{"70213.99807403237`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.9205887784082103`*^6", "-", 
        RowBox[{"834220.1210900247`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.821839271136663`*^7", "-", 
        RowBox[{"8.020184308970645`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.874988440381133`*^6", "-", 
        RowBox[{"2.2161459784018127`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.230939106038204`*^7", "-", 
        RowBox[{"1.0487993329750782`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3582502757407708`*^7", "+", 
        RowBox[{"8.372496868250832`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.009934054064105`*^7", "-", 
        RowBox[{"6.348147646064198`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0200529367913693`*^7", "-", 
        RowBox[{"4.403554111746726`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3734586167369943`*^7", "+", 
        RowBox[{"5.7035990645740125`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.831129042179566`*^6", "+", 
        RowBox[{"1.2766459568909215`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.33395535004`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0041074115492202`*^7", "+", 
        RowBox[{"5.187583270317461`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.356666792955521`*^6", "+", 
        RowBox[{"2.242856729243711`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"775437.784742234`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.415518000475684`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.517749851489207`*^6", "+", 
        RowBox[{"4.676461932941762`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0937335890318102`*^6", "+", 
        RowBox[{"1.7407131431686762`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9464676353957724`*^7", "+", 
        RowBox[{"1.2759866323716687`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.745254047351068`*^6", "+", 
        RowBox[{"1.6612276040235087`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"565892.932292813`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.732315472123073`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.476680533029526`*^6", "-", 
        RowBox[{"1.6933378028282714`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.85136885532612`*^6", "-", 
        RowBox[{"9.600950629759457`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9617934803739905`*^7", "+", 
        RowBox[{"7.94185754794254`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.457990057941157`*^6", "+", 
        RowBox[{"1.2978249961520981`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.467375049018744`*^7", "+", 
        RowBox[{"2.2589043715994877`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0179582705576118`*^7", "+", 
        RowBox[{"2.6502890069736697`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.041052439824016`*^7", "+", 
        RowBox[{"1.0040639032553437`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.051235823844385`*^7", "+", 
        RowBox[{"1.0326602286220378`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9293532170888513`*^7", "+", 
        RowBox[{"8.722624834653306`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3246764633569102`*^9", "+", 
        RowBox[{"8.80267972878525`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.563856271297711`*^6", "-", 
        RowBox[{"9.987034902240127`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.879448948761029`*^6", "-", 
        RowBox[{"1.2931761443313878`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0564121713683708`*^6", "-", 
        RowBox[{"2.0097536920717647`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.215887785025674`*^6", "-", 
        RowBox[{"8.005216283690108`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"702626.744290754`", "\[VeryThinSpace]", "-", 
        RowBox[{"341416.99531738186`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.003257352493247`*^7", "-", 
        RowBox[{"1.3562381231316373`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.210835417272279`*^6", "-", 
        RowBox[{"6.561832308142623`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"444015.36429880443`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.7134574349279418`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2096956024995884`*^6", "-", 
        RowBox[{"7.24277293718866`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.343992316310389`*^6", "+", 
        RowBox[{"5.877604966013075`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9830235656943325`*^7", "-", 
        RowBox[{"2.7135389024053246`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6711883045480307`*^6", "+", 
        RowBox[{"1.4892814301857825`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.09955901877515`*^7", "-", 
        RowBox[{"1.3186163812093737`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.711112394495285`*^7", "-", 
        RowBox[{"1.7746046408883616`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1926402612259392`*^7", "-", 
        RowBox[{"7.618555960422923`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.199220822691243`*^6", "-", 
        RowBox[{"1.9665353953418847`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.887351206363735`*^7", "-", 
        RowBox[{"3.4713927144760475`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7611395080273488`*^8", "-", 
        RowBox[{"3.319776126918452`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.008856093894789`*^6", "+", 
        RowBox[{"1.788269404201379`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.324448771358108`*^6", "-", 
        RowBox[{"1.156457136872371`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"79662.7745139238`", "\[VeryThinSpace]", "-", 
        RowBox[{"853710.4321011542`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.670812944035499`*^6", "+", 
        RowBox[{"300227.3088930552`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.209974247420626`*^6", "+", 
        RowBox[{"356404.6186415162`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.090144798804119`*^6", "+", 
        RowBox[{"4.593914420823334`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6624733668431076`*^6", "+", 
        RowBox[{"132727.8069771421`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"295137.69078979385`", "\[VeryThinSpace]", "+", 
        RowBox[{"964231.3453738393`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.4606385857661534`*^6", "-", 
        RowBox[{"2.054335876685684`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.212823707040078`*^6", "-", 
        RowBox[{"910551.3051297578`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.398349706202855`*^6", "+", 
        RowBox[{"1.840943448011519`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.0123605454603685`*^6", "-", 
        RowBox[{"1.8305176639808821`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6802757231093273`*^6", "+", 
        RowBox[{"8.360583775245166`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1592649163923545`*^7", "+", 
        RowBox[{"8.0577816061851885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1031172234304342`*^6", "+", 
        RowBox[{"4.495863397030264`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"286059.9413085021`", "\[VeryThinSpace]", "-", 
        RowBox[{"6.577836308913303`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.144122648114262`*^6", "+", 
        RowBox[{"3.242539335876529`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.67931290137917`*^6", "-", 
        RowBox[{"5.848589209440218`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8092439512383144`*^6", "-", 
        RowBox[{"855188.6809067567`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4936512737749955`*^6", "+", 
        RowBox[{"2.0895378601669937`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"937014.2139554129`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.4497044666183093`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.593599455770224`*^6", "-", 
        RowBox[{"7.7336154075039765`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"424945.2222259379`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.39537670844053`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0202544302087164`*^7", "-", 
        RowBox[{"1.2758945123932924`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1975588705345583`*^6", "-", 
        RowBox[{"4.548539031732785`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"72354.39338424278`", "\[VeryThinSpace]", "-", 
        RowBox[{"239336.8372251141`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0170584494499356`*^7", "-", 
        RowBox[{"3.466613790102006`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.805486171840096`*^6", "-", 
        RowBox[{"2.2353171196162105`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.771896496861333`*^6", "+", 
        RowBox[{"157475.9529261114`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.572563121185701`*^6", "-", 
        RowBox[{"371419.6076434358`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2516968697031684`*^7", "+", 
        RowBox[{"1.3801645221836753`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.876944705645696`*^7", "+", 
        RowBox[{"2.6797600589518053`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0299365030693792`*^7", "+", 
        RowBox[{"927802.2753971275`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.808428260606755`*^6", "+", 
        RowBox[{"926294.0620946223`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6318835812243287`*^7", "-", 
        RowBox[{"3.8363135692133876`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.3824038225846484`*^7", "-", 
        RowBox[{"3.2374566715503655`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1875732113245144`*^7", "+", 
        RowBox[{"1.0643003238540847`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1191324790708462`*^7", "+", 
        RowBox[{"7.698276697467098`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3154946963834544`*^6", "+", 
        RowBox[{"3.0956129628914753`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.83178297585423`*^6", "+", 
        RowBox[{"6.080239285024058`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5739384915828402`*^6", "+", 
        RowBox[{"1.0863043703189061`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7438330362108544`*^7", "+", 
        RowBox[{"1.866590674745358`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.051150464022875`*^6", "+", 
        RowBox[{"2.903415012241978`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.291083924881338`*^6", "+", 
        RowBox[{"1.0084575166713567`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.48777641689534`*^6", "+", 
        RowBox[{"6.174658607835654`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.784901376295536`*^6", "+", 
        RowBox[{"4.065764416137223`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1834064256533477`*^7", "+", 
        RowBox[{"1.35910031525144`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6476891969821945`*^7", "+", 
        RowBox[{"1.279895295776188`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.20765784667569`*^7", "+", 
        RowBox[{"2.949303144312923`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.277698629904868`*^7", "-", 
        RowBox[{"3.553211257801732`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0198813471540987`*^7", "+", 
        RowBox[{"1.5103522239961347`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.78822110453362`*^6", "-", 
        RowBox[{"1.0888210176588083`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.760890337048731`*^7", "+", 
        RowBox[{"502630.89872195804`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4852077723223997`*^7", "+", 
        RowBox[{"7.349376951255517`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.3339553501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3134889603650369`*^7", "+", 
        RowBox[{"7.9325824373290315`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2450482281113688`*^7", "+", 
        RowBox[{"4.987855896255282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"170420.8945026826`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.0690513971723877`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.4319797796362955`*^6", "+", 
        RowBox[{"5.120428572449958`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3628010246187672`*^6", "+", 
        RowBox[{"2.031559527409961`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9539151495788418`*^7", "+", 
        RowBox[{"1.2583193575285014`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.569052319940324`*^6", "+", 
        RowBox[{"1.0801639395822305`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1938887139365626`*^6", "+", 
        RowBox[{"751623.2197852752`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.2738286983362455`*^6", "+", 
        RowBox[{"8.235285259678005`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.878441620176929`*^6", "+", 
        RowBox[{"3.0459207538426467`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.681423231201904`*^7", "-", 
        RowBox[{"2.0592359756573315`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2457461750832777`*^7", "+", 
        RowBox[{"5.240258118471345`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3472559779400531`*^7", "+", 
        RowBox[{"3.973303954982888`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.120648200558016`*^6", "+", 
        RowBox[{"1.72081515651707`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.706456647245731`*^6", "+", 
        RowBox[{"1.9512854272168688`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.639266597431374`*^6", "-", 
        RowBox[{"71335.1561639416`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.451896978595946`*^7", "-", 
        RowBox[{"532213.5174226398`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8541871327036954`*^7", "+", 
        RowBox[{"1.0586605007516392`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.3339553501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.090004974258069`*^6", "-", 
        RowBox[{"1.0953000593159007`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7744122967947507`*^6", "-", 
        RowBox[{"8.008274052085258`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.943611637159805`*^6", "-", 
        RowBox[{"2.479707882279875`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.844332801268136`*^6", "-", 
        RowBox[{"7.5981183036819985`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6016208862313214`*^6", "-", 
        RowBox[{"3.5414644691852015`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.148491214665994`*^6", "+", 
        RowBox[{"1.4835490288602943`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.807689402525806`*^6", "+", 
        RowBox[{"4.30514330828986`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"639224.7653177087`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.1413667407349413`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6874817998703405`*^7", "+", 
        RowBox[{"5.461650959354688`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.629202846962219`*^6", "-", 
        RowBox[{"7.059543299812375`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0944905770783424`*^6", "-", 
        RowBox[{"2.8568910135379404`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1673629532234065`*^7", "-", 
        RowBox[{"2.9896204692825235`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1417698385355268`*^7", "-", 
        RowBox[{"2.5943340126360636`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6579832943631157`*^7", "-", 
        RowBox[{"1.2294007942970578`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.481379390032708`*^6", "-", 
        RowBox[{"2.0885709965675082`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"18970.375277383253`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.0926764643118411`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.8279175402793996`*^7", "+", 
        RowBox[{"132350.55231758952`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.556602713112241`*^7", "+", 
        RowBox[{"6.603095522925385`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764621`*^6"}], "-", 
        RowBox[{"432555.3339553501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8408921021692948`*^6", "-", 
        RowBox[{"2.8964432378645474`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.156484779632613`*^6", "-", 
        RowBox[{"5.841169778938297`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0420322541521372`*^6", "+", 
        RowBox[{"60590.70247740473`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.014795037214523`*^6", "-", 
        RowBox[{"5.212164734120043`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2508263831928826`*^6", "-", 
        RowBox[{"895753.486606468`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6843345948609635`*^7", "-", 
        RowBox[{"6.317843362218989`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1621391989363665`*^6", "-", 
        RowBox[{"4.0064383641343834`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"822077.8030219777`", "\[VeryThinSpace]", "-", 
        RowBox[{"282494.37325193617`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.201674688698222`*^6", "+", 
        RowBox[{"4.905648123454906`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.575607435370534`*^6", "+", 
        RowBox[{"1.951346969837251`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6032304241890987`*^7", "+", 
        RowBox[{"6.396562429319811`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.859671866327945`*^6", "+", 
        RowBox[{"9.014199210078288`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.8203454522133395`*^6", "-", 
        RowBox[{"8.258338830466542`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"641594.9444152135`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.4924880161492232`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8324153321165256`*^6", "-", 
        RowBox[{"4.347389146850385`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7565140483227717`*^6", "-", 
        RowBox[{"3.1223511349623036`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"357716.2342495769`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.6042971430788344`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4340480946929788`*^7", "-", 
        RowBox[{"7.326782889363868`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.33395535004`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0542305447695505`*^7", "+", 
        RowBox[{"1.1995516696276978`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.857898125158824`*^6", "+", 
        RowBox[{"9.050790155203227`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"597547.8246159928`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.730204489334873`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.743463694427229`*^6", "+", 
        RowBox[{"6.559769152206843`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"552907.7339725908`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.477882498656515`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8785076442663454`*^7", "+", 
        RowBox[{"1.6468934792403996`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.118784891295979`*^6", "+", 
        RowBox[{"2.2205688487668484`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.22099008354927`*^6", "+", 
        RowBox[{"1.4990875951141254`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0451822589032394`*^6", "-", 
        RowBox[{"8.85418339395148`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9319014109210623`*^6", "+", 
        RowBox[{"8.063003956508156`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.811797236762449`*^7", "+", 
        RowBox[{"1.6813006436769992`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9879076807241324`*^7", "+", 
        RowBox[{"2.1292697195708655`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.239181953574711`*^6", "-", 
        RowBox[{"2.681436140574632`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.390797001932675`*^6", "-", 
        RowBox[{"3.1547990661522247`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.2504350978537435`*^6", "-", 
        RowBox[{"1.1140469652044723`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.783478446242688`*^6", "-", 
        RowBox[{"1.608913604075486`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7496569700779743`*^7", "+", 
        RowBox[{"9.415920508259777`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1035035244359829`*^7", "+", 
        RowBox[{"1.3997528336966371`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.144373830724711`*^7", "+", 
        RowBox[{"7.3775714935013`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0759330984710429`*^7", "+", 
        RowBox[{"4.432844952427549`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"538051.2372175939`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.247049925325`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.5709007997693075`*^6", "+", 
        RowBox[{"5.89431539008159`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8052079901894338`*^6", "+", 
        RowBox[{"1.7573628191922887`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.702992147119935`*^7", "+", 
        RowBox[{"1.3860946018922336`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.273521413159667`*^6", "+", 
        RowBox[{"1.893184116985525`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.35407641504635`*^6", "+", 
        RowBox[{"1.523123384053405`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.610136124856487`*^6", "+", 
        RowBox[{"6.489983973831005`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.692362897871684`*^6", "+", 
        RowBox[{"1.6427521012784983`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0106361063603483`*^7", "+", 
        RowBox[{"4.448800818495978`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7084694426474545`*^7", "+", 
        RowBox[{"2.2271377267340356`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9883701317885462`*^7", "+", 
        RowBox[{"1.1685438547761362`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.171638029478375`*^6", "-", 
        RowBox[{"9.962388204421671`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4588671530655071`*^7", "+", 
        RowBox[{"5.3433031686395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2014344572513888`*^7", "+", 
        RowBox[{"2.471372011210285`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.5933584973032236`*^7", "+", 
        RowBox[{"1.108224979945072`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8232691679971598`*^7", "+", 
        RowBox[{"3.5361323363071136`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4410019067890658`*^6", "-", 
        RowBox[{"2.7904411985268723`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"756594.584252385`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.735167739600623`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"618438.4863594347`", "\[VeryThinSpace]", "-", 
        RowBox[{"136008.2849107797`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.533610047526315`*^6", "-", 
        RowBox[{"386978.6803468233`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3869895848720728`*^6", "+", 
        RowBox[{"1.2667244523707265`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2578322435002707`*^7", "-", 
        RowBox[{"5.520843749508587`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.37824783884234`*^6", "-", 
        RowBox[{"2.182489712513609`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"475633.31838882994`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.374018100285969`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"310825.8754848023`", "\[VeryThinSpace]", "+", 
        RowBox[{"4.124402962777802`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.591712071516734`*^6", "+", 
        RowBox[{"2.5840970393859083`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.821937920245707`*^6", "-", 
        RowBox[{"1.2611892355664106`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.661254205241883`*^6", "+", 
        RowBox[{"2.2113001003349684`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.481778309992719`*^6", "-", 
        RowBox[{"4.329814592436407`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"136258.04566254467`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.7743502978671983`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119991`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6567391014353503`*^6", "+", 
        RowBox[{"1.5265162466233969`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0993965434453096`*^6", "+", 
        RowBox[{"4.1501983982605133`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2351986241560468`*^7", "-", 
        RowBox[{"2.5287097543406812`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.2236611799889445`*^7", "-", 
        RowBox[{"7.097280831676647`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.33395535004`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"679997.8613253082`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.685559786036144`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4409.461211374495`", "\[VeryThinSpace]", "+", 
        RowBox[{"259166.75503760716`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"147119.68168453453`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3937753169711526`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"665142.7548735018`", "\[VeryThinSpace]", "+", 
        RowBox[{"5.837901727198574`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"58924.99979342322`", "\[VeryThinSpace]", "-", 
        RowBox[{"755861.1399407759`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2232861644432084`*^6", "+", 
        RowBox[{"1.3979914952195967`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.132015274026288`*^6", "+", 
        RowBox[{"3.8820478568416703`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"315978.33269813453`", "\[VeryThinSpace]", "+", 
        RowBox[{"160157.52847239975`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"276146.0048577525`", "\[VeryThinSpace]", "+", 
        RowBox[{"6.048855165170694`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4677986550520426`*^6", "+", 
        RowBox[{"4.0014231372328354`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.7014667892736616`*^6", "-", 
        RowBox[{"2.863034256410468`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"412314.25182365393`", "\[VeryThinSpace]", "+", 
        RowBox[{"5.632565780131962`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0053903527476043`*^7", "-", 
        RowBox[{"2.0921741054813755`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"934390.0724243373`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.4340947394052166`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.403187974998493`*^6", "-", 
        RowBox[{"1.5860144564256975`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.449805936121181`*^6", "-", 
        RowBox[{"1.600921192778302`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0578479966534665`*^6", "+", 
        RowBox[{"4.400752234249036`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.553446114795683`*^6", "-", 
        RowBox[{"6.478960834498126`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.3339553499`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"674606.4253664273`", "\[VeryThinSpace]", "+", 
        RowBox[{"190842.888216733`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3590137479031081`*^6", "+", 
        RowBox[{"3.135569429290483`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8211692857213507`*^6", "-", 
        RowBox[{"885450.1202307439`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7888873117883725`*^6", "-", 
        RowBox[{"7.78613459941379`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"86701.09880434611`", "\[VeryThinSpace]", "-", 
        RowBox[{"165326.9482636294`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.465621693407923`*^7", "-", 
        RowBox[{"1.8724840320435196`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.919780544987557`*^6", "-", 
        RowBox[{"6.145806915167298`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"187052.67077018268`", "\[VeryThinSpace]", "-", 
        RowBox[{"372181.0402757479`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.091877472071722`*^6", "-", 
        RowBox[{"4.953428684628396`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.9486231522374116`*^6", "-", 
        RowBox[{"3.224070220955422`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"578188.3788435794`", "\[VeryThinSpace]", "-", 
        RowBox[{"7.6337165439036805`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.289542803168078`*^6", "-", 
        RowBox[{"7.411750735907521`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1593048082004376`*^6", "+", 
        RowBox[{"8.609001274788063`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2911165853748783`*^7", "-", 
        RowBox[{"1.4801019640125453`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0137937029481884`*^6", "+", 
        RowBox[{"3.5720019342757356`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.912686972652845`*^6", "+", 
        RowBox[{"3.8861790177959567`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.647046873480979`*^6", "-", 
        RowBox[{"3.8399334013430397`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"821770.8825840726`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.965547552839638`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4504897388796922`*^7", "-", 
        RowBox[{"2.448685017996844`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3820490066260241`*^7", "-", 
        RowBox[{"5.393411559070594`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6932253039462573`*^6", "+", 
        RowBox[{"2.6271116894038413`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1006381753238015`*^7", "+", 
        RowBox[{"5.303380113940658`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.537656963593688`*^6", "+", 
        RowBox[{"1.4668006967498837`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1848818953105222`*^7", "+", 
        RowBox[{"9.132952031073714`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.292983876964379`*^6", "-", 
        RowBox[{"82612.97901235148`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.034450542900591`*^6", "+", 
        RowBox[{"1.6123016655334015`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8612103977729365`*^7", "-", 
        RowBox[{"2.8443083386008656`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.162776828530779`*^6", "-", 
        RowBox[{"6.295131992217709`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.917209652717123`*^7", "-", 
        RowBox[{"6.160391689013833`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0303935497708037`*^7", "-", 
        RowBox[{"2.6912516276364975`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.016594003321946`*^6", "-", 
        RowBox[{"5.946441927898385`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.717107490875603`*^7", "-", 
        RowBox[{"1.5973796059463369`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.086463449064076`*^6", "-", 
        RowBox[{"2.796830121259243`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.326974543922663`*^6", "+", 
        RowBox[{"2.0261958468977222`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.43317216170324`*^7", "-", 
        RowBox[{"3.470128616815111`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2740873048399523`*^7", "-", 
        RowBox[{"8.900147286433396`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.3339553501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0625885125944382`*^7", "+", 
        RowBox[{"1.2475857587046575`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.9414778034077`*^6", "+", 
        RowBox[{"9.531131045972826`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"525579.6544278541`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.459524120349269`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.466341848047503`*^6", "+", 
        RowBox[{"6.318583082395399`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"476458.79865640483`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.257826452737872`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0405833790900975`*^7", "+", 
        RowBox[{"1.759155206964124`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.773729323874494`*^6", "+", 
        RowBox[{"2.2252393004963156`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5640778693208522`*^6", "+", 
        RowBox[{"1.3572661428470016`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7580884843094167`*^6", "-", 
        RowBox[{"8.621180941514483`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8051219647153942`*^6", "+", 
        RowBox[{"8.54174711383855`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5349896850814678`*^7", "+", 
        RowBox[{"1.4350313538370818`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0246446075825583`*^7", "+", 
        RowBox[{"2.1978519723516557`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"446870.667528037`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.327292245987167`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.174909743657275`*^6", "-", 
        RowBox[{"3.2764854763468012`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"780171.1104674023`", "\[VeryThinSpace]", "-", 
        RowBox[{"9.442213722993769`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"989389.4324395582`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.450300348032285`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1471218138091214`*^7", "+", 
        RowBox[{"1.152662089007781`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.417736486786533`*^6", "+", 
        RowBox[{"2.561501536188655`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.3339553502`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.1591217375243222`*^6", "-", 
        RowBox[{"3.27575115372062`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.4747144149876414`*^6", "-", 
        RowBox[{"6.220477694794371`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"949442.2438447443`", "\[VeryThinSpace]", "+", 
        RowBox[{"322237.83828952746`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.419686881823163`*^6", "-", 
        RowBox[{"2.7987106219487255`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8218831149559512`*^6", "-", 
        RowBox[{"566497.9387699199`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7763357363652408`*^7", "-", 
        RowBox[{"1.1224396198182954`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.264553038317097`*^6", "-", 
        RowBox[{"2.7955812863465203`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2232835947323544`*^6", "+", 
        RowBox[{"132432.1893407394`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"832983.8855692376`", "\[VeryThinSpace]", "+", 
        RowBox[{"7.753957364653429`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.987109897004541`*^6", "+", 
        RowBox[{"4.1458607908563362`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.324495747653733`*^6", "+", 
        RowBox[{"1.3309538891468918`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"261101.93263481464`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.65654212438527`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.06301036594641`*^6", "-", 
        RowBox[{"6.893691268725224`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.006974007574549`*^7", "-", 
        RowBox[{"1.86313253704432`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119991`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8237063480326505`*^6", "-", 
        RowBox[{"3.0763168688751785`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"249715.4507302437`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.2134855186955314`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1001684088622892`*^7", "-", 
        RowBox[{"5.9641449956698315`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.25320876315986`*^6", "-", 
        RowBox[{"1.5097613725217818`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.33395535016`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.338541703525996`*^6", "-", 
        RowBox[{"426866.3756765048`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.654134380989315`*^6", "-", 
        RowBox[{"3.3715929167502546`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"893658.9653022294`", "\[VeryThinSpace]", "+", 
        RowBox[{"598458.8537929899`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.219461513047626`*^6", "-", 
        RowBox[{"3.422915985262484`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"561841.7180566428`", "\[VeryThinSpace]", "+", 
        RowBox[{"133727.06641074992`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0533557605303936`*^7", "-", 
        RowBox[{"6.587988463330789`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.183908777633225`*^6", "-", 
        RowBox[{"3.1467676655973457`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"547995.8462011393`", "\[VeryThinSpace]", "+", 
        RowBox[{"89346.28549280317`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"458995.5988238165`", "\[VeryThinSpace]", "-", 
        RowBox[{"341157.50908641354`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"196629.79118815204`", "\[VeryThinSpace]", "-", 
        RowBox[{"266029.2757290758`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1339708178546637`*^7", "-", 
        RowBox[{"1.881107009170954`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9521712899485715`*^6", "-", 
        RowBox[{"2.259044179548788`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8017121612715637`*^6", "+", 
        RowBox[{"9.37989571292886`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0573222717658319`*^6", "+", 
        RowBox[{"697814.7918107063`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5169851839089743`*^6", "+", 
        RowBox[{"5.0360707917035315`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5949286124371572`*^6", "+", 
        RowBox[{"4.450232621062982`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.522939231141993`*^6", "+", 
        RowBox[{"4.5650571463154275`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"175374.31485337578`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.489588786158014`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.3339553501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7246562610423006`*^7", "-", 
        RowBox[{"7.159733860577438`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6562155287886325`*^7", "-", 
        RowBox[{"1.0104460401651185`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0418810769538046`*^6", "+", 
        RowBox[{"481167.8200410808`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6506018950419571`*^7", "+", 
        RowBox[{"5.110858838190293`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7299644539449525`*^6", "-", 
        RowBox[{"347150.10928089655`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.327608892593856`*^7", "+", 
        RowBox[{"3.359332227480514`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6185351213892024`*^7", "+", 
        RowBox[{"4.912459576382177`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1719239773039687`*^6", "+", 
        RowBox[{"2.2742841546850917`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3278738411104055`*^7", "-", 
        RowBox[{"1.8824074310708784`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3027986725111457`*^7", "-", 
        RowBox[{"1.744785153818737`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1178959200014728`*^8", "+", 
        RowBox[{"4.36317998043289`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8844044107864972`*^7", "-", 
        RowBox[{"2.5256064543269947`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2484444040558226`*^6", "-", 
        RowBox[{"1.2491377383900134`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.706584301317321`*^7", "-", 
        RowBox[{"2.5030781419025168`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4238524948048173`*^6", "-", 
        RowBox[{"6.489562971462106`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7677592513282192`*^6", "+", 
        RowBox[{"2.9514193312897948`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.311341441307415`*^7", "-", 
        RowBox[{"6.493286038273351`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.562064822316936`*^7", "+", 
        RowBox[{"8.817775244180068`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.484981324785879`*^6", "+", 
        RowBox[{"9.389494486044727`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.800574002249198`*^6", "+", 
        RowBox[{"6.444767944970978`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.288688743215545`*^6", "+", 
        RowBox[{"463489.4863714087`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.705625677639938`*^6", "-", 
        RowBox[{"1.9250568009687178`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6073466969041242`*^6", "-", 
        RowBox[{"1.4824184963918051`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.455429433661831`*^7", "+", 
        RowBox[{"23555.974481161684`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.785371085956212`*^6", "-", 
        RowBox[{"3.6017079822819997`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2126609815276798`*^6", "-", 
        RowBox[{"1.1802751720535082`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"570490.104642082`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.6169828216528185`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5914798935598582`*^6", "+", 
        RowBox[{"1.0733390230040994`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.102883116045509`*^6", "-", 
        RowBox[{"1.9045032943464536`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6307191173426174`*^7", "+", 
        RowBox[{"2.169556568946843`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"318230.16761559015`", "\[VeryThinSpace]", "+", 
        RowBox[{"5.104156407303095`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.836481573376134`*^6", "+", 
        RowBox[{"2.389111916175379`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3129724502187723`*^6", "-", 
        RowBox[{"577832.2639895203`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.174744208490377`*^6", "-", 
        RowBox[{"3.7680248937480925`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.6221047575153194`*^7", "-", 
        RowBox[{"1.312842918927201`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9688466457416773`*^7", "-", 
        RowBox[{"5.418900598750203`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395535`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"553700.0949225733`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.0909574859486318`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2381074174592542`*^6", "+", 
        RowBox[{"853769.0551251171`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"844475.5365204392`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.669363516537586`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"813611.512956819`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.0898796174729657`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.135025207954966`*^6", "+", 
        RowBox[{"40096.06380782934`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.7926590086291484`*^6", "+", 
        RowBox[{"5.631500740213745`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"978758.2230903385`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.0487504402315386`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"122109.51540294627`", "\[VeryThinSpace]", "-", 
        RowBox[{"712096.2300550794`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"584591.0269644042`", "\[VeryThinSpace]", "-", 
        RowBox[{"287543.5386377652`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"390671.03209380223`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.1802619223485843`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.896484310963567`*^6", "+", 
        RowBox[{"1.9367141127628386`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.127461740169831`*^6", "-", 
        RowBox[{"521480.17327738355`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7975.339020801708`", "\[VeryThinSpace]", "+", 
        RowBox[{"6.110651599849219`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.76900254351726`*^6", "+", 
        RowBox[{"2.4165818311444316`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"88145.33709728438`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.9627368783416804`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.223096216477493`*^6", "-", 
        RowBox[{"2.904732662112413`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.641091240390633`*^6", "+", 
        RowBox[{"449741.5968039867`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8733399209509958`*^6", "+", 
        RowBox[{"1.3574900264613513`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764624`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.334479815215656`*^6", "+", 
        RowBox[{"4.928218030611558`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.650072492678974`*^6", "+", 
        RowBox[{"1.983491489537808`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"591075.6145164589`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.262614013649354`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"811960.7864357792`", "\[VeryThinSpace]", "+", 
        RowBox[{"5.144687991236752`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"676470.8632324745`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.4689053001701655`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0469366400316883`*^7", "+", 
        RowBox[{"6.243488040624691`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.854920828564687`*^6", "+", 
        RowBox[{"1.2328550608610027`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"226925.28337257262`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.796913321355604`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"421496.215525073`", "\[VeryThinSpace]", "-", 
        RowBox[{"4.999485987174799`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5547380632964047`*^6", "+", 
        RowBox[{"1.198533246862031`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.361954736683809`*^6", "+", 
        RowBox[{"5.179360228868664`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1773280083040562`*^7", "+", 
        RowBox[{"1.1366827589844037`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6448464806005415`*^6", "+", 
        RowBox[{"2.420424278553774`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.5241194640055783`*^6", "-", 
        RowBox[{"3.748955700932244`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755119997`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.101852665339498`*^6", "+", 
        RowBox[{"1.1901161689220753`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.223564563339507`*^6", "+", 
        RowBox[{"7.61791774054914`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"380037.39234960265`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.9776053061849423`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.044973753606331`*^7", "-", 
        RowBox[{"62160.14984146319`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.065480117105264`*^6", "+", 
        RowBox[{"2.3622156644978624`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3810727945685573`*^6", "+", 
        RowBox[{"2.0677430103904873`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.005099252697918`*^6", "-", 
        RowBox[{"2.8567828093000557`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"496971.9594287751`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.6923591233931663`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3950364402547944`*^6", "-", 
        RowBox[{"2.2768859296081215`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6408732902666623`*^7", "+", 
        RowBox[{"2.439290771518099`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.481559376376713`*^6", "+", 
        RowBox[{"4.536762133282278`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9093908180228404`*^6", "-", 
        RowBox[{"731269.0489806854`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.888127699875277`*^6", "-", 
        RowBox[{"1.635799814837372`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8096322471522875`*^6", "-", 
        RowBox[{"1.5779378762363149`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.713977782070043`*^7", "-", 
        RowBox[{"2.0445134796140797`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.963507162286996`*^7", "-", 
        RowBox[{"4.764284745696485`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.390637824835655`*^7", "-", 
        RowBox[{"3.29470337879679`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.726173884997529`*^7", "-", 
        RowBox[{"5.2635403927411586`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.6075512002`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.164532963005602`*^6", "-", 
        RowBox[{"1.5889781368702203`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5480047875967968`*^7", "+", 
        RowBox[{"3.896376160696948`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.645608236695454`*^7", "-", 
        RowBox[{"1.9914474013167497`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.784573355239369`*^7", "+", 
        RowBox[{"9.599657879755414`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1.7311987150764628`*^6"}], "-", 
        RowBox[{"432555.33395534987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.754166913667618`*^6", "-", 
        RowBox[{"6.596156545259908`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0697595911309374`*^6", "-", 
        RowBox[{"9.540883086333657`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8218218665915055`*^6", "+", 
        RowBox[{"1.0738738199984967`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.80691029594091`*^6", "-", 
        RowBox[{"7.491576118202722`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"916545.7563419873`", "\[VeryThinSpace]", "-", 
        RowBox[{"320684.9029310205`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.386591783318665`*^7", "-", 
        RowBox[{"1.5686811109725915`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.402061274952557`*^6", "-", 
        RowBox[{"7.206532318341477`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1159509473227519`*^6", "-", 
        RowBox[{"1.473558526789925`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"769419.0726152603`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.978255946329999`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8895042406806862`*^6", "+", 
        RowBox[{"2.8968490023016827`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.855129597493255`*^7", "-", 
        RowBox[{"1.4073812881632596`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.6435521741492506`*^6", "+", 
        RowBox[{"7.1087017436799435`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.761969006879477`*^6", "-", 
        RowBox[{"1.1050213057865249`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.353349039993869`*^6", "+", 
        RowBox[{"1.0129242378889062`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"77745.60755120008`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3294619740956249`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.883295341406849`*^6", "-", 
        RowBox[{"6.143889573705632`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4933059427343127`*^6", "-", 
        RowBox[{"4.357765323833693`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4396699396764308`*^7", "+", 
        RowBox[{"2.460358098578872`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.81350759058762`*^6", "-", 
        RowBox[{"978359.806276001`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.08410517999245`*^6", "-", 
        RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "\[Lambda]"}]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619236713396962*^9, 3.619236880539884*^9, 3.619237000579589*^9, 
   3.619237048379258*^9, 3.61923709189137*^9, 3.6192372281109953`*^9, 
   3.6192372963930597`*^9, 3.619237786267847*^9, {3.619237908284073*^9, 
   3.619238012603725*^9}, 3.61923807139123*^9, 3.619238141755127*^9, 
   3.619238228754908*^9, 3.619238263802507*^9, {3.619238301836074*^9, 
   3.619238359174882*^9}, 3.6192401896951847`*^9, 3.6192429198033333`*^9, 
   3.619243668751142*^9, 3.61924623881572*^9, {3.61924640579837*^9, 
   3.619246412663979*^9}, 3.6192469862046127`*^9, 3.6192472491922073`*^9, 
   3.6192474671861477`*^9, 3.619250329849607*^9, 3.619253124165639*^9, 
   3.6192544141567593`*^9, 3.619259600225254*^9, 3.619259870585545*^9, 
   3.619259916232139*^9, 3.61925997003017*^9, 3.619343683831526*^9, 
   3.619412731615349*^9, 3.619413272516634*^9, 3.6194152394965143`*^9, 
   3.619418816156578*^9, 3.6194198994658127`*^9, 3.619423008084231*^9, 
   3.619427133680147*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$qlightcone2$ward2", "]"}]], "Input",
 CellChangeTimes->{{3.619413298708581*^9, 3.619413300534478*^9}}],

Cell[BoxData[
 FormBox["40", TraditionalForm]], "Output",
 CellChangeTimes->{3.619413300760298*^9, 3.619415239528617*^9, 
  3.619418817221367*^9, 3.619419899590777*^9, 3.619423008169565*^9, 
  3.619427133747593*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$ward2", "[", 
  RowBox[{"[", "10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.619246246845746*^9, 3.619246247318962*^9}, {
   3.619246445896468*^9, 3.619246449407371*^9}, {3.61924699790209*^9, 
   3.61924700749713*^9}, {3.6192472050257587`*^9, 3.619247205197611*^9}, {
   3.6192474889175587`*^9, 3.619247495105204*^9}, 3.619413311402684*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"770203.0155108545`", "\[VeryThinSpace]", "+", 
       RowBox[{"306185.5299740446`", " ", "\[ImaginaryI]"}]}], ")"}]}], " ", 
    "b11"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"997821.2935051566`", "\[VeryThinSpace]", "-", 
      RowBox[{"4.839623311225794`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b7"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"568178.1736123527`", "\[VeryThinSpace]", "-", 
      RowBox[{"719767.8929066337`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b8"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"287118.0333253518`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.8321857353920396`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c2"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"77745.60755119991`", "\[VeryThinSpace]", "-", 
      RowBox[{"1.329461974095625`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "e3"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1.7311987150764626`*^6"}], "-", 
      RowBox[{"432555.3339553499`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.94879045118645`*^6", "-", 
      RowBox[{"3.5003100722915577`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a2"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.264383128649769`*^6", "-", 
      RowBox[{"6.445036613365309`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a3"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.4110062110644607`*^6", "+", 
      RowBox[{"867866.8262564332`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.560021801969369`*^6", "-", 
      RowBox[{"4.561748664681161`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b10"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.2964735343289284`*^7", "-", 
      RowBox[{"1.2213532587412968`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b4"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.3280698101330772`*^6", "-", 
      RowBox[{"1.664079697815606`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.4479212367158096`*^7", "-", 
      RowBox[{"1.483549383868262`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c3"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.7293119711498227`*^6", "-", 
      RowBox[{"5.633573756495974`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c4"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.0434961315458356`*^6", "+", 
      RowBox[{"9.728099924039954`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c5"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.7121372356898896`*^6", "+", 
      RowBox[{"549021.9432098251`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c6"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.160749023947148`*^6", "+", 
      RowBox[{"5.120003084656319`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "f1"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.5193418209303862`*^6", "+", 
      RowBox[{"4.794608083392687`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "g1"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.074144015834728`*^6", "+", 
      RowBox[{"7.08166387152197`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "g2"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4.265820799414344`*^6", "+", 
      RowBox[{"2.25220142661741`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "ii"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.08410517999245`*^6", "-", 
      RowBox[{"1.0998646974282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "\[Lambda]"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619246247927534*^9, {3.619246431180839*^9, 3.619246449750126*^9}, {
   3.619246999551182*^9, 3.6192470082780323`*^9}, 3.619247249301611*^9, {
   3.619247474848068*^9, 3.6192474954243193`*^9}, 3.619253143481003*^9, 
   3.619254507782629*^9, 3.619343684071299*^9, 3.619412731774173*^9, {
   3.61941330458409*^9, 3.619413312008706*^9}, 3.619415239565143*^9, 
   3.6194188200596333`*^9, 3.6194198998482103`*^9, 3.619423008253044*^9, 
   3.619427133809993*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"amp4$qlightcone2$ward2", "[", 
      RowBox[{"[", "iq", "]"}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{"{", 
     RowBox[{"iq", ",", "1", ",", 
      RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.619413702328198*^9, 3.619413735638481*^9}, {
  3.6194143354943523`*^9, 3.619414376255455*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"0.1383327865678233`", "\[VeryThinSpace]", "+", 
           RowBox[{"0.7333793505898774`", " ", "\[ImaginaryI]"}]}], ")"}]}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.44000684187641076`", "\[VeryThinSpace]", "-", 
          RowBox[{"0.745259335408937`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
        "\[Lambda]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "0.7721369439040504`"}], "-", 
          RowBox[{"1.5080502109365075`", " ", "\[ImaginaryI]"}]}], ")"}], " ",
         "a3"}]}]}], ",", 
     RowBox[{"a2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1.`"}], "-", 
          RowBox[{"5.551115123125783`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "a3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4.7974672750104797`*^-17", "-", 
          RowBox[{"2.776557691523636`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.3388462033227507`*^-16", "-", 
          RowBox[{"8.086132650657524`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.6341331005333027`*^-16", "-", 
          RowBox[{"4.6926828988131257`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.9335801510138806`*^-16", "+", 
          RowBox[{"1.6140461276497816`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b10", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.787250298423255`*^-16", "-", 
          RowBox[{"2.0334074314994825`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4.059707073813937`*^-16", "-", 
          RowBox[{"5.473047470154859`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b11", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4.367345640864128`*^-16", "-", 
          RowBox[{"2.093617344738037`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.1229590947608872`*^-15", "-", 
          RowBox[{"1.0755679336301385`*^-15", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8.149182863435677`*^-17", "+", 
          RowBox[{"2.941463587086975`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.214971794710074`*^-17", "-", 
          RowBox[{"3.595556934151259`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b7", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1.308102312430323`*^-16"}], "-", 
          RowBox[{"8.575660704040016`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.75228567606411`*^-16", "-", 
          RowBox[{"6.10225617385349`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b8", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4.037029799552684`*^-17"}], "-", 
          RowBox[{"1.3300881266340941`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.6427055928339846`*^-16", "-", 
          RowBox[{"1.0887438216686249`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.6064520428468348`*^-17", "+", 
          RowBox[{"1.708384638044017`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6.753874831034803`*^-17", "+", 
          RowBox[{"2.0057238045387397`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8.2011795426811`*^-18", "+", 
          RowBox[{"1.457521788810535`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"7.659855959093614`*^-17", "+", 
          RowBox[{"1.1669752978126655`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c3", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6.440582801745056`*^-19", "+", 
          RowBox[{"3.3815709881392937`*^-19", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.933814637194039`*^-18", "-", 
          RowBox[{"4.283607815789644`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8.499730477723362`*^-18", "-", 
          RowBox[{"1.8899913983336193`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6.841734357949702`*^-18", "-", 
          RowBox[{"4.4661612115685167`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c5", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.0329490827825783`*^-18", "+", 
          RowBox[{"1.0596809119842854`*^-18", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.078077708937299`*^-17", "-", 
          RowBox[{"9.512665002705361`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c6", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.624949636606655`*^-18", "-", 
          RowBox[{"7.095754771272978`*^-19", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.058824086770924`*^-18", "-", 
          RowBox[{"1.279658496505351`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"f1", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1.2452703137471279`*^-16", "-", 
         RowBox[{"2.28972189372151`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}], ",", 
     RowBox[{"g1", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "6.950537847814708`*^-17"}], "-", 
         RowBox[{"1.3715159697646847`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}], ",", 
     RowBox[{"g2", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4.423324904934816`*^-18"}], "-", 
         RowBox[{"2.7868297331558076`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}], ",", 
     RowBox[{"ii", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2.177047574915216`*^-19", "-", 
         RowBox[{"4.934915122400005`*^-19", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6194143643092527`*^9, 3.619414376854364*^9}, 
   3.619415240669402*^9, 3.6194188297808743`*^9, 3.6194199016696253`*^9, 
   3.6194230102433567`*^9, 3.619427134295826*^9}]
}, Open  ]],

Cell[TextData[{
 "Compare this to the numerically evaluated Ward identity of the original ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "4"], TraditionalForm]]],
 "-amplitude:"
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.619174112444458*^9, {3.619242955678088*^9, 
   3.619242977714387*^9}, {3.619413412521263*^9, 3.619413414903133*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4num", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"amp4", "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"rules0", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", "rulesward1", ",", 
       "rulesward3"}], "]"}]}], ")"}], "/.", 
   RowBox[{"Join", "[", 
    RowBox[{"rules1", ",", "rules3"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.619243050186409*^9, 3.6192431000563173`*^9}, {
  3.6192467286478443`*^9, 3.6192467330975037`*^9}, {3.619413371671934*^9, 
  3.619413428705387*^9}, {3.619413490652618*^9, 3.61941350744374*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.619243053214594*^9, 3.61924310115626*^9}, 
   3.619243677202939*^9, {3.619246729606061*^9, 3.619246733653371*^9}, 
   3.619247012573942*^9, 3.619247502133204*^9, 3.619250329939883*^9, 
   3.6192531477574863`*^9, 3.61925451665207*^9, 3.61934368413831*^9, 
   3.619412731846592*^9, {3.619413372848015*^9, 3.6194133930922127`*^9}, 
   3.619413429440604*^9, {3.6194134911143084`*^9, 3.619413508199016*^9}, 
   3.619415240726199*^9, 3.619418830963575*^9, 3.619419901806731*^9, 
   3.619423010332466*^9, 3.619427134367661*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second kinematical configuration", "Subsubsection",
 CellChangeTimes->{{3.619426499642606*^9, 3.619426531438857*^9}, {
  3.619426562424374*^9, 3.6194265638212748`*^9}}],

Cell["First need 4 light-like momenta adding up to zero.", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"k1", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, 3.604043486987067*^9, {3.604051375692047*^9, 
   3.604051380225711*^9}, {3.6120866065182667`*^9, 3.612086606758206*^9}, {
   3.612505924058659*^9, 3.612505936532402*^9}, {3.612684208346747*^9, 
   3.6126842128136387`*^9}, {3.619173534353448*^9, 3.61917353448518*^9}, {
   3.6192428328385477`*^9, 3.619242834469954*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k2", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, 3.6040434902674513`*^9, {
   3.604051400892659*^9, 3.604051410913472*^9}, {3.612086612732903*^9, 
   3.612086614349341*^9}, {3.612505939428406*^9, 3.6125059543631077`*^9}, {
   3.61268421467281*^9, 3.612684221598008*^9}, {3.619173536026105*^9, 
   3.6191735361820107`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k3", "=", 
   RowBox[{"{", 
    RowBox[{"k31", ",", "k32", ",", "k33", ",", "k34"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, 3.604043493634906*^9, {
   3.60430121239147*^9, 3.604301216957938*^9}, 3.6043040418011713`*^9, {
   3.61208661791853*^9, 3.612086618148158*^9}, {3.612086936652397*^9, 
   3.612086944450577*^9}, 3.619173550969096*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"k4", "=", 
   RowBox[{"{", 
    RowBox[{"k41", ",", "k42", ",", "k43", ",", "k44"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, 3.604043497194705*^9, {
   3.604301219134789*^9, 3.6043012254138393`*^9}, {3.604303998849719*^9, 
   3.6043040088803873`*^9}, {3.612086632200843*^9, 3.612086646982294*^9}, 
   3.6191735537450657`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"x", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "2", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "3", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"x", "[", 
     RowBox[{"[", "4", "]"}], "]"}], 
    RowBox[{"y", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.612086707631708*^9, 3.612086713887814*^9}, 
   3.6191735610392447`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"kinsys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k1", ",", "k1"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k2", ",", "k2"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k3", ",", "k3"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"k4", ",", "k4"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"k1", "+", "k2", "+", "k3", "+", "k4"}], "\[Equal]", "0"}]}], 
    "}"}]}], ";", 
  RowBox[{"kinsys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.612258217072095*^9, 3.612258219089881*^9}, {
  3.612258263321577*^9, 3.612258271721939*^9}, {3.612505966669755*^9, 
  3.612505985721085*^9}, {3.6191735688138533`*^9, 3.619173572268476*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"True"},
      {"True"},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k31", "2"]}], "+", 
         SuperscriptBox["k32", "2"], "+", 
         SuperscriptBox["k33", "2"], "+", 
         SuperscriptBox["k34", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["k41", "2"]}], "+", 
         SuperscriptBox["k42", "2"], "+", 
         SuperscriptBox["k43", "2"], "+", 
         SuperscriptBox["k44", "2"]}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"k31", "+", "k41", "+", "2"}], ",", 
          RowBox[{"k32", "+", "k42"}], ",", 
          RowBox[{"k33", "+", "k43"}], ",", 
          RowBox[{"k34", "+", "k44"}]}], "}"}], "\[LongEqual]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612258223332856*^9, 3.612258277667809*^9, 3.612505994584982*^9, 
   3.6126800091197*^9, 3.6126842296073713`*^9, 3.614415251319221*^9, 
   3.614416681331402*^9, 3.614506889916788*^9, 3.6145783531107807`*^9, 
   3.61493838358314*^9, 3.615634944521681*^9, 3.6157167540016603`*^9, 
   3.6162157977373037`*^9, 3.617337299458859*^9, 3.617339456664722*^9, 
   3.618218573787261*^9, {3.619173572887054*^9, 3.619173586936594*^9}, 
   3.619242838388041*^9, 3.6193436271101513`*^9, 3.619411834288629*^9, 
   3.619412717518421*^9, 3.6194144187326727`*^9, 3.6194153087505503`*^9, 
   3.619419019310787*^9, 3.619422172653228*^9, 3.6194266143258877`*^9, 
   3.61942713449155*^9, 3.619427612142252*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"FindInstance", "[", 
   RowBox[{"kinsys", ",", 
    RowBox[{"Join", "[", 
     RowBox[{"k4", ",", "k3"}], "]"}], ",", "2"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086667146719*^9, 3.612086669789753*^9}, {
   3.61208672018432*^9, 3.6120867609601393`*^9}, {3.612086820399687*^9, 
   3.61208684701149*^9}, {3.6120868882347116`*^9, 3.612086911234775*^9}, {
   3.612086947214334*^9, 3.612086966920597*^9}, {3.612087130200302*^9, 
   3.612087138062559*^9}, {3.612257132872628*^9, 3.6122571670798407`*^9}, 
   3.612257397692018*^9, {3.61225751058984*^9, 3.612257511578771*^9}, {
   3.6122576055168962`*^9, 3.612257613202684*^9}, 3.612257694530752*^9, {
   3.612258060499379*^9, 3.612258062723226*^9}, {3.612258192623537*^9, 
   3.612258193411767*^9}, 3.612258282749514*^9, {3.6125060012757797`*^9, 
   3.612506003735097*^9}, {3.612680017069385*^9, 3.6126800172139387`*^9}, 
   3.612684254591062*^9, 3.6145769005945463`*^9, 3.614576952464837*^9, {
   3.6145770875853148`*^9, 3.614577088568757*^9}, {3.6191736130014772`*^9, 
   3.6191736131373873`*^9}, 3.6194265915186768`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k41", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"k42", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["46", "5"]}], "-", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k43", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["67", "10"]}], "-", 
        FractionBox[
         RowBox[{"3", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k44", "\[Rule]", 
       RowBox[{"-", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "127"}], "-", 
          FractionBox[
           RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}], ",", 
      RowBox[{"k31", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"k32", "\[Rule]", 
       RowBox[{
        FractionBox["46", "5"], "+", 
        FractionBox[
         RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k33", "\[Rule]", 
       RowBox[{
        FractionBox["67", "10"], "+", 
        FractionBox[
         RowBox[{"3", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{"k34", "\[Rule]", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "127"}], "-", 
         FractionBox[
          RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"k41", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"k42", "\[Rule]", 
       RowBox[{
        FractionBox["47", "5"], "+", 
        RowBox[{"10", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{"k43", "\[Rule]", 
       RowBox[{
        FractionBox["13", "2"], "+", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k44", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1937"}], "-", 
          RowBox[{"22960", " ", "\[ImaginaryI]"}]}]]}]}], ",", 
      RowBox[{"k31", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"k32", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["47", "5"]}], "-", 
        RowBox[{"10", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{"k33", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["13", "2"]}], "-", 
        FractionBox[
         RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"k34", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1937"}], "-", 
          RowBox[{"22960", " ", "\[ImaginaryI]"}]}]]}]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.612086762118141*^9, 3.612086780893147*^9}, {
   3.612086823214789*^9, 3.612086847939478*^9}, {3.61208688888518*^9, 
   3.612086911822865*^9}, {3.612086954278853*^9, 3.612086967359386*^9}, {
   3.612087131307373*^9, 3.6120871383511143`*^9}, 3.612257142281363*^9, 
   3.612257394237977*^9, {3.6122575076936417`*^9, 3.612257512163836*^9}, {
   3.6122576069012537`*^9, 3.612257627804504*^9}, {3.612257690411792*^9, 
   3.612257695104991*^9}, 3.612258189484466*^9, 3.61225822195914*^9, 
   3.612258276336063*^9, 3.612259320778799*^9, 3.612511330729707*^9, 
   3.6126803950144*^9, {3.6126842499610157`*^9, 3.612684258655238*^9}, 
   3.6144152518055267`*^9, 3.614416681520438*^9, 3.6145068908943377`*^9, 
   3.614576906819211*^9, 3.614576960270529*^9, 3.614577089264464*^9, 
   3.6145783532449417`*^9, 3.614938384517983*^9, 3.615634945242508*^9, 
   3.615716763753829*^9, 3.616215797986451*^9, 3.617337299646379*^9, 
   3.617339456758937*^9, 3.618218573949119*^9, 3.619173619583102*^9, 
   3.619242840164323*^9, 3.619343627163353*^9, 3.619411842939118*^9, 
   3.619412717583315*^9, 3.619414418766119*^9, 3.61941530879943*^9, 
   3.619419020880562*^9, 3.6194221728038893`*^9, {3.619426592298934*^9, 
   3.61942661442725*^9}, 3.6194271345832*^9, 3.6194276137826977`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k3", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.612086972550753*^9, 3.612086977276445*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{
     FractionBox["46", "5"], "+", 
     FractionBox[
      RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}], ",", 
    RowBox[{
     FractionBox["67", "10"], "+", 
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]"}], "10"]}], ",", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "127"}], "-", 
      FractionBox[
       RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.612086977587695*^9, 3.6122575146527653`*^9, 
  3.612257696324094*^9, 3.612684263546081*^9, 3.6144152519329348`*^9, 
  3.6144166815767603`*^9, 3.614506890949765*^9, 3.614578353276498*^9, 
  3.614938384565001*^9, 3.615634945289898*^9, 3.615716766074543*^9, 
  3.616215798017215*^9, 3.617337299676415*^9, 3.617339456797743*^9, 
  3.618218573984281*^9, 3.619173630677906*^9, 3.619242841374653*^9, 
  3.619343627209127*^9, 3.61941184560463*^9, 3.619412717642727*^9, 
  3.6194144188001947`*^9, 3.619415308839137*^9, 3.619419021034181*^9, 
  3.619422172870103*^9, 3.619426614484292*^9, 3.6194271346308937`*^9, 
  3.6194276166682*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k3", ",", "k3"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122571125898314`*^9, 3.612257119072855*^9}, {
  3.612257544299827*^9, 3.612257553190195*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6122571193226643`*^9, 3.612257515599658*^9, {3.612257545928628*^9, 
   3.612257553598151*^9}, 3.612257697150077*^9, 3.612684265607835*^9, 
   3.6144152519576693`*^9, 3.614416681638151*^9, 3.614506890967968*^9, 
   3.61457835328469*^9, 3.614938384605798*^9, 3.615634945325961*^9, 
   3.615716767074236*^9, 3.616215798046818*^9, 3.617337299711178*^9, 
   3.617339456832644*^9, 3.618218574015799*^9, 3.6191736350394297`*^9, 
   3.6192428424830933`*^9, 3.619343627215727*^9, 3.61941184687271*^9, 
   3.619412717696143*^9, 3.6194144188087997`*^9, 3.619415308899968*^9, 
   3.619419021180119*^9, 3.6194221729470654`*^9, 3.619426614529591*^9, 
   3.619427134690647*^9, 3.6194276179424343`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"k4", "/.", 
  RowBox[{"sols", "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{3.612086983780642*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "1"}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["46", "5"]}], "-", 
     FractionBox[
      RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["67", "10"]}], "-", 
     FractionBox[
      RowBox[{"3", " ", "\[ImaginaryI]"}], "10"]}], ",", 
    RowBox[{"-", 
     SqrtBox[
      RowBox[{
       RowBox[{"-", "127"}], "-", 
       FractionBox[
        RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.612086984684704*^9, 3.612257555469883*^9, 
  3.612257697740192*^9, 3.612684268914393*^9, 3.614415251973494*^9, 
  3.6144166816980267`*^9, 3.614506890983892*^9, 3.614578353290989*^9, 
  3.614938384647709*^9, 3.615634945363903*^9, 3.6157167682912292`*^9, 
  3.616215798191144*^9, 3.617337299746804*^9, 3.617339456867691*^9, 
  3.6182185740487432`*^9, 3.619173636567751*^9, 3.61924284322722*^9, 
  3.619343627221695*^9, 3.619411848922373*^9, 3.6194127177368402`*^9, 
  3.619414418815596*^9, 3.6194153089619102`*^9, 3.61941902126154*^9, 
  3.619422173010064*^9, 3.619426614575779*^9, 3.61942713475558*^9, 
  3.6194276203629017`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"min", "[", 
    RowBox[{"k4", ",", "k4"}], "]"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.6122575625202703`*^9, 3.612257564202305*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.612257565498811*^9, 3.612257698283271*^9, 
  3.6126842714539623`*^9, 3.614415251992217*^9, 3.614416681767228*^9, 
  3.614506890999983*^9, 3.614578353295656*^9, 3.614938384652294*^9, 
  3.615634945401319*^9, 3.615716769807744*^9, 3.616215798222134*^9, 
  3.617337299789431*^9, 3.617339456902569*^9, 3.618218574055382*^9, 
  3.6192428439067097`*^9, 3.619343627227079*^9, 3.619411850482154*^9, 
  3.619412717775824*^9, 3.619414418821764*^9, 3.619415309003797*^9, 
  3.619419021335904*^9, 3.619422173059569*^9, 3.6194266146289577`*^9, 
  3.619427134810897*^9, 3.619427621198168*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"s", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
     RowBox[{"t", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
     RowBox[{"u", "\[Rule]", 
      RowBox[{"2", 
       RowBox[{"min", "[", 
        RowBox[{"k1", ",", "k4"}], "]"}]}]}]}], "}"}], "/.", 
   RowBox[{"sols", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.612087426835834*^9, 3.612087432664119*^9}, {
   3.612258338518701*^9, 3.612258339672268*^9}, 3.6145769704085627`*^9, 
   3.614577080572277*^9, {3.619173653576743*^9, 3.619173663300818*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"s", "\[Rule]", 
     RowBox[{"-", "4"}]}], ",", 
    RowBox[{"t", "\[Rule]", 
     RowBox[{
      FractionBox["102", "5"], "+", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
    RowBox[{"u", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["82", "5"]}], "-", 
      FractionBox[
       RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612087439480166*^9, 3.612257591558383*^9, 3.612257700130177*^9, 
   3.612258340118903*^9, 3.6126842783468533`*^9, 3.614415252427136*^9, 
   3.614416681890109*^9, 3.6145068911892233`*^9, {3.6145769429963827`*^9, 
   3.614576970611363*^9}, 3.614578353362673*^9, 3.614938384741045*^9, 
   3.61563494553862*^9, 3.615716776067073*^9, 3.616215798269853*^9, 
   3.617337299947012*^9, 3.617339456954917*^9, 3.618218574108639*^9, 
   3.6191736638778257`*^9, 3.6192428449891157`*^9, 3.619343627270199*^9, 
   3.619411852210965*^9, 3.619412717816416*^9, 3.619414418855288*^9, 
   3.619415309046014*^9, 3.619419021449251*^9, 3.61942217309978*^9, 
   3.619426614681304*^9, 3.619427134820486*^9, 3.619427626123591*^9}]
}, Open  ]],

Cell[TextData[{
 "This is to check that the kinematical configuration is not singular (i.e. \
all ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["s", "ij"], "\[NotEqual]", "0"}], TraditionalForm]]],
 ")."
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQ7fEx+ZPxtVeOF1wefwHRizo9um2A9Ie74WBakPf0
VRDN+ufETRAt8fr/NK1brxxn/cqdDaIPH3+/DESvW3BlOYj+V7v06EogbTPv
9RkQfVM88wqINltUfg1Eb2mWuQeidTQWPwDRLi991FcBadkJ9WA6wPpce8jt
V448u26D6SqZNQdOAumyCzNPgWi31wvO/QTSAtX/r4LoGye8+H4B6RmLXwqC
aJ72s8Zdz4H0rRumIJrla5QbiA7ZIegOohmNOhWbXgLVn96uAqL/dfd9X/bq
lSP3n4AfIDolbtbHz29fOXI1hP8A0We/bNvxBUjPeiCyE0TvKXd7IPvuleOm
z9FgWm1P+lMnIP1wZvl7EA0ACNrNIA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"qq", "=", 
   RowBox[{"{", 
    RowBox[{"q1", ",", "q2", ",", "q3", ",", "q4"}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.619245750462315*^9, 3.6192457583034897`*^9}, {
  3.61925359622964*^9, 3.619253624137032*^9}, {3.6192536823679132`*^9, 
  3.619253690597275*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solsQ", "=", 
   RowBox[{"FindInstance", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{"qq", ",", "qq"}], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k2"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k3"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"k1", "+", "k4"}], ",", "qq"}], "]"}], "\[NotEqual]", 
         "0"}], ",", 
        RowBox[{"q3", "\[NotEqual]", "0"}]}], "}"}], "/.", 
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ",", "qq", ",", "40"}], "]"}]}], ";", 
  RowBox[{"solsQ", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619245735712246*^9, 3.619245843386804*^9}, {
   3.619245898655726*^9, 3.619245907321413*^9}, {3.619246907400166*^9, 
   3.619246907649767*^9}, {3.6192471569505043`*^9, 3.619247157251212*^9}, {
   3.619247302920272*^9, 3.619247327249937*^9}, {3.619247363111875*^9, 
   3.619247380569146*^9}, 3.619250174378536*^9, {3.619252969898986*^9, 
   3.619252989345154*^9}, {3.6192534788689737`*^9, 3.619253483581024*^9}, 
   3.619253561288389*^9, {3.6192536348760147`*^9, 3.619253659843577*^9}, {
   3.619253696488311*^9, 3.619253696662755*^9}, 3.619253796719205*^9, {
   3.619259185839983*^9, 3.619259186016962*^9}, {3.619259675735292*^9, 
   3.619259676084115*^9}, {3.619411868929187*^9, 3.619411869159006*^9}, 
   3.619414412353684*^9, 3.619415301351286*^9, {3.619419007538918*^9, 
   3.619419007730249*^9}, {3.619422167668703*^9, 3.619422167946136*^9}, {
   3.619426769992065*^9, 3.619426770202424*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["529", "2"]}], "+", 
        FractionBox[
         RowBox[{"3721", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1447", "10"]}], "-", 
        FractionBox[
         RowBox[{"7", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6829", "10"]}], "-", 
        FractionBox[
         RowBox[{"7607", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "39248715"}], "-", 
          RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1457", "2"]}], "+", 
        RowBox[{"977", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1091", "2"], "+", 
        FractionBox[
         RowBox[{"7691", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8869", "10"]}], "+", 
        FractionBox[
         RowBox[{"6147", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "53860771"}], "-", 
          RowBox[{"117222224", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6603", "10"], "+", 
        FractionBox[
         RowBox[{"673", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4642", "5"]}], "-", 
        FractionBox[
         RowBox[{"7149", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["113", "2"], "+", 
        FractionBox[
         RowBox[{"788", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{"2556694", "-", 
          FractionBox[
           RowBox[{"62817937", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3061", "10"], "-", 
        FractionBox[
         RowBox[{"6737", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["2799", "5"], "-", 
        FractionBox[
         RowBox[{"6579", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4531", "5"]}], "-", 
        FractionBox[
         RowBox[{"4527", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["42848963", "2"]}], "-", 
          FractionBox[
           RowBox[{"24816389", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1593", "2"]}], "+", 
        FractionBox[
         RowBox[{"1334", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3961", "5"]}], "+", 
        FractionBox[
         RowBox[{"6559", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1209", "2"]}], "+", 
        FractionBox[
         RowBox[{"2533", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"25707729", "+", 
          RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1934", "5"]}], "-", 
        FractionBox[
         RowBox[{"4921", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4419", "10"]}], "+", 
        FractionBox[
         RowBox[{"9831", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1827", "2"]}], "-", 
        FractionBox[
         RowBox[{"3863", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "659273"}], "+", 
          RowBox[{"54378224", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3378", "5"]}], "-", 
        FractionBox[
         RowBox[{"8619", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1169", "10"]}], "-", 
        FractionBox[
         RowBox[{"2709", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["357", "10"], "-", 
        FractionBox[
         RowBox[{"4874", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"94240593", "+", 
          RowBox[{"110752716", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4177", "5"]}], "+", 
        FractionBox[
         RowBox[{"1629", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["462", "5"]}], "-", 
        FractionBox[
         RowBox[{"184", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["199", "5"], "-", 
        FractionBox[
         RowBox[{"567", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"3857491", "-", 
          RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2606", "5"], "+", 
        FractionBox[
         RowBox[{"1363", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["768", "5"]}], "-", 
        FractionBox[
         RowBox[{"1166", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1997", "2"], "+", 
        FractionBox[
         RowBox[{"1807", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "63826433"}], "-", 
          RowBox[{"50919660", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["4979", "5"], "+", 
        FractionBox[
         RowBox[{"8653", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["2341", "10"], "-", 
        FractionBox[
         RowBox[{"3764", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3127", "10"]}], "-", 
        FractionBox[
         RowBox[{"8073", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["65436529", "2"], "+", 
          FractionBox[
           RowBox[{"78545351", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2796", "5"], "-", 
        FractionBox[
         RowBox[{"4514", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["651", "10"]}], "-", 
        FractionBox[
         RowBox[{"2479", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1467", "5"], "-", 
        FractionBox[
         RowBox[{"1824", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "9953283"}], "-", 
          FractionBox[
           RowBox[{"41395173", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["829", "2"], "-", 
        FractionBox[
         RowBox[{"4348", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1763", "5"], "+", 
        RowBox[{"62", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["5339", "10"], "+", 
        FractionBox[
         RowBox[{"857", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "80631363"}], "-", 
          RowBox[{"122217310", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7409", "10"]}], "-", 
        FractionBox[
         RowBox[{"4866", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["177", "2"]}], "-", 
        FractionBox[
         RowBox[{"7597", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4242", "5"], "-", 
        RowBox[{"312", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "45131215"}], "+", 
          RowBox[{"183702246", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4303", "5"]}], "+", 
        FractionBox[
         RowBox[{"4997", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2632", "5"]}], "-", 
        FractionBox[
         RowBox[{"1349", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6293", "10"], "+", 
        FractionBox[
         RowBox[{"1437", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["1339619", "2"]}], "-", 
          RowBox[{"37646268", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["888", "5"], "-", 
        FractionBox[
         RowBox[{"9979", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["3631", "10"], "-", 
        FractionBox[
         RowBox[{"3413", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1943", "2"], "-", 
        FractionBox[
         RowBox[{"7069", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["53713307", "2"]}], "+", 
          FractionBox[
           RowBox[{"75737837", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["242", "5"], "+", 
        FractionBox[
         RowBox[{"797", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"275", "+", 
        FractionBox[
         RowBox[{"2789", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1205", "2"], "-", 
        FractionBox[
         RowBox[{"2849", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1480995"}], "+", 
          RowBox[{"13716098", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["49", "2"], "+", 
        FractionBox[
         RowBox[{"1435", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["9043", "10"], "+", 
        FractionBox[
         RowBox[{"448", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["2727", "10"], "+", 
        FractionBox[
         RowBox[{"2677", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "132663833"}], "-", 
          RowBox[{"27289664", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["567", "5"], "+", 
        FractionBox[
         RowBox[{"1611", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["6939", "10"], "-", 
        FractionBox[
         RowBox[{"4506", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1472", "5"], "-", 
        FractionBox[
         RowBox[{"3663", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["13794847", "5"], "+", 
          FractionBox[
           RowBox[{"35102304", " ", "\[ImaginaryI]"}], "5"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3979", "10"]}], "+", 
        FractionBox[
         RowBox[{"2457", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["863", "10"], "+", 
        RowBox[{"297", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3209", "5"]}], "-", 
        FractionBox[
         RowBox[{"145", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "5698344"}], "-", 
          FractionBox[
           RowBox[{"16992563", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["1672", "5"], "+", 
        FractionBox[
         RowBox[{"5687", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "184"}], "-", 
        FractionBox[
         RowBox[{"8527", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5253", "10"]}], "+", 
        FractionBox[
         RowBox[{"3617", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"72901243", "+", 
          RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["27", "10"]}], "-", 
        FractionBox[
         RowBox[{"5137", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["6669", "10"], "-", 
        RowBox[{"919", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["713", "10"], "+", 
        FractionBox[
         RowBox[{"7341", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"66974411", "+", 
          RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3128", "5"], "+", 
        FractionBox[
         RowBox[{"3576", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8859", "10"]}], "+", 
        FractionBox[
         RowBox[{"1467", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["529", "10"]}], "+", 
        FractionBox[
         RowBox[{"3631", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "35886557"}], "+", 
          RowBox[{"123161326", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3869", "5"], "-", 
        FractionBox[
         RowBox[{"3039", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["86", "5"]}], "+", 
        FractionBox[
         RowBox[{"5527", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1889", "10"]}], "+", 
        RowBox[{"451", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{"97931047", "-", 
          RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2561", "5"]}], "+", 
        FractionBox[
         RowBox[{"1335", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7933", "10"]}], "+", 
        FractionBox[
         RowBox[{"3659", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3217", "5"]}], "-", 
        FractionBox[
         RowBox[{"2691", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "61854981"}], "+", 
          RowBox[{"13100900", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["9009", "10"], "-", 
        FractionBox[
         RowBox[{"5249", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3399", "5"]}], "-", 
        FractionBox[
         RowBox[{"8991", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1085", "2"], "+", 
        FractionBox[
         RowBox[{"793", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{"15330032", "-", 
          FractionBox[
           RowBox[{"117013109", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["837", "2"], "+", 
        FractionBox[
         RowBox[{"3956", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2943", "5"]}], "+", 
        FractionBox[
         RowBox[{"4664", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "425"}], "+", 
        FractionBox[
         RowBox[{"251", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["5359215", "2"]}], "+", 
          RowBox[{"44541539", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["6859", "10"], "-", 
        FractionBox[
         RowBox[{"1121", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["877", "5"]}], "+", 
        FractionBox[
         RowBox[{"6871", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["872", "5"], "+", 
        FractionBox[
         RowBox[{"4433", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["80858931", "2"], "-", 
          RowBox[{"9394224", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2618", "5"], "+", 
        FractionBox[
         RowBox[{"7807", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["1471", "10"], "+", 
        FractionBox[
         RowBox[{"2501", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["8377", "10"], "-", 
        FractionBox[
         RowBox[{"1109", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["47348499", "2"]}], "+", 
          FractionBox[
           RowBox[{"55778667", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["747", "10"], "+", 
        FractionBox[
         RowBox[{"3479", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "605"}], "-", 
        FractionBox[
         RowBox[{"1513", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1627", "10"], "-", 
        FractionBox[
         RowBox[{"1273", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["14127815", "2"]}], "-", 
          FractionBox[
           RowBox[{"38499453", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["3357", "10"], "+", 
        FractionBox[
         RowBox[{"3556", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2109", "10"]}], "+", 
        FractionBox[
         RowBox[{"673", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1739", "10"]}], "-", 
        RowBox[{"83", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "8692743"}], "+", 
          FractionBox[
           RowBox[{"29528399", " ", "\[ImaginaryI]"}], "2"]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2422", "5"], "-", 
        FractionBox[
         RowBox[{"839", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{"169", "-", 
        RowBox[{"102", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["9163", "10"], "+", 
        FractionBox[
         RowBox[{"4022", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", 
           FractionBox["7602011", "2"]}], "-", 
          RowBox[{"46151976", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["171", "5"]}], "+", 
        FractionBox[
         RowBox[{"9369", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8957", "10"]}], "+", 
        FractionBox[
         RowBox[{"2987", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1343", "10"]}], "-", 
        RowBox[{"128", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "132365619"}], "+", 
          RowBox[{"97171760", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "745"}], "-", 
        FractionBox[
         RowBox[{"1283", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3117", "10"]}], "+", 
        FractionBox[
         RowBox[{"7363", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1171", "10"], "-", 
        FractionBox[
         RowBox[{"7701", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"116782515", "+", 
          RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["5809", "10"], "-", 
        FractionBox[
         RowBox[{"1749", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["9209", "10"]}], "+", 
        RowBox[{"205", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3697", "10"]}], "+", 
        FractionBox[
         RowBox[{"2551", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "10"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "130493933"}], "-", 
          RowBox[{"44980416", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2104", "5"]}], "-", 
        FractionBox[
         RowBox[{"4916", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6199", "10"]}], "+", 
        FractionBox[
         RowBox[{"4183", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["6583", "10"], "+", 
        FractionBox[
         RowBox[{"1943", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "5"]}], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "12211434"}], "+", 
          RowBox[{"1674814", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4954", "5"]}], "-", 
        FractionBox[
         RowBox[{"1201", " ", "\[ImaginaryI]"}], "2"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1949", "10"]}], "-", 
        FractionBox[
         RowBox[{"2692", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["4669", "5"], "+", 
        FractionBox[
         RowBox[{"6823", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"46652379", "-", 
          RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2687", "5"], "-", 
        FractionBox[
         RowBox[{"7103", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["239", "2"], "+", 
        FractionBox[
         RowBox[{"9633", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["1676", "5"], "-", 
        FractionBox[
         RowBox[{"4116", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"126323851", "-", 
          RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{"829", "-", 
        FractionBox[
         RowBox[{"3603", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        FractionBox["3637", "5"], "-", 
        FractionBox[
         RowBox[{"7841", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["9067", "10"], "-", 
        FractionBox[
         RowBox[{"3163", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{"22120483", "+", 
          RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        FractionBox["2058", "5"], "+", 
        FractionBox[
         RowBox[{"2792", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4309", "10"]}], "-", 
        FractionBox[
         RowBox[{"4141", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        FractionBox["5821", "10"], "-", 
        FractionBox[
         RowBox[{"1953", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "5"], " ", 
        SqrtBox[
         RowBox[{
          FractionBox["8578619", "2"], "+", 
          RowBox[{"5016716", " ", "\[ImaginaryI]"}]}]]}]}]},
     {
      RowBox[{"q1", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3393", "5"]}], "-", 
        RowBox[{"751", " ", "\[ImaginaryI]"}]}]}], 
      RowBox[{"q2", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4239", "10"]}], "+", 
        FractionBox[
         RowBox[{"1561", " ", "\[ImaginaryI]"}], "5"]}]}], 
      RowBox[{"q3", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["777", "2"]}], "+", 
        FractionBox[
         RowBox[{"4069", " ", "\[ImaginaryI]"}], "10"]}]}], 
      RowBox[{"q4", "\[Rule]", 
       RowBox[{
        FractionBox["1", "10"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "17109005"}], "+", 
          RowBox[{"160010166", " ", "\[ImaginaryI]"}]}]]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619247306337376*^9, 3.6192473275798597`*^9}, {
   3.619247366761524*^9, 3.6192473862009478`*^9}, 3.619250189167459*^9, 
   3.619253006482288*^9, 3.619253501155623*^9, 3.619253562818247*^9, {
   3.619253636647204*^9, 3.6192536606192513`*^9}, 3.619253714663269*^9, 
   3.619253798174103*^9, 3.619259192689518*^9, 3.619259679665366*^9, 
   3.619343628769216*^9, {3.61941186770128*^9, 3.619411869795827*^9}, 
   3.619412717990695*^9, 3.619414425743634*^9, 3.619415316499393*^9, 
   3.619419029729253*^9, {3.619422172023136*^9, 3.619422175309548*^9}, 
   3.619426657188671*^9, 3.619427141830152*^9, 3.619427633898312*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"min", "[", 
       RowBox[{"qq", ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k2"}], ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k3"}], ",", "qq"}], "]"}], ",", 
      RowBox[{"min", "[", 
       RowBox[{
        RowBox[{"k1", "+", "k4"}], ",", "qq"}], "]"}]}], "}"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"solsQ", "[", 
       RowBox[{"[", "10", "]"}], "]"}]}], "]"}]}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellChangeTimes->{{3.6191737450948343`*^9, 3.619173797754238*^9}, {
  3.6191738286543903`*^9, 3.6191738320823097`*^9}, {3.619245862668565*^9, 
  3.6192458852495947`*^9}, {3.619245916409066*^9, 3.619245923800671*^9}, {
  3.619411876427549*^9, 3.619411876569488*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {"0"},
      {
       RowBox[{
        RowBox[{"-", 
         FractionBox["9958", "5"]}], "-", 
        FractionBox[
         RowBox[{"8653", " ", "\[ImaginaryI]"}], "5"]}]},
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["35957", "25"], "-", 
          FractionBox[
           RowBox[{"322509", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["62604055219", "5"]}], "-", 
           FractionBox[
            RowBox[{"116831529839", " ", "\[ImaginaryI]"}], "5"]}]]}]}]},
      {
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["24252", "25"]}], "+", 
          FractionBox[
           RowBox[{"284869", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["62604055219", "5"]}], "-", 
           FractionBox[
            RowBox[{"116831529839", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619245867709139*^9, 3.6192459244387503`*^9}, 
   3.6192469121346416`*^9, {3.619247376009243*^9, 3.619247390701576*^9}, 
   3.619253029812439*^9, 3.6192538056839447`*^9, 3.6192592221682997`*^9, 
   3.619259691088504*^9, 3.6193436293231564`*^9, 3.619411877276538*^9, 
   3.6194127180281563`*^9, 3.61941442596553*^9, 3.619415316772113*^9, 
   3.61941904197148*^9, 3.6194221756500473`*^9, 3.6194266622007217`*^9, 
   3.619427144213209*^9, 3.619427637420885*^9}]
}, Open  ]],

Cell["\<\
So we found a light-like q that leads to non-singular terms in the \
propagators.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules0", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k2"}], "]"}]}]}], ",", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k3"}], "]"}]}]}], ",", 
       RowBox[{"u", "\[Rule]", 
        RowBox[{"2", 
         RowBox[{"min", "[", 
          RowBox[{"k1", ",", "k4"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"1", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"2", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"3", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "qq"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"k", "[", 
           RowBox[{"4", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", 
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "qq"}], "]"}]}]}], "}"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"solsQ", "[", 
        RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"iq", ",", "1", ",", 
      RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619243019476788*^9, 3.619243024257585*^9}, {
   3.61924594137394*^9, 3.619246017843701*^9}, 3.619251664736548*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["599", "5"], "-", 
        FractionBox[
         RowBox[{"7477", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2046", "5"], "-", 
        FractionBox[
         RowBox[{"7407", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["148469", "25"]}], "-", 
          FractionBox[
           RowBox[{"23816", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["7849743", "2"]}], "-", 
           FractionBox[
            RowBox[{"71682938", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["135244", "25"], "+", 
          FractionBox[
           RowBox[{"31258", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["7849743", "2"]}], "-", 
           FractionBox[
            RowBox[{"71682938", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"1274", "-", 
        FractionBox[
         RowBox[{"2079", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"183", "-", 
        FractionBox[
         RowBox[{"17461", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["137973", "50"]}], "+", 
          FractionBox[
           RowBox[{"627987", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["53860771", "10"]}], "-", 
           FractionBox[
            RowBox[{"58611112", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["65123", "50"], "-", 
          FractionBox[
           RowBox[{"530287", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["53860771", "10"]}], "-", 
           FractionBox[
            RowBox[{"58611112", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15887", "10"]}], "-", 
        FractionBox[
         RowBox[{"3911", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2681", "10"], "+", 
        FractionBox[
         RowBox[{"3238", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["669183", "100"]}], "-", 
          FractionBox[
           RowBox[{"655099", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1778"}], "-", 
           FractionBox[
            RowBox[{"1827", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"730484", "-", 
           RowBox[{"8973991", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["801243", "100"], "+", 
          FractionBox[
           RowBox[{"668559", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1778"}], "-", 
           FractionBox[
            RowBox[{"1827", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"730484", "-", 
           RowBox[{"8973991", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2537", "10"], "+", 
        FractionBox[
         RowBox[{"79", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8659", "10"]}], "+", 
        FractionBox[
         RowBox[{"6658", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["31001", "100"], "-", 
          FractionBox[
           RowBox[{"935957", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["42848963", "5"]}], "-", 
           FractionBox[
            RowBox[{"24816389", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["30219", "100"], "+", 
          FractionBox[
           RowBox[{"801217", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["42848963", "5"]}], "-", 
           FractionBox[
            RowBox[{"24816389", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["43", "10"], "+", 
        FractionBox[
         RowBox[{"3891", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["15887", "10"], "-", 
        FractionBox[
         RowBox[{"9227", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["261479", "20"]}], "+", 
          FractionBox[
           RowBox[{"856331", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"25707729", "+", 
           RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["229619", "20"], "-", 
          FractionBox[
           RowBox[{"802971", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"25707729", "+", 
           RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["551", "10"]}], "+", 
        FractionBox[
         RowBox[{"7376", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["8287", "10"], "-", 
        RowBox[{"491", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["290914", "25"]}], "+", 
          FractionBox[
           RowBox[{"128997", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["659273", "10"]}], "+", 
           FractionBox[
            RowBox[{"27189112", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["271574", "25"], "-", 
          FractionBox[
           RowBox[{"153602", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["659273", "10"]}], "+", 
           FractionBox[
            RowBox[{"27189112", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5587", "10"], "+", 
        FractionBox[
         RowBox[{"3201", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1585", "2"], "+", 
        FractionBox[
         RowBox[{"14037", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["56929", "100"]}], "-", 
          FractionBox[
           RowBox[{"1250719", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "381"}], "-", 
           FractionBox[
            RowBox[{"783", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"31413531", "+", 
           RowBox[{"36917572", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["78191", "100"]}], "+", 
          FractionBox[
           RowBox[{"1078339", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "381"}], "-", 
           FractionBox[
            RowBox[{"783", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"31413531", "+", 
           RowBox[{"36917572", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"743", "-", 
        FractionBox[
         RowBox[{"8513", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4639", "5"], "-", 
        FractionBox[
         RowBox[{"7777", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["33516", "25"]}], "-", 
          FractionBox[
           RowBox[{"19139", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"3857491", "-", 
           RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["8254", "25"]}], "+", 
          FractionBox[
           RowBox[{"100589", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"3857491", "-", 
           RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3374", "5"]}], "-", 
        FractionBox[
         RowBox[{"2529", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1838", "5"]}], "-", 
        FractionBox[
         RowBox[{"197", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["119389", "20"], "+", 
          FractionBox[
           RowBox[{"66377", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["63826433", "10"]}], "-", 
           RowBox[{"5091966", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["98541", "20"]}], "-", 
          FractionBox[
           RowBox[{"11857", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["63826433", "10"]}], "-", 
           RowBox[{"5091966", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7617", "10"]}], "-", 
        FractionBox[
         RowBox[{"16181", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["12299", "10"]}], "-", 
        FractionBox[
         RowBox[{"225", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["109999", "50"], "-", 
          FractionBox[
           RowBox[{"564113", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"65436529", "+", 
           RowBox[{"78545351", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["10419", "50"]}], "+", 
          FractionBox[
           RowBox[{"650643", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"65436529", "+", 
           RowBox[{"78545351", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6243", "10"]}], "+", 
        FractionBox[
         RowBox[{"6549", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4941", "10"]}], "+", 
        FractionBox[
         RowBox[{"11507", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["116649", "50"], "-", 
          FractionBox[
           RowBox[{"280887", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["19906566", "5"]}], "-", 
           FractionBox[
            RowBox[{"41395173", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["60729", "50"]}], "+", 
          FractionBox[
           RowBox[{"190607", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["19906566", "5"]}], "-", 
           FractionBox[
            RowBox[{"41395173", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["619", "10"]}], "+", 
        FractionBox[
         RowBox[{"4658", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7671", "10"]}], "+", 
        FractionBox[
         RowBox[{"4038", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["35163", "5"], "+", 
          FractionBox[
           RowBox[{"78876", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["80631363", "10"]}], "-", 
           RowBox[{"12221731", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["31018", "5"]}], "-", 
          FractionBox[
           RowBox[{"122356", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["80631363", "10"]}], "-", 
           RowBox[{"12221731", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["3262", "5"], "+", 
        FractionBox[
         RowBox[{"427", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4147", "5"], "+", 
        FractionBox[
         RowBox[{"17329", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["256721", "50"], "-", 
          FractionBox[
           RowBox[{"247613", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["9026243", "2"]}], "+", 
           FractionBox[
            RowBox[{"91851123", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["330811", "50"]}], "+", 
          FractionBox[
           RowBox[{"198953", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["9026243", "2"]}], "+", 
           FractionBox[
            RowBox[{"91851123", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1671", "5"], "-", 
        FractionBox[
         RowBox[{"1539", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"1387", "-", 
        FractionBox[
         RowBox[{"2299", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["124963", "100"]}], "-", 
          FractionBox[
           RowBox[{"49977", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["1339619", "5"]}], "-", 
           FractionBox[
            RowBox[{"75292536", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["47157", "100"]}], "+", 
          FractionBox[
           RowBox[{"149917", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["1339619", "5"]}], "-", 
           FractionBox[
            RowBox[{"75292536", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["371", "2"], "+", 
        FractionBox[
         RowBox[{"3153", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["5407", "10"]}], "+", 
        FractionBox[
         RowBox[{"3361", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["276459", "25"], "-", 
          FractionBox[
           RowBox[{"282172", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["53713307", "5"]}], "+", 
           FractionBox[
            RowBox[{"75737837", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["267579", "25"]}], "+", 
          FractionBox[
           RowBox[{"232277", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["53713307", "5"]}], "+", 
           FractionBox[
            RowBox[{"75737837", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1133", "5"], "+", 
        FractionBox[
         RowBox[{"239", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1617", "5"]}], "-", 
        FractionBox[
         RowBox[{"4383", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["645141", "100"], "-", 
          FractionBox[
           RowBox[{"58163", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["296199", "2"]}], "+", 
           FractionBox[
            RowBox[{"6858049", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["635461", "100"]}], "+", 
          FractionBox[
           RowBox[{"90043", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["296199", "2"]}], "+", 
           FractionBox[
            RowBox[{"6858049", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4399", "5"], "-", 
        FractionBox[
         RowBox[{"6279", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4644", "5"]}], "-", 
        FractionBox[
         RowBox[{"8071", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["249583", "25"], "+", 
          FractionBox[
           RowBox[{"225119", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["132663833", "10"]}], "-", 
           FractionBox[
            RowBox[{"13644832", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["248358", "25"]}], "-", 
          FractionBox[
           RowBox[{"153369", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["132663833", "10"]}], "-", 
           FractionBox[
            RowBox[{"13644832", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1161", "2"], "-", 
        FractionBox[
         RowBox[{"6117", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8073", "10"]}], "+", 
        RowBox[{"579", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["488549", "50"], "-", 
          FractionBox[
           RowBox[{"597813", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "635"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "2"]}]], " ", 
         SqrtBox[
          RowBox[{"13794847", "+", 
           RowBox[{"35102304", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["477209", "50"]}], "+", 
          FractionBox[
           RowBox[{"630033", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "635"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "2"]}]], " ", 
         SqrtBox[
          RowBox[{"13794847", "+", 
           RowBox[{"35102304", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2421", "5"], "+", 
        FractionBox[
         RowBox[{"513", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1558", "5"], "-", 
        FractionBox[
         RowBox[{"5427", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["84773", "20"]}], "+", 
          FractionBox[
           RowBox[{"240337", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["11396688", "5"]}], "-", 
           FractionBox[
            RowBox[{"16992563", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["68857", "20"], "-", 
          FractionBox[
           RowBox[{"191197", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["11396688", "5"]}], "-", 
           FractionBox[
            RowBox[{"16992563", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2592", "5"]}], "-", 
        FractionBox[
         RowBox[{"7107", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["752", "5"]}], "+", 
        RowBox[{"284", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["407169", "100"]}], "-", 
          FractionBox[
           RowBox[{"11231", " ", "\[ImaginaryI]"}], "4"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"72901243", "+", 
           RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["474049", "100"], "+", 
          FractionBox[
           RowBox[{"78903", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"72901243", "+", 
           RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["3348", "5"], "-", 
        FractionBox[
         RowBox[{"4053", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3321", "5"]}], "+", 
        FractionBox[
         RowBox[{"14327", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["374653", "50"], "-", 
          FractionBox[
           RowBox[{"80709", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"66974411", "+", 
           RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["374923", "50"]}], "+", 
          FractionBox[
           RowBox[{"55024", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"66974411", "+", 
           RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3023", "2"]}], "-", 
        FractionBox[
         RowBox[{"1137", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2603", "10"], "-", 
        FractionBox[
         RowBox[{"8619", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["827301", "100"]}], "+", 
          FractionBox[
           RowBox[{"585143", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["35886557", "10"]}], "+", 
           FractionBox[
            RowBox[{"61580663", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["952421", "100"], "-", 
          FractionBox[
           RowBox[{"442103", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["35886557", "10"]}], "+", 
           FractionBox[
            RowBox[{"61580663", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", "791"}], "+", 
        FractionBox[
         RowBox[{"4283", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3783", "5"]}], "-", 
        FractionBox[
         RowBox[{"1244", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["144861", "100"]}], "+", 
          FractionBox[
           RowBox[{"772533", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"97931047", "-", 
           RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["299621", "100"], "-", 
          FractionBox[
           RowBox[{"833313", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"97931047", "-", 
           RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2811", "10"]}], "+", 
        FractionBox[
         RowBox[{"643", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2611", "2"], "-", 
        FractionBox[
         RowBox[{"13993", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1291877", "100"]}], "+", 
          FractionBox[
           RowBox[{"445211", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["61854981", "10"]}], "+", 
           RowBox[{"1310090", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1189437", "100"], "-", 
          FractionBox[
           RowBox[{"311711", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["61854981", "10"]}], "+", 
           RowBox[{"1310090", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["15807", "10"]}], "-", 
        FractionBox[
         RowBox[{"1871", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2211", "10"]}], "+", 
        RowBox[{"1424", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["68717", "100"]}], "-", 
          FractionBox[
           RowBox[{"838701", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"30660064", "-", 
           RowBox[{"117013109", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["248897", "100"], "+", 
          FractionBox[
           RowBox[{"733721", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"30660064", "-", 
           RowBox[{"117013109", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["10071", "10"]}], "+", 
        FractionBox[
         RowBox[{"708", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["1701", "10"], "-", 
        RowBox[{"1724", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["897101", "100"]}], "+", 
          FractionBox[
           RowBox[{"870731", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1071843"}], "+", 
           FractionBox[
            RowBox[{"89083078", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["980801", "100"], "-", 
          FractionBox[
           RowBox[{"712491", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1071843"}], "+", 
           FractionBox[
            RowBox[{"89083078", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["8613", "10"]}], "+", 
        FractionBox[
         RowBox[{"9113", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1021", "2"]}], "-", 
        FractionBox[
         RowBox[{"4629", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["4249", "5"]}], "+", 
          FractionBox[
           RowBox[{"593959", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "762"}], "-", 
           FractionBox[
            RowBox[{"783", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"26952977", "-", 
           RowBox[{"6262816", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["11108", "5"], "-", 
          FractionBox[
           RowBox[{"616379", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "762"}], "-", 
           FractionBox[
            RowBox[{"783", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"26952977", "-", 
           RowBox[{"6262816", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["753", "2"]}], "-", 
        FractionBox[
         RowBox[{"2653", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6707", "10"]}], "-", 
        FractionBox[
         RowBox[{"5154", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["725593", "100"], "+", 
          FractionBox[
           RowBox[{"202339", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["47348499", "5"]}], "+", 
           FractionBox[
            RowBox[{"55778667", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["620873", "100"]}], "-", 
          FractionBox[
           RowBox[{"46199", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["47348499", "5"]}], "+", 
           FractionBox[
            RowBox[{"55778667", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6797", "10"]}], "-", 
        FractionBox[
         RowBox[{"14523", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["5303", "10"], "+", 
        FractionBox[
         RowBox[{"607", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["172761", "50"]}], "-", 
          FractionBox[
           RowBox[{"77941", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "2825563"}], "-", 
           FractionBox[
            RowBox[{"38499453", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["180231", "50"], "+", 
          FractionBox[
           RowBox[{"91857", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "2825563"}], "-", 
           FractionBox[
            RowBox[{"38499453", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2733", "5"]}], "-", 
        FractionBox[
         RowBox[{"3747", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["624", "5"]}], "-", 
        FractionBox[
         RowBox[{"10477", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["314861", "100"]}], "+", 
          FractionBox[
           RowBox[{"58913", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["17385486", "5"]}], "+", 
           FractionBox[
            RowBox[{"29528399", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["382001", "100"], "-", 
          FractionBox[
           RowBox[{"6093", " ", "\[ImaginaryI]"}], "4"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["17385486", "5"]}], "+", 
           FractionBox[
            RowBox[{"29528399", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1577", "5"]}], "+", 
        FractionBox[
         RowBox[{"635", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3267", "5"]}], "+", 
        FractionBox[
         RowBox[{"1043", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["805949", "100"], "+", 
          FractionBox[
           RowBox[{"450927", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["7602011", "5"]}], "-", 
           FractionBox[
            RowBox[{"92303952", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["709069", "100"]}], "-", 
          FractionBox[
           RowBox[{"534827", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["7602011", "5"]}], "-", 
           FractionBox[
            RowBox[{"92303952", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1723", "2"]}], "-", 
        FractionBox[
         RowBox[{"679", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["9299", "10"], "-", 
        FractionBox[
         RowBox[{"15343", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["985293", "100"]}], "+", 
          FractionBox[
           RowBox[{"17841", " ", "\[ImaginaryI]"}], "4"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["132365619", "10"]}], "+", 
           RowBox[{"9717176", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["978453", "100"], "-", 
          FractionBox[
           RowBox[{"51729", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["132365619", "10"]}], "+", 
           RowBox[{"9717176", " ", "\[ImaginaryI]"}]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["4333", "10"], "+", 
        FractionBox[
         RowBox[{"6889", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10567", "10"], "-", 
        FractionBox[
         RowBox[{"474", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["17403", "5"]}], "+", 
          FractionBox[
           RowBox[{"15847", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"116782515", "+", 
           RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["9953", "5"], "-", 
          FractionBox[
           RowBox[{"47922", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"116782515", "+", 
           RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7509", "5"]}], "+", 
        FractionBox[
         RowBox[{"2159", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{"340", "+", 
        FractionBox[
         RowBox[{"1339", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["106909", "10"]}], "+", 
          FractionBox[
           RowBox[{"37617", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["130493933", "10"]}], "-", 
           FractionBox[
            RowBox[{"22490208", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["118527", "10"], "-", 
          FractionBox[
           RowBox[{"81342", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["130493933", "10"]}], "-", 
           FractionBox[
            RowBox[{"22490208", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1991", "10"]}], "+", 
        FractionBox[
         RowBox[{"2803", " ", "\[ImaginaryI]"}], "2"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["10407", "10"], "+", 
        FractionBox[
         RowBox[{"5649", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["62667", "25"]}], "+", 
          FractionBox[
           RowBox[{"441391", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["6105717", "5"]}], "+", 
           FractionBox[
            RowBox[{"837407", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["41627", "25"], "-", 
          FractionBox[
           RowBox[{"539711", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["6105717", "5"]}], "+", 
           FractionBox[
            RowBox[{"837407", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["7959", "10"], "+", 
        FractionBox[
         RowBox[{"621", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["11857", "10"], "+", 
        FractionBox[
         RowBox[{"11389", " ", "\[ImaginaryI]"}], "10"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["391397", "100"], "-", 
          FractionBox[
           RowBox[{"93611", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"46652379", "-", 
           RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["589557", "100"]}], "-", 
          FractionBox[
           RowBox[{"26489", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"46652379", "-", 
           RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4179", "10"]}], "+", 
        FractionBox[
         RowBox[{"8368", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["6569", "10"]}], "-", 
        RowBox[{"253", " ", "\[ImaginaryI]"}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["74341", "25"], "+", 
          FractionBox[
           RowBox[{"144029", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"126323851", "-", 
           RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["47471", "25"]}], "-", 
          FractionBox[
           RowBox[{"215059", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"126323851", "-", 
           RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["508", "5"]}], "-", 
        FractionBox[
         RowBox[{"2119", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["7782", "5"]}], "+", 
        FractionBox[
         RowBox[{"5722", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["1472667", "100"], "-", 
          FractionBox[
           RowBox[{"213351", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"22120483", "+", 
           RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1306867", "100"]}], "+", 
          FractionBox[
           RowBox[{"198939", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         SqrtBox[
          RowBox[{"22120483", "+", 
           RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1685", "2"]}], "-", 
        FractionBox[
         RowBox[{"6933", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["193", "10"], "+", 
        FractionBox[
         RowBox[{"1349", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["145841", "100"], "-", 
          FractionBox[
           RowBox[{"1002051", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"8578619", "+", 
           RowBox[{"10033432", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["63521", "100"]}], "+", 
          FractionBox[
           RowBox[{"1113731", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "254"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{"8578619", "+", 
           RowBox[{"10033432", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}], ",", 
    
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "\[Rule]", 
       RowBox[{"-", "4"}]}], ",", 
      RowBox[{"t", "\[Rule]", 
       RowBox[{
        FractionBox["102", "5"], "+", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{"u", "\[Rule]", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["82", "5"]}], "-", 
        FractionBox[
         RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "1"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2547", "10"], "+", 
        FractionBox[
         RowBox[{"5316", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "2"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        FractionBox["2205", "2"], "+", 
        FractionBox[
         RowBox[{"2194", " ", "\[ImaginaryI]"}], "5"]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "3"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["383907", "50"]}], "+", 
          FractionBox[
           RowBox[{"105556", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["3421801", "2"]}], "+", 
           FractionBox[
            RowBox[{"80005083", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
      RowBox[{
       RowBox[{
        FormBox["q",
         TraditionalForm], "\[CenterDot]", 
        FormBox[
         SubscriptBox["k", "4"],
         TraditionalForm]}], "\[Rule]", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["316047", "50"], "-", 
          FractionBox[
           RowBox[{"143106", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
        RowBox[{
         FractionBox["1", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["3421801", "2"]}], "+", 
           FractionBox[
            RowBox[{"80005083", " ", "\[ImaginaryI]"}], "5"]}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "1270"}], "-", 
           RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.619251667731608*^9, 3.6192530358732567`*^9, 
  3.619253808214054*^9, 3.619259226480626*^9, 3.619259694413026*^9, 
  3.619343630253477*^9, 3.619411889898546*^9, 3.619412718158453*^9, 
  3.6194144269751167`*^9, 3.619415318677949*^9, 3.6194190445058327`*^9, 
  3.6194221771857853`*^9, 3.619426663340382*^9, 3.619427144748865*^9, 
  3.619427641059599*^9}]
}, Open  ]],

Cell["Now choose random polarizations:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}, {3.619235593173221*^9, 3.619235598976385*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi1", "=", 
   RowBox[{"{", 
    RowBox[{"xix1", ",", "xix2", ",", "xix3", ",", "xix4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043270708568*^9, 3.6040432967635603`*^9}, 
   3.604043499802985*^9, 3.604301554870967*^9, {3.6043021515175753`*^9, 
   3.604302152636281*^9}, {3.612166399986412*^9, 3.612166401456052*^9}, {
   3.615717383769212*^9, 3.61571738455131*^9}, 3.619235607803103*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi2", "=", 
   RowBox[{"{", 
    RowBox[{"xiy1", ",", "xiy2", ",", "xiy3", ",", "xiy4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.6040433084930897`*^9, 
   3.6040433346916733`*^9}, 3.604043502795218*^9, {3.612166409439506*^9, 
   3.612166414318565*^9}, 3.619235609169167*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi3", "=", 
   RowBox[{"{", 
    RowBox[{"xiz1", ",", "xiz2", ",", "xiz3", ",", "xiz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043312238144*^9, 
   3.6040433496909523`*^9}, 3.60404350564257*^9, {3.612166418225318*^9, 
   3.6121664207438507`*^9}, 3.61923561085168*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"xi4", "=", 
   RowBox[{"{", 
    RowBox[{"xiu1", ",", "xiu2", ",", "xiu3", ",", "xiu4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.6040433145245943`*^9, 
   3.604043314748054*^9}, {3.6040433534274893`*^9, 3.604043369394578*^9}, 
   3.60404350847479*^9, {3.61216642588039*^9, 3.612166429007922*^9}, 
   3.6192356125390587`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et1", "=", 
   RowBox[{"{", 
    RowBox[{"etx1", ",", "etx2", ",", "etx3", ",", "etx4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043025672207*^9, 3.604043045505906*^9}, {
   3.604043076331349*^9, 3.604043086542512*^9}, {3.6040431956128817`*^9, 
   3.604043199883696*^9}, {3.6040433875103607`*^9, 3.604043405643474*^9}, 
   3.604043511306425*^9, 3.604301558638516*^9, {3.604302156974309*^9, 
   3.604302158069281*^9}, {3.612166432744034*^9, 3.6121664410321913`*^9}, 
   3.619235615211533*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et2", "=", 
   RowBox[{"{", 
    RowBox[{"ety1", ",", "ety2", ",", "ety3", ",", "ety4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043091446137*^9, 3.604043146101923*^9}, {
   3.604043203285386*^9, 3.604043208859435*^9}, {3.604043389260811*^9, 
   3.6040434154828787`*^9}, 3.6040435138414288`*^9, {3.61216644492061*^9, 
   3.612166446303801*^9}, 3.6192356168433237`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et3", "=", 
   RowBox[{"{", 
    RowBox[{"etz1", ",", "etz2", ",", "etz3", ",", "etz4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043130732497*^9, 3.604043166324193*^9}, {
   3.604043221781107*^9, 3.604043226579508*^9}, {3.604043390773636*^9, 
   3.6040434271162777`*^9}, 3.604043516609764*^9, {3.612166449248323*^9, 
   3.6121664509560738`*^9}, 3.619235618371313*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"et4", "=", 
   RowBox[{"{", 
    RowBox[{"etu1", ",", "etu2", ",", "etu3", ",", "etu4"}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.604043169578208*^9, 3.604043192436401*^9}, {
   3.60404322967647*^9, 3.604043235644086*^9}, {3.604043392149412*^9, 
   3.604043392255167*^9}, {3.6040434286448727`*^9, 3.604043435995811*^9}, 
   3.604043520033565*^9, {3.612166453399662*^9, 3.6121664555841017`*^9}, 
   3.6192356200145407`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"conditions", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "xi1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k1", ",", "et1"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "xi2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k2", ",", "et2"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "xi3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k3", ",", "et3"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "xi4"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"min", "[", 
         RowBox[{"k4", ",", "et4"}], "]"}], "\[Equal]", "0"}]}], "}"}], "/.", 
     
     RowBox[{"sols", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
  RowBox[{"conditions", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.61216653422339*^9, 3.612166556960194*^9}, {
   3.612166600729034*^9, 3.6121666133164167`*^9}, {3.612258455793024*^9, 
   3.612258468175284*^9}, 3.6192356384135313`*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[LongEqual]", "xix2"}]},
      {
       RowBox[{"etx1", "\[LongEqual]", "etx2"}]},
      {
       RowBox[{
        RowBox[{"xiy1", "+", "xiy2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"ety1", "+", "ety2"}], "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"10", " ", "xiz1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"92", "+", 
            RowBox[{"12", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiz2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"67", "+", 
            RowBox[{"3", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiz3"}], "+", 
         
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{"-", "12700"}], "-", 
            RowBox[{"2610", " ", "\[ImaginaryI]"}]}]], " ", "xiz4"}]}], 
        "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"10", " ", "etz1"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"92", "+", 
            RowBox[{"12", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etz2"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"67", "+", 
            RowBox[{"3", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etz3"}], "+", 
         
         RowBox[{
          SqrtBox[
           RowBox[{
            RowBox[{"-", "12700"}], "-", 
            RowBox[{"2610", " ", "\[ImaginaryI]"}]}]], " ", "etz4"}]}], 
        "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{"xiu1", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "10"], "-", 
            FractionBox["\[ImaginaryI]", "10"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"40", "+", 
               RowBox[{"52", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiu2"}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"32", "+", 
               RowBox[{"35", " ", "\[ImaginaryI]"}]}], ")"}], " ", "xiu3"}]}],
            ")"}]}]}], "\[LongEqual]", 
        RowBox[{
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", 
         "xiu4"}]}]},
      {
       RowBox[{
        RowBox[{"etu1", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "10"], "-", 
            FractionBox["\[ImaginaryI]", "10"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"40", "+", 
               RowBox[{"52", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etu2"}], 
            "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"32", "+", 
               RowBox[{"35", " ", "\[ImaginaryI]"}]}], ")"}], " ", "etu3"}]}],
            ")"}]}]}], "\[LongEqual]", 
        RowBox[{
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]], " ", "etu4"}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.612166557730864*^9, 3.612166613587278*^9, 3.612257786626362*^9, {
   3.612258449865247*^9, 3.6122584694730263`*^9}, 3.612684401222273*^9, 
   3.6144153037766237`*^9, 3.614416733198262*^9, 3.614506942881184*^9, 
   3.6145770516151667`*^9, 3.614578403574582*^9, 3.6149384370663424`*^9, 
   3.615634998183165*^9, 3.6157168339297047`*^9, 3.61571741922215*^9, 
   3.6157966523647614`*^9, 3.6162158522704887`*^9, 3.6173373519442377`*^9, 
   3.6173395085025463`*^9, 3.618218625975627*^9, 3.619235639546756*^9, 
   3.619242887012747*^9, 3.6192436415076227`*^9, 3.6192530487462673`*^9, 
   3.619343630583494*^9, 3.6194119064607563`*^9, 3.6194127182382793`*^9, 
   3.619414427181924*^9, 3.6194153188634443`*^9, 3.619419046651602*^9, 
   3.619422177818959*^9, 3.619426679410864*^9, 3.619427144859129*^9, 
   3.619427651730568*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "=", 
   RowBox[{
    RowBox[{"FindInstance", "[", 
     RowBox[{"conditions", ",", 
      RowBox[{"Join", "[", 
       RowBox[{
       "xi1", ",", "xi2", ",", "xi3", ",", "xi4", ",", "et1", ",", "et2", ",",
         "et3", ",", "et4"}], "]"}], ",", "2"}], "]"}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6040434539319687`*^9, 3.604043456064081*^9}, {
   3.6040435241208487`*^9, 3.604043608882557*^9}, {3.604043726069791*^9, 
   3.604043812230796*^9}, 3.6040438598300467`*^9, {3.604043935569573*^9, 
   3.604043942363667*^9}, {3.604044470558268*^9, 3.604044522614917*^9}, {
   3.604044556881448*^9, 3.604044589458551*^9}, 3.604051449215879*^9, {
   3.6042995327036743`*^9, 3.6042996240238*^9}, {3.6043010032399693`*^9, 
   3.604301016524191*^9}, 3.604301051457429*^9, {3.60430124604068*^9, 
   3.604301246210772*^9}, {3.604302167607551*^9, 3.6043022327017097`*^9}, {
   3.604302604494876*^9, 3.604302610488236*^9}, 3.6043983397745447`*^9, {
   3.612166575888966*^9, 3.612166576370742*^9}, {3.6121666241502*^9, 
   3.612166629642056*^9}, 3.6122577970426483`*^9, {3.6122584771168823`*^9, 
   3.612258481721101*^9}, 3.615716743846897*^9, {3.619235681872355*^9, 
   3.619235715558448*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sols$pol", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellChangeTimes->{{3.615716687944995*^9, 3.6157166901908703`*^9}, 
   3.615796959672283*^9}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{"xix1", "\[Rule]", 
        RowBox[{
         FractionBox["19", "5"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{"xix2", "\[Rule]", 
        RowBox[{
         FractionBox["19", "5"], "+", 
         FractionBox["\[ImaginaryI]", "5"]}]}]},
      {
       RowBox[{"xix3", "\[Rule]", 
        RowBox[{
         FractionBox["1", "5"], "-", 
         FractionBox[
          RowBox[{"15", " ", "\[ImaginaryI]"}], "2"]}]}]},
      {
       RowBox[{"xix4", "\[Rule]", 
        RowBox[{"6", "-", 
         FractionBox[
          RowBox[{"31", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiy1", "\[Rule]", 
        RowBox[{
         FractionBox["27", "5"], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiy2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["27", "5"]}], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiy3", "\[Rule]", 
        RowBox[{
         FractionBox["49", "10"], "+", 
         FractionBox[
          RowBox[{"11", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiy4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["49", "10"]}], "+", 
         FractionBox[
          RowBox[{"33", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz1", "\[Rule]", 
        RowBox[{
         FractionBox["3", "10"], "+", 
         FractionBox["\[ImaginaryI]", "2"]}]}]},
      {
       RowBox[{"xiz2", "\[Rule]", 
        RowBox[{
         FractionBox["51", "10"], "+", 
         FractionBox[
          RowBox[{"19", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz3", "\[Rule]", 
        RowBox[{"7", "-", 
         FractionBox[
          RowBox[{"39", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"xiz4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["54949923447", "8405105"]}], "+", 
           FractionBox[
            RowBox[{"11206680146", " ", "\[ImaginaryI]"}], 
            "8405105"]}]]}]}]},
      {
       RowBox[{"xiu1", "\[Rule]", 
        RowBox[{
         FractionBox["11", "5"], "-", 
         FractionBox[
          RowBox[{"43", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu2", "\[Rule]", 
        RowBox[{
         FractionBox["47", "5"], "+", 
         RowBox[{"10", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"xiu3", "\[Rule]", 
        RowBox[{
         FractionBox["13", "2"], "+", 
         FractionBox[
          RowBox[{"16", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"xiu4", "\[Rule]", 
        RowBox[{
         FractionBox["3", "10"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", 
            FractionBox["905806421", "8405105"]}], "-", 
           FractionBox[
            RowBox[{"4533282918", " ", "\[ImaginaryI]"}], "1681021"]}]]}]}]},
      {
       RowBox[{"etx1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["46", "5"]}], "-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["46", "5"]}], "-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etx3", "\[Rule]", 
        RowBox[{
         FractionBox["49", "5"], "-", 
         FractionBox[
          RowBox[{"47", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etx4", "\[Rule]", 
        RowBox[{"5", "+", 
         FractionBox[
          RowBox[{"43", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"ety1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["15", "2"]}], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety2", "\[Rule]", 
        RowBox[{
         FractionBox["15", "2"], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["83", "10"]}], "+", 
         FractionBox[
          RowBox[{"39", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"ety4", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"10", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["13", "5"]}], "-", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{"etz2", "\[Rule]", 
        RowBox[{
         FractionBox["73", "10"], "-", 
         FractionBox[
          RowBox[{"11", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etz3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "10"]}], "+", 
         RowBox[{"5", " ", "\[ImaginaryI]"}]}]}]},
      {
       RowBox[{"etz4", "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["8809259", "16810210"], "+", 
           FractionBox[
            RowBox[{"981147", " ", "\[ImaginaryI]"}], "16810210"]}], ")"}], 
         " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"-", "127"}], "-", 
           FractionBox[
            RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]},
      {
       RowBox[{"etu1", "\[Rule]", 
        RowBox[{
         FractionBox["33", "5"], "+", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"etu2", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["29", "10"]}], "+", 
         FractionBox[
          RowBox[{"26", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu3", "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["11", "5"]}], "+", 
         FractionBox[
          RowBox[{"24", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{"etu4", "\[Rule]", 
        RowBox[{
         FractionBox["1", "5"], " ", 
         SqrtBox[
          RowBox[{
           FractionBox["1338381759", "1681021"], "+", 
           FractionBox[
            RowBox[{"12422679818", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.615716686264927*^9, 3.615716690541438*^9}, 
   3.615716837926202*^9, 3.6157969736709547`*^9, 3.616215854088387*^9, 
   3.617337353622591*^9, 3.617339509744925*^9, 3.6182186276162148`*^9, {
   3.6192356917235203`*^9, 3.619235718040629*^9}, 3.619242890133157*^9, 
   3.619243645459914*^9, 3.6192530517234907`*^9, 3.619343630684009*^9, 
   3.61941191005159*^9, 3.619412718328298*^9, 3.619414427263516*^9, 
   3.619415318955674*^9, 3.619419047458848*^9, 3.619422178175963*^9, 
   3.619426681420582*^9, 3.619427144993878*^9, 3.6194276559408817`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"leg2k", "[", "l_", "]"}], "=", 
  RowBox[{"Switch", "[", 
   RowBox[{
   "l", ",", "1", ",", "k1", ",", "2", ",", "k2", ",", "3", ",", "k3", ",", 
    "4", ",", "k4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619236521062236*^9, 3.6192365496795073`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Switch", "[", 
   RowBox[{
   "l", ",", "\[IndentingNewLine]", "1", ",", "k1", ",", 
    "\[IndentingNewLine]", "2", ",", "k2", ",", "\[IndentingNewLine]", "3", 
    ",", "k3", ",", "\[IndentingNewLine]", "4", ",", "k4"}], "]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6192365504484243`*^9, 3.6192429019015207`*^9, 
  3.619243648336986*^9, 3.61925305403577*^9, 3.619343630733646*^9, 
  3.619411913551228*^9, 3.6194127183671503`*^9, 3.619414427316038*^9, 
  3.619415318982546*^9, 3.619419047660269*^9, 3.619422178254744*^9, 
  3.619426681476091*^9, 3.6194271450433617`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ind2pols", "[", "i_", "]"}], "=", 
  RowBox[{"Switch", "[", 
   RowBox[{
   "i", ",", "a", ",", "xi1", ",", "b", ",", "et1", ",", "c", ",", "xi2", ",",
     "d", ",", "et2", ",", "e", ",", "xi3", ",", "f", ",", "et3", ",", "g", 
    ",", "xi4", ",", "h", ",", "et4"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619236308508829*^9, 3.619236416287768*^9}, {
  3.6192374423377123`*^9, 3.6192374951804256`*^9}, {3.619237584106935*^9, 
  3.619237607040175*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"Switch", "[", 
   RowBox[{
   "i", ",", "\[IndentingNewLine]", "a", ",", "xi1", ",", 
    "\[IndentingNewLine]", "b", ",", "et1", ",", "\[IndentingNewLine]", "c", 
    ",", "xi2", ",", "\[IndentingNewLine]", "d", ",", "et2", ",", 
    "\[IndentingNewLine]", "e", ",", "xi3", ",", "\[IndentingNewLine]", "f", 
    ",", "et3", ",", "\[IndentingNewLine]", "g", ",", "xi4", ",", 
    "\[IndentingNewLine]", "h", ",", "et4"}], "]"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619236347953261*^9, 3.619236359045373*^9}, 
   3.6192364172726183`*^9, 3.619237449695252*^9, 3.619237495854807*^9, 
   3.619237607542542*^9, 3.6192429044198847`*^9, 3.619243650338719*^9, 
   3.6192530555236893`*^9, 3.619343630779799*^9, 3.619411914442868*^9, 
   3.619412718400263*^9, 3.619414427367017*^9, 3.619415319009656*^9, 
   3.6194190478606663`*^9, 3.619422178308936*^9, 3.6194266815148983`*^9, 
   3.619427145100677*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"indices", "=", 
  RowBox[{"{", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
    "h"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619239158604762*^9, 3.619239170171886*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "f", ",", "g", ",", 
    "h"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619239171626947*^9, 3.6192429065479813`*^9, 3.619243651783976*^9, 
   3.6192530569798813`*^9, 3.619343630790625*^9, {3.6194119156498213`*^9, 
   3.619411936843273*^9}, 3.619412718439302*^9, 3.619414427431369*^9, 
   3.619415319031279*^9, 3.619419047962557*^9, 3.619422178358959*^9, 
   3.619426681555867*^9, 3.619427145147183*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"kc", "[", 
            RowBox[{"leg", ",", 
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind", "]"}], "]"}]}], "]"}], "\[Rule]", 
           RowBox[{"min", "[", 
            RowBox[{
             RowBox[{"leg2k", "[", "leg", "]"}], ",", 
             RowBox[{"ind2pols", "[", 
              RowBox[{"indices", "[", 
               RowBox[{"[", "ind", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"leg", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"ind", ",", "1", ",", "8"}], "}"}]}], "]"}], ")"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"rules1", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619239137912868*^9, 3.619239142802182*^9}, {
  3.619239181944091*^9, 3.619239373739903*^9}, {3.6192394261171017`*^9, 
  3.619239427997581*^9}, {3.619239473148394*^9, 3.619239479671443*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["38", "5"]}], "-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["4211", "100"], "-", 
           FractionBox[
            RowBox[{"4359", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "10"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["3451", "100"]}], "+", 
           FractionBox[
            RowBox[{"4399", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"6", "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "10"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["92", "5"], "+", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["2533", "100"]}], "-", 
           FractionBox[
            RowBox[{"5183", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            FractionBox[
             RowBox[{"43", " ", "\[ImaginaryI]"}], "5"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["b",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["693", "100"], "+", 
           FractionBox[
            RowBox[{"4943", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            FractionBox[
             RowBox[{"43", " ", "\[ImaginaryI]"}], "5"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["54", "5"]}], "-", 
         FractionBox[
          RowBox[{"14", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["1043", "100"]}], "-", 
           FractionBox[
            RowBox[{"7", " ", "\[ImaginaryI]"}], "4"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["49", "10"], "-", 
            FractionBox[
             RowBox[{"33", " ", "\[ImaginaryI]"}], "10"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["c",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["2123", "100"], "+", 
           FractionBox[
            RowBox[{"91", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["49", "10"], "-", 
            FractionBox[
             RowBox[{"33", " ", "\[ImaginaryI]"}], "10"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"15", "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["97", "25"], "+", 
           FractionBox[
            RowBox[{"1919", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"10", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["d",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["472", "25"]}], "-", 
           FractionBox[
            RowBox[{"1989", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"10", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "127"}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["24", "5"], "+", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["27", "5"]}], "-", 
         FractionBox[
          RowBox[{"12", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["9301", "100"], "+", 
           FractionBox[
            RowBox[{"7", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          FractionBox["1", "50"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["54949923447", "3362042"]}], "+", 
            FractionBox[
             RowBox[{"5603340073", " ", "\[ImaginaryI]"}], "1681021"]}]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1270"}], "-", 
            RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["e",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["9241", "100"]}], "+", 
           FractionBox[
            RowBox[{"93", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          FractionBox["1", "50"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["54949923447", "3362042"]}], "+", 
            FractionBox[
             RowBox[{"5603340073", " ", "\[ImaginaryI]"}], "1681021"]}]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1270"}], "-", 
            RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["99", "10"], "-", 
         FractionBox[
          RowBox[{"13", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["47", "10"]}], "+", 
         FractionBox[
          RowBox[{"31", " ", "\[ImaginaryI]"}], "10"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["f",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["26", "5"]}], "-", 
         FractionBox[
          RowBox[{"9", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["36", "5"], "+", 
         FractionBox[
          RowBox[{"93", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["58", "5"]}], "-", 
         FractionBox[
          RowBox[{"7", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["11927", "100"], "+", 
           FractionBox[
            RowBox[{"11807", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          FractionBox["3", "50"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1270"}], "-", 
            RowBox[{"261", " ", "\[ImaginaryI]"}]}]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["905806421", "3362042"]}], "-", 
            FractionBox[
             RowBox[{"11333207295", " ", "\[ImaginaryI]"}], 
             "1681021"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["g",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["11487", "100"]}], "-", 
           FractionBox[
            RowBox[{"13527", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          FractionBox["3", "50"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1270"}], "-", 
            RowBox[{"261", " ", "\[ImaginaryI]"}]}]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["905806421", "3362042"]}], "-", 
            FractionBox[
             RowBox[{"11333207295", " ", "\[ImaginaryI]"}], 
             "1681021"]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["19", "2"]}], "+", 
         FractionBox[
          RowBox[{"21", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["37", "10"]}], "-", 
         FractionBox[
          RowBox[{"31", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["85", "2"]}], "+", 
           FractionBox[
            RowBox[{"3843", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          FractionBox["1", "25"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["635", "1681021"]}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "3362042"]}]], " ", 
          SqrtBox[
           RowBox[{"6691908795", "+", 
            RowBox[{"12422679818", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["h",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["557", "10"], "-", 
           FractionBox[
            RowBox[{"3743", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          FractionBox["1", "25"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["635", "1681021"]}], "-", 
            FractionBox[
             RowBox[{"261", " ", "\[ImaginaryI]"}], "3362042"]}]], " ", 
          SqrtBox[
           RowBox[{"6691908795", "+", 
            RowBox[{"12422679818", " ", "\[ImaginaryI]"}]}]]}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.61923921283426*^9, 3.6192392238744507`*^9}, {
   3.619239296819813*^9, 3.6192393414974527`*^9}, 3.619239373991585*^9, 
   3.619239428356347*^9, 3.619239480439577*^9, 3.619242908197208*^9, 
   3.619243653772341*^9, 3.619253058148912*^9, 3.6193436308378563`*^9, 
   3.619412718504106*^9, 3.6194144275242243`*^9, 3.61941531906747*^9, 
   3.6194190481522017`*^9, 3.619422178443902*^9, 3.619426681639402*^9, 
   3.619427145219223*^9, 3.6194276710681458`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k3", ",", "et4"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239396112124*^9, 3.619239462797274*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["85", "2"]}], "+", 
     FractionBox[
      RowBox[{"3843", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
   RowBox[{
    FractionBox["1", "25"], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", 
       FractionBox["635", "1681021"]}], "-", 
      FractionBox[
       RowBox[{"261", " ", "\[ImaginaryI]"}], "3362042"]}]], " ", 
    SqrtBox[
     RowBox[{"6691908795", "+", 
      RowBox[{"12422679818", " ", "\[ImaginaryI]"}]}]]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.6192394091672373`*^9, 3.6192394630970716`*^9}, 
   3.6192429108792257`*^9, 3.619243657538933*^9, 3.61925306056183*^9, 
   3.619343630892432*^9, 3.6194127185438004`*^9, 3.619414427582204*^9, 
   3.619415319087006*^9, 3.619419048276211*^9, 3.619422178516365*^9, 
   3.619426681690929*^9, 3.6194271452790833`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rules2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Pair", "[", 
           RowBox[{
            RowBox[{"LorentzIndex", "[", 
             RowBox[{
              RowBox[{"indices", "[", 
               RowBox[{"[", "ind", "]"}], "]"}], ",", "D"}], "]"}], ",", 
            RowBox[{"Momentum", "[", 
             RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", " ", 
          RowBox[{"min", "[", 
           RowBox[{"qq", ",", 
            RowBox[{"ind2pols", "[", 
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ind", ",", "1", ",", "8"}], "}"}]}], "]"}], ")"}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"sols", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"sols$pol", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"solsQ", "[", 
         RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"rules2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619239498168215*^9, 3.61923950278657*^9}, {
  3.619239533212517*^9, 3.619239653462655*^9}, {3.619246060578376*^9, 
  3.619246065085746*^9}, {3.6192460967103662`*^9, 3.619246105142829*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          TagBox[
           RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
           Function[BoxForm`e$, 
            TableForm[BoxForm`e$]]],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 1335, 23719710895012768101, 
            5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 1335, 23719710895012768101, 
            5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
            Function[{OutputSizeLimit`Dump`x$}, 
             TableForm[OutputSizeLimit`Dump`x$]], 1335, 23719710895012768101, 
            Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[1335]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619239655223105*^9, 3.619242912013666*^9, 
  3.619243658775285*^9, 3.619246111099959*^9, 3.619246943666779*^9, 
  3.619247189962232*^9, 3.619247409699597*^9, 3.61925020872122*^9, 
  3.6192530627606363`*^9, 3.619253819672687*^9, 3.619259231805781*^9, 
  3.619259714922319*^9, 3.6192597910059633`*^9, 3.6193436333112383`*^9, 
  3.619412547566163*^9, 3.619412718821464*^9, 3.6194144304394007`*^9, 
  3.6194153240745573`*^9, 3.619419051850832*^9, 3.619422181693461*^9, 
  3.61942668452691*^9, 3.619427146375589*^9, 3.619427677740616*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"qq", ",", "et2"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"solsQ", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239664221813*^9, 3.6192396792379*^9}, {
  3.619253086407671*^9, 3.6192530905073223`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox["504731", "100"], "+", 
     FractionBox[
      RowBox[{"891931", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["3", "10"], "-", "\[ImaginaryI]"}], ")"}], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"-", "39248715"}], "-", 
      RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619239666472765*^9, 3.619239679962988*^9}, 
   3.619242914306307*^9, 3.6192436608671427`*^9, {3.619253066756884*^9, 
   3.619253090890196*^9}, 3.6192592368026037`*^9, 3.6193436335131197`*^9, 
   3.6194127188890676`*^9, 3.619414430523732*^9, 3.619415324149371*^9, 
   3.619419052005918*^9, 3.61942218183997*^9, 3.619426684592381*^9, 
   3.6194271464421387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rules3", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Pair", "[", 
          RowBox[{
           RowBox[{"LorentzIndex", "[", 
            RowBox[{
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind1", "]"}], "]"}], ",", "D"}], "]"}], ",", 
           RowBox[{"LorentzIndex", "[", 
            RowBox[{
             RowBox[{"indices", "[", 
              RowBox[{"[", "ind2", "]"}], "]"}], ",", "D"}], "]"}]}], "]"}], 
         "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"ind2pols", "[", 
            RowBox[{"indices", "[", 
             RowBox[{"[", "ind1", "]"}], "]"}], "]"}], ",", 
           RowBox[{"ind2pols", "[", 
            RowBox[{"indices", "[", 
             RowBox[{"[", "ind2", "]"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"ind2", ",", 
          RowBox[{"ind1", "+", "1"}], ",", "8"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"ind1", ",", "1", ",", "8"}], "}"}]}], "]"}], "/.", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"sols", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"sols$pol", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619239941847797*^9, 3.6192399886826353`*^9}, 
   3.619240025873451*^9, {3.61924005782653*^9, 3.6192400996716957`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "b"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2337", "100"], "-", 
      FractionBox[
       RowBox[{"1917", " ", "\[ImaginaryI]"}], "50"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["4217", "100"]}], "-", 
      FractionBox[
       RowBox[{"353", " ", "\[ImaginaryI]"}], "25"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "d"}]], "\[Rule]", 
     RowBox[{
      FractionBox["9731", "100"], "+", 
      FractionBox[
       RowBox[{"2813", " ", "\[ImaginaryI]"}], "20"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["989", "100"]}], "-", 
        RowBox[{"47", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["3", "5"], "-", 
         FractionBox[
          RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["54949923447", "8405105"]}], "+", 
         FractionBox[
          RowBox[{"11206680146", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1884", "25"], "-", 
        FractionBox[
         RowBox[{"121", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["558971097", "168102100"], "-", 
         FractionBox[
          RowBox[{"214218209", " ", "\[ImaginaryI]"}], "168102100"]}], ")"}], 
       " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "127"}], "-", 
         FractionBox[
          RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["2447", "50"], "+", 
        FractionBox[
         RowBox[{"2401", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["9", "5"], "-", 
         FractionBox[
          RowBox[{"93", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["905806421", "8405105"]}], "-", 
         FractionBox[
          RowBox[{"4533282918", " ", "\[ImaginaryI]"}], "1681021"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["69", "50"]}], "+", 
        FractionBox[
         RowBox[{"788", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["6", "5"], "-", 
         FractionBox[
          RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         FractionBox["1338381759", "1681021"], "+", 
         FractionBox[
          RowBox[{"12422679818", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "c"}]], "\[Rule]", 
     RowBox[{
      FractionBox["2537", "25"], "+", 
      FractionBox[
       RowBox[{"1161", " ", "\[ImaginaryI]"}], "100"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "d"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["30033", "100"]}], "+", 
      FractionBox[
       RowBox[{"1411", " ", "\[ImaginaryI]"}], "20"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["779", "100"], "-", 
        FractionBox[
         RowBox[{"2244", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox[
          RowBox[{"43", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["54949923447", "8405105"]}], "+", 
         FractionBox[
          RowBox[{"11206680146", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1753", "25"]}], "+", 
        FractionBox[
         RowBox[{"991", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["89021077", "42025525"], "+", 
         FractionBox[
          RowBox[{"201663406", " ", "\[ImaginaryI]"}], "42025525"]}], ")"}], 
       " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "127"}], "-", 
         FractionBox[
          RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1741", "50"], "-", 
        FractionBox[
         RowBox[{"3579", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["3", "2"], "+", 
         FractionBox[
          RowBox[{"129", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["905806421", "8405105"]}], "-", 
         FractionBox[
          RowBox[{"4533282918", " ", "\[ImaginaryI]"}], "1681021"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"b", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["2336", "25"], "+", 
        FractionBox[
         RowBox[{"1507", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"43", " ", "\[ImaginaryI]"}], "25"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         FractionBox["1338381759", "1681021"], "+", 
         FractionBox[
          RowBox[{"12422679818", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "d"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1351", "20"]}], "-", 
      FractionBox[
       RowBox[{"1161", " ", "\[ImaginaryI]"}], "20"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["427", "25"], "-", 
        FractionBox[
         RowBox[{"2423", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["49", "100"], "-", 
         FractionBox[
          RowBox[{"33", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["54949923447", "8405105"]}], "+", 
         FractionBox[
          RowBox[{"11206680146", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["4121", "100"]}], "+", 
        FractionBox[
         RowBox[{"861", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["232015771", "84051050"], "-", 
         FractionBox[
          RowBox[{"60657336", " ", "\[ImaginaryI]"}], "42025525"]}], ")"}], 
       " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "127"}], "-", 
         FractionBox[
          RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3587", "100"]}], "+", 
        FractionBox[
         RowBox[{"309", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["147", "100"], "-", 
         FractionBox[
          RowBox[{"99", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["905806421", "8405105"]}], "-", 
         FractionBox[
          RowBox[{"4533282918", " ", "\[ImaginaryI]"}], "1681021"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"c", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["816", "25"]}], "-", 
        FractionBox[
         RowBox[{"999", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["49", "50"], "-", 
         FractionBox[
          RowBox[{"33", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         FractionBox["1338381759", "1681021"], "+", 
         FractionBox[
          RowBox[{"12422679818", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "e"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["407", "100"]}], "+", 
        FractionBox[
         RowBox[{"1629", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["3", "10"], "-", "\[ImaginaryI]"}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["54949923447", "8405105"]}], "+", 
         FractionBox[
          RowBox[{"11206680146", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["75", "4"], "-", 
        FractionBox[
         RowBox[{"1237", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["36239247", "16810210"], "-", 
         FractionBox[
          RowBox[{"85149149", " ", "\[ImaginaryI]"}], "16810210"]}], ")"}], 
       " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "127"}], "-", 
         FractionBox[
          RowBox[{"261", " ", "\[ImaginaryI]"}], "10"]}]]}]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1959", "100"], "+", 
        FractionBox[
         RowBox[{"1741", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["9", "10"], "-", 
         RowBox[{"3", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["905806421", "8405105"]}], "-", 
         FractionBox[
          RowBox[{"4533282918", " ", "\[ImaginaryI]"}], "1681021"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"d", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["459", "20"], "+", 
        FractionBox[
         RowBox[{"67", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["3", "5"], "-", 
         RowBox[{"2", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{
         FractionBox["1338381759", "1681021"], "+", 
         FractionBox[
          RowBox[{"12422679818", " ", "\[ImaginaryI]"}], "8405105"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "f"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["3027", "50"], "+", 
        FractionBox[
         RowBox[{"3961", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["8809259", "840510500"], "+", 
         FractionBox[
          RowBox[{"981147", " ", "\[ImaginaryI]"}], "840510500"]}], ")"}], 
       " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["54949923447", "3362042"]}], "+", 
         FractionBox[
          RowBox[{"5603340073", " ", "\[ImaginaryI]"}], "1681021"]}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "1270"}], "-", 
         RowBox[{"261", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["2049", "25"], "+", 
        FractionBox[
         RowBox[{"6739", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "54949923447"}], "+", 
          RowBox[{"11206680146", " ", "\[ImaginaryI]"}]}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "905806421"}], "-", 
          RowBox[{"22666414590", " ", "\[ImaginaryI]"}]}]]}], 
       "840510500"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"e", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["2283", "100"]}], "+", 
        FractionBox[
         RowBox[{"5959", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
      FractionBox[
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"-", "54949923447"}], "+", 
          RowBox[{"11206680146", " ", "\[ImaginaryI]"}]}]], " ", 
        SqrtBox[
         RowBox[{"6691908795", "+", 
          RowBox[{"12422679818", " ", "\[ImaginaryI]"}]}]]}], 
       "420255250"]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"f", "g"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["8743", "100"], "+", 
        FractionBox[
         RowBox[{"1603", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["26427777", "840510500"], "+", 
         FractionBox[
          RowBox[{"2943441", " ", "\[ImaginaryI]"}], "840510500"]}], ")"}], 
       " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "1270"}], "-", 
         RowBox[{"261", " ", "\[ImaginaryI]"}]}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["905806421", "3362042"]}], "-", 
         FractionBox[
          RowBox[{"11333207295", " ", "\[ImaginaryI]"}], "1681021"]}]]}]}]}], 
    ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"f", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["69", "4"]}], "+", 
        FractionBox[
         RowBox[{"207", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["8809259", "420255250"], "+", 
         FractionBox[
          RowBox[{"981147", " ", "\[ImaginaryI]"}], "420255250"]}], ")"}], 
       " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", 
          FractionBox["635", "1681021"]}], "-", 
         FractionBox[
          RowBox[{"261", " ", "\[ImaginaryI]"}], "3362042"]}]], " ", 
       SqrtBox[
        RowBox[{"6691908795", "+", 
         RowBox[{"12422679818", " ", "\[ImaginaryI]"}]}]]}]}]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"g", "h"}]], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["3301", "25"]}], "+", 
        FractionBox[
         RowBox[{"493", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "905806421"}], "-", 
          RowBox[{"22666414590", " ", "\[ImaginaryI]"}]}]], " ", 
        SqrtBox[
         RowBox[{"6691908795", "+", 
          RowBox[{"12422679818", " ", "\[ImaginaryI]"}]}]]}], 
       "420255250"]}]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.61924010032931*^9, 3.619242915317422*^9, 
  3.619243662861741*^9, 3.619247195513521*^9, 3.61925310552606*^9, 
  3.619343633581479*^9, 3.6194127189564962`*^9, 3.619414430602275*^9, 
  3.619415324225881*^9, 3.619419052085876*^9, 3.6194221819369383`*^9, 
  3.619426684666573*^9, 3.619427146519331*^9, 3.6194276795478697`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"xi1", ",", "et2"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.61924014756181*^9, 3.619240162565056*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["9731", "100"], "+", 
   FractionBox[
    RowBox[{"2813", " ", "\[ImaginaryI]"}], "20"]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.619240158523693*^9, 3.619240163202877*^9}, 
   3.61924291753172*^9, 3.61924366653813*^9, 3.619253108251897*^9, 
   3.61934363362945*^9, 3.619412718995681*^9, 3.619414430667799*^9, 
   3.6194153242803783`*^9, 3.619419052229499*^9, 3.619422181990479*^9, 
   3.6194266847315893`*^9, 3.619427146569887*^9}]
}, Open  ]],

Cell[TextData[{
 "Before choosing polarizations we contract the index a into ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 "in order to check the Ward identity."
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}, {3.619235593173221*^9, 3.619235598976385*^9}, {
   3.619411957188622*^9, 3.619412060723302*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesward1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"kc", "[", 
          RowBox[{"leg", ",", "a"}], "]"}], "\[Rule]", 
         RowBox[{"min", "[", 
          RowBox[{
           RowBox[{"leg2k", "[", "leg", "]"}], ",", 
           RowBox[{"leg2k", "[", "1", "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"leg", ",", "1", ",", "4"}], "}"}]}], "]"}], ")"}], "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"sols", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"sols$pol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}]}], ";", 
  RowBox[{"rulesward1", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619412156842771*^9, 3.619412191524993*^9}, {
  3.619412224880752*^9, 3.619412263898706*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["1",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", "0"}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["2",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{"-", "2"}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["3",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         FractionBox["51", "5"], "+", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]},
      {
       RowBox[{
        SubsuperscriptBox["k", 
         FormBox["4",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["41", "5"]}], "-", 
         FractionBox[
          RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619412196401766*^9, 3.6194122656343946`*^9}, 
   3.619412719030764*^9, 3.6194144307165117`*^9, 3.619415324329966*^9, 
   3.619419052290638*^9, 3.619422182062059*^9, 3.6194266847873783`*^9, 
   3.619427146619549*^9, 3.619427687152474*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"min", "[", 
   RowBox[{"k1", ",", "k4"}], "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"sols$pol", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619412278062975*^9, 3.619412296012594*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["41", "5"]}], "-", 
   FractionBox[
    RowBox[{"6", " ", "\[ImaginaryI]"}], "5"]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6194122847719707`*^9, 3.619412296204054*^9}, 
   3.619412719069291*^9, 3.6194144307238827`*^9, 3.6194153243830233`*^9, 
   3.619419052322007*^9, 3.619422182101104*^9, 3.61942668482819*^9, 
   3.61942714667045*^9, 3.619427689471167*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesward2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Pair", "[", 
         RowBox[{
          RowBox[{"LorentzIndex", "[", 
           RowBox[{"a", ",", "D"}], "]"}], ",", 
          RowBox[{"Momentum", "[", 
           RowBox[{"q", ",", "D"}], "]"}]}], "]"}], "\[Rule]", " ", 
        RowBox[{"min", "[", 
         RowBox[{"qq", ",", 
          RowBox[{"ind2pols", "[", "a", "]"}]}], "]"}]}], ")"}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"sols", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"sols$pol", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"solsQ", "[", 
         RowBox[{"[", "iq", "]"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}], ";", 
  RowBox[{"rulesward2", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619412453834653*^9, 3.619412593462965*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["104741", "20"]}], "+", 
           FractionBox[
            RowBox[{"215231", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "39248715"}], "-", 
            RowBox[{"143365876", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["186313", "20"], "+", 
           FractionBox[
            RowBox[{"623947", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "53860771"}], "-", 
            RowBox[{"117222224", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["117183", "25"]}], "-", 
           FractionBox[
            RowBox[{"368233", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"2556694", "-", 
            FractionBox[
             RowBox[{"62817937", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["261559", "100"]}], "+", 
           FractionBox[
            RowBox[{"340837", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["42848963", "2"]}], "-", 
            FractionBox[
             RowBox[{"24816389", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["90428", "25"], "+", 
           FractionBox[
            RowBox[{"611451", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"25707729", "+", 
            RowBox[{"122667496", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["358437", "100"]}], "+", 
           FractionBox[
            RowBox[{"1236873", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "659273"}], "+", 
            RowBox[{"54378224", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["262241", "50"]}], "+", 
           FractionBox[
            RowBox[{"86541", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"94240593", "+", 
            RowBox[{"110752716", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["53778", "25"], "-", 
           FractionBox[
            RowBox[{"85188", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"3857491", "-", 
            RowBox[{"135864060", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["11178", "25"], "-", 
           FractionBox[
            RowBox[{"947347", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "63826433"}], "-", 
            RowBox[{"50919660", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["868813", "100"]}], "-", 
           FractionBox[
            RowBox[{"411733", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["65436529", "2"], "+", 
            FractionBox[
             RowBox[{"78545351", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["129516", "25"]}], "+", 
           FractionBox[
            RowBox[{"903", " ", "\[ImaginaryI]"}], "10"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "9953283"}], "-", 
            FractionBox[
             RowBox[{"41395173", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["289899", "100"], "-", 
           FractionBox[
            RowBox[{"7817", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "80631363"}], "-", 
            RowBox[{"122217310", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["2661", "10"], "-", 
           FractionBox[
            RowBox[{"274181", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "45131215"}], "+", 
            RowBox[{"183702246", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["185261", "50"], "-", 
           FractionBox[
            RowBox[{"751953", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["1339619", "2"]}], "-", 
            RowBox[{"37646268", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["446561", "100"]}], "-", 
           FractionBox[
            RowBox[{"619239", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["53713307", "2"]}], "+", 
            FractionBox[
             RowBox[{"75737837", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["165791", "50"]}], "-", 
           FractionBox[
            RowBox[{"413329", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "1480995"}], "+", 
            RowBox[{"13716098", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["553111", "100"], "-", 
           FractionBox[
            RowBox[{"420177", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "132663833"}], "-", 
            RowBox[{"27289664", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["74626", "25"]}], "-", 
           FractionBox[
            RowBox[{"344367", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "20"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["13794847", "5"], "+", 
            FractionBox[
             RowBox[{"35102304", " ", "\[ImaginaryI]"}], "5"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["115759", "100"], "+", 
           FractionBox[
            RowBox[{"254539", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "5698344"}], "-", 
            FractionBox[
             RowBox[{"16992563", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["18174", "5"], "-", 
           FractionBox[
            RowBox[{"142057", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"72901243", "+", 
            RowBox[{"82655700", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["162911", "20"], "-", 
           FractionBox[
            RowBox[{"35883", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"66974411", "+", 
            RowBox[{"112385352", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["4852", "25"]}], "-", 
           FractionBox[
            RowBox[{"192061", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "35886557"}], "+", 
            RowBox[{"123161326", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["838", "5"], "+", 
           FractionBox[
            RowBox[{"460383", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"97931047", "-", 
            RowBox[{"28091496", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["322797", "100"]}], "+", 
           FractionBox[
            RowBox[{"24799", " ", "\[ImaginaryI]"}], "5"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "61854981"}], "+", 
            RowBox[{"13100900", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["231691", "50"]}], "-", 
           FractionBox[
            RowBox[{"577513", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"15330032", "-", 
            FractionBox[
             RowBox[{"117013109", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["75041", "20"]}], "+", 
           FractionBox[
            RowBox[{"176459", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["5359215", "2"]}], "+", 
            RowBox[{"44541539", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["161459", "50"], "+", 
           RowBox[{"2160", " ", "\[ImaginaryI]"}]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["80858931", "2"], "-", 
            RowBox[{"9394224", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["141027", "50"]}], "-", 
           FractionBox[
            RowBox[{"841869", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["47348499", "2"]}], "+", 
            FractionBox[
             RowBox[{"55778667", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["321461", "100"]}], "-", 
           FractionBox[
            RowBox[{"690039", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["14127815", "2"]}], "-", 
            FractionBox[
             RowBox[{"38499453", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["132971", "50"]}], "-", 
           FractionBox[
            RowBox[{"24553", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "8692743"}], "+", 
            FractionBox[
             RowBox[{"29528399", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["123856", "25"], "-", 
           FractionBox[
            RowBox[{"111359", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["7602011", "2"]}], "-", 
            RowBox[{"46151976", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["209633", "50"]}], "-", 
           FractionBox[
            RowBox[{"1923", " ", "\[ImaginaryI]"}], "4"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "132365619"}], "+", 
            RowBox[{"97171760", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["87627", "20"]}], "+", 
           FractionBox[
            RowBox[{"429003", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"116782515", "+", 
            RowBox[{"159520184", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["408343", "100"]}], "+", 
           FractionBox[
            RowBox[{"662551", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "130493933"}], "-", 
            RowBox[{"44980416", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["638103", "100"], "+", 
           FractionBox[
            RowBox[{"54293", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["12", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "25"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", 
             FractionBox["6105717", "2"]}], "+", 
            FractionBox[
             RowBox[{"837407", " ", "\[ImaginaryI]"}], "2"]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["831601", "100"], "-", 
           FractionBox[
            RowBox[{"161797", " ", "\[ImaginaryI]"}], "25"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"46652379", "-", 
            RowBox[{"29418100", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["80297", "10"]}], "+", 
           FractionBox[
            RowBox[{"179873", " ", "\[ImaginaryI]"}], "50"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"126323851", "-", 
            RowBox[{"44178586", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["121612", "25"]}], "-", 
           FractionBox[
            RowBox[{"855753", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"22120483", "+", 
            RowBox[{"169048812", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            FractionBox["286863", "50"]}], "-", 
           FractionBox[
            RowBox[{"197629", " ", "\[ImaginaryI]"}], "20"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["6", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "50"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            FractionBox["8578619", "2"], "+", 
            RowBox[{"5016716", " ", "\[ImaginaryI]"}]}]]}]}]}]},
      {
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["a",
           TraditionalForm],
          TraditionalForm]], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["372927", "100"], "+", 
           FractionBox[
            RowBox[{"708623", " ", "\[ImaginaryI]"}], "100"]}], ")"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["3", "5"], "-", 
            FractionBox[
             RowBox[{"31", " ", "\[ImaginaryI]"}], "100"]}], ")"}], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"-", "17109005"}], "+", 
            RowBox[{"160010166", " ", "\[ImaginaryI]"}]}]]}]}]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619412496418803*^9, 3.61941255225438*^9, {3.6194125834607363`*^9, 
   3.6194125943428373`*^9}, 3.619412719110879*^9, 3.619414431064124*^9, 
   3.61941532503345*^9, 3.619419053613039*^9, 3.619422182656433*^9, 
   3.619426685163241*^9, 3.619427146806666*^9, 3.619427690542609*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rulesward3", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"dc", "[", 
      RowBox[{"a", ",", 
       RowBox[{"indices", "[", 
        RowBox[{"[", "ind", "]"}], "]"}]}], "]"}], "\[Rule]", 
     RowBox[{"kc", "[", 
      RowBox[{"1", ",", 
       RowBox[{"indices", "[", 
        RowBox[{"[", "ind", "]"}], "]"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"ind", ",", "2", ",", "8"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619412313576882*^9, 3.619412402678738*^9}, 
   3.6194124360974817`*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "b"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["b",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "c"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["c",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "d"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["d",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "e"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["e",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "f"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["f",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "g"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["g",
        TraditionalForm],
       TraditionalForm]]}], ",", 
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"a", "h"}]], "\[Rule]", 
     SubsuperscriptBox["k", 
      FormBox["1",
       TraditionalForm], 
      FormBox[
       FormBox["h",
        TraditionalForm],
       TraditionalForm]]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619412403806982*^9, 3.6194124466630287`*^9, 
  3.619412719167528*^9, 3.6194144311622543`*^9, 3.619415325227663*^9, 
  3.619419053864347*^9, 3.619422182830111*^9, 3.619426685245184*^9, 
  3.61942714685709*^9, 3.6194276953755283`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$ward", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"amp4$qlightcone2", "/.", 
     RowBox[{"Join", "[", 
      RowBox[{"rulesward1", ",", 
       RowBox[{"{", 
        RowBox[{"rulesward2", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], "}"}], ",", "rulesward3"}], "]"}]}],
     ",", 
    RowBox[{"{", 
     RowBox[{"iq", ",", "1", ",", 
      RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619412063800127*^9, 3.619412070470079*^9}, {
  3.619412610431522*^9, 3.619412618367523*^9}, {3.6194129261265993`*^9, 
  3.6194129692352467`*^9}, {3.619413016601595*^9, 3.619413027674564*^9}, {
  3.619413131136685*^9, 3.619413134234509*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", "a2", " ", 
                SuperscriptBox["g", 
                 RowBox[{"b", "f"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"c", "g"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"d", "h"}]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["1",
                  TraditionalForm], 
                 FormBox[
                  FormBox["e",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox["s", "2"]}], 
               RowBox[{"16", " ", 
                SuperscriptBox["t", "2"]}]]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
               SuperscriptBox["g", 
                RowBox[{"b", "f"}]], " ", 
               SuperscriptBox["g", 
                RowBox[{"c", "g"}]], " ", 
               SuperscriptBox["g", 
                RowBox[{"d", "h"}]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["e",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox["s", "2"]}], 
              RowBox[{"16", " ", 
               SuperscriptBox["t", "2"]}]], "+", 
             FractionBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FractionBox["3", "20"], "-", 
                 FractionBox[
                  RowBox[{"51", " ", "\[ImaginaryI]"}], "40"]}], ")"}], " ", 
               "a2", " ", 
               SuperscriptBox["g", 
                RowBox[{"b", "f"}]], " ", 
               SubsuperscriptBox["k", 
                FormBox["4",
                 TraditionalForm], 
                FormBox[
                 FormBox["c",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SuperscriptBox["g", 
                RowBox[{"d", "h"}]], " ", 
               SuperscriptBox["g", 
                RowBox[{"e", "g"}]], " ", "s"}], 
              SuperscriptBox["t", "2"]], "+", 
             RowBox[{"\[LeftSkeleton]", "16619", "\[RightSkeleton]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SuperscriptBox["g", 
                RowBox[{"b", "c"}]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["d",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["e",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["s", "3"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["b",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["c",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["d",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["e",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"4", " ", 
               SuperscriptBox["s", "3"]}]]}], ",", 
            RowBox[{"\[LeftSkeleton]", "38", "\[RightSkeleton]"}], ",", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"\[ImaginaryI]", " ", "a2", " ", 
                SuperscriptBox["g", 
                 RowBox[{"b", "f"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"c", "g"}]], " ", 
                SuperscriptBox["g", 
                 RowBox[{"d", "h"}]], " ", 
                SubsuperscriptBox["k", 
                 FormBox["1",
                  TraditionalForm], 
                 FormBox[
                  FormBox["e",
                   TraditionalForm],
                  TraditionalForm]], " ", 
                SuperscriptBox["s", "2"]}], 
               RowBox[{"16", " ", 
                SuperscriptBox["t", "2"]}]]}], "-", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "a3", " ", 
               RowBox[{"\[LeftSkeleton]", "4", "\[RightSkeleton]"}], " ", 
               SuperscriptBox["s", "2"]}], 
              RowBox[{"16", " ", 
               SuperscriptBox["t", "2"]}]], "+", 
             FractionBox[
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
              RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], "+", 
             RowBox[{"\[LeftSkeleton]", "16619", "\[RightSkeleton]"}], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", 
               RowBox[{"\[LeftSkeleton]", "6", "\[RightSkeleton]"}], " ", 
               RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}], 
              RowBox[{"2", " ", 
               SuperscriptBox["s", "3"]}]], "+", 
             FractionBox[
              RowBox[{"\[ImaginaryI]", " ", "e3", " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 FormBox["b",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["1",
                 TraditionalForm], 
                FormBox[
                 RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
               SubsuperscriptBox["k", 
                RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}], 
                RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]], " ", 
               SubsuperscriptBox["k", 
                FormBox["2",
                 TraditionalForm], 
                FormBox[
                 FormBox["f",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["g",
                  TraditionalForm],
                 TraditionalForm]], " ", 
               SubsuperscriptBox["k", 
                FormBox["3",
                 TraditionalForm], 
                FormBox[
                 FormBox["h",
                  TraditionalForm],
                 TraditionalForm]]}], 
              RowBox[{"4", " ", 
               SuperscriptBox["s", "3"]}]]}]}], "}"}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1298, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1298, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1298, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[1298]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619412726823831*^9, 3.619413101047892*^9, 
  3.6194132063152122`*^9, 3.619415157101575*^9, 3.619418408999012*^9, 
  3.619419815331244*^9, 3.6194229249271183`*^9, 3.619426748382578*^9, 
  3.619427441858088*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Filter", "[", 
    RowBox[{
     RowBox[{"amp4$qlightcone2$ward", "[", 
      RowBox[{"[", "iq", "]"}], "]"}], ",", 
     RowBox[{"LorentzIndex", "[", 
      RowBox[{"a", ",", "D"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"iq", ",", "1", ",", 
     RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619412776495097*^9, 3.619412795255933*^9}, {
  3.6194132140187483`*^9, 3.619413236804791*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
     ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
    ",", "0", ",", "0", ",", "0"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6194127966598873`*^9, 3.619413240947672*^9, 
  3.619415192171403*^9, 3.619418645277316*^9, 3.6194198597523623`*^9, 
  3.619422960083191*^9, 3.619427455856538*^9}]
}, Open  ]],

Cell["\<\
Now all indices a have gone. We can therefore savely apply the original rules \
for the contractions into polarizations.\
\>", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, 
   3.619173531426968*^9, 3.619173698266375*^9, {3.619173847345159*^9, 
   3.619173873646263*^9}, {3.619235593173221*^9, 3.619235598976385*^9}, {
   3.619411957188622*^9, 3.619412060723302*^9}, {3.619412811354751*^9, 
   3.6194128551686296`*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$ward2", "=", 
  RowBox[{"N", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"amp4$qlightcone2$ward", "[", 
       RowBox[{"[", "iq", "]"}], "]"}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"rules0", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], ",", "rules1", ",", 
        RowBox[{"rules2", "[", 
         RowBox[{"[", "iq", "]"}], "]"}], ",", "rules3"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"iq", ",", "1", ",", 
       RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.619174090652886*^9, 3.6191740932519493`*^9}, {
   3.6191741401679697`*^9, 3.6191741406610947`*^9}, {3.61923575463708*^9, 
   3.6192357570857067`*^9}, {3.619236448618927*^9, 3.619236504574319*^9}, {
   3.619236563719427*^9, 3.619236567088612*^9}, {3.619236864755721*^9, 
   3.619236867380209*^9}, {3.61923695240946*^9, 3.619236981307167*^9}, {
   3.6192370158471622`*^9, 3.6192370436549377`*^9}, {3.619237081637163*^9, 
   3.6192370857360153`*^9}, {3.619237181822341*^9, 3.619237222082407*^9}, 
   3.619237292907866*^9, {3.6192377416628027`*^9, 3.619237776673604*^9}, {
   3.619237877858811*^9, 3.619238191513442*^9}, {3.619238234861478*^9, 
   3.61923835670647*^9}, {3.619240181475733*^9, 3.619240188813858*^9}, {
   3.6192461927732477`*^9, 3.6192462234944773`*^9}, {3.619246283517706*^9, 
   3.6192462902520113`*^9}, 3.619246408486841*^9, {3.619246958317753*^9, 
   3.61924696063234*^9}, {3.619247426612483*^9, 3.619247427423375*^9}, 
   3.619259918646023*^9, {3.6194126257666893`*^9, 3.6194126279267187`*^9}, {
   3.619413263733199*^9, 3.61941326610187*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084565`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.3605695862040473`*^6", "-", 
        RowBox[{"6.911811166116401`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7605911823763375`*^6", "-", 
        RowBox[{"1.3278961658766408`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2935990061438704`*^7", "-", 
        RowBox[{"2.8756075271127233`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.404119728194941`*^6", "+", 
        RowBox[{"1.72100400423847`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.27593083791297`*^6", "-", 
        RowBox[{"807317.096223507`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0956608669369303`*^7", "-", 
        RowBox[{"1.0991801368053189`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2817745612595538`*^6", "+", 
        RowBox[{"2.447108901383413`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5620222140877508`*^6", "-", 
        RowBox[{"456444.3611574415`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8947640723603144`*^6", "+", 
        RowBox[{"1.8616225445763352`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1832246135713654`*^7", "+", 
        RowBox[{"1.1442232253432617`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.1353356899249814`*^7", "+", 
        RowBox[{"9.738857774684269`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3398497353607513`*^7", "+", 
        RowBox[{"1.5633629249517564`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4950408731758103`*^7", "+", 
        RowBox[{"4.193004904995666`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9944677859328967`*^6", "+", 
        RowBox[{"4.490895709568288`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.0754291192845395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"708191.5475937601`", "\[VeryThinSpace]", "-", 
        RowBox[{"907786.2466443736`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8829935087533416`*^6", "+", 
        RowBox[{"1.239245239753183`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.554269120284656`*^6", "+", 
        RowBox[{"1.6609001540591314`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.833032729132492`*^6", "-", 
        RowBox[{"8.629522651408086`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.523183160396787`*^6", "-", 
        RowBox[{"7.367235072178714`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.923204756569069`*^6", "-", 
        RowBox[{"1.3734385564828718`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.401955163006745`*^6", "-", 
        RowBox[{"3.561475972048219`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"748846.7156833163`", "\[VeryThinSpace]", "-", 
        RowBox[{"16205.25171021896`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"950896.5423031372`", "\[VeryThinSpace]", "+", 
        RowBox[{"713377.4724341683`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4869549026432652`*^6", "+", 
        RowBox[{"6.051258049150247`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7223719245088063`*^6", "-", 
        RowBox[{"1.3299600139507314`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0291943610220461`*^6", "+", 
        RowBox[{"2.427373671692025`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.784014295121013`*^6", "-", 
        RowBox[{"3.5221798635365604`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.76355394922194`*^7", "-", 
        RowBox[{"5.8443792084931344`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1210171771735307`*^7", "-", 
        RowBox[{"8.237788593891504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.208852272326098`*^6", "-", 
        RowBox[{"3.1403610180624793`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.154585866497846`*^6", "+", 
        RowBox[{"5.590366910029139`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.589177934704602`*^6", "-", 
        RowBox[{"134453.77263311483`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"319864.7647541998`", "\[VeryThinSpace]", "-", 
        RowBox[{"175358.03216563188`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0288442395251859`*^6", "+", 
        RowBox[{"139958.36644758738`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"89112.32088901661`", "\[VeryThinSpace]", "-", 
        RowBox[{"333324.2430017451`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.535868766646568`*^6", "-", 
        RowBox[{"9.774486648096319`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2220400253304232`*^7", "+", 
        RowBox[{"8.474889844054952`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3820378657131981`*^7", "+", 
        RowBox[{"1.4842040336704955`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.57927843053419`*^6", "+", 
        RowBox[{"323245.5705790402`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"198884.65642401972`", "\[VeryThinSpace]", "-", 
        RowBox[{"45721.81063851074`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.12915902696402`*^6", "-", 
        RowBox[{"390812.70107158297`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.053118161024787`*^6", "-", 
        RowBox[{"2.5350374844471025`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9252862124220473`*^6", "-", 
        RowBox[{"1.0845448045211162`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"497481.0150964267`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.1836712425630405`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3761145430132039`*^7", "+", 
        RowBox[{"3.6826967948522037`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1194891288816893`*^8", "-", 
        RowBox[{"2.35844084193493`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.829144689361247`*^8", "-", 
        RowBox[{"2.510811303566455`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.23019435007426`*^7", "+", 
        RowBox[{"3.25849484654859`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.7795863970656767`*^6", "-", 
        RowBox[{"2.8510046577156177`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.17634131172277`*^7", "-", 
        RowBox[{"9.541884435880847`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"169441.16693523584`", "\[VeryThinSpace]", "-", 
        RowBox[{"520629.21033881564`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"633460.2803231208`", "\[VeryThinSpace]", "+", 
        RowBox[{"149391.7734184228`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"364301.89377249405`", "\[VeryThinSpace]", "-", 
        RowBox[{"281277.0874218531`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0108353461628795`*^7", "+", 
        RowBox[{"2.652577810459137`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"390195.2337200842`", "\[VeryThinSpace]", "-", 
        RowBox[{"6.696035974389492`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.209783170107637`*^6", "+", 
        RowBox[{"1.3063186467039494`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"234438.04133743607`", "\[VeryThinSpace]", "+", 
        RowBox[{"6.155583055843003`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2904884518495426`*^6", "-", 
        RowBox[{"400719.75125509955`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.016451624236174`*^6", "-", 
        RowBox[{"1.87811625395462`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1290916912884006`*^7", "-", 
        RowBox[{"1.8864998357437546`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2503447567121107`*^6", "+", 
        RowBox[{"349517.1828617044`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7043881340543986`*^6", "-", 
        RowBox[{"1.5997640369409716`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8735196834657355`*^6", "-", 
        RowBox[{"4.4749388932211865`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.279969889455691`*^6", "-", 
        RowBox[{"2.7743297778263856`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3960553755682163`*^7", "+", 
        RowBox[{"8.348523863949913`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"333876.8980741957`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.0809279968666276`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0974379792057462`*^7", "-", 
        RowBox[{"1.6887137457451183`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.287264836125907`*^6", "-", 
        RowBox[{"4.356010248518685`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"288640.9606054323`", "\[VeryThinSpace]", "+", 
        RowBox[{"930633.5773314665`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"873560.7046020282`", "\[VeryThinSpace]", "+", 
        RowBox[{"933912.7058926084`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.193619680491086`*^6", "+", 
        RowBox[{"1.3801950804341922`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1076037431585357`*^7", "-", 
        RowBox[{"5.646119180703109`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084563`*^7"}], "+", 
        RowBox[{"2.7299044604225043`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.590227575378472`*^6", "+", 
        RowBox[{"1.074264061988674`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1902059792061923`*^6", "+", 
        RowBox[{"1.7109791112536736`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1029230801195135`*^7", "+", 
        RowBox[{"2.1823813951108877`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.745547464217326`*^6", "-", 
        RowBox[{"2.3090054087403747`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.758887680980744`*^6", "-", 
        RowBox[{"424168.36442270386`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4164673079614548`*^7", "+", 
        RowBox[{"2.9667636072867915`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7722631107949824`*^6", "-", 
        RowBox[{"3.544840494613013`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"134613.63049668958`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.218914761144562`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.238170806294343`*^6", "-", 
        RowBox[{"5.482723295522836`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2660204034918921`*^7", "-", 
        RowBox[{"2.8233429678653117`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3492662659017904`*^7", "+", 
        RowBox[{"5.449387020944623`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.813796926404099`*^7", "-", 
        RowBox[{"1.7674061260108467`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.527842117508296`*^7", "-", 
        RowBox[{"1.4405680225264845`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.158134982510324`*^7", "+", 
        RowBox[{"1.376661027460788`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3234413285834868`*^6", "+", 
        RowBox[{"2.5928887631601067`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.685130727649263`*^6", "+", 
        RowBox[{"5.3084507078650305`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.037779415628973`*^6", "-", 
        RowBox[{"1.574246582403779`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.2562777492388844`*^7", "+", 
        RowBox[{"1.3603910494954072`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.047378115436875`*^6", "-", 
        RowBox[{"5.855868178248076`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.447399711609159`*^6", "-", 
        RowBox[{"1.2223018670898082`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4450762262432372`*^7", "-", 
        RowBox[{"1.0077036126331799`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"327347.3560353371`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.2002418824364066`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.341983285418453`*^6", "-", 
        RowBox[{"4.734603196355896`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5162146226336513`*^7", "-", 
        RowBox[{"1.525520444069639`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.610934972462097`*^6", "-", 
        RowBox[{"7.037491682866443`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.201559769632795`*^6", "+", 
        RowBox[{"3.743048054191154`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.853229738630874`*^6", "-", 
        RowBox[{"7.179182673457461`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.506340864649849`*^7", "+", 
        RowBox[{"2.0001002208189487`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.827827926921538`*^7", "-", 
        RowBox[{"4.5286000360410914`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6155534182686556`*^7", "+", 
        RowBox[{"1.5009715942899235`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2895811391479407`*^7", "+", 
        RowBox[{"2.8270361005627904`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.308482243550718`*^7", "+", 
        RowBox[{"2.4084955115501165`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.189309497263947`*^6", "+", 
        RowBox[{"780915.0817076368`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.700161580662534`*^6", "+", 
        RowBox[{"1.1225404511741482`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5017725275720388`*^7", "+", 
        RowBox[{"1.4233791831289025`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5970284145657603`*^7", "-", 
        RowBox[{"1.124435911088504`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225032`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.469016990689729`*^6", "+", 
        RowBox[{"6.114477108643905`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.068995394517449`*^6", "+", 
        RowBox[{"1.2481627601293907`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"784209.43679858`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.119571347899551`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"292066.7774141043`", "\[VeryThinSpace]", "-", 
        RowBox[{"795484.7932950987`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8810424176799236`*^6", "+", 
        RowBox[{"1.2137836875566933`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"309290.9181285794`", "\[VeryThinSpace]", "+", 
        RowBox[{"721294.4825701071`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7543178538474273`*^6", "-", 
        RowBox[{"2.101619017627183`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"938821.1975080182`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.6405770771398842`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.320269539707801`*^6", "+", 
        RowBox[{"489432.78235673043`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7090470043928046`*^7", "+", 
        RowBox[{"9.027895081649361`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8353288058338743`*^7", "+", 
        RowBox[{"1.2047689443860892`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0066397905828562`*^6", "+", 
        RowBox[{"446798.1005222942`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1492015117627135`*^6", "-", 
        RowBox[{"3.493025349224047`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0974475267042425`*^6", "-", 
        RowBox[{"6.900622757598685`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894861`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"96539.63236154482`", "\[VeryThinSpace]", "-", 
        RowBox[{"495703.21536093764`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"611.4720363536617`", "\[VeryThinSpace]", "-", 
        RowBox[{"487197.16036927776`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"181541.41273063514`", "\[VeryThinSpace]", "+", 
        RowBox[{"410384.29834631004`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.531495401486374`*^6", "+", 
        RowBox[{"845482.6750754546`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084563`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6956307103963117`*^6", "-", 
        RowBox[{"6.735689094640108`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"95652.3065685851`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3102839587290116`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1050922325081736`*^7", "-", 
        RowBox[{"1.189140491098493`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"117685.54084156908`", "\[VeryThinSpace]", "+", 
        RowBox[{"945167.732950445`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7145458345961003`*^6", "+", 
        RowBox[{"1.9963834948457987`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.195848549723277`*^6", "-", 
        RowBox[{"1.4778937243804187`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"655413.9553114567`", "\[VeryThinSpace]", "-", 
        RowBox[{"867804.6127101505`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4654054196940481`*^6", "+", 
        RowBox[{"692230.2285950154`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"295112.3585595968`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.2606222588325301`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"533917.9741852013`", "\[VeryThinSpace]", "-", 
        RowBox[{"9.208462871074434`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.443820406602293`*^6", "-", 
        RowBox[{"1.4094897520566028`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9055915699775363`*^6", "-", 
        RowBox[{"933376.363250586`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.1116003806151487`*^6", "-", 
        RowBox[{"2.413091209810666`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.266352417343988`*^6", "+", 
        RowBox[{"3.501981543903983`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894954`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"269650.9983932413`", "\[VeryThinSpace]", "-", 
        RowBox[{"490318.1189386393`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4049166372119398`*^6", "+", 
        RowBox[{"151764.45961010875`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"836229.7824339119`", "\[VeryThinSpace]", "-", 
        RowBox[{"272636.3546786057`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.985193307506463`*^6", "+", 
        RowBox[{"4.058036473064175`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0455066605989814`*^7", "+", 
        RowBox[{"1.4400471128647663`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.855088202162042`*^6", "-", 
        RowBox[{"4.927103379785247`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.73194269202333`*^6", "-", 
        RowBox[{"5.639423836497642`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"93994.81585765432`", "\[VeryThinSpace]", "-", 
        RowBox[{"458998.16463917407`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9276923189373903`*^6", "+", 
        RowBox[{"3.027638748631328`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9468853233328625`*^6", "-", 
        RowBox[{"499460.9503242057`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.187687832769467`*^6", "-", 
        RowBox[{"2.6678626768468646`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.12981426074956`*^6", "+", 
        RowBox[{"1.0962022472743958`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2363541586279452`*^7", "+", 
        RowBox[{"3.90139841993548`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5413772568641664`*^7", "-", 
        RowBox[{"3.31816132130559`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.767669631206655`*^7", "-", 
        RowBox[{"2.2500303588223442`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1168077559856463`*^7", "-", 
        RowBox[{"1.4135834668784067`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6125549012998762`*^6", "-", 
        RowBox[{"5.792074093316134`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0113942227314766`*^7", "-", 
        RowBox[{"1.9783464631064683`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894917`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"424800.79787236743`", "\[VeryThinSpace]", "-", 
        RowBox[{"619836.7146056207`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0972552329794238`*^6", "-", 
        RowBox[{"646627.0975709998`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"184307.5055803638`", "\[VeryThinSpace]", "-", 
        RowBox[{"595674.2292352594`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.675405671786186`*^7", "-", 
        RowBox[{"7.397787676789589`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.386210830660205`*^6", "-", 
        RowBox[{"6.640220404165751`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"786232.4268324815`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3007370896815754`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.126041668514423`*^6", "-", 
        RowBox[{"2.257610498387336`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7043911612910992`*^6", "+", 
        RowBox[{"2.0329107018730508`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3295245792910517`*^6", "-", 
        RowBox[{"765887.4747229584`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.363565728991463`*^6", "+", 
        RowBox[{"1.5934704941916201`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3221295247469093`*^6", "-", 
        RowBox[{"3.219976456124636`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1456793760779959`*^6", "+", 
        RowBox[{"3.972168333842788`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2262758392297295`*^6", "-", 
        RowBox[{"208025.45695687574`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.531604576198384`*^6", "-", 
        RowBox[{"2.8422147081120826`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.383752069635473`*^6", "-", 
        RowBox[{"2.9334382408587046`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.8556641783804875`*^6", "+", 
        RowBox[{"5.357496849248815`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.448095006722067`*^6", "-", 
        RowBox[{"9.449855291414928`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.788799325641487`*^7", "-", 
        RowBox[{"3.9019167126739398`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2709641053150855`*^6", "+", 
        RowBox[{"735321.0114136653`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"639462.0125757006`", "\[VeryThinSpace]", "-", 
        RowBox[{"584691.8819548661`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1657022971755564`*^6", "+", 
        RowBox[{"4.0724367110022833`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.75627535410769`*^6", "-", 
        RowBox[{"1.2841208262835942`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.242893697627549`*^6", "-", 
        RowBox[{"7.04460979005018`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.64291529379983`*^6", "-", 
        RowBox[{"1.3411760282700188`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.990386504913416`*^6", "-", 
        RowBox[{"3.866792178762976`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"616569.3449542333`", "\[VeryThinSpace]", "+", 
        RowBox[{"401148.4928509087`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.377151001255651`*^6", "+", 
        RowBox[{"1.7173950067330194`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"660016.0480288831`", "\[VeryThinSpace]", "-", 
        RowBox[{"4.719431381944397`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8643783795969165`*^6", "-", 
        RowBox[{"1.12714994136725`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2471352034211513`*^6", "+", 
        RowBox[{"1.5141310925468197`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9747911147358348`*^6", "-", 
        RowBox[{"2.254356171954482`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.48853862279242`*^6", "-", 
        RowBox[{"2.2562987665141378`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.599379372759835`*^6", "-", 
        RowBox[{"3.2296100626428697`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6516859955413244`*^6", "-", 
        RowBox[{"260597.55282785278`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.59320811162751`*^6", "-", 
        RowBox[{"3.121963166382935`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.90829846772544`*^6", "-", 
        RowBox[{"573677.1260525463`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"404181.6187696956`", "\[VeryThinSpace]", "-", 
        RowBox[{"428858.7607255105`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4285063571532124`*^6", "+", 
        RowBox[{"82976.98986753996`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"335191.83918247186`", "\[VeryThinSpace]", "-", 
        RowBox[{"453191.18321299786`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.190425595254516`*^6", "+", 
        RowBox[{"1.9758290339536946`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.7299044604225043`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.535854313727525`*^6", "-", 
        RowBox[{"1.2610103784008006`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"64124.09010014497`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.8977254276658006`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"270896.1110859383`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.5995325332986163`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"49797.30809270649`", "\[VeryThinSpace]", "+", 
        RowBox[{"925450.7868087358`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.388610629347018`*^6", "+", 
        RowBox[{"698845.6399554934`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2137564058669442`*^6", "+", 
        RowBox[{"2.197134758872574`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8438032657997552`*^6", "-", 
        RowBox[{"2.302567353609944`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0530402285285764`*^6", "+", 
        RowBox[{"2.112283953652121`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"776115.634634342`", "\[VeryThinSpace]", "+", 
        RowBox[{"8.288593705781475`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.17463753075241`*^6", "+", 
        RowBox[{"4.962270489605244`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8089329003127255`*^6", "+", 
        RowBox[{"5.568046303635921`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"612825.8766008224`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.361790026792159`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.787659248254299`*^6", "+", 
        RowBox[{"1.6003626611453358`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.4991711948644`*^6", "+", 
        RowBox[{"3.1588393975407556`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"314673.734735646`", "\[VeryThinSpace]", "-", 
        RowBox[{"232447.4744830515`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"129697.55288120965`", "\[VeryThinSpace]", "+", 
        RowBox[{"79905.28770259942`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"472993.67988038156`", "\[VeryThinSpace]", "+", 
        RowBox[{"163150.24880827486`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.706559457657971`*^7", "-", 
        RowBox[{"3.068390598326475`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3168078347074264`*^6", "-", 
        RowBox[{"7.480991205789372`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"283170.56912030256`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.3848141698439382`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5007185621564817`*^7", "-", 
        RowBox[{"6.655749249791628`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.977047592279213`*^6", "+", 
        RowBox[{"1.6855918859768696`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.9687492971317833`*^6", "+", 
        RowBox[{"777243.7815003986`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.377875970931624`*^7", "-", 
        RowBox[{"1.5749932514305403`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7444474365611277`*^6", "+", 
        RowBox[{"2.669426650935875`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8110899840081253`*^6", "-", 
        RowBox[{"97370.06098780886`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3002353667933596`*^6", "-", 
        RowBox[{"130220.0755348577`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.330913537818881`*^6", "+", 
        RowBox[{"4.754691245199956`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8367719028132994`*^7", "+", 
        RowBox[{"3.9989349325216613`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3817622213995902`*^7", "+", 
        RowBox[{"1.164123542624489`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.736419644534742`*^7", "+", 
        RowBox[{"1.0721996648132298`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.1642243836241074`*^7", "+", 
        RowBox[{"3.529956619709985`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"922631.6096450497`", "\[VeryThinSpace]", "-", 
        RowBox[{"478029.1054020752`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9510686138918153`*^6", "+", 
        RowBox[{"1.8184104372048504`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.180146984466492`*^6", "+", 
        RowBox[{"3.0363188821869306`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.568406374317723`*^6", "-", 
        RowBox[{"1.0381812807992019`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225043`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"666659.306344776`", "\[VeryThinSpace]", "+", 
        RowBox[{"6.046675374305696`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.266637710172492`*^6", "+", 
        RowBox[{"1.2413825866955701`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.921893761843838`*^6", "-", 
        RowBox[{"498488.2851912466`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"652526.8032632122`", "\[VeryThinSpace]", "-", 
        RowBox[{"697575.3523558122`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6642494047836415`*^6", "+", 
        RowBox[{"3.527726006107157`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4700724314103806`*^6", "+", 
        RowBox[{"2.285653444471051`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"282634.22771508666`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.0849823283165256`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.654152141864552`*^6", "+", 
        RowBox[{"175180.45413604658`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.050993966254599`*^6", "+", 
        RowBox[{"676406.7012029523`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.929523722423691`*^6", "+", 
        RowBox[{"2.135326211348217`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.146987226869521`*^6", "+", 
        RowBox[{"2.628418348993783`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7854238208280522`*^6", "+", 
        RowBox[{"699210.6687019202`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.895898176567031`*^6", "-", 
        RowBox[{"4.5965596138157565`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.155388851073754`*^6", "-", 
        RowBox[{"5.449022674954811`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894917`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"279902.15752336825`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.0070223798813468`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9800535086346385`*^6", "-", 
        RowBox[{"22633.037334510824`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0730969190637628`*^6", "+", 
        RowBox[{"335038.05978230084`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4493340167087074`*^6", "-", 
        RowBox[{"2.518522379558072`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0872530248158302`*^6", "+", 
        RowBox[{"5.732739167373974`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.687231428643551`*^6", "+", 
        RowBox[{"1.2099889660023982`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8159828834505763`*^7", "-", 
        RowBox[{"6.924290792416029`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0689871845143707`*^6", "+", 
        RowBox[{"896604.3200579454`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"52923.73488744197`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.5167706210860482`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.373551798211956`*^6", "+", 
        RowBox[{"2.654711370958553`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.292349836919776`*^6", "+", 
        RowBox[{"906385.4487096267`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"69838.63973773923`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.6582784541516183`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"577911.490098042`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.0034642457755983`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.774607173745619`*^7", "-", 
        RowBox[{"1.2076301502157992`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.904059820104959`*^7", "-", 
        RowBox[{"5.1104153310613304`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"879.1337742945179`", "\[VeryThinSpace]", "-", 
        RowBox[{"710572.0433752714`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0866349051233097`*^6", "+", 
        RowBox[{"9.615065339447863`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.916018932417603`*^7", "-", 
        RowBox[{"2.623766290244313`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"539110.322881565`", "\[VeryThinSpace]", "-", 
        RowBox[{"27914.617392556393`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7334543414385733`*^6", "+", 
        RowBox[{"804809.5599444839`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4122436924004452`*^6", "-", 
        RowBox[{"913205.6982014653`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3741434469032876`*^7", "-", 
        RowBox[{"2.432068713737659`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2469032248566914`*^6", "-", 
        RowBox[{"1.1975106173144918`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"646924.8210289404`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.8342256665794924`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5444851505226907`*^6", "-", 
        RowBox[{"4.036674367742723`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.478526454311307`*^6", "+", 
        RowBox[{"156648.16452770634`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.579093906712323`*^6", "-", 
        RowBox[{"3.84207621796233`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.412632285689095`*^7", "-", 
        RowBox[{"2.5918147204685006`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8909200867401585`*^6", "+", 
        RowBox[{"1.9839902300134897`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9629446765654716`*^6", "-", 
        RowBox[{"1.3578363406493478`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.520397179024572`*^6", "-", 
        RowBox[{"1.3179903715832448`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.145169778113055`*^7", "-", 
        RowBox[{"1.82290714853736`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.18675153052667`*^8", "+", 
        RowBox[{"4.5152775777506244`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7275635961353187`*^7", "-", 
        RowBox[{"1.3817145390045559`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9566874972554818`*^7", "-", 
        RowBox[{"2.23440583803816`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.89747527982989`*^6", "-", 
        RowBox[{"1.4265127145364936`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894917`*^6", "-", 
        RowBox[{"5.0754291192845395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.317203625033757`*^6", "-", 
        RowBox[{"4.160645752106756`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.16302076029928`*^6", "-", 
        RowBox[{"5.35126800574464`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0567781079697013`*^6", "+", 
        RowBox[{"1.2311076948552065`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9798808375277996`*^7", "-", 
        RowBox[{"3.0121767687740607`*^9", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5466456214276026`*^6", "+", 
        RowBox[{"3.4147095996866627`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.146624025255332`*^6", "+", 
        RowBox[{"9.781860092336662`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.579794256648785`*^6", "+", 
        RowBox[{"9.09436978473979`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"452296.2450604653`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.802800156917367`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.432262040489603`*^6", "+", 
        RowBox[{"2.832377665621847`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1469371375965863`*^7", "-", 
        RowBox[{"5.970359928910848`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"785636.5325258737`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.4270581154545005`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"649012.7645382262`", "\[VeryThinSpace]", "+", 
        RowBox[{"575435.3909706222`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.302367903788654`*^6", "-", 
        RowBox[{"2.2276510020279363`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.105199956843061`*^6", "+", 
        RowBox[{"2.968391511258199`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4812885518090349`*^7", "-", 
        RowBox[{"3.7639887288579345`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8459451032592133`*^7", "-", 
        RowBox[{"4.015637867556069`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2518412154407937`*^7", "+", 
        RowBox[{"3.616660720262636`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.648015188989962`*^7", "-", 
        RowBox[{"5.808301267959948`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894861`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6459421348671354`*^6", "-", 
        RowBox[{"1.4554034189779717`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.266498486709701`*^6", "+", 
        RowBox[{"10876.034391519614`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.437238457313912`*^6", "+", 
        RowBox[{"3.982592671584901`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.03355250755455`*^7", "-", 
        RowBox[{"5.913235152251316`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.103774708204247`*^7", "+", 
        RowBox[{"4.397538434365098`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.263772548587029`*^7", "+", 
        RowBox[{"5.034253483630094`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.9490335252627563`*^6", "-", 
        RowBox[{"1.5917230608631785`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"96551.75843834691`", "\[VeryThinSpace]", "-", 
        RowBox[{"159705.33990635467`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4180100284073493`*^6", "+", 
        RowBox[{"795479.6696123617`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"195974.5752012222`", "\[VeryThinSpace]", "-", 
        RowBox[{"770194.0983144729`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5343507402317794`*^6", "-", 
        RowBox[{"1.5945635345895588`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"970237.1506855665`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.679569458650908`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.71205630198541`*^7", "+", 
        RowBox[{"2.4330363067948714`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.0619804190610826`*^8", "-", 
        RowBox[{"1.010322193566371`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.819541743655255`*^8", "+", 
        RowBox[{"2.1177436272646293`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.494257084211904`*^7", "+", 
        RowBox[{"1.9027725487990268`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.67159886596118`*^7", "+", 
        RowBox[{"2.412212937637474`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.807441601492697`*^7", "-", 
        RowBox[{"6.2539973845940016`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"102445.93387918151`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.1609111001844127`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"425692.89920803905`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.674444522952795`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"81952.0010176003`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.6511191534624994`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.976178807217121`*^9", "-", 
        RowBox[{"4.421643041909199`*^9", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.657542480151179`*^6", "-", 
        RowBox[{"8.613872294302808`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0575640763234487`*^6", "-", 
        RowBox[{"1.4981022786952816`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.989933458928268`*^6", "-", 
        RowBox[{"1.3183646768794623`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"971049.744182962`", "\[VeryThinSpace]", "+", 
        RowBox[{"220016.56719648774`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"243725.52425783582`", "\[VeryThinSpace]", "-", 
        RowBox[{"782138.088795445`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"533059.1459785653`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.2962772414609104`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.488649100158009`*^6", "-", 
        RowBox[{"381497.2456772255`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"288161.0655448516`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.2318861682926402`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.636745806293104`*^6", "-", 
        RowBox[{"4.503340099857189`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6142426356692202`*^7", "-", 
        RowBox[{"7.601543639863321`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.284460317259181`*^6", "+", 
        RowBox[{"1.208922707114966`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"301012.8307583709`", "\[VeryThinSpace]", "-", 
        RowBox[{"7.671176411449819`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1857967574828962`*^7", "+", 
        RowBox[{"1.4489777321564153`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1375138895490397`*^7", "+", 
        RowBox[{"6.578970462622106`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.0754291192845395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"30192.731911349634`", "\[VeryThinSpace]", "+", 
        RowBox[{"171343.54435903445`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.054353313287428`*^6", "+", 
        RowBox[{"48522.729646165855`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"474223.2655359488`", "\[VeryThinSpace]", "+", 
        RowBox[{"541515.8340926599`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"533861.8404804543`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.7090737664655763`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084563`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9683932791775255`*^6", "+", 
        RowBox[{"7.342144187505574`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.5683716830052375`*^6", "+", 
        RowBox[{"1.3709294680155579`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"865588.3528958969`", "\[VeryThinSpace]", "+", 
        RowBox[{"4.499445756173284`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"621245.4598541044`", "\[VeryThinSpace]", "+", 
        RowBox[{"586056.3058011017`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.93227387460793`*^6", "+", 
        RowBox[{"2.8981893361500786`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6592590622427766`*^6", "-", 
        RowBox[{"90634.84188833903`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"244827.60736305267`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.376634539343101`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4513668572024726`*^6", "+", 
        RowBox[{"392089.78555362846`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.635643745910804`*^6", "+", 
        RowBox[{"112029.09297370166`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4858266307910178`*^7", "+", 
        RowBox[{"1.7120641692735832`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.608057708173726`*^6", "+", 
        RowBox[{"1.7492560196789965`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"183887.32767401636`", "\[VeryThinSpace]", "+", 
        RowBox[{"319979.73133961624`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.2174189074438475`*^6", "+", 
        RowBox[{"1.364166112681061`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"772430.0656707408`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.91143719968984`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894842`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"234167.99395621836`", "\[VeryThinSpace]", "-", 
        RowBox[{"612932.8429401367`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"304478.6073419475`", "\[VeryThinSpace]", "+", 
        RowBox[{"237513.9452862834`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"946696.4493633593`", "\[VeryThinSpace]", "-", 
        RowBox[{"12925.74719339516`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.660921363686368`*^6", "+", 
        RowBox[{"4.018205538448046`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.962387675354818`*^6", "-", 
        RowBox[{"2.394525627172988`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.3624092715271`*^6", "-", 
        RowBox[{"8.761676119822992`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.5391898700566962`*^6", "+", 
        RowBox[{"1.884930258639621`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.912694095832762`*^6", "+", 
        RowBox[{"956805.719093183`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"277368.7783538505`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.899453976618136`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.670438238266786`*^6", "-", 
        RowBox[{"3.856117815995328`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"419848.34035458555`", "\[VeryThinSpace]", "+", 
        RowBox[{"4.908834243388865`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.5303184243550915`*^6", "+", 
        RowBox[{"1.5051937857876697`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.53822132781351`*^6", "+", 
        RowBox[{"4.281353546067394`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.3125276588151097`*^7", "-", 
        RowBox[{"2.4343684105179757`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7822864105572976`*^7", "-", 
        RowBox[{"8.915971062261932`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3743328989784854`*^7", "-", 
        RowBox[{"6.43673338162904`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2864400821748292`*^7", "+", 
        RowBox[{"3.3000437072143964`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.84285312282437`*^6", "+", 
        RowBox[{"3.6881816939202296`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.0754291192845395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8727748083830455`*^6", "-", 
        RowBox[{"1.1132438275358547`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"529065.0298655815`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.5242406615685038`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"254222.44279127195`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.488142213626046`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0810491817863278`*^7", "-", 
        RowBox[{"4.393707019957818`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084565`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5395343299109`*^6", "-", 
        RowBox[{"1.0798574955955628`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"939555.9260831876`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.7165725448605638`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"474234.90788949886`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.368356545304013`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"49532.61762218352`", "\[VeryThinSpace]", "-", 
        RowBox[{"510970.0710467991`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.6572898785184356`*^6", "+", 
        RowBox[{"301330.61236834363`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2086052464032173`*^6", "-", 
        RowBox[{"942911.8648755122`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4225662319391305`*^6", "-", 
        RowBox[{"1.446760223847379`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"308057.46568093554`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.5405534208225077`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2566950252656937`*^6", "-", 
        RowBox[{"6.160760659374648`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.301866241097071`*^7", "-", 
        RowBox[{"4.124343743685455`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0346325586593986`*^7", "-", 
        RowBox[{"4.271394457796135`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1501349901435385`*^6", "-", 
        RowBox[{"2.694584126881142`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.140289123125825`*^6", "+", 
        RowBox[{"677390.1146461519`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.64908090584819`*^6", "+", 
        RowBox[{"3.2234988811166617`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"316672.13114953507`", "\[VeryThinSpace]", "-", 
        RowBox[{"339852.9363861077`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"104634.63401407981`", "\[VeryThinSpace]", "+", 
        RowBox[{"115341.03302139358`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"732444.0357824573`", "\[VeryThinSpace]", "+", 
        RowBox[{"100542.81720453809`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.532106530768062`*^7", "-", 
        RowBox[{"9.562410246507078`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.850626844127875`*^6", "-", 
        RowBox[{"1.0593594978917476`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.250648440300171`*^6", "-", 
        RowBox[{"1.6960745471567474`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"32809.1172985835`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.2925351824581467`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"67699.42912055878`", "\[VeryThinSpace]", "+", 
        RowBox[{"803466.457138518`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2904707005537353`*^6", "+", 
        RowBox[{"205989.2032426009`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3991204554609475`*^6", "+", 
        RowBox[{"2.8740274735450945`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.975842415352093`*^6", "-", 
        RowBox[{"2.0779621170700183`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"879874.8949723886`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.3267505817232057`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.596270549304131`*^6", "-", 
        RowBox[{"7.210741458842902`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.39124406867596`*^7", "-", 
        RowBox[{"6.155525142613215`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.0474894330703616`*^7", "-", 
        RowBox[{"6.9435494747505`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.899393647237867`*^6", "-", 
        RowBox[{"5.547565189122946`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.202943160009902`*^6", "+", 
        RowBox[{"3.491102154614811`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"410808.7123404741`", "\[VeryThinSpace]", "+", 
        RowBox[{"7.795274453426259`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"303437.0073673658`", "\[VeryThinSpace]", "-", 
        RowBox[{"136684.49082170514`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"204979.48896078952`", "\[VeryThinSpace]", "+", 
        RowBox[{"320420.23702968296`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"338436.22206868324`", "\[VeryThinSpace]", "+", 
        RowBox[{"24790.86971527571`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.792942647601997`*^7", "+", 
        RowBox[{"8.470895337942255`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.913969572992072`*^6", "+", 
        RowBox[{"4.829777385969205`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1513947976819783`*^7", "+", 
        RowBox[{"1.119692787861921`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8686129067362957`*^6", "-", 
        RowBox[{"4.920740759828936`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"615273.9211661418`", "\[VeryThinSpace]", "-", 
        RowBox[{"868460.3865877239`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0147300190740079`*^6", "+", 
        RowBox[{"395728.2540853567`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.524657699745515`*^6", "+", 
        RowBox[{"3.041376819172997`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6664948472316563`*^6", "-", 
        RowBox[{"2.0090884599670044`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"797016.3433209343`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.469412211083129`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0475643130569218`*^7", "-", 
        RowBox[{"958439.7219746093`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.577268873203304`*^7", "-", 
        RowBox[{"3.7901036591585755`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.847688634940159`*^7", "-", 
        RowBox[{"4.548362670399338`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.948018207928695`*^6", "-", 
        RowBox[{"1.5706958937167386`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.060651416708421`*^6", "-", 
        RowBox[{"3.3821004938950725`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.496616776186211`*^6", "-", 
        RowBox[{"1.322086825732913`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894917`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"42809.5417180534`", "\[VeryThinSpace]", "+", 
        RowBox[{"553352.0430987165`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"72216.47988256044`", "\[VeryThinSpace]", "-", 
        RowBox[{"511826.28752038436`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"265541.53177831974`", "\[VeryThinSpace]", "+", 
        RowBox[{"118003.19437975716`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.19033905150748`*^6", "-", 
        RowBox[{"6.735528675747582`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225043`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1531383630153248`*^6", "+", 
        RowBox[{"5.477607300637627`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7531167668430535`*^6", "+", 
        RowBox[{"1.1844757793287627`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.8363238041736847`*^6", "+", 
        RowBox[{"6.420248361114281`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"441679.21477228706`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.775996720780708`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9566602236363436`*^6", "+", 
        RowBox[{"3.0310136571057877`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4558750034765704`*^6", "-", 
        RowBox[{"1.0196307238536961`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"691803.261734935`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.421923795110061`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.9130448556859246`*^6", "+", 
        RowBox[{"967528.4302973945`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"813496.0611311984`", "\[VeryThinSpace]", "+", 
        RowBox[{"42237.56590315566`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.837815999973003`*^6", "+", 
        RowBox[{"3.511975351938837`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"394684.3695063805`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.3330314741781503`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5471063144634124`*^6", "-", 
        RowBox[{"2.9367724308455763`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.2620648452374768`*^6", "+", 
        RowBox[{"9.942833949631106`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.583837464147488`*^6", "-", 
        RowBox[{"1.0048803475325279`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894936`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"10272.838618434733`", "\[VeryThinSpace]", "-", 
        RowBox[{"169405.93491715807`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.256453181949107`*^6", "+", 
        RowBox[{"753576.4095568057`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0756147104845187`*^6", "+", 
        RowBox[{"3.012866661794087`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.428769879133419`*^7", "-", 
        RowBox[{"1.398336658076495`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6890492199611235`*^6", "+", 
        RowBox[{"1.837814996842489`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.289027623788839`*^6", "+", 
        RowBox[{"2.4745300461074926`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"877569.6430250937`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.083960157376647`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"371776.57676291093`", "\[VeryThinSpace]", "-", 
        RowBox[{"778537.0983707075`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3673366366217616`*^6", "-", 
        RowBox[{"35987.1582979518`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"201642.1100462554`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.571462387463996`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3747371206445345`*^6", "-", 
        RowBox[{"1.7374212036692016`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"530474.7304990168`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.396618872504443`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.006442352083735`*^6", "+", 
        RowBox[{"1.381124821179441`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.969964862335748`*^7", "+", 
        RowBox[{"8.052392960678774`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.25536662458618`*^7", "+", 
        RowBox[{"1.1365155778689915`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6475909336471427`*^6", "+", 
        RowBox[{"9.500130138384288`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5247079832307`*^6", "+", 
        RowBox[{"296524.7423834307`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2407500950632146`*^7", "+", 
        RowBox[{"748534.5777959235`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894861`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"265294.7254906169`", "\[VeryThinSpace]", "-", 
        RowBox[{"385679.92720647727`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"297793.3966083862`", "\[VeryThinSpace]", "-", 
        RowBox[{"87608.35219397768`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"367877.1784768896`", "\[VeryThinSpace]", "-", 
        RowBox[{"127171.68475415278`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.399956825444028`*^7", "-", 
        RowBox[{"1.105607951681954`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.356478322972102`*^6", "-", 
        RowBox[{"1.9909990322387185`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.756499919144331`*^6", "-", 
        RowBox[{"2.6277140815037183`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0423030736902677`*^6", "-", 
        RowBox[{"2.01545280238529`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"70654.04945399496`", "\[VeryThinSpace]", "+", 
        RowBox[{"545006.4002906368`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.720005079826357`*^6", "+", 
        RowBox[{"834504.6766627819`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"764275.699007665`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.0133998540709508`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.509213824780225`*^6", "-", 
        RowBox[{"1.956522604191774`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"974354.7026453333`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.7421487350045438`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.842617030961271`*^6", "-", 
        RowBox[{"1.5439932793134738`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1628226181112144`*^7", "-", 
        RowBox[{"9.663951904994744`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.4450256197713144`*^7", "-", 
        RowBox[{"1.0563722188692069`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.960902368546225`*^6", "-", 
        RowBox[{"8.161082139924055`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.780713212193757`*^6", "-", 
        RowBox[{"64169.05784411589`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.681904190741625`*^6", "+", 
        RowBox[{"1.3733226872002168`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"519853.07312191534`", "\[VeryThinSpace]", "-", 
        RowBox[{"252194.3984715644`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"483370.58842194173`", "\[VeryThinSpace]", "+", 
        RowBox[{"182889.34288162692`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"569251.8005934991`", "\[VeryThinSpace]", "+", 
        RowBox[{"229105.5636661779`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0845726070866525`*^8", "+", 
        RowBox[{"7.131255971524623`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8151098715010714`*^6", "-", 
        RowBox[{"1.0586976426059289`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.215131467673355`*^6", "-", 
        RowBox[{"1.6954126918709286`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.130333523409584`*^6", "-", 
        RowBox[{"3.382434596527062`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"81707.37584466144`", "\[VeryThinSpace]", "+", 
        RowBox[{"230026.34217340266`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.225880440341337`*^6", "+", 
        RowBox[{"2.505436992814407`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"13168.076694729272`", "\[VeryThinSpace]", "-", 
        RowBox[{"134020.4582876861`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"915308.0357725886`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.7270227686745492`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6551391791881628`*^6", "+", 
        RowBox[{"837479.8320796961`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"799307.6612909455`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.818115140281655`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1892419212094251`*^7", "+", 
        RowBox[{"2.3434272660524614`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.174901692529548`*^6", "+", 
        RowBox[{"2.8510817816460498`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"125740.81535603106`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.0955896211453043`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.77131365082441`*^6", "-", 
        RowBox[{"1.2020921848807188`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.59082899733706`*^6", "+", 
        RowBox[{"1.8090822864359887`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894861`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"386575.31370535237`", "\[VeryThinSpace]", "-", 
        RowBox[{"690987.6276531504`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2902161836961124`*^6", "-", 
        RowBox[{"337874.45834641415`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"295181.3124626246`", "\[VeryThinSpace]", "-", 
        RowBox[{"7752.294091235846`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.943949699737768`*^7", "-", 
        RowBox[{"5.533099193484083`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5326428613183363`*^6", "-", 
        RowBox[{"6.56766042604007`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"67335.5425094061`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.2934810918690082`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4923440374942202`*^7", "+", 
        RowBox[{"1.1917371886759356`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4729774447178368`*^6", "-", 
        RowBox[{"480617.3206068834`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.721495519355276`*^6", "-", 
        RowBox[{"3.4068712840730236`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.012212998191411`*^6", "+", 
        RowBox[{"5.796984305700064`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"92420.1305697225`", "\[VeryThinSpace]", "+", 
        RowBox[{"4.247061944572786`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.04103452209351`*^6", "+", 
        RowBox[{"1.8526322384630872`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"151358.89596663148`", "\[VeryThinSpace]", "-", 
        RowBox[{"4.9327640679235235`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1398536866597526`*^7", "+", 
        RowBox[{"8.309572047892212`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5337093299354438`*^7", "+", 
        RowBox[{"4.981849875028058`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"280133.66203264846`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.1105252455509301`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1687864980010493`*^7", "+", 
        RowBox[{"5.614542639601221`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.838124907781467`*^6", "-", 
        RowBox[{"4.0686149198645893`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.0754291192845395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6047304869651478`*^6", "-", 
        RowBox[{"324361.06862864434`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6303726640566383`*^6", "+", 
        RowBox[{"4.986246018974703`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.788518885366355`*^6", "-", 
        RowBox[{"6.177516946087363`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.204482504432704`*^6", "+", 
        RowBox[{"5.111525985730875`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1589627004183433`*^6", "-", 
        RowBox[{"5.961717518206802`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"558984.2965906088`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.2328868010856804`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4214429526578661`*^7", "-", 
        RowBox[{"1.3795964401123347`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"132975.22734746302`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.840772584541652`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.215854934592122`*^6", "+", 
        RowBox[{"3.367127907443088`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.34878701501545`*^6", "-", 
        RowBox[{"1.474183511061809`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"497911.10371304`", "\[VeryThinSpace]", "+", 
        RowBox[{"95938.4908463431`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.573795039483287`*^6", "-", 
        RowBox[{"763419.9342385825`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"783004.5558512656`", "\[VeryThinSpace]", "-", 
        RowBox[{"654556.0637208188`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.94912082931534`*^6", "-", 
        RowBox[{"6.150510838988051`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.145337086769903`*^6", "-", 
        RowBox[{"7.4611361052399725`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.539616321036529`*^6", "-", 
        RowBox[{"6.17973347443546`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8923441423406226`*^6", "-", 
        RowBox[{"1.976470645240611`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.406371728918126`*^6", "-", 
        RowBox[{"1.1798203879458409`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894917`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"72463.91277945566`", "\[VeryThinSpace]", "-", 
        RowBox[{"436502.0326614947`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7357810619533346`*^6", "-", 
        RowBox[{"539445.5114623712`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.116684024769007`*^6", "-", 
        RowBox[{"2.09985894239137`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.452208244047518`*^6", "+", 
        RowBox[{"1.242072934730581`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1518777591008658`*^7", "+", 
        RowBox[{"2.2774219277057983`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.311875599483643`*^7", "+", 
        RowBox[{"2.9141369769707985`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4339960005544694`*^6", "-", 
        RowBox[{"3.233496873834748`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"140273.69132200594`", "\[VeryThinSpace]", "+", 
        RowBox[{"753640.0561623566`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.216073419868209`*^6", "+", 
        RowBox[{"1.680116848526038`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7072670983460133`*^6", "+", 
        RowBox[{"450228.1144178952`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4315937150466598`*^6", "-", 
        RowBox[{"2.569046898197532`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.591834987885036`*^6", "+", 
        RowBox[{"1.671795199946079`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6503996620074693`*^7", "+", 
        RowBox[{"1.4217752458547479`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.784973031595996`*^7", "+", 
        RowBox[{"3.851387513961144`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.163803024979011`*^7", "+", 
        RowBox[{"4.950266054358201`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.641491204064306`*^6", "+", 
        RowBox[{"5.3253780927485`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"755285.5498261983`", "\[VeryThinSpace]", "+", 
        RowBox[{"3.623680241465828`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.0705528234019317`*^7", "-", 
        RowBox[{"3.550357806766744`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"512023.84403827915`", "\[VeryThinSpace]", "-", 
        RowBox[{"581351.6313677575`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"463048.79759079637`", "\[VeryThinSpace]", "-", 
        RowBox[{"324050.40068135294`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"400779.47919374704`", "\[VeryThinSpace]", "+", 
        RowBox[{"198085.5751102995`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.965273785254955`*^7", "+", 
        RowBox[{"2.5976560446955666`*^8", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225043`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.936268764241158`*^6", "+", 
        RowBox[{"1.4336549365004009`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.53624716806887`*^6", "+", 
        RowBox[{"2.070369985765401`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"589308.561267944`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.496145893859598`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"497209.97189074836`", "\[VeryThinSpace]", "-", 
        RowBox[{"784856.382381589`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5845428746631034`*^6", "-", 
        RowBox[{"299155.49086207343`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"704833.8694068287`", "\[VeryThinSpace]", "-", 
        RowBox[{"4.0709665146053103`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.477557810596103`*^6", "-", 
        RowBox[{"1.5185532476493411`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"257974.931505432`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.4104482103034034`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.510300969592784`*^6", "+", 
        RowBox[{"1.021816990280449`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.767545438616385`*^7", "+", 
        RowBox[{"6.287831437967384`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.308318319499614`*^7", "+", 
        RowBox[{"9.35005540098002`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.139232808919711`*^6", "+", 
        RowBox[{"7.497784586054144`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0892907112199077`*^6", "+", 
        RowBox[{"3.200038074123608`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.182270835860899`*^6", "-", 
        RowBox[{"2.0657214833782164`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894954`*^6", "-", 
        RowBox[{"5.0754291192845395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"121929.01774779486`", "\[VeryThinSpace]", "-", 
        RowBox[{"406141.82059906796`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"124466.30526038399`", "\[VeryThinSpace]", "-", 
        RowBox[{"105532.96148662176`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"360595.30332729034`", "\[VeryThinSpace]", "-", 
        RowBox[{"196828.35200246796`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.605031859713048`*^7", "-", 
        RowBox[{"3.6485232350777864`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8160672966509343`*^6", "+", 
        RowBox[{"6.163912703333369`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.41604570047866`*^6", "+", 
        RowBox[{"1.2531063195983373`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5156983446126068`*^6", "+", 
        RowBox[{"5.473089148155743`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"401500.1735037138`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.2747762650754333`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.990447714553216`*^6", "+", 
        RowBox[{"2.6679816631860267`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"118161.81799597898`", "\[VeryThinSpace]", "+", 
        RowBox[{"559609.1776503816`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"808782.5902830639`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.014045967255157`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7393844468934883`*^6", "+", 
        RowBox[{"1.034525331965385`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.1794530034324713`*^6", "+", 
        RowBox[{"473407.6390722501`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.287020143111901`*^6", "+", 
        RowBox[{"2.9791171204207234`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7998827301377468`*^6", "+", 
        RowBox[{"2.0836582042759314`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"834160.2927054707`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.3675615936112357`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.240270485748848`*^6", "+", 
        RowBox[{"6.4868274883173965`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.655462277595386`*^6", "-", 
        RowBox[{"6.322988727161361`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894954`*^6", "-", 
        RowBox[{"5.075429119284539`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"177746.14709738723`", "\[VeryThinSpace]", "-", 
        RowBox[{"335455.11177174846`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"600096.9506036972`", "\[VeryThinSpace]", "+", 
        RowBox[{"486706.7696142328`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.596111053510874`*^6", "+", 
        RowBox[{"1.23944462440139`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.467208205968393`*^7", "-", 
        RowBox[{"1.1749809594235908`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.7299044604225036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4508782579650427`*^6", "-", 
        RowBox[{"6.374076311049227`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"850899.8541373212`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.2741226803699229`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.581567045876663`*^6", "-", 
        RowBox[{"2.5339871767587196`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.7577700206686507`*^6", "+", 
        RowBox[{"891436.4780745439`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.319738455877913`*^6", "-", 
        RowBox[{"477218.2340873019`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.827810563262355`*^6", "+", 
        RowBox[{"1.3786080603349254`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1863771783404718`*^6", "-", 
        RowBox[{"2.0003532454685955`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"444049.23118803045`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.5769374201095747`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"152908.73688354203`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.7780127549001796`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3171639413384767`*^6", "-", 
        RowBox[{"2.0003987184901662`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.91778059581783`*^6", "-", 
        RowBox[{"1.3961690861395834`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"920204.3094270816`", "\[VeryThinSpace]", "+", 
        RowBox[{"153711.3171999061`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"831916.7081832606`", "\[VeryThinSpace]", "-", 
        RowBox[{"4.51775205180831`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.9830110930269055`*^7", "-", 
        RowBox[{"8.662627334880859`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894954`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.138543066254625`*^6", "-", 
        RowBox[{"86421.04832742573`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2436.4593401557067`", "\[VeryThinSpace]", "+", 
        RowBox[{"388268.14846042957`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.2749049577939403`*^6", "+", 
        RowBox[{"3.606196250759282`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.303616364433184`*^6", "-", 
        RowBox[{"6.054484859880612`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"899179.5160339666`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.26013638249621`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"700798.8877937648`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.1627286875146214`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.0566805936425105`*^6", "+", 
        RowBox[{"1.3020442540379914`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"179038.70947905944`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.062508829087852`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8605961276200004`*^6", "+", 
        RowBox[{"1.2675798889473304`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.097831484572591`*^6", "+", 
        RowBox[{"6.730126749136234`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"240802.6205861068`", "\[VeryThinSpace]", "+", 
        RowBox[{"530987.2654581327`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"766175.1969491986`", "\[VeryThinSpace]", "+", 
        RowBox[{"25228.015400819248`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2339557335392758`*^6", "+", 
        RowBox[{"552618.49445665`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.894199131115512`*^6", "-", 
        RowBox[{"6.596011468183601`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6058875042300863`*^7", "-", 
        RowBox[{"363661.98604087485`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.743161172417399`*^6", "+", 
        RowBox[{"2.2056755968239107`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"56868.861707139295`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.0874079419559524`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.6383059882038245`*^6", "+", 
        RowBox[{"4.806045436533681`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894842`*^6", "-", 
        RowBox[{"5.0754291192845395`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"109906.8687859443`", "\[VeryThinSpace]", "-", 
        RowBox[{"347758.58923590387`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"759834.0572161211`", "\[VeryThinSpace]", "-", 
        RowBox[{"157509.63032631646`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"742976.7233221834`", "\[VeryThinSpace]", "-", 
        RowBox[{"5284.872794486815`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.4296609438182246`*^6", "+", 
        RowBox[{"5.6800251891256925`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8494335798823903`*^6", "-", 
        RowBox[{"7.807604425267609`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"249455.17605467583`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.4174754917917617`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.628936694753921`*^6", "+", 
        RowBox[{"4.934632613495168`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2039430880257788`*^6", "-", 
        RowBox[{"2.524618829571376`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"234151.06293566246`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.893718744297426`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.498461580115335`*^6", "+", 
        RowBox[{"1.7282912534319825`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.807221006610763`*^6", "-", 
        RowBox[{"2.33159279243073`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"321648.04274819186`", "\[VeryThinSpace]", "-", 
        RowBox[{"5.604789551004178`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.5201080965970308`*^6", "+", 
        RowBox[{"6.781004542532585`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0059563857132014`*^7", "+", 
        RowBox[{"4.332343743261957`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0715931610026535`*^7", "+", 
        RowBox[{"4.8513481034590356`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.701901775024349`*^6", "+", 
        RowBox[{"1.374125223280169`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.6019349161951605`*^7", "+", 
        RowBox[{"1.1737340621520726`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.059848542776959`*^7", "+", 
        RowBox[{"1.6707387376628036`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5725725431736282`*^6", "-", 
        RowBox[{"553541.7203928289`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"471076.37141993083`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.8655210846239426`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.935459772986045`*^6", "-", 
        RowBox[{"2.83362224210669`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.726776348171595`*^7", "+", 
        RowBox[{"1.5867706844738696`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084564`*^7"}], "+", 
        RowBox[{"2.7299044604225032`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.9190189169020224`*^6", "-", 
        RowBox[{"6.518395930975012`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3190405130742993`*^6", "-", 
        RowBox[{"1.2885546423625017`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.558555673699008`*^6", "-", 
        RowBox[{"8.498861654953334`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"182515.22398030676`", "\[VeryThinSpace]", "-", 
        RowBox[{"99017.91827936261`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.619763992725932`*^6", "+", 
        RowBox[{"5.64221345857222`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.046599485625085`*^6", "+", 
        RowBox[{"1.0724697094965614`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"384392.20722399093`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.7853800306382924`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0617434480286464`*^6", "-", 
        RowBox[{"156057.14856911567`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.987201082155587`*^6", "-", 
        RowBox[{"1.3830604741373672`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.480513270133959`*^6", "-", 
        RowBox[{"1.3860587532044042`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.0671363495992585`*^6", "-", 
        RowBox[{"5.7443730402638335`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.523633374311369`*^6", "-", 
        RowBox[{"833503.1703880504`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2036713570939733`*^7", "-", 
        RowBox[{"9.728226857552962`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.8155853309514793`*^6", "-", 
        RowBox[{"7.71769006899789`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.003099941989488`*^6", "-", 
        RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"502359.21125804656`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.600540582576264`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.1029000263328445`*^6", "-", 
        RowBox[{"2.5696196636149734`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"366795.8177347474`", "\[VeryThinSpace]", "+", 
        RowBox[{"442350.01742923853`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.7509311811371064`*^6", "-", 
        RowBox[{"8.688191660945933`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.8510838410845645`*^7"}], "+", 
        RowBox[{"2.7299044604225043`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.2284177117327973`*^7", "+", 
        RowBox[{"7.649213270090451`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0684198713500213`*^7", "+", 
        RowBox[{"1.282062777440466`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.5127533073618775`*^6", "-", 
        RowBox[{"4.411155133599914`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"426769.52574328845`", "\[VeryThinSpace]", "-", 
        RowBox[{"274561.85696142237`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.3916092229192886`*^6", "+", 
        RowBox[{"1.3232441976576308`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"640600.8140124381`", "\[VeryThinSpace]", "+", 
        RowBox[{"1.361122464695767`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8146677939524215`*^6", "-", 
        RowBox[{"1.6973592847053008`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.032001318887475`*^6", "+", 
        RowBox[{"1.6061550354826597`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.3004389155895986`*^7", "+", 
        RowBox[{"9.48349216978245`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"7.57505109333396`*^7", "-", 
        RowBox[{"6.129246290855033`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.95711767993128`*^7", "+", 
        RowBox[{"7.608709143254558`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.758794826350665`*^6", "+", 
        RowBox[{"3.8825347331615724`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"130975.89411397232`", "\[VeryThinSpace]", "-", 
        RowBox[{"9.820549196138984`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.5208512951636989`*^7", "-", 
        RowBox[{"687885.4729858749`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"113860.00117282028`", "\[VeryThinSpace]", "-", 
        RowBox[{"290362.5610480175`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"551673.6593815817`", "\[VeryThinSpace]", "-", 
        RowBox[{"141212.48898712115`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"101139.30353234243`", "\[VeryThinSpace]", "-", 
        RowBox[{"257701.6615483798`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.5983565374664927`*^8", "+", 
        RowBox[{"5.703492154166019`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084563`*^7"}], "+", 
        RowBox[{"2.7299044604225043`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.10949455572218`*^6", "+", 
        RowBox[{"7.683482431450504`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0709472959549898`*^7", "+", 
        RowBox[{"1.4050632924100503`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.211686039413538`*^6", "+", 
        RowBox[{"616913.9422427565`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"62392.22280974209`", "\[VeryThinSpace]", "+", 
        RowBox[{"370527.2944961453`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"303157.62051085645`", "\[VeryThinSpace]", "+", 
        RowBox[{"539436.5665485344`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "b11"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.004231742293815`*^6", "+", 
        RowBox[{"1.295953657716746`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2634767053091563`*^6", "-", 
        RowBox[{"2.444623954715651`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8796776406378485`*^6", "+", 
        RowBox[{"2.7916029465790866`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0743133554773936`*^7", "+", 
        RowBox[{"1.3270559218325475`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.581904561115936`*^7", "-", 
        RowBox[{"7.113206709919459`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"5.2313911443998575`*^7", "-", 
        RowBox[{"8.30696031946793`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.421369238358328`*^6", "-", 
        RowBox[{"403107.3218998448`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "c4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.746348860287175`*^6", "+", 
        RowBox[{"1.726174195856613`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1697424725190924`*^7", "-", 
        RowBox[{"9.427046365487758`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894898`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"208945.49872237293`", "\[VeryThinSpace]", "-", 
        RowBox[{"479288.9921499861`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "f1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"335534.0839871387`", "\[VeryThinSpace]", "+", 
        RowBox[{"111239.37249281583`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"190882.49638722278`", "\[VeryThinSpace]", "+", 
        RowBox[{"365973.0803015828`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "g2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"4.863945465687379`*^7", "-", 
        RowBox[{"1.010423375068906`*^8", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3.851083841084563`*^7"}], "+", 
        RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.2989977880579433`*^6", "-", 
        RowBox[{"5.356566303963529`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "a2"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"699019.3842302181`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.1723716796613533`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "a3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.838443214005832`*^6", "+", 
        RowBox[{"3.4373000449646846`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"234907.23397522722`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.5466886230347403`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b10"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3.557663895257861`*^6", "-", 
        RowBox[{"1.6060485740657342`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b11"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.272168722502658`*^6", "-", 
        RowBox[{"1.2861725772256993`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b4"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.425137883250901`*^6", "-", 
        RowBox[{"1.886660301408484`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "b7"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"831093.1548903261`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.9433797578045325`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "b8"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2.660425627887668`*^6", "+", 
        RowBox[{"6.361859346637257`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.1454375357650422`*^7", "-", 
        RowBox[{"2.2430641445778694`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.8489358455459125`*^7", "-", 
        RowBox[{"2.7363601303587634`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c3"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0509906941213492`*^7", "-", 
        RowBox[{"9.829675557913061`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c4"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.4000546639387919`*^7", "+", 
        RowBox[{"6.759686474607787`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "c5"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.61389265411437`*^7", "+", 
        RowBox[{"2.7040968866532817`*^7", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "c6"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.0030999419894936`*^6", "-", 
        RowBox[{"5.07542911928454`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
      "e3"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"256108.52884271834`", "\[VeryThinSpace]", "-", 
        RowBox[{"1.0321437882223977`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "f1"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"32737.021546650096`", "\[VeryThinSpace]", "-", 
        RowBox[{"3.1108198611945137`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "g1"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"8.472375214698045`*^6", "-", 
        RowBox[{"2.807192697727996`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "g2"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"6.7387939025718495`*^6", "-", 
        RowBox[{"6.016165640132248`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ",
       "ii"}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"9.59193288301334`*^6", "+", 
        RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], 
      " ", "\[Lambda]"}]}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619236713396962*^9, 3.619236880539884*^9, 3.619237000579589*^9, 
   3.619237048379258*^9, 3.61923709189137*^9, 3.6192372281109953`*^9, 
   3.6192372963930597`*^9, 3.619237786267847*^9, {3.619237908284073*^9, 
   3.619238012603725*^9}, 3.61923807139123*^9, 3.619238141755127*^9, 
   3.619238228754908*^9, 3.619238263802507*^9, {3.619238301836074*^9, 
   3.619238359174882*^9}, 3.6192401896951847`*^9, 3.6192429198033333`*^9, 
   3.619243668751142*^9, 3.61924623881572*^9, {3.61924640579837*^9, 
   3.619246412663979*^9}, 3.6192469862046127`*^9, 3.6192472491922073`*^9, 
   3.6192474671861477`*^9, 3.619250329849607*^9, 3.619253124165639*^9, 
   3.6192544141567593`*^9, 3.619259600225254*^9, 3.619259870585545*^9, 
   3.619259916232139*^9, 3.61925997003017*^9, 3.619343683831526*^9, 
   3.619412731615349*^9, 3.619413272516634*^9, 3.6194152394965143`*^9, 
   3.619418816156578*^9, 3.6194198994658127`*^9, 3.619423008084231*^9, 
   3.6194274869599247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "amp4$qlightcone2$ward2", "]"}]], "Input",
 CellChangeTimes->{{3.619413298708581*^9, 3.619413300534478*^9}}],

Cell[BoxData[
 FormBox["40", TraditionalForm]], "Output",
 CellChangeTimes->{3.619413300760298*^9, 3.619415239528617*^9, 
  3.619418817221367*^9, 3.619419899590777*^9, 3.619423008169565*^9, 
  3.619427487197754*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4$qlightcone2$ward2", "[", 
  RowBox[{"[", "10", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.619246246845746*^9, 3.619246247318962*^9}, {
   3.619246445896468*^9, 3.619246449407371*^9}, {3.61924699790209*^9, 
   3.61924700749713*^9}, {3.6192472050257587`*^9, 3.619247205197611*^9}, {
   3.6192474889175587`*^9, 3.619247495105204*^9}, 3.619413311402684*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"786232.4268324815`", "\[VeryThinSpace]", "-", 
       RowBox[{"1.3007370896815754`*^7", " ", "\[ImaginaryI]"}]}], ")"}]}], 
    " ", "a3"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"639462.0125757006`", "\[VeryThinSpace]", "-", 
      RowBox[{"584691.8819548661`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "g1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "3.851083841084564`*^7"}], "+", 
      RowBox[{"2.729904460422504`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a1"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.386210830660205`*^6", "-", 
      RowBox[{"6.640220404165751`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "a2"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"9.126041668514423`*^6", "-", 
      RowBox[{"2.257610498387336`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b1"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.7043911612910992`*^6", "+", 
      RowBox[{"2.0329107018730508`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b10"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.3295245792910517`*^6", "-", 
      RowBox[{"765887.4747229584`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b11"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.363565728991463`*^6", "+", 
      RowBox[{"1.5934704941916201`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b4"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2.3221295247469093`*^6", "-", 
      RowBox[{"3.219976456124636`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b7"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.1456793760779959`*^6", "+", 
      RowBox[{"3.972168333842788`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "b8"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.2262758392297295`*^6", "-", 
      RowBox[{"208025.45695687574`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c1"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.531604576198384`*^6", "-", 
      RowBox[{"2.8422147081120826`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c2"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4.383752069635473`*^6", "-", 
      RowBox[{"2.9334382408587046`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c3"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.8556641783804875`*^6", "+", 
      RowBox[{"5.357496849248815`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c4"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"6.448095006722067`*^6", "-", 
      RowBox[{"9.449855291414928`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c5"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3.788799325641487`*^7", "-", 
      RowBox[{"3.9019167126739398`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "c6"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.0030999419894898`*^6", "-", 
      RowBox[{"5.075429119284541`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "e3"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.2709641053150855`*^6", "+", 
      RowBox[{"735321.0114136653`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "f1"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1.1657022971755564`*^6", "+", 
      RowBox[{"4.0724367110022833`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "g2"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"8.75627535410769`*^6", "-", 
      RowBox[{"1.2841208262835942`*^7", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "ii"}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"9.59193288301334`*^6", "+", 
      RowBox[{"7.6389521192266885`*^6", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
    "\[Lambda]"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619246247927534*^9, {3.619246431180839*^9, 3.619246449750126*^9}, {
   3.619246999551182*^9, 3.6192470082780323`*^9}, 3.619247249301611*^9, {
   3.619247474848068*^9, 3.6192474954243193`*^9}, 3.619253143481003*^9, 
   3.619254507782629*^9, 3.619343684071299*^9, 3.619412731774173*^9, {
   3.61941330458409*^9, 3.619413312008706*^9}, 3.619415239565143*^9, 
   3.6194188200596333`*^9, 3.6194198998482103`*^9, 3.619423008253044*^9, 
   3.6194274872736387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"amp4$qlightcone2$ward2", "[", 
      RowBox[{"[", "iq", "]"}], "]"}], "\[Equal]", "0"}], ",", 
    RowBox[{"{", 
     RowBox[{"iq", ",", "1", ",", 
      RowBox[{"Length", "[", "solsQ", "]"}]}], "}"}]}], "]"}], "]"}]], "Input",\

 CellChangeTimes->{{3.619413702328198*^9, 3.619413735638481*^9}, {
  3.6194143354943523`*^9, 3.619414376255455*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.07951478512718238`", "\[VeryThinSpace]", "-", 
          RowBox[{"0.07542685574416659`", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"0.07218761281162711`", "\[VeryThinSpace]", "+", 
          RowBox[{"0.24952988243791333`", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "0.0503520540476111`"}], "+", 
          RowBox[{"0.12964110181210323`", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "a3"}]}]}], ",", 
     RowBox[{"a2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1.0000000000000004`"}], "+", 
          RowBox[{"4.440892098500626`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "a3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4.1964330919774103`*^-16", "-", 
          RowBox[{"6.4331840265442`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"7.993335365284748`*^-16", "+", 
          RowBox[{"4.124914185757269`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.9626160861486464`*^-16", "+", 
          RowBox[{"7.641657453746306`*^-15", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"9.328304890128626`*^-15", "+", 
          RowBox[{"1.283657845041829`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}]}]}], ",", 
     RowBox[{"b10", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8.047085235178438`*^-15", "-", 
          RowBox[{"5.977258098726591`*^-15", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.8382619534964554`*^-14", "+", 
          RowBox[{"1.2613521184390291`*^-14", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b11", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.8716558961209384`*^-14", "+", 
          RowBox[{"7.985393404055307`*^-14", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8.427276722035025`*^-14", "-", 
          RowBox[{"3.872542822263188`*^-15", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.3672073791695386`*^-15", "-", 
          RowBox[{"8.807793844240924`*^-15", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8.701962739331477`*^-15", "+", 
          RowBox[{"2.8402133778425197`*^-15", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b7", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.71538819241668`*^-14", "+", 
          RowBox[{"7.944379266546478`*^-14", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.0861199449729013`*^-13", "-", 
          RowBox[{"3.2977510106751986`*^-14", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"b8", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5.03715552980251`*^-14"}], "-", 
          RowBox[{"1.1233490710065761`*^-13", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.4457392392963995`*^-13", "-", 
          RowBox[{"3.83646364534041`*^-15", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c1", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "4.790806117070634`*^-16"}], "+", 
          RowBox[{"2.1768485808278966`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.167106089147039`*^-15", "+", 
          RowBox[{"5.641516899596997`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c2", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2.1468591410012562`*^-16", "-", 
          RowBox[{"5.1984457223634385`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.6639827643862977`*^-16", "-", 
          RowBox[{"2.554770874797483`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}]}]}], ",", 
     RowBox[{"c3", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"8.260663540582104`*^-17", "+", 
          RowBox[{"2.5460495403959506`*^-18", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.4371814239454642`*^-16", "-", 
          RowBox[{"1.8941692554764946`*^-17", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c4", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"6.966501500185964`*^-16", "+", 
          RowBox[{"3.5225799841437483`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "\[Lambda]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4.17500299237418`*^-17", "-", 
          RowBox[{"5.512348489240874`*^-18", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "e3"}]}]}], ",", 
     RowBox[{"c5", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3.697443291337661`*^-17", "+", 
          RowBox[{"1.6055444280998753`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5.908436697555099`*^-17", "-", 
          RowBox[{"3.475662723966653`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"c6", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6.616829527552265`*^-18"}], "+", 
          RowBox[{"1.1242686773041107`*^-16", " ", "\[ImaginaryI]"}]}], ")"}],
         " ", "e3"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"7.903857492323913`*^-17", "-", 
          RowBox[{"7.43837383260798`*^-17", " ", "\[ImaginaryI]"}]}], ")"}], 
        " ", "\[Lambda]"}]}]}], ",", 
     RowBox[{"f1", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2.5887662629902525`*^-15"}], "-", 
         RowBox[{"4.8786081164154485`*^-15", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}], ",", 
     RowBox[{"g1", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "8.302301841087609`*^-16"}], "+", 
         RowBox[{"1.8823673950446595`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}], ",", 
     RowBox[{"g2", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1.457042042253443`*^-17"}], "+", 
         RowBox[{"1.7337845169389598`*^-16", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}], ",", 
     RowBox[{"ii", "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4.489546184179906`*^-19", "+", 
         RowBox[{"8.261478696198895`*^-19", " ", "\[ImaginaryI]"}]}], ")"}], 
       " ", "\[Lambda]"}]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.6194143643092527`*^9, 3.619414376854364*^9}, 
   3.619415240669402*^9, 3.6194188297808743`*^9, 3.6194199016696253`*^9, 
   3.6194230102433567`*^9, 3.6194274876264353`*^9}]
}, Open  ]],

Cell[TextData[{
 "Compare this to the numerically evaluated Ward identity of the original ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "4"], TraditionalForm]]],
 "-amplitude:"
}], "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.619174112444458*^9, {3.619242955678088*^9, 
   3.619242977714387*^9}, {3.619413412521263*^9, 3.619413414903133*^9}},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"amp4num", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"amp4", "/.", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"rules0", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", "rulesward1", ",", 
       "rulesward3"}], "]"}]}], ")"}], "/.", 
   RowBox[{"Join", "[", 
    RowBox[{"rules1", ",", "rules3"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.619243050186409*^9, 3.6192431000563173`*^9}, {
  3.6192467286478443`*^9, 3.6192467330975037`*^9}, {3.619413371671934*^9, 
  3.619413428705387*^9}, {3.619413490652618*^9, 3.61941350744374*^9}, {
  3.6194275300716543`*^9, 3.619427556238023*^9}}],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   TagBox[
    PanelBox[GridBox[{
       {
        StyleBox[
         StyleBox[
          DynamicBox[ToBoxes[
            FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
            TraditionalForm],
           ImageSizeCache->{280., {2., 8.}}],
          StripOnInput->False,
          DynamicUpdating->True], "Panel",
         StripOnInput->False,
         Background->None]},
       {
        ItemBox[
         TagBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              FractionBox["63411962637626237", "188655375000"]}], "+", 
             FractionBox[
              RowBox[{"17750293252361791", " ", "\[ImaginaryI]"}], 
              "47163843750"]}], ")"}], "+", 
           RowBox[{"\[LeftSkeleton]", "389", "\[RightSkeleton]"}]}],
          Short[#, 5]& ],
         Background->GrayLevel[1],
         BaseStyle->{Deployed -> False},
         Frame->True,
         FrameStyle->GrayLevel[0, 0.2],
         StripOnInput->False]},
       {
        RowBox[{
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
              TraditionalForm],
             ImageSizeCache->{47., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1341, 23719710895012768101, 5/2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
              TraditionalForm],
             ImageSizeCache->{52., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1341, 23719710895012768101, 5 2],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
              TraditionalForm],
             ImageSizeCache->{39., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          
          ButtonFunction:>OutputSizeLimit`ButtonFunction[
           Identity, 1341, 23719710895012768101, Infinity],
          Enabled->True,
          Evaluator->Automatic,
          Method->"Queued"], "\[ThinSpace]", 
         ButtonBox[
          StyleBox[
           StyleBox[
            DynamicBox[ToBoxes[
              FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
              TraditionalForm],
             ImageSizeCache->{69., {0., 8.}}],
            StripOnInput->False,
            DynamicUpdating->True], "Panel",
           StripOnInput->False,
           Background->None],
          Appearance->Automatic,
          ButtonFunction:>FrontEndExecute[{
             FrontEnd`SetOptions[
             FrontEnd`$FrontEnd, 
              FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
             FrontEnd`FrontEndToken["PreferencesDialog"]}],
          Evaluator->None,
          Method->"Preemptive"]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[1.2]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     DefaultBaseStyle->{},
     FrameMargins->5],
    Deploy,
    DefaultBaseStyle->{Deployed -> True}],
   Out[1341]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619243053214594*^9, 3.61924310115626*^9}, 
   3.619243677202939*^9, {3.619246729606061*^9, 3.619246733653371*^9}, 
   3.619247012573942*^9, 3.619247502133204*^9, 3.619250329939883*^9, 
   3.6192531477574863`*^9, 3.61925451665207*^9, 3.61934368413831*^9, 
   3.619412731846592*^9, {3.619413372848015*^9, 3.6194133930922127`*^9}, 
   3.619413429440604*^9, {3.6194134911143084`*^9, 3.619413508199016*^9}, 
   3.619415240726199*^9, 3.619418830963575*^9, 3.619419901806731*^9, 
   3.619423010332466*^9, 3.6194274879565067`*^9, {3.619427539785286*^9, 
   3.619427546852872*^9}, 3.619427711010744*^9}]
}, Open  ]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.619174112444458*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
   3.604652950305522*^9}, 3.604653026772519*^9},
 Background->RGBColor[1, 0.9, 0.8]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.604042935997448*^9, 3.604042971436841*^9}, {
   3.604043063493135*^9, 3.604043070644614*^9}, {3.60430340517163*^9, 
   3.6043034633630657`*^9}, {3.604303523284161*^9, 3.604303539738551*^9}, {
   3.604303600891077*^9, 3.604303621098654*^9}, {3.604304186403475*^9, 
   3.604304187986342*^9}, {3.6046531184447403`*^9, 3.604653118866461*^9}, {
   3.604893189378476*^9, 3.604893268806697*^9}, {3.60499160502872*^9, 
   3.6049916639837723`*^9}, {3.604992114337017*^9, 3.60499214330122*^9}, {
   3.611054494422735*^9, 3.611054510776617*^9}, {3.611054642842409*^9, 
   3.611054648553751*^9}, {3.612086540287354*^9, 3.6120865657436028`*^9}, {
   3.612686268454589*^9, 3.612686274530767*^9}, {3.6144167808240223`*^9, 
   3.61441683473438*^9}, {3.614418373717383*^9, 3.614418376652417*^9}, {
   3.614502658202116*^9, 3.614502658873498*^9}, {3.614586529884842*^9, 
   3.614586533937353*^9}, 3.619174112444458*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell["", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.604652925172988*^9, 
   3.604652950305522*^9}, 3.604653026772519*^9},
 Background->RGBColor[1, 0.9, 0.8]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["B-field propagator in q-lightcone gauge", "Subsection",
 CellChangeTimes->{{3.6194194195745707`*^9, 3.6194194456943274`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "j"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"s", ",", "t"}], "]"}]}], "+", 
       RowBox[{"a2", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "s"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"j", ",", "t"}], "]"}]}], "+", 
       RowBox[{"a3", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "t"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"j", ",", "s"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b7", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b8", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b9", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b10", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"b11", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"b12", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"c2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"c3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"c4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"c5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"c6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}], 
       "+", 
       RowBox[{"d", " ", 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "j"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "s"}], "]"}], 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "t"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"e1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}], 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"f2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"f3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"f4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"f5", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"f6", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"g1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "3"}], ")"}]}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "+", 
          RowBox[{"h4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "+", 
          RowBox[{"h6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "o"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "o"}], "]"}]}], "]"}]}], "+", 
       RowBox[{"ii", " ", 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "j"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}], 
        RowBox[{
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "4"}], 
          ")"}]}]}]}], ")"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6179703517595673`*^9, 3.617970779129396*^9}, {
   3.617970879468876*^9, 3.617970919076379*^9}, {3.6179709519702663`*^9, 
   3.6179709533780193`*^9}, {3.617970984844159*^9, 3.61797114731628*^9}, {
   3.6179714109042788`*^9, 3.6179714542681723`*^9}, {3.617971514353078*^9, 
   3.617971601477254*^9}, {3.617971643385899*^9, 3.6179718972932*^9}, 
   3.6179719296959248`*^9, 3.617972009927199*^9, 3.617972050362486*^9, 
   3.6179724567357693`*^9, {3.617972660466942*^9, 3.617972672014579*^9}, 
   3.61797289536517*^9, {3.617972978809762*^9, 3.617972982014348*^9}, {
   3.617973026458253*^9, 3.6179730287227707`*^9}, 3.61803425058486*^9, {
   3.6180357071967497`*^9, 3.618035710039319*^9}, {3.618052871007208*^9, 
   3.618052921229148*^9}, {3.618052978179215*^9, 3.618053074353793*^9}, {
   3.618140015348394*^9, 3.6181400387410088`*^9}, {3.618140078679212*^9, 
   3.618140140134884*^9}, {3.618140224639729*^9, 3.618140275649692*^9}, {
   3.618140349871594*^9, 3.618140350074747*^9}, 3.618202878154153*^9, {
   3.618735662852004*^9, 3.618735698391954*^9}, {3.619342635843162*^9, 
   3.6193426480919933`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b9", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b12", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f4", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"d", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"ii", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6193440182432213`*^9, 3.6195131006723347`*^9, 
  3.619519228246482*^9}]
}, Open  ]],

Cell[TextData[{
 "Starting with the most generic ansatz with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["q", "2"], "=", "0"}], TraditionalForm]]],
 " we first restrict the coefficients such that:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["w", "abcd"], 
      SuperscriptBox["q", "a"]}], "=", "0"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["w", "abcd"], 
      SuperscriptBox["q", "b"]}], "=", "0"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["w", "abcd"], "=", 
     RowBox[{
      SubscriptBox["w", 
       RowBox[{
        RowBox[{"[", "ab", "]"}], "cd"}]], "=", 
      SubscriptBox["w", 
       RowBox[{"ab", "[", "cd", "]"}]]}]}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVtIk2EAh/FVuOFQmMtRpBkLWQNNc8KYsyWvpQ0VQwV1XnRh2/AuKhP1
05SKoLZSjHSihR0giZqizsOMjl4UE1zaQfs2CVchL15s9lWQOnv/38XD7+JR
154tt+2USCQaFjRHzqxnf6bEfyIkwAfXzY6jzHCwSjQh3vcJxmy+W4KXbPnH
ZF8ocQ7xeTDg1XXAK3fedsLv6kqpktkQvipq0ytyoLY/3whTWvS8jvlIPiea
mapuysXX/uPg7XafjmdaDy6bRM2t0cWvlHj8bduwf6Sv+yJPySiZccGTS2Wt
DUyfibZD4bV1BDpzVkUd3PkFWHlrdhFauLsrsHRvxk+ouRk5PfaLkuqBYjsM
9oT28Mzdybn7oHBclQID+7kDsPeHQhpkjhcbYqFn3hkPNwb6VNAgmVJOC5Q8
dKsSoWL6hv05c96eVAc/Hp6aDTF3vKyZg5uc60nMb0pcJW+ewlPDLzxQ453w
wrqEmW8ypkVmCcFOXrqRzjQK0S0YtZ7zZDDXnhVMwiMrW34YqOA+wLA7LSuT
WavsEs061KaHhfcvEGhKjhTBcmNvCRwsWqiHNe/DjdA9XH95+w8lqY/TrsHS
2F0OeO9Vcxcc18njtH8pKcvrEPUP2tMtzKg8zgD/A5AEVQQ=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sys", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "dd"}], "]"}], "+", 
             RowBox[{"w", "[", 
              RowBox[{"b", ",", "a", ",", "c", ",", "dd"}], "]"}]}], 
            "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "dd"}], "]"}], "+", 
             RowBox[{"w", "[", 
              RowBox[{"a", ",", "b", ",", "dd", ",", "c"}], "]"}]}], 
            "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{"Expand", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "]"}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{"Expand", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "j"}], "]"}]}], "]"}], "]"}], "\[Equal]", 
            "0"}]}], "}"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
          "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ii", "\[Rule]", "0"}], ",", 
         RowBox[{"g2", "\[Rule]", "0"}], ",", 
         RowBox[{"c5", "\[Rule]", "0"}], ",", 
         RowBox[{"g1", "\[Rule]", "0"}], ",", 
         RowBox[{"f1", "\[Rule]", "0"}], ",", 
         RowBox[{"c6", "\[Rule]", "0"}], ",", 
         RowBox[{"b4", "\[Rule]", "0"}], ",", 
         RowBox[{"a1", "\[Rule]", "0"}], ",", 
         RowBox[{"b1", "\[Rule]", "0"}], ",", 
         RowBox[{"h6", "\[Rule]", "0"}], ",", 
         RowBox[{"f6", "\[Rule]", "0"}], ",", 
         RowBox[{"e2", "\[Rule]", "0"}], ",", 
         RowBox[{"d", "\[Rule]", "0"}], ",", 
         RowBox[{"e1", "\[Rule]", "0"}], ",", 
         RowBox[{"h1", "\[Rule]", "0"}], ",", 
         RowBox[{"c4", "\[Rule]", 
          RowBox[{"-", "c3"}]}], ",", 
         RowBox[{"b11", "\[Rule]", 
          RowBox[{"-", "b8"}]}], ",", 
         RowBox[{"c2", "\[Rule]", 
          RowBox[{"-", "c1"}]}], ",", 
         RowBox[{"b10", "\[Rule]", 
          RowBox[{"-", "b7"}]}], ",", 
         RowBox[{"g4", "\[Rule]", 
          RowBox[{"-", "g3"}]}], ",", 
         RowBox[{"f5", "\[Rule]", 
          RowBox[{"-", "f2"}]}], ",", 
         RowBox[{"b12", "\[Rule]", 
          RowBox[{"-", "b9"}]}], ",", 
         RowBox[{"f4", "\[Rule]", 
          RowBox[{"-", "f3"}]}], ",", 
         RowBox[{"e4", "\[Rule]", 
          RowBox[{"-", "e3"}]}], ",", 
         RowBox[{"b6", "\[Rule]", 
          RowBox[{"-", "b5"}]}], ",", 
         RowBox[{"b3", "\[Rule]", 
          RowBox[{"-", "b2"}]}], ",", 
         RowBox[{"h5", "\[Rule]", 
          RowBox[{"-", "h4"}]}], ",", 
         RowBox[{"h3", "\[Rule]", 
          RowBox[{"-", "h2"}]}], ",", 
         RowBox[{"a3", "\[Rule]", 
          RowBox[{"-", "a2"}]}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b9", "\[Rule]", "0"}], ",", 
       RowBox[{"e3", "\[Rule]", "0"}], ",", 
       RowBox[{"g3", "\[Rule]", "0"}], ",", 
       RowBox[{"f3", "\[Rule]", 
        RowBox[{"-", "f2"}]}], ",", 
       RowBox[{"c3", "\[Rule]", "c1"}], ",", 
       RowBox[{"b8", "\[Rule]", 
        RowBox[{"-", "b7"}]}], ",", 
       RowBox[{"b5", "\[Rule]", 
        RowBox[{"-", "b2"}]}], ",", 
       RowBox[{"h4", "\[Rule]", 
        RowBox[{"-", "h2"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h2", "\[Rule]", "0"}], ",", 
     RowBox[{"b2", "\[Rule]", "a2"}], ",", 
     RowBox[{"f2", "\[Rule]", 
      RowBox[{"-", "b7"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618736039868785*^9, 3.6187361229945707`*^9}, {
  3.618736172901292*^9, 3.6187362638114233`*^9}, {3.618736373365267*^9, 
  3.6187365127096252`*^9}, {3.618736543974063*^9, 3.618736704892205*^9}, {
  3.618736805831768*^9, 3.618736808003583*^9}, {3.618740688101403*^9, 
  3.618740700612451*^9}, {3.618907256931685*^9, 3.618907258880978*^9}, {
  3.6193427990585737`*^9, 3.619342882962376*^9}, {3.61934407829175*^9, 
  3.619344372349032*^9}, {3.6193444297212133`*^9, 3.6193444465401154`*^9}, {
  3.61934460414895*^9, 3.619344844114943*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619159224269464*^9, 3.6193382099981613`*^9, 3.619344026217037*^9, 
   3.619344089501408*^9, {3.619344147609438*^9, 3.6193441568466377`*^9}, 
   3.619344254034203*^9, {3.6193443305568247`*^9, 3.619344374989933*^9}, 
   3.619344447591009*^9, {3.619344605057809*^9, 3.619344632438489*^9}, {
   3.619344680398192*^9, 3.619344705248294*^9}, {3.619344748027232*^9, 
   3.619344845363861*^9}, 3.619513108185115*^9, 3.619519235566104*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"w", "[", 
       RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ii", "\[Rule]", "0"}], ",", 
        RowBox[{"g2", "\[Rule]", "0"}], ",", 
        RowBox[{"c5", "\[Rule]", "0"}], ",", 
        RowBox[{"g1", "\[Rule]", "0"}], ",", 
        RowBox[{"f1", "\[Rule]", "0"}], ",", 
        RowBox[{"c6", "\[Rule]", "0"}], ",", 
        RowBox[{"b4", "\[Rule]", "0"}], ",", 
        RowBox[{"a1", "\[Rule]", "0"}], ",", 
        RowBox[{"b1", "\[Rule]", "0"}], ",", 
        RowBox[{"h6", "\[Rule]", "0"}], ",", 
        RowBox[{"f6", "\[Rule]", "0"}], ",", 
        RowBox[{"e2", "\[Rule]", "0"}], ",", 
        RowBox[{"d", "\[Rule]", "0"}], ",", 
        RowBox[{"e1", "\[Rule]", "0"}], ",", 
        RowBox[{"h1", "\[Rule]", "0"}], ",", 
        RowBox[{"c4", "\[Rule]", 
         RowBox[{"-", "c3"}]}], ",", 
        RowBox[{"b11", "\[Rule]", 
         RowBox[{"-", "b8"}]}], ",", 
        RowBox[{"c2", "\[Rule]", 
         RowBox[{"-", "c1"}]}], ",", 
        RowBox[{"b10", "\[Rule]", 
         RowBox[{"-", "b7"}]}], ",", 
        RowBox[{"g4", "\[Rule]", 
         RowBox[{"-", "g3"}]}], ",", 
        RowBox[{"f5", "\[Rule]", 
         RowBox[{"-", "f2"}]}], ",", 
        RowBox[{"b12", "\[Rule]", 
         RowBox[{"-", "b9"}]}], ",", 
        RowBox[{"f4", "\[Rule]", 
         RowBox[{"-", "f3"}]}], ",", 
        RowBox[{"e4", "\[Rule]", 
         RowBox[{"-", "e3"}]}], ",", 
        RowBox[{"b6", "\[Rule]", 
         RowBox[{"-", "b5"}]}], ",", 
        RowBox[{"b3", "\[Rule]", 
         RowBox[{"-", "b2"}]}], ",", 
        RowBox[{"h5", "\[Rule]", 
         RowBox[{"-", "h4"}]}], ",", 
        RowBox[{"h3", "\[Rule]", 
         RowBox[{"-", "h2"}]}], ",", 
        RowBox[{"a3", "\[Rule]", 
         RowBox[{"-", "a2"}]}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"b9", "\[Rule]", "0"}], ",", 
      RowBox[{"e3", "\[Rule]", "0"}], ",", 
      RowBox[{"g3", "\[Rule]", "0"}], ",", 
      RowBox[{"f3", "\[Rule]", 
       RowBox[{"-", "f2"}]}], ",", 
      RowBox[{"c3", "\[Rule]", "c1"}], ",", 
      RowBox[{"b8", "\[Rule]", 
       RowBox[{"-", "b7"}]}], ",", 
      RowBox[{"b5", "\[Rule]", 
       RowBox[{"-", "b2"}]}], ",", 
      RowBox[{"h4", "\[Rule]", 
       RowBox[{"-", "h2"}]}]}], "}"}]}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"h2", "\[Rule]", "0"}], ",", 
    RowBox[{"b2", "\[Rule]", "a2"}], ",", 
    RowBox[{"f2", "\[Rule]", 
     RowBox[{"-", "b7"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619344865396747*^9, 3.619344871438109*^9}, {
  3.619346338533216*^9, 3.619346368271214*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619344872446163*^9, {3.6193463481406612`*^9, 3.619346369115699*^9}, 
   3.6195131086124077`*^9, 3.6195192357806*^9}]
}, Open  ]],

Cell["w is now given in terms of a2, b7, c1.", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyV1IU2EAh/FVuOHS2FarKDMmYguXywVjzpa89jWcLDTQNqIL24Zd9aWi
nZZSEdRWilFNtLAPSKKWWLOc0adEMWFLrbSzRbiKOBRsdbJInb3/c/Hwu3hU
NfsrnfNFItFaGjQn9/7c8I4jkS1xHl47bfZspCZi1YLyzNBbmDbzagIec5Zu
krzniPcuWwKjQV0rPHHhRRv8rKoSK6gNiZOCTr2sCKq7So0w+6ie1VFvSMOC
2lxVUzG++h8Dz7eEdCzVkfPRJGh2p8Y/cCQQaZ6DXX2dF+tZjtwjQz64faLC
3UANmbgWyD9z9EFv0TdBD3NoFFadGx6HNubyJLQuL/gK884m99z/xZFd3RYX
jF2KL2Opi7OKV0B+szIbRlcxq2HHF5k4Ru23GNJhYMSbCae7O5XQIBpQDPIc
ue5XLoGywTOuR9QR18paOLZuYDhOnffEHoYzjO9W2m+O+Mqf34Y7eh8HYF7w
QRDWyoc+Sag2iS0O21jxtIZq5FOzMOU4GCigfr+z9SFcPzkbgdGdzBuY8OcX
aqk1inbBwjXNerjt6mECTVnJMlhp7CiHPWWjddD+OtEI/b11x+emOJJ7M/8U
tKYv8MArT4+0w36dNEP9hyMVJa2CkR6XxkZNSTMMUPNjXzVcqv27G4brF1rt
1LGXOYKLLPJGOOU+0AT/A+nhbkQ=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "1"}], "/", "4"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "c"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"x", ",", "y"}], "]"}]}], "-", 
     RowBox[{"2", 
      RowBox[{"d", "[", 
       RowBox[{"a", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"b", ",", "d"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"c", ",", "x"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.61934293535236*^9, 3.619342970882812*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["g", 
       RowBox[{"a", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"c", "x"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"a", "c"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"b", "d"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"x", "y"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619344026333817*^9, 3.619344888700067*^9, 
  3.6193463909228077`*^9, 3.6195131089801064`*^9, 3.6195192358252153`*^9}]
}, Open  ]],

Cell[TextData[{
 "The mixed terms are the following expression contracted into ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["J", "st"]}], 
    RowBox[{
     SubscriptBox["b", "mn"], "'"}]}], TraditionalForm]]],
 ".\n"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyWtIU2EAh/FVuOFSmKtVlBkTWQuXywVjzpa8dhsqCw20reiDbcM+RTWl
OplSEdRWit0ms7ALJFFLrFnO6CqRbLClVtrZIlxFHAq2Ol1Inb3/8+Hh9+FR
1u+tccwViUSraNCc2v1j7VuORDcmeHjtlNm9jpqM1wnmZIfewIzpVxPwqKN8
veQdRzx32TIYC+ra4PELL9rhJ2WtWE5tSp4QdOhlJVDdVW6EeUf0rI56QxoR
1BYoD5Xiq/8x8FxrSMdS7fkfTILm5vT4e44Eoi2zsKvPd7GR5cg9MuSFWyaq
m5uoIRPXCvln9j7oKfkq6Gb2j8Las+FxaGUuT0LLkqIvUHUmtev+T45s7650
wvilxGKWuiC3dCnkNyjyYGw5swJ2fpaJ49T+SkMmDIx4suFUt08BDaIB+SDP
ket+xUIoGzztfEQdcS5rgGOrB8IJ6pwntgicZry3Mn5xxFv1/Dbc2vs4AFXB
B0HYkDP0UUK1SqwJ2M6KpzRUI5+egWn7vkAR9dudTQ/hmsmZKIxtY17DpL+w
WEutl3cIFq9s0cPNVw8QaMpNVcAaY2cV7KkYdUHbcPIg9Pe6js3+5kjBzcKT
0JI5zw2vPD3cAft10iz1H45Ul7UJRnucGis1Lc0yQM33PXVwkfbvThhpnG+x
Ucde5gv6zMOqHdTzrrDgf/W0btQ=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixed", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{"Expand", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"T", "[", 
              RowBox[{"m", ",", "n", ",", "c", ",", "d", ",", "x", ",", "y"}],
               "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "x"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "y"}], "]"}], " ", 
             RowBox[{"w", "[", 
              RowBox[{"c", ",", "d", ",", "s", ",", "t"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"T", "[", 
              RowBox[{"a", ",", "b", ",", "m", ",", "n", ",", "x", ",", "y"}],
               "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "x"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "y"}], "]"}], 
             RowBox[{"w", "[", 
              RowBox[{"a", ",", "b", ",", "s", ",", "t"}], "]"}]}], "-", 
            RowBox[{
             RowBox[{"d", "[", 
              RowBox[{"s", ",", "m"}], "]"}], 
             RowBox[{"d", "[", 
              RowBox[{"t", ",", "n"}], "]"}]}]}], "]"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ii", "\[Rule]", "0"}], ",", 
           RowBox[{"g2", "\[Rule]", "0"}], ",", 
           RowBox[{"c5", "\[Rule]", "0"}], ",", 
           RowBox[{"g1", "\[Rule]", "0"}], ",", 
           RowBox[{"f1", "\[Rule]", "0"}], ",", 
           RowBox[{"c6", "\[Rule]", "0"}], ",", 
           RowBox[{"b4", "\[Rule]", "0"}], ",", 
           RowBox[{"a1", "\[Rule]", "0"}], ",", 
           RowBox[{"b1", "\[Rule]", "0"}], ",", 
           RowBox[{"h6", "\[Rule]", "0"}], ",", 
           RowBox[{"f6", "\[Rule]", "0"}], ",", 
           RowBox[{"e2", "\[Rule]", "0"}], ",", 
           RowBox[{"d", "\[Rule]", "0"}], ",", 
           RowBox[{"e1", "\[Rule]", "0"}], ",", 
           RowBox[{"h1", "\[Rule]", "0"}], ",", 
           RowBox[{"c4", "\[Rule]", 
            RowBox[{"-", "c3"}]}], ",", 
           RowBox[{"b11", "\[Rule]", 
            RowBox[{"-", "b8"}]}], ",", 
           RowBox[{"c2", "\[Rule]", 
            RowBox[{"-", "c1"}]}], ",", 
           RowBox[{"b10", "\[Rule]", 
            RowBox[{"-", "b7"}]}], ",", 
           RowBox[{"g4", "\[Rule]", 
            RowBox[{"-", "g3"}]}], ",", 
           RowBox[{"f5", "\[Rule]", 
            RowBox[{"-", "f2"}]}], ",", 
           RowBox[{"b12", "\[Rule]", 
            RowBox[{"-", "b9"}]}], ",", 
           RowBox[{"f4", "\[Rule]", 
            RowBox[{"-", "f3"}]}], ",", 
           RowBox[{"e4", "\[Rule]", 
            RowBox[{"-", "e3"}]}], ",", 
           RowBox[{"b6", "\[Rule]", 
            RowBox[{"-", "b5"}]}], ",", 
           RowBox[{"b3", "\[Rule]", 
            RowBox[{"-", "b2"}]}], ",", 
           RowBox[{"h5", "\[Rule]", 
            RowBox[{"-", "h4"}]}], ",", 
           RowBox[{"h3", "\[Rule]", 
            RowBox[{"-", "h2"}]}], ",", 
           RowBox[{"a3", "\[Rule]", 
            RowBox[{"-", "a2"}]}]}], "}"}]}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b9", "\[Rule]", "0"}], ",", 
         RowBox[{"e3", "\[Rule]", "0"}], ",", 
         RowBox[{"g3", "\[Rule]", "0"}], ",", 
         RowBox[{"f3", "\[Rule]", 
          RowBox[{"-", "f2"}]}], ",", 
         RowBox[{"c3", "\[Rule]", "c1"}], ",", 
         RowBox[{"b8", "\[Rule]", 
          RowBox[{"-", "b7"}]}], ",", 
         RowBox[{"b5", "\[Rule]", 
          RowBox[{"-", "b2"}]}], ",", 
         RowBox[{"h4", "\[Rule]", 
          RowBox[{"-", "h2"}]}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h2", "\[Rule]", "0"}], ",", 
       RowBox[{"b2", "\[Rule]", "a2"}], ",", 
       RowBox[{"f2", "\[Rule]", 
        RowBox[{"-", "b7"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "m"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "n"}], "]"}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.619343088326528*^9, 3.6193431592784*^9}, {
  3.619343449142192*^9, 3.619343459751338*^9}, {3.619344916020316*^9, 
  3.6193449936098337`*^9}, {3.6193450406949263`*^9, 3.6193450420955353`*^9}, {
  3.619346745876843*^9, 3.619346781902206*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619344969765562*^9, 3.619344999223496*^9}, 
   3.619345046190477*^9, 3.619345111447053*^9, 3.619346481397852*^9, 
   3.619346785424179*^9, 3.619513111929328*^9, 3.619519238539912*^9}]
}, Open  ]],

Cell["In this contraction only the antisymmetric parts contribute:", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVtIk2EAh/FVuOFQmKt1NGMhNnC6XDDmbMlrp6FiaKBNpAvbhl1FZVJ9
mVIR1JYOo5poYRokokvMac6oLC+KCS7toH1bhKuIl4LNvg6kzt7/d/Hwu3jU
1cfK7CslEomGBS2xI/M73lES3BMRYOcVi3MnMxquEE1JDryFCYsvZ+F5e8Eu
2XtKXA/4fBjy65vhxRsv3PCzulyqZNZFL4naDYpcqGkvMMG0cwZez7wnnxTV
pavP5OFr/nHwemNAzzNtWz+aRS318ZkPlPiCDcuwfaDt5imekodk3AP3z5bW
1zEDZtoIhTHbAHTlfhN1ciemYXnTxAy0crfnYMn67K8w41rs8OBPSg51FDlg
+FZkHc9cnZq3EQq7VWkwtJnbAlu/KKRh5lCRMRH6plzJcKGjTQWNkhHlqEBJ
l1e1BipGrzoeM6ccm2rgm6yRiQhzxdPKSbjIeXoSflHiKX7eCw/0P/HBDP+w
H9akjH+SMa0yawS6eemClmkS4kswbjvuy2Z+79v7CG6fWwrC0EHuNYx6M3N0
zGpli2jOtgYD3Hf3JIHm1FghLDO1FsPuwulaWPkqehp6+2svLP+mJP1+5mVY
krjKCe88O9sCh/TyJM0fSkrzm0WD3Q6tlRmXJxmh9sfRCrhW97cK9lXNN8EN
Qq8b/gdVQ2c2
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixedanti", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mixed", "[", 
         RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "-", 
        RowBox[{"mixed", "[", 
         RowBox[{"t", ",", "s", ",", "m", ",", "n"}], "]"}]}], ")"}], "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mixed", "[", 
         RowBox[{"s", ",", "t", ",", "n", ",", "m"}], "]"}], "-", 
        RowBox[{"mixed", "[", 
         RowBox[{"t", ",", "s", ",", "n", ",", "m"}], "]"}]}], ")"}]}], 
     ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619343495328998*^9, 3.619343505263935*^9}, {
  3.619343663360697*^9, 3.6193437075143967`*^9}, {3.619345076376606*^9, 
  3.619345114343253*^9}, {3.619346909115327*^9, 3.619346939172804*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"a2", " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["m",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["t",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "s"}]]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]]}], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619344029323474*^9, {3.619345027985772*^9, 3.619345114964498*^9}, 
   3.619346531926855*^9, 3.619346796641436*^9, 3.619346942596128*^9, 
   3.619513112206154*^9, 3.6195192386797733`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixedanti", "[", 
   RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "+", 
  RowBox[{"mixedanti", "[", 
   RowBox[{"t", ",", "s", ",", "p", ",", "q"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619345190144669*^9, 3.619345198654861*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6193451940386257`*^9, 3.6193451990910597`*^9}, 
   3.61934653463984*^9, 3.6193468030883083`*^9, 3.61934694495994*^9, 
   3.6195131122694387`*^9, 3.619519238720809*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"mixedanti", "[", 
    RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "+", 
   RowBox[{"mixedanti", "[", 
    RowBox[{"s", ",", "t", ",", "q", ",", "p"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619345121783123*^9, 3.619345180325617*^9}, {
  3.619346871060742*^9, 3.619346873837055*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6193451323681507`*^9, 3.619345180867734*^9}, 
   3.619346535888644*^9, 3.619346804744907*^9, 3.6193468742248096`*^9, 
   3.619346947655848*^9, 3.619513112313445*^9, 3.619519238757333*^9}]
}, Open  ]],

Cell["Now want that these mixed terms vanish.", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyWtIU2EAh/FVuOFSmKtlFzMWYguXywljzpa8dhsqhkbahvTBtqH0ISqT
6mRKRVBbOoxqooVlkIRO0WY5o6tQMcE1u2hni3AVcSjY7HQhdfb+z4eH34dH
WX2o3LZYJBJtpEFT7MBM7juOBLZHeHjrgsmxhRoNVwqmJPvfwoS5l1PwtK1w
q+Q9R5x9bAEM+bQt8OyV5y74WVkhllPro+cEbTpZHlR1FBpg+ikdq6Xelo4L
ajKUJ/LxVf8YeLnJr2Wp1vUfjYKmhvjkB454A40LsGOg/eoxliODZNQNd02V
NdRT/UauCfJPrQPQmfdN0MEcmYAVzWOT0Mxcn4alK7O/wsxLsf33fnJkX2ex
HYavRVJZ6rK0/NWQ36ZIh6G1zDrY9kUmDlOHivWJ0Bt0JsPZznYF1IuG5SM8
R7o8iuVQNnLR/pAatK+pgW82DY9FqIseW8bhHOO+m/CLI+6SZz1wd/8jL8z0
3ffBmpTRTxKqWWKOQBcrnlVTDXx8Hsath73Z1O+9Ox7AzdPzARjaw7yGUU9W
joZaLW8VzNnQqIM7bx4l0JgWK4LlhrYS2F00UQctr6LHoae/7szCb45k3Mk6
D0sTlzjgjScnW+GQVpqk+sORsoIWwUC3XW2mxqVJeqj+UVsJV2j+VsHeqplm
uIrvccHcpS9qLdRg6t6D8D8Lmm9G
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"mixedanti", "[", 
     RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "\[Equal]", "0"}], 
   "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a2", "\[Rule]", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{"b7", "\[Rule]", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{"c1", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619345259741219*^9, 3.619345290355543*^9}, {
  3.619345409277294*^9, 3.619345409868456*^9}, {3.619346565849185*^9, 
  3.619346598727993*^9}, {3.6193469612741003`*^9, 3.619346996375458*^9}}],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619345269190913*^9, 3.619345300146064*^9, 3.619345410139189*^9, {
   3.619346566379876*^9, 3.619346599020526*^9}, {3.619346957480111*^9, 
   3.619346996815539*^9}, 3.6195131123928137`*^9, 3.6195192388625717`*^9}]
}, Open  ]],

Cell[TextData[{
 "Hence, the JJ term is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["J", "st"]}], 
    SuperscriptBox["J", "mn"]}], TraditionalForm]]],
 "times the following expression:\n\n(The propagator is the following term \
multiplied by 2i"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyWtIU3EAhvFV6HBpTGvNzAxFbOFyOWV4yfSsi7dlqaVtjgLbhtKHqEyq
ZUqFMDVdRjnRwi6QxDSxZjm7J90UXDNNO1uEs4iDxbR1IXX2f8+Hh9+HJ7z4
UJ52MYfDkZBgxvSBmbhRhrJtdXngdUNG7Sai21nIGhgwMAJ95l6Pw9Na+Wbu
B4aqu0OnQodV2gDPXnphhJPhBb5BxHL3OVatjJ8IRa3yJBh2SkZLiTd5Q6yS
yPATyfiif3p4sWpAShM1EZ9SWDMqvGMfGcpiq1yArd0tl4/RDHWX6jfB9PHc
inLiQApTBT3PNN2wLvEba63+yDAsqB8cg0r9lQmYExzzFUadn9537ydD7W3L
1kFnk0tIE5eHJodAzxZBGHSs0a+FzV/4vk5iT3aCH7TY6wLgbFuLACZweoP6
PAx1o1OwAvL7anQPiXbd6hL4fkPvoIu46IlqCM7pTbd9fjGUSfHcDHd2PbbA
KOt9KywJ7P/MJSq5Shc00r6zYmKSxzsPvZrDlhjiVMe2B3DjxLwNOvL176C7
MzpWQiwOamSNXVcpg9uvHaVgSuh0FsxLalbA9qzhMqh64z4OO7vKziz8ZqjI
W9HVMMdvSS28+vRkI+yR8vxFfxgqN7WB1dauEyuJXp5/AhR/Ly2EKyV/1bBD
PVMPV3nMRhi39FWpimgX7jkI5Wkvq+HusiEDNF8YTS8i1qznZsKp4LQdcCRi
WS4McQbEq4mTiiLWuf3xmdAgn1TAEuGjXfDtj+x8+B9hGaIK
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prop", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"p", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
    RowBox[{"Contract", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}]}], "]"}], 
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"T", "[", 
                   RowBox[{
                   "a", ",", "b", ",", "c", ",", "dd", ",", "x", ",", "y"}], 
                   "]"}], 
                  RowBox[{"FVD", "[", 
                   RowBox[{"p", ",", "x"}], "]"}], 
                  RowBox[{"FVD", "[", 
                   RowBox[{"p", ",", "y"}], "]"}], 
                  RowBox[{"w", "[", 
                   RowBox[{"a", ",", "b", ",", "s", ",", "t"}], "]"}], 
                  RowBox[{"w", "[", 
                   RowBox[{"c", ",", "dd", ",", "m", ",", "n"}], "]"}]}], "-", 
                 RowBox[{"w", "[", 
                  RowBox[{"m", ",", "n", ",", "s", ",", "t"}], "]"}]}], ")"}],
                "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"ii", "\[Rule]", "0"}], ",", 
                 RowBox[{"g2", "\[Rule]", "0"}], ",", 
                 RowBox[{"c5", "\[Rule]", "0"}], ",", 
                 RowBox[{"g1", "\[Rule]", "0"}], ",", 
                 RowBox[{"f1", "\[Rule]", "0"}], ",", 
                 RowBox[{"c6", "\[Rule]", "0"}], ",", 
                 RowBox[{"b4", "\[Rule]", "0"}], ",", 
                 RowBox[{"a1", "\[Rule]", "0"}], ",", 
                 RowBox[{"b1", "\[Rule]", "0"}], ",", 
                 RowBox[{"h6", "\[Rule]", "0"}], ",", 
                 RowBox[{"f6", "\[Rule]", "0"}], ",", 
                 RowBox[{"e2", "\[Rule]", "0"}], ",", 
                 RowBox[{"d", "\[Rule]", "0"}], ",", 
                 RowBox[{"e1", "\[Rule]", "0"}], ",", 
                 RowBox[{"h1", "\[Rule]", "0"}], ",", 
                 RowBox[{"c4", "\[Rule]", 
                  RowBox[{"-", "c3"}]}], ",", 
                 RowBox[{"b11", "\[Rule]", 
                  RowBox[{"-", "b8"}]}], ",", 
                 RowBox[{"c2", "\[Rule]", 
                  RowBox[{"-", "c1"}]}], ",", 
                 RowBox[{"b10", "\[Rule]", 
                  RowBox[{"-", "b7"}]}], ",", 
                 RowBox[{"g4", "\[Rule]", 
                  RowBox[{"-", "g3"}]}], ",", 
                 RowBox[{"f5", "\[Rule]", 
                  RowBox[{"-", "f2"}]}], ",", 
                 RowBox[{"b12", "\[Rule]", 
                  RowBox[{"-", "b9"}]}], ",", 
                 RowBox[{"f4", "\[Rule]", 
                  RowBox[{"-", "f3"}]}], ",", 
                 RowBox[{"e4", "\[Rule]", 
                  RowBox[{"-", "e3"}]}], ",", 
                 RowBox[{"b6", "\[Rule]", 
                  RowBox[{"-", "b5"}]}], ",", 
                 RowBox[{"b3", "\[Rule]", 
                  RowBox[{"-", "b2"}]}], ",", 
                 RowBox[{"h5", "\[Rule]", 
                  RowBox[{"-", "h4"}]}], ",", 
                 RowBox[{"h3", "\[Rule]", 
                  RowBox[{"-", "h2"}]}], ",", 
                 RowBox[{"a3", "\[Rule]", 
                  RowBox[{"-", "a2"}]}]}], "}"}]}], ")"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"b9", "\[Rule]", "0"}], ",", 
               RowBox[{"e3", "\[Rule]", "0"}], ",", 
               RowBox[{"g3", "\[Rule]", "0"}], ",", 
               RowBox[{"f3", "\[Rule]", 
                RowBox[{"-", "f2"}]}], ",", 
               RowBox[{"c3", "\[Rule]", "c1"}], ",", 
               RowBox[{"b8", "\[Rule]", 
                RowBox[{"-", "b7"}]}], ",", 
               RowBox[{"b5", "\[Rule]", 
                RowBox[{"-", "b2"}]}], ",", 
               RowBox[{"h4", "\[Rule]", 
                RowBox[{"-", "h2"}]}]}], "}"}]}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"h2", "\[Rule]", "0"}], ",", 
             RowBox[{"b2", "\[Rule]", "a2"}], ",", 
             RowBox[{"f2", "\[Rule]", 
              RowBox[{"-", "b7"}]}]}], "}"}]}], ")"}], ")"}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a2", "\[Rule]", 
          RowBox[{"-", "1"}]}], ",", 
         RowBox[{"b7", "\[Rule]", 
          RowBox[{"-", "1"}]}], ",", 
         RowBox[{"c1", "\[Rule]", "0"}]}], "}"}]}], "]"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6193470899869213`*^9, 3.619347228215808*^9}, {
  3.619347266194653*^9, 3.619347302539509*^9}, {3.619348306110195*^9, 
  3.6193483098403463`*^9}, {3.619348399484983*^9, 3.6193484007660713`*^9}, {
  3.6193485626928062`*^9, 3.619348589254005*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "s"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "s"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "t"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "t"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "t"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "t"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "s"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "s"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "t"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "s"}]]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "s"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "t"}]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619347119941616*^9, 3.6193471284690847`*^9}, {
   3.619347161744639*^9, 3.619347213210972*^9}, 3.619347245527862*^9, 
   3.619347284385618*^9, 3.6193473205371237`*^9, 3.619347487769169*^9, 
   3.619348327207716*^9, 3.619348418611639*^9, 3.6193486081912003`*^9, 
   3.619513130031473*^9, 3.619519255721939*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"prop", "[", 
      RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "n"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.61934740256304*^9, 3.619347416881691*^9}, {
  3.619347459211953*^9, 3.619347512093034*^9}, {3.619348202483295*^9, 
  3.619348206814651*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6193474931598873`*^9, 3.619347512606176*^9}, {
   3.619348203227603*^9, 3.6193482071571903`*^9}, 3.619348632379183*^9, 
   3.619513130208334*^9, 3.619519255899006*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"prop", "[", 
      RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], 
     RowBox[{"FVD", "[", 
      RowBox[{"p", ",", "n"}], "]"}]}], "]"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
   "}"}]}]], "Input",
 CellChangeTimes->{3.619349259277369*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6193492598191338`*^9, 3.619513130343954*^9, 
  3.619519256003977*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"prop", "[", 
    RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "+", 
   RowBox[{"prop", "[", 
    RowBox[{"t", ",", "s", ",", "m", ",", "n"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619348416333166*^9, 3.619348424147896*^9}, {
  3.6193486404588537`*^9, 3.619348643123197*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.61934842471614*^9, {3.619348633764613*^9, 3.6193486433929243`*^9}, 
   3.6195131303770447`*^9, 3.6195192560395317`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"prop", "[", 
    RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "+", 
   RowBox[{"prop", "[", 
    RowBox[{"s", ",", "t", ",", "n", ",", "m"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619348432171382*^9, 3.619348435533359*^9}, {
  3.619348647086617*^9, 3.619348649548791*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619348435886047*^9, {3.619348645574504*^9, 3.619348649763308*^9}, 
   3.619513130403448*^9, 3.619519256073615*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["metric propagator in q-lightcone gauge impossible", "Subsection",
 CellChangeTimes->{{3.6194194195745707`*^9, 3.6194194456943274`*^9}, {
  3.619428562348688*^9, 3.619428562824698*^9}, {3.619520277301272*^9, 
  3.619520279100787*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{"Contract", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "j"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"s", ",", "t"}], "]"}]}], "+", 
       RowBox[{"a2", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "s"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"j", ",", "t"}], "]"}]}], "+", 
       RowBox[{"a3", " ", 
        RowBox[{"d", "[", 
         RowBox[{"i", ",", "t"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"j", ",", "s"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"b1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"b4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"b7", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b8", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b9", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "+", 
          RowBox[{"b10", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"b11", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"b12", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"c1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"c2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"c3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"c4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"c5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"c6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"i", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}], 
       "+", 
       RowBox[{"d", " ", 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "j"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "s"}], "]"}], 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "t"}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"e1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}], "+", 
          RowBox[{"e4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}], 
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"f2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"f3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"f4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}], "+", 
          RowBox[{"f5", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}]}], "+", 
          RowBox[{"f6", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"g1", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g2", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g3", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "+", 
          RowBox[{"g4", " ", 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}]}], ")"}], 
        RowBox[{
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "3"}], ")"}]}]}], 
       "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"h1", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h2", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h3", " ", 
           RowBox[{"d", "[", 
            RowBox[{"s", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "+", 
          RowBox[{"h4", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "j"}], "]"}]}], "+", 
          RowBox[{"h5", " ", 
           RowBox[{"d", "[", 
            RowBox[{"t", ",", "j"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}]}], "+", 
          RowBox[{"h6", " ", 
           RowBox[{"d", "[", 
            RowBox[{"j", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "s"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "o"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "o"}], "]"}]}], "]"}]}], "+", 
       RowBox[{"ii", " ", 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "j"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}], 
        RowBox[{
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "4"}], 
          ")"}]}]}]}], ")"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6179703517595673`*^9, 3.617970779129396*^9}, {
   3.617970879468876*^9, 3.617970919076379*^9}, {3.6179709519702663`*^9, 
   3.6179709533780193`*^9}, {3.617970984844159*^9, 3.61797114731628*^9}, {
   3.6179714109042788`*^9, 3.6179714542681723`*^9}, {3.617971514353078*^9, 
   3.617971601477254*^9}, {3.617971643385899*^9, 3.6179718972932*^9}, 
   3.6179719296959248`*^9, 3.617972009927199*^9, 3.617972050362486*^9, 
   3.6179724567357693`*^9, {3.617972660466942*^9, 3.617972672014579*^9}, 
   3.61797289536517*^9, {3.617972978809762*^9, 3.617972982014348*^9}, {
   3.617973026458253*^9, 3.6179730287227707`*^9}, 3.61803425058486*^9, {
   3.6180357071967497`*^9, 3.618035710039319*^9}, {3.618052871007208*^9, 
   3.618052921229148*^9}, {3.618052978179215*^9, 3.618053074353793*^9}, {
   3.618140015348394*^9, 3.6181400387410088`*^9}, {3.618140078679212*^9, 
   3.618140140134884*^9}, {3.618140224639729*^9, 3.618140275649692*^9}, {
   3.618140349871594*^9, 3.618140350074747*^9}, 3.618202878154153*^9, {
   3.618735662852004*^9, 3.618735698391954*^9}, {3.619342635843162*^9, 
   3.6193426480919933`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b9", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b12", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f4", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"d", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"ii", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6193440182432213`*^9, 3.619423800696354*^9, 
  3.619428568830606*^9, 3.61950659514508*^9, 3.6195088076061373`*^9, 
  3.619513130884714*^9, 3.6195192564557343`*^9}]
}, Open  ]],

Cell[TextData[{
 "Starting with the most generic ansatz with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["q", "2"], "=", "0"}], TraditionalForm]]],
 " we first restrict the coefficients such that:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["w", "abcd"], 
      SuperscriptBox["q", "a"]}], "=", "0"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["w", "abcd"], 
      SuperscriptBox["q", "b"]}], "=", "0"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["w", "abcd"], "=", 
     RowBox[{
      SubscriptBox["w", 
       RowBox[{
        RowBox[{"(", "ab", ")"}], "cd"}]], "=", 
      SubscriptBox["w", 
       RowBox[{"ab", "(", "cd", ")"}]]}]}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVtIk2EAh/FVuOFQmLORlBkL0YGmuWDM2ZTXTkPFUMGaF17oNrwLy6T6
MkdFoFspRjXRwg6QdJhizcOM1BI0Jri0g/ZtEVtFvARt9VWQOnv/38XD7+JR
1x2rtG6USCSZLGiK1v/c844S//6wAO+0mRx7mZHgEdGkRN9bGLc6uwzPWYsL
Ze8pcQ7wRTDg1XbAC9dedsLP6mqpktkcuShq1Snyoaa32ADTzup4LfOefF40
N119ugBf84+DV+0+Lc+07PxoFDW1xJY+UOLxt67D3qGe6yd5Sp6QaRc8tFzR
0sz0GakdClOWIejM/ybq4I4vwuorc0vQzN0MwfKUnK8w43K09ukvSo72ldpg
8EZ4C89MTi3YCoV9qjQY2M7tgN1fFNIgc7hUHw89C85EuNLXo4J6yZhyXKDk
rlu1GSrG223PmAu2bQ3wza6xuTBzw0TNPFzlXA/iflPiKnvxCB4efO6BGd4R
L2xImv4kY5pl5jDs5KUr2UyDEFuDMUujJ4f5/fGBUbg7tOaHgSruNYy4s/Jy
mXXKLtG8zFYdPHj7BIHG1GgJrDR0l8H+ksUmWPMqcgq6B5vOr/+hJP1+1iVY
Hr/JAW9NnumCw1p5guYvJRVFHaL+flu2mRmTJ+ihvf3HjJ2Z/DA0C/8DO9Zf
cQ==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sys", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"w", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "dd"}], "]"}], "-", 
         RowBox[{"w", "[", 
          RowBox[{"b", ",", "a", ",", "c", ",", "dd"}], "]"}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"w", "[", 
          RowBox[{"a", ",", "b", ",", "c", ",", "dd"}], "]"}], "-", 
         RowBox[{"w", "[", 
          RowBox[{"a", ",", "b", ",", "dd", ",", "c"}], "]"}]}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{"w", "[", 
            RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "]"}], "\[Equal]", "0"}],
        ",", 
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{"w", "[", 
            RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "j"}], "]"}]}], "]"}], "]"}], "\[Equal]", 
        "0"}]}], "}"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], "}"}]}], 
    "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d", "\[Rule]", "0"}], ",", 
     RowBox[{"h1", "\[Rule]", "0"}], ",", 
     RowBox[{"h2", "\[Rule]", "0"}], ",", 
     RowBox[{"h3", "\[Rule]", "0"}], ",", 
     RowBox[{"h4", "\[Rule]", "0"}], ",", 
     RowBox[{"h5", "\[Rule]", "0"}], ",", 
     RowBox[{"e2", "\[Rule]", "0"}], ",", 
     RowBox[{"a2", "\[Rule]", "0"}], ",", 
     RowBox[{"c1", "\[Rule]", "0"}], ",", 
     RowBox[{"c4", "\[Rule]", "0"}], ",", 
     RowBox[{"a3", "\[Rule]", "0"}], ",", 
     RowBox[{"b10", "\[Rule]", "0"}], ",", 
     RowBox[{"b11", "\[Rule]", "0"}], ",", 
     RowBox[{"b1", "\[Rule]", "0"}], ",", 
     RowBox[{"e1", "\[Rule]", "0"}], ",", 
     RowBox[{"b3", "\[Rule]", "0"}], ",", 
     RowBox[{"b4", "\[Rule]", "0"}], ",", 
     RowBox[{"b6", "\[Rule]", "0"}], ",", 
     RowBox[{"c3", "\[Rule]", "0"}], ",", 
     RowBox[{"b8", "\[Rule]", "0"}], ",", 
     RowBox[{"c2", "\[Rule]", "0"}], ",", 
     RowBox[{"b7", "\[Rule]", "0"}], ",", 
     RowBox[{"b5", "\[Rule]", "0"}], ",", 
     RowBox[{"b2", "\[Rule]", "0"}], ",", 
     RowBox[{"f6", "\[Rule]", "0"}], ",", 
     RowBox[{"f5", "\[Rule]", "0"}], ",", 
     RowBox[{"f2", "\[Rule]", "0"}], ",", 
     RowBox[{"f3", "\[Rule]", "0"}], ",", 
     RowBox[{"f4", "\[Rule]", "0"}], ",", 
     RowBox[{"b12", "\[Rule]", 
      RowBox[{"-", "a1"}]}], ",", 
     RowBox[{"g2", "\[Rule]", "g1"}], ",", 
     RowBox[{"g3", "\[Rule]", 
      RowBox[{"-", "c6"}]}], ",", 
     RowBox[{"g4", "\[Rule]", 
      RowBox[{"-", "c6"}]}], ",", 
     RowBox[{"h6", "\[Rule]", 
      RowBox[{"-", "e3"}]}], ",", 
     RowBox[{"b9", "\[Rule]", 
      RowBox[{"-", "a1"}]}], ",", 
     RowBox[{"e4", "\[Rule]", "e3"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618736039868785*^9, 3.6187361229945707`*^9}, {
  3.618736172901292*^9, 3.6187362638114233`*^9}, {3.618736373365267*^9, 
  3.6187365127096252`*^9}, {3.618736543974063*^9, 3.618736704892205*^9}, {
  3.618736805831768*^9, 3.618736808003583*^9}, {3.618740688101403*^9, 
  3.618740700612451*^9}, {3.618907256931685*^9, 3.618907258880978*^9}, {
  3.6193427990585737`*^9, 3.619342882962376*^9}, {3.61934407829175*^9, 
  3.619344372349032*^9}, {3.6193444297212133`*^9, 3.6193444465401154`*^9}, {
  3.61934460414895*^9, 3.619344844114943*^9}, {3.619423820935863*^9, 
  3.619423825830516*^9}, {3.619423885988105*^9, 3.619423892588375*^9}, {
  3.619424021536643*^9, 3.6194240843253307`*^9}, {3.619424157667192*^9, 
  3.6194244585896397`*^9}, {3.619424677530136*^9, 3.6194246807318163`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619159224269464*^9, 3.6193382099981613`*^9, 3.619344026217037*^9, 
   3.619344089501408*^9, {3.619344147609438*^9, 3.6193441568466377`*^9}, 
   3.619344254034203*^9, {3.6193443305568247`*^9, 3.619344374989933*^9}, 
   3.619344447591009*^9, {3.619344605057809*^9, 3.619344632438489*^9}, {
   3.619344680398192*^9, 3.619344705248294*^9}, {3.619344748027232*^9, 
   3.619344845363861*^9}, 3.619423875498185*^9, 3.6194239886956387`*^9, 
   3.6194240237659817`*^9, 3.619424109656242*^9, {3.6194241595640697`*^9, 
   3.6194242963764973`*^9}, {3.6194243331859083`*^9, 3.619424459513543*^9}, 
   3.619424681606709*^9, 3.619428583327437*^9, 3.619506598151864*^9, 
   3.619508814260186*^9, 3.6195131336744347`*^9, 3.619519259217752*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", 
   RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"d", "\[Rule]", "0"}], ",", 
    RowBox[{"h1", "\[Rule]", "0"}], ",", 
    RowBox[{"h2", "\[Rule]", "0"}], ",", 
    RowBox[{"h3", "\[Rule]", "0"}], ",", 
    RowBox[{"h4", "\[Rule]", "0"}], ",", 
    RowBox[{"h5", "\[Rule]", "0"}], ",", 
    RowBox[{"e2", "\[Rule]", "0"}], ",", 
    RowBox[{"a2", "\[Rule]", "0"}], ",", 
    RowBox[{"c1", "\[Rule]", "0"}], ",", 
    RowBox[{"c4", "\[Rule]", "0"}], ",", 
    RowBox[{"a3", "\[Rule]", "0"}], ",", 
    RowBox[{"b10", "\[Rule]", "0"}], ",", 
    RowBox[{"b11", "\[Rule]", "0"}], ",", 
    RowBox[{"b1", "\[Rule]", "0"}], ",", 
    RowBox[{"e1", "\[Rule]", "0"}], ",", 
    RowBox[{"b3", "\[Rule]", "0"}], ",", 
    RowBox[{"b4", "\[Rule]", "0"}], ",", 
    RowBox[{"b6", "\[Rule]", "0"}], ",", 
    RowBox[{"c3", "\[Rule]", "0"}], ",", 
    RowBox[{"b8", "\[Rule]", "0"}], ",", 
    RowBox[{"c2", "\[Rule]", "0"}], ",", 
    RowBox[{"b7", "\[Rule]", "0"}], ",", 
    RowBox[{"b5", "\[Rule]", "0"}], ",", 
    RowBox[{"b2", "\[Rule]", "0"}], ",", 
    RowBox[{"f6", "\[Rule]", "0"}], ",", 
    RowBox[{"f5", "\[Rule]", "0"}], ",", 
    RowBox[{"f2", "\[Rule]", "0"}], ",", 
    RowBox[{"f3", "\[Rule]", "0"}], ",", 
    RowBox[{"f4", "\[Rule]", "0"}], ",", 
    RowBox[{"b12", "\[Rule]", 
     RowBox[{"-", "a1"}]}], ",", 
    RowBox[{"g2", "\[Rule]", "g1"}], ",", 
    RowBox[{"g3", "\[Rule]", 
     RowBox[{"-", "c6"}]}], ",", 
    RowBox[{"g4", "\[Rule]", 
     RowBox[{"-", "c6"}]}], ",", 
    RowBox[{"h6", "\[Rule]", 
     RowBox[{"-", "e3"}]}], ",", 
    RowBox[{"b9", "\[Rule]", 
     RowBox[{"-", "a1"}]}], ",", 
    RowBox[{"e4", "\[Rule]", "e3"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619344865396747*^9, 3.619344871438109*^9}, {
  3.619346338533216*^9, 3.619346368271214*^9}, {3.619424463691934*^9, 
  3.61942446899702*^9}, {3.61942467274938*^9, 3.6194246745941553`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"a1", " ", 
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["i",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["j",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"s", "t"}]]}], 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}]]}], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "-", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "-", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"ii", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "4"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619344872446163*^9, {3.6193463481406612`*^9, 3.619346369115699*^9}, 
   3.61942446987114*^9, 3.619424683007712*^9, 3.619428585583086*^9, 
   3.619506598237074*^9, 3.6195088209208803`*^9, 3.619513133738832*^9, 
   3.6195192593059063`*^9}]
}, Open  ]],

Cell["w is now given in terms of a1,c5,c6,e3,f1,g1,ii", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyWtIU3EAhvFVuOHS2FaryEtMxEYulwvGnC05dhtOFhpoG+EH24ZB0E1F
Oy3tQlBbKUY10cIsSKKWrGY5o6tEMWFLrbSzRbiKOBRsdbJInf3f8+Hh9+FR
1O6vtC8UCARrSdCY2PNzwzuWCm+JcbD3jNG1kRiPVvNK04NvYcrsq0l4zF66
SfSepdx3mRIYCWja4MmLL9rhZ0WVUEZsjJ/itWslRVDZXaqH2Ue1jIZ4Qxzi
Vecqmovxlf9oeKE1qGGItpyPBl6jMznxgaX84ZZ52O3rutTAsNQ9atgDt09W
OBuJQQPbCrlnNh90F33jddGHxmDV+ZEJaKGvTEHzyoKvMO9coub+L5ba1WNy
wOjl2AqGuDSzeBXkNsuzYSSLXg07v0iEUeKASZcK/aPudDjT0yWHOsGgbIhj
qete+TIoGTrreEQcdWTUwfF1gyMx4oIn1hCcpT23Un6zlKf8+W24o/+xH+YF
HgRgnXT4k4hoEVlisJ0RzqiIei45B5O2g/4C4vc7Wx/C9VNzYRjZSb+BcW9+
oZpYK+vgLVzTooXbrh2moCEzUQYr9Z3lsK9srB5aX8eboLe//sT8NEvl3sw/
Dc2pi1zw6tMjHXBAI05T/mGpipI23nCfQ2UhJsVpOqj6sbcaLlf/3Q1DDYvN
VuL4yxzeJSZpE5x2HmiGNb59GceJepkiC/4HD491rA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Talt", "[", 
   RowBox[{"k_", ",", "l_", ",", "m_", ",", "n_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{"1", "/", "2"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"m", ",", "n"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"l", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "x"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"m", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"l", ",", "n"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"d", "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "m"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"l", ",", "n"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"d", "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "l"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.619428615537554*^9, 3.619428667664604*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"k", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"l", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "n"}]]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"k", "l"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "n"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"x", "y"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"k", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"l", "n"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "x"}]]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"k", "m"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"l", "n"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"x", "y"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619428668954516*^9, 3.6195065989180613`*^9, 
  3.619508851289557*^9, 3.6195131343275137`*^9, 3.619519259366124*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Taltsym", "[", 
   RowBox[{"k_", ",", "l_", ",", "m_", ",", "n_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", "8"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Talt", "[", 
       RowBox[{"k", ",", "l", ",", "m", ",", "n", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"l", ",", "k", ",", "m", ",", "n", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"k", ",", "l", ",", "n", ",", "m", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"l", ",", "k", ",", "n", ",", "m", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"m", ",", "n", ",", "k", ",", "l", ",", "y", ",", "x"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"n", ",", "m", ",", "k", ",", "l", ",", "y", ",", "x"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"m", ",", "n", ",", "l", ",", "k", ",", "y", ",", "x"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"n", ",", "m", ",", "l", ",", "k", ",", "y", ",", "x"}], 
       "]"}]}], ")"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.6194287289281807`*^9, 3.619428740811838*^9}, {
  3.6194975014281816`*^9, 3.619497539837103*^9}, {3.6194979178290253`*^9, 
  3.619497984315345*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619428736105389*^9, 3.6194287413712187`*^9}, 
   3.61950659901649*^9, 3.619507293932802*^9, 3.6195088533604193`*^9, 
   3.619513134401136*^9, 3.619519259460266*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"FVD", "[", 
    RowBox[{"p", ",", "x"}], "]"}], 
   RowBox[{"FVD", "[", 
    RowBox[{"p", ",", "y"}], "]"}], 
   RowBox[{"Taltsym", "[", 
    RowBox[{"k", ",", "l", ",", "m", ",", "n", ",", "x", ",", "y"}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.619428750096835*^9, 3.61942875030587*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["k",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["l",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]]}], "-", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["k",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["m",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "n"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["l",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["m",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "n"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["k",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["n",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "m"}]]}], "-", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["l",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["n",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "m"}]]}], "+", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["m",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["n",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "m"}]]}], "+", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "n"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6194287508445997`*^9, 3.619506599096631*^9, 
  3.619508949008333*^9, 3.619513134467873*^9, 3.619519259535396*^9}]
}, Open  ]],

Cell[TextData[{
 "The mixed terms are the following expression contracted into ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["J", "st"]}], 
    RowBox[{
     SubscriptBox["h", "mn"], "'"}]}], TraditionalForm]]],
 ".\n"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwlyVtIU3EAx/FVuOFSmKtVlBkTWSOXywVjzpYcuw2VhQabW9GDbcOeoppS
nUypCGorxW4bs7ALJFJLbLOc0VUi2WBLrbSzRbiKOBRstS6kzv6/08OXz8NX
2rCvzjafx+OtIUF9as/39W9YKro5kYbXT+udG4jJuIkzLzf0GmbNvJyEx2yV
GwVvWcp1l6mAsaCqHZ64+LwDfpQa+WJic/Ikp00tKoPyrkotLDiqZlTEm8II
p7JIergcX/6XhufbQiqGaC18r+PUt2Qm3rFUINo6B7v6vZeaGJa6Rw274bbJ
2pZmYkjHtsH0U2s/dJV94XTSB8ag8Vx4AprpK1PQsKzkM5SdTe32/2Cp+u5q
O4xfTixliIvyy5fD9CZJAYytpFdBzycRP04cqNZkw8CoKxdOd3slUMMbFA+l
WeqGT7IYiobO2B8SR+0rGuH42sFwgjjvsSUCZ2h3b9ZPlnLXPLsNt/c9CkBZ
8H4QNuYNfxAQzQJzAnYw/GkFUZvOzMKMdX+ghPj1zpYHcN3UbBTGdtCvYNJX
XKokNog7OUtXt6rh1msHKajLT1XBOq2nBvZUjTmgZSR5CPr6HMfnfrFU0a3i
U9CQvcAJrz450gkHVMIc+W+Wqq1o54z22BVmYkaYo4GKb3tNcInyzy4YaVpo
sBDHXxRyevUjsp3EC44wp8dY7+8l+k3//Qc123h/
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixed", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Talt", "[", 
         RowBox[{"m", ",", "n", ",", "c", ",", "dd", ",", "x", ",", "y"}], 
         "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "x"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "y"}], "]"}], " ", 
        RowBox[{"w", "[", 
         RowBox[{"c", ",", "dd", ",", "s", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Talt", "[", 
         RowBox[{"a", ",", "b", ",", "m", ",", "n", ",", "x", ",", "y"}], 
         "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "x"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"p", ",", "y"}], "]"}], 
        RowBox[{"w", "[", 
         RowBox[{"a", ",", "b", ",", "s", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"d", "[", 
         RowBox[{"s", ",", "m"}], "]"}], 
        RowBox[{"d", "[", 
         RowBox[{"t", ",", "n"}], "]"}]}]}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"d", "\[Rule]", "0"}], ",", 
       RowBox[{"h1", "\[Rule]", "0"}], ",", 
       RowBox[{"h2", "\[Rule]", "0"}], ",", 
       RowBox[{"h3", "\[Rule]", "0"}], ",", 
       RowBox[{"h4", "\[Rule]", "0"}], ",", 
       RowBox[{"h5", "\[Rule]", "0"}], ",", 
       RowBox[{"e2", "\[Rule]", "0"}], ",", 
       RowBox[{"a2", "\[Rule]", "0"}], ",", 
       RowBox[{"c1", "\[Rule]", "0"}], ",", 
       RowBox[{"c4", "\[Rule]", "0"}], ",", 
       RowBox[{"a3", "\[Rule]", "0"}], ",", 
       RowBox[{"b10", "\[Rule]", "0"}], ",", 
       RowBox[{"b11", "\[Rule]", "0"}], ",", 
       RowBox[{"b1", "\[Rule]", "0"}], ",", 
       RowBox[{"e1", "\[Rule]", "0"}], ",", 
       RowBox[{"b3", "\[Rule]", "0"}], ",", 
       RowBox[{"b4", "\[Rule]", "0"}], ",", 
       RowBox[{"b6", "\[Rule]", "0"}], ",", 
       RowBox[{"c3", "\[Rule]", "0"}], ",", 
       RowBox[{"b8", "\[Rule]", "0"}], ",", 
       RowBox[{"c2", "\[Rule]", "0"}], ",", 
       RowBox[{"b7", "\[Rule]", "0"}], ",", 
       RowBox[{"b5", "\[Rule]", "0"}], ",", 
       RowBox[{"b2", "\[Rule]", "0"}], ",", 
       RowBox[{"f6", "\[Rule]", "0"}], ",", 
       RowBox[{"f5", "\[Rule]", "0"}], ",", 
       RowBox[{"f2", "\[Rule]", "0"}], ",", 
       RowBox[{"f3", "\[Rule]", "0"}], ",", 
       RowBox[{"f4", "\[Rule]", "0"}], ",", 
       RowBox[{"b12", "\[Rule]", 
        RowBox[{"-", "a1"}]}], ",", 
       RowBox[{"g2", "\[Rule]", "g1"}], ",", 
       RowBox[{"g3", "\[Rule]", 
        RowBox[{"-", "c6"}]}], ",", 
       RowBox[{"g4", "\[Rule]", 
        RowBox[{"-", "c6"}]}], ",", 
       RowBox[{"h6", "\[Rule]", 
        RowBox[{"-", "e3"}]}], ",", 
       RowBox[{"b9", "\[Rule]", 
        RowBox[{"-", "a1"}]}], ",", 
       RowBox[{"e4", "\[Rule]", "e3"}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "m"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "n"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.619343088326528*^9, 3.6193431592784*^9}, {
   3.619343449142192*^9, 3.619343459751338*^9}, {3.619344916020316*^9, 
   3.6193449936098337`*^9}, {3.6193450406949263`*^9, 
   3.6193450420955353`*^9}, {3.619346745876843*^9, 3.619346781902206*^9}, {
   3.6194246980892076`*^9, 3.61942470458995*^9}, {3.619424855350925*^9, 
   3.619424873015131*^9}, {3.619424919677514*^9, 3.619424921935769*^9}, {
   3.6194249602829733`*^9, 3.619424968051961*^9}, {3.619428678336111*^9, 
   3.6194286813185062`*^9}, 3.619509773333761*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a1", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "a1", " ", "D", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   RowBox[{"a1", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "c5", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   FractionBox[
    RowBox[{"c6", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"c6", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"ii", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619344969765562*^9, 3.619344999223496*^9}, 
   3.619345046190477*^9, 3.619345111447053*^9, 3.619346481397852*^9, 
   3.619346785424179*^9, 3.619424787208252*^9, 3.619424885318141*^9, 
   3.619424936297092*^9, 3.619424980088998*^9, 3.619428702752151*^9, 
   3.619506600648134*^9, 3.619509782444858*^9, 3.619513135980136*^9, 
   3.619519261019058*^9}]
}, Open  ]],

Cell["In this contraction only the symmetric parts contribute:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
   3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
   3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
   3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
   3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
   3.6044001159150867`*^9, 3.604400123994227*^9}, {3.604720820865553*^9, 
   3.60472083813302*^9}, {3.604722666557773*^9, 3.604722695320043*^9}, {
   3.604723091148676*^9, 3.604723095257025*^9}, {3.604723355577581*^9, 
   3.604723398392375*^9}, {3.604723476921307*^9, 3.604723505440467*^9}, {
   3.61743231154848*^9, 3.617432370363323*^9}, {3.617511615112288*^9, 
   3.617511633847177*^9}, {3.617511664664545*^9, 3.617511675847395*^9}, {
   3.617515568528027*^9, 3.617515593759242*^9}, {3.617515628400721*^9, 
   3.617515692863401*^9}, {3.6179703257812767`*^9, 3.617970336677568*^9}, {
   3.617973044335335*^9, 3.6179730568563013`*^9}, {3.6180537337868443`*^9, 
   3.618053754835816*^9}, {3.618123092765135*^9, 3.61812311007185*^9}, {
   3.618123181959022*^9, 3.618123221741473*^9}, {3.618127622127125*^9, 
   3.618127642782147*^9}, {3.618203608214302*^9, 3.618203631967313*^9}, {
   3.618207147543578*^9, 3.6182071701774807`*^9}, {3.618207367933861*^9, 
   3.6182073718539867`*^9}, {3.6182081373651047`*^9, 3.618208140564744*^9}, {
   3.618208179973534*^9, 3.6182082676134367`*^9}, {3.618208343534697*^9, 
   3.618208356788369*^9}, {3.6182086786028633`*^9, 3.618208711524579*^9}, {
   3.6191590596465673`*^9, 3.619159089364153*^9}, {3.619159128094886*^9, 
   3.619159187836013*^9}, {3.6192420803186903`*^9, 3.619242084476479*^9}, {
   3.619342691208107*^9, 3.619342784376342*^9}, {3.6193430353102016`*^9, 
   3.619343079755748*^9}, {3.619343479573813*^9, 3.619343493404797*^9}, 
   3.6194247436576567`*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixedsym", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mixed", "[", 
         RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "+", 
        RowBox[{"mixed", "[", 
         RowBox[{"t", ",", "s", ",", "m", ",", "n"}], "]"}]}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mixed", "[", 
         RowBox[{"s", ",", "t", ",", "n", ",", "m"}], "]"}], "+", 
        RowBox[{"mixed", "[", 
         RowBox[{"t", ",", "s", ",", "n", ",", "m"}], "]"}]}], ")"}]}], 
     ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619343495328998*^9, 3.619343505263935*^9}, {
  3.619343663360697*^9, 3.6193437075143967`*^9}, {3.619345076376606*^9, 
  3.619345114343253*^9}, {3.619346909115327*^9, 3.619346939172804*^9}, {
  3.619424751054744*^9, 3.619424758742614*^9}, {3.619424998237258*^9, 
  3.6194249984932127`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a1", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "a1", " ", "D", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   RowBox[{"a1", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "c5", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   FractionBox[
    RowBox[{"c6", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"c6", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"c6", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"ii", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619344029323474*^9, {3.619345027985772*^9, 3.619345114964498*^9}, 
   3.619346531926855*^9, 3.619346796641436*^9, 3.619346942596128*^9, 
   3.619425003973073*^9, 3.619506600815529*^9, 3.619509885837367*^9, 
   3.619513136115398*^9, 3.619519261180128*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixedsym", "[", 
   RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "-", 
  RowBox[{"mixedsym", "[", 
   RowBox[{"t", ",", "s", ",", "p", ",", "q"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619345190144669*^9, 3.619345198654861*^9}, {
  3.619425045767671*^9, 3.619425050264908*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6193451940386257`*^9, 3.6193451990910597`*^9}, 
   3.61934653463984*^9, 3.6193468030883083`*^9, 3.61934694495994*^9, {
   3.6194250470347643`*^9, 3.6194250506310263`*^9}, 3.619506600862376*^9, 
   3.619509917449135*^9, 3.619513136146056*^9, 3.6195192612223167`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"mixedsym", "[", 
    RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "-", 
   RowBox[{"mixedsym", "[", 
    RowBox[{"s", ",", "t", ",", "q", ",", "p"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619345121783123*^9, 3.619345180325617*^9}, {
  3.619346871060742*^9, 3.619346873837055*^9}, {3.619425052649048*^9, 
  3.619425056221531*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6193451323681507`*^9, 3.619345180867734*^9}, 
   3.619346535888644*^9, 3.619346804744907*^9, 3.6193468742248096`*^9, 
   3.619346947655848*^9, 3.619425056506399*^9, 3.6195066008995657`*^9, 
   3.619509918872862*^9, 3.619513136159582*^9, 3.61951926125604*^9}]
}, Open  ]],

Cell["Now want that these mixed terms vanish. D\[NotEqual]2", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyWtIU3EAhvFVuOFSmLNlpRkL0ZHL5YQxZ1OO3YaKoZG2JX2wbSgGUZlU
J9MuBLWlw8gmWmgFSegSa5YzugoVE1yzi3a2CFcRB4PNThdSZ//3fHj4fXjk
1QfLLUsFAsEGEjRE9s/mvGcp39YQB29cMNg2E8PBSt6EeO87GDP/agqeshTm
iz6wlP0uUwADHnUrPHvlhQN+kVcIpcSG8Dlei0aSCxVdhTqYelLDqIm3xOO8
qjT58Tx8xT8aXm72qhmief0nPa+hMTr5kaXcvqZF2DXY2X6UYal71KgT7pgq
a2wgevVsM+SemQehPfc7r40+PAErWsYmoZG+Ng1LV2V9g+mXIvvu/2SpPd3F
Vhi8GkpiiIkpeWsgt0WWCgNr6XWw46tEGCQOFWtjodtvj4dz3Z0yqBUMS0c4
lrrpkq2AkpGL1kdEvzW5Br7dODwWIi55YhqH87TzTswvlnKWPO+DOwceu2G6
54EH1iSMfhYRjSJjCDoY4ZySqOOiCzBqPuTOIs70b3sIN00v+GBgF/0Ghl2Z
2SpitbSNNzujSQO39xyhoD4lUgTLdR0lsLdooh6aXoePQddA/ZnF3yyVdjvz
PCyNXWaD15+eaINDanGc4g9LlRW08vp6rUojMSqO00Llj9pKuFL1twr2V822
wNVcnwPmLH9ZayL6k3bXwfyZvXWnie3y5APwP0qRd7s=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"mixedsym", "[", 
     RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "\[Equal]", "0"}], 
   "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"g1", "\[Rule]", "0"}], ",", 
    RowBox[{"a1", "\[Rule]", "0"}], ",", 
    RowBox[{"e3", "\[Rule]", "0"}], ",", 
    RowBox[{"c6", "\[Rule]", "0"}], ",", 
    RowBox[{"ii", "\[Rule]", "0"}], ",", 
    RowBox[{"f1", "\[Rule]", "0"}], ",", 
    RowBox[{"c5", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619345259741219*^9, 3.619345290355543*^9}, {
  3.619345409277294*^9, 3.619345409868456*^9}, {3.619346565849185*^9, 
  3.619346598727993*^9}, {3.6193469612741003`*^9, 3.619346996375458*^9}, {
  3.619425060127437*^9, 3.6194252503626213`*^9}, {3.619509938995936*^9, 
  3.619509987777143*^9}, {3.6195100432496967`*^9, 3.6195101096122303`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["g", 
         RowBox[{"p", "t"}]], " ", 
        SuperscriptBox["g", 
         RowBox[{"q", "s"}]]}]}], "-", 
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"p", "s"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"q", "t"}]]}]}], ")"}]}], "\[LongEqual]", "0"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619345269190913*^9, 3.619345300146064*^9, 3.619345410139189*^9, {
   3.619346566379876*^9, 3.619346599020526*^9}, {3.619346957480111*^9, 
   3.619346996815539*^9}, {3.6194250725483103`*^9, 3.619425251112821*^9}, 
   3.619506601174234*^9, {3.619509940738439*^9, 3.61950997603132*^9}, {
   3.6195100679944468`*^9, 3.619510110465024*^9}, 3.6195131363958282`*^9, 
   3.619519261512183*^9}]
}, Open  ]],

Cell["\<\
As a result it is not possible to get rid of the mixed terms.\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyV1IU3EAhvFVuOFSmKtlNTMWYoMtlxPGnE059jVUDI20LenCtqEYRGVS
LdM+CGpLh5FN1LASEtEl1ixn9ClUTHDNSm1bhauIg9Vmp4zU2f89Fw+/i0dS
fqjYtJTD4chIUBc5MJPxjqa820IMvHlRZ91CDAdLWRPiPW9hzPzLSXjalJvN
G6cp2x1/Dgy4lY3w3NXndvhZUsIVEmvC51lNKkEmlLblamDyKZVfSezkj7Iq
UiQnsvCl/yzwSr1H6ScaN3zQsupqoxPvacrlrVuEbf2tzcf8NHWXGnbAnZNF
tTVEj5auh8xTYz+0ZX5jtVqOjMGShpEJqLe0T8HC1WlfYerlyP57v2hqb0e+
GQavhRL9xBVJWWshs1WUDAPrLOthyxcBN0gcyFfHQpfPFg/nOlpFUM0ZFA4x
NHXLKVoJBUOXzA+JPrO4Ar7ZNDgSIi55bBiF8xZHd8xvmnIUPOuBu/oeuWCq
+74bViQMf+IR9Tx9CNr93Dk5UcNEF2DUeNiVRpzu3f4Abp5a8MLAbstrGHbK
0hXEcmETa/rGOhXcceMoBbVJkTxYrGkpgF15Y9XQ8Cp8HDr7qs8u/qGplNuy
C7AwdpkVXn9ysgkOKPlx0lmaKsppZPV2meV6YpQfp4by75WlcJXibxnsLZtp
gGuYHjvMWP6i0kD0Je6pgtnT+6rOEJsl4oOw8+P4j26iuH32J/wPLdaDOg==

  "],
 Background->RGBColor[0.94, 0.88, 0.94]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "metric propagator in q-lightcone gauge with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["J", "++"], "=", "0"}], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.6194194195745707`*^9, 3.6194194456943274`*^9}, {
  3.619428562348688*^9, 3.619428562824698*^9}, {3.6195102106013927`*^9, 
  3.619510217248247*^9}}],

Cell[TextData[{
 "Try with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["J", "st"], 
     SubscriptBox["q", "s"], 
     SubscriptBox["q", "t"]}], "=", "0."}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyX0s1HEAx/Grxs3lGlc6SYqZrpHrjpnH+F3J4VIo3LHaxO2sP5qSVedp
1WzchbSKUdPDlhkydQo9Zz2x3UVEd2fNXa39Rrvjelg4fT+/P957/fH2zz+R
UbiaxWKJSFBqPzYfNkFThr0WB7xdI9XEEm3mbEZP7vA4dFl6NwUrCiW72Z9p
SnvfGA9NA+J6eOHq6wZo9c9y5RFLbRcZCyM8oqCgVRIN/coijGLiXY6eURjo
fzYGX/BPDa9UDYuNxIKA6ThGablz8gtN6QyVK7C1t+XaaSNNPaCGmmDSVHp5
KXE4jq6CjpcFvVAb9YNRoz45BrPqRiahXH1jBqZ5h36HQZfsRx4u0FROW6oS
mq9b+Ebiet8YH+jY4+UHTVvUW2HzNw9XM7EvNdIN6ka1XLjY1uIFI1n9vEEH
Td3p9toAPQZrlU+Io8rNKvhpZ/+IhbjquUIPl9RNHS6/aKpJ9qoTHuh5poNB
A48GoMpz6CubKGfLLbDB6LoYQox2OJehs6BYF0qc7Up8DHfNLBugKVP9Edq6
g0VCYj6vkVG0vTIC7rt1ioJxvvYUmBHdLIPtKWMlUPHedgZ295ScX/lNU4H3
gqthmtsaDbz54lwj7BNz3AV/aCo9vp7R0K4MkROdHPdIGDJXlA03Cv/mwa68
+Tq4ydHZAMPWvi1SEEf5h49DScKbanioRF8DOy9PJOUSa3ewk+Gsd8J+OB6w
Lh36mLnheUSrLJdx6Wh4MqyRWGVQxX96EH74mZoJF2PnsuF0xVQO3GYotncQ
eWWJC/A/8R21wA==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"w", "[", 
   RowBox[{"i_", ",", "j_", ",", "s_", ",", "t_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"Contract", "[", 
        RowBox[{
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a1", " ", 
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "j"}], "]"}], 
         RowBox[{"d", "[", 
          RowBox[{"s", ",", "t"}], "]"}]}], "+", 
        RowBox[{"a2", " ", 
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "s"}], "]"}], 
         RowBox[{"d", "[", 
          RowBox[{"j", ",", "t"}], "]"}]}], "+", 
        RowBox[{"a3", " ", 
         RowBox[{"d", "[", 
          RowBox[{"i", ",", "t"}], "]"}], 
         RowBox[{"d", "[", 
          RowBox[{"j", ",", "s"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"b1", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"b2", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"b3", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"b4", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"b5", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"b6", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"b7", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "+", 
           RowBox[{"b8", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "+", 
           RowBox[{"b9", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}], "+", 
           RowBox[{"b10", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"b11", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"b12", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "i"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"q", ",", "i"}], "]"}]}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"c1", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"c2", " ", 
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"c3", " ", 
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"c4", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"c5", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"c6", " ", 
            RowBox[{"d", "[", 
             RowBox[{"i", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}],
         "+", 
        RowBox[{"d", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "j"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"p", ",", "s"}], "]"}], 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "t"}], "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}]}],
         "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"e1", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"e2", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}], "+", 
           RowBox[{"e3", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}], "+", 
           RowBox[{"e4", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], 
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"f1", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"f2", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"f3", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"f4", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}], "+", 
           RowBox[{"f5", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}]}], "+", 
           RowBox[{"f6", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "2"}], ")"}]}], 
        "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"g1", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"g2", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"g3", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "j"}], "]"}]}], "+", 
           RowBox[{"g4", " ", 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"q", ",", "i"}], "]"}]}]}], ")"}], 
         RowBox[{
          RowBox[{"Contract", "[", 
           RowBox[{
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "3"}], ")"}]}]}],
         "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"h1", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}]}], "+", 
           RowBox[{"h2", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}]}], "+", 
           RowBox[{"h3", " ", 
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "+", 
           RowBox[{"h4", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "j"}], "]"}]}], "+", 
           RowBox[{"h5", " ", 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "j"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "i"}], "]"}]}], "+", 
           RowBox[{"h6", " ", 
            RowBox[{"d", "[", 
             RowBox[{"j", ",", "i"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "s"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "t"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"Contract", "[", 
          RowBox[{
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "o"}], "]"}], 
           RowBox[{"FVD", "[", 
            RowBox[{"p", ",", "o"}], "]"}]}], "]"}]}], "+", 
        RowBox[{"ii", " ", 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "i"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "j"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "s"}], "]"}], 
         RowBox[{"FVD", "[", 
          RowBox[{"q", ",", "t"}], "]"}], 
         RowBox[{
          RowBox[{
           RowBox[{"Contract", "[", 
            RowBox[{
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}], 
             RowBox[{"FVD", "[", 
              RowBox[{"p", ",", "i"}], "]"}]}], "]"}], "^", "2"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"p", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "^", "4"}], 
           ")"}]}]}]}], ")"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "s"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6179703517595673`*^9, 3.617970779129396*^9}, {
   3.617970879468876*^9, 3.617970919076379*^9}, {3.6179709519702663`*^9, 
   3.6179709533780193`*^9}, {3.617970984844159*^9, 3.61797114731628*^9}, {
   3.6179714109042788`*^9, 3.6179714542681723`*^9}, {3.617971514353078*^9, 
   3.617971601477254*^9}, {3.617971643385899*^9, 3.6179718972932*^9}, 
   3.6179719296959248`*^9, 3.617972009927199*^9, 3.617972050362486*^9, 
   3.6179724567357693`*^9, {3.617972660466942*^9, 3.617972672014579*^9}, 
   3.61797289536517*^9, {3.617972978809762*^9, 3.617972982014348*^9}, {
   3.617973026458253*^9, 3.6179730287227707`*^9}, 3.61803425058486*^9, {
   3.6180357071967497`*^9, 3.618035710039319*^9}, {3.618052871007208*^9, 
   3.618052921229148*^9}, {3.618052978179215*^9, 3.618053074353793*^9}, {
   3.618140015348394*^9, 3.6181400387410088`*^9}, {3.618140078679212*^9, 
   3.618140140134884*^9}, {3.618140224639729*^9, 3.618140275649692*^9}, {
   3.618140349871594*^9, 3.618140350074747*^9}, 3.618202878154153*^9, {
   3.618735662852004*^9, 3.618735698391954*^9}, {3.619342635843162*^9, 
   3.6193426480919933`*^9}, {3.61951026266216*^9, 3.619510286601647*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b9", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b12", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b8", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b11", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b10", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e4", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"h1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"h6", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c4", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f4", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"d", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6193440182432213`*^9, 3.619423800696354*^9, 
  3.619428568830606*^9, 3.61950659514508*^9, 3.6195088076061373`*^9, 
  3.619510291068219*^9, 3.619513136843811*^9, 3.619519261893508*^9}]
}, Open  ]],

Cell[TextData[{
 "Starting with the most generic ansatz with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["q", "2"], "=", "0"}], TraditionalForm]]],
 " we first restrict the coefficients such that:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["w", "abcd"], 
      SuperscriptBox["q", "a"]}], "=", "0"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SubscriptBox["w", "abcd"], 
      SuperscriptBox["q", "b"]}], "=", "0"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     SubscriptBox["w", "abcd"], "=", 
     RowBox[{
      SubscriptBox["w", 
       RowBox[{
        RowBox[{"(", "ab", ")"}], "cd"}]], "=", 
      SubscriptBox["w", 
       RowBox[{"ab", "(", "cd", ")"}]]}]}]}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyVtIk2EAh/FVuOFQmLORlBkL0YGmuWDM2ZTXTkPFUMGaF17oNrwLy6T6
MkdFoFspRjXRwg6QdJhizcOM1BI0Jri0g/ZtEVtFvARt9VWQOnv/38XD7+JR
1x2rtG6USCSZLGiK1v/c844S//6wAO+0mRx7mZHgEdGkRN9bGLc6uwzPWYsL
Ze8pcQ7wRTDg1XbAC9dedsLP6mqpktkcuShq1Snyoaa32ADTzup4LfOefF40
N119ugBf84+DV+0+Lc+07PxoFDW1xJY+UOLxt67D3qGe6yd5Sp6QaRc8tFzR
0sz0GakdClOWIejM/ybq4I4vwuorc0vQzN0MwfKUnK8w43K09ukvSo72ldpg
8EZ4C89MTi3YCoV9qjQY2M7tgN1fFNIgc7hUHw89C85EuNLXo4J6yZhyXKDk
rlu1GSrG223PmAu2bQ3wza6xuTBzw0TNPFzlXA/iflPiKnvxCB4efO6BGd4R
L2xImv4kY5pl5jDs5KUr2UyDEFuDMUujJ4f5/fGBUbg7tOaHgSruNYy4s/Jy
mXXKLtG8zFYdPHj7BIHG1GgJrDR0l8H+ksUmWPMqcgq6B5vOr/+hJP1+1iVY
Hr/JAW9NnumCw1p5guYvJRVFHaL+flu2mRmTJ+ihvf3HjJ2Z/DA0C/8DO9Zf
cQ==
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sys", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "dd"}], "]"}], "-", 
             RowBox[{"w", "[", 
              RowBox[{"b", ",", "a", ",", "c", ",", "dd"}], "]"}]}], 
            "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"w", "[", 
              RowBox[{"a", ",", "b", ",", "c", ",", "dd"}], "]"}], "-", 
             RowBox[{"w", "[", 
              RowBox[{"a", ",", "b", ",", "dd", ",", "c"}], "]"}]}], 
            "\[Equal]", "0"}], ",", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{"Expand", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "]"}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{"Expand", "[", 
              RowBox[{
               RowBox[{"w", "[", 
                RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], 
               RowBox[{"FVD", "[", 
                RowBox[{"q", ",", "j"}], "]"}]}], "]"}], "]"}], "\[Equal]", 
            "0"}]}], "}"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
           RowBox[{
            RowBox[{"Contract", "[", 
             RowBox[{
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "s"}], "]"}], 
              RowBox[{"FVD", "[", 
               RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
          "}"}]}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"h1", "\[Rule]", "0"}], ",", 
         RowBox[{"h2", "\[Rule]", "0"}], ",", 
         RowBox[{"h3", "\[Rule]", "0"}], ",", 
         RowBox[{"h4", "\[Rule]", "0"}], ",", 
         RowBox[{"h5", "\[Rule]", "0"}], ",", 
         RowBox[{"e1", "\[Rule]", "0"}], ",", 
         RowBox[{"e2", "\[Rule]", "0"}], ",", 
         RowBox[{"d", "\[Rule]", "0"}], ",", 
         RowBox[{"a3", "\[Rule]", "a2"}], ",", 
         RowBox[{"f5", "\[Rule]", "f2"}], ",", 
         RowBox[{"f4", "\[Rule]", "f3"}], ",", 
         RowBox[{"c4", "\[Rule]", "c3"}], ",", 
         RowBox[{"c2", "\[Rule]", "c1"}], ",", 
         RowBox[{"e4", "\[Rule]", "e3"}], ",", 
         RowBox[{"b12", "\[Rule]", "b9"}], ",", 
         RowBox[{"b11", "\[Rule]", "b8"}], ",", 
         RowBox[{"b10", "\[Rule]", "b7"}], ",", 
         RowBox[{"b6", "\[Rule]", "b5"}], ",", 
         RowBox[{"b3", "\[Rule]", "b2"}], ",", 
         RowBox[{"g2", "\[Rule]", "g1"}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b8", "\[Rule]", "b7"}], ",", 
       RowBox[{"b4", "\[Rule]", "b1"}], ",", 
       RowBox[{"b5", "\[Rule]", "b2"}], ",", 
       RowBox[{"c3", "\[Rule]", "c1"}], ",", 
       RowBox[{"f3", "\[Rule]", "f2"}], ",", 
       RowBox[{"b9", "\[Rule]", 
        RowBox[{"-", "a1"}]}]}], "}"}]}], ")"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b2", "\[Rule]", 
      RowBox[{"-", "a2"}]}], ",", 
     RowBox[{"h6", "\[Rule]", 
      RowBox[{"-", "e3"}]}], ",", 
     RowBox[{"b1", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}]}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.618736039868785*^9, 3.6187361229945707`*^9}, {
   3.618736172901292*^9, 3.6187362638114233`*^9}, {3.618736373365267*^9, 
   3.6187365127096252`*^9}, {3.618736543974063*^9, 3.618736704892205*^9}, {
   3.618736805831768*^9, 3.618736808003583*^9}, {3.618740688101403*^9, 
   3.618740700612451*^9}, {3.618907256931685*^9, 3.618907258880978*^9}, {
   3.6193427990585737`*^9, 3.619342882962376*^9}, {3.61934407829175*^9, 
   3.619344372349032*^9}, {3.6193444297212133`*^9, 3.6193444465401154`*^9}, {
   3.61934460414895*^9, 3.619344844114943*^9}, {3.619423820935863*^9, 
   3.619423825830516*^9}, {3.619423885988105*^9, 3.619423892588375*^9}, {
   3.619424021536643*^9, 3.6194240843253307`*^9}, {3.619424157667192*^9, 
   3.6194244585896397`*^9}, {3.619424677530136*^9, 3.6194246807318163`*^9}, {
   3.619510327508314*^9, 3.619510358170541*^9}, 3.619510447059803*^9, {
   3.6195106026548147`*^9, 3.6195106032086773`*^9}, {3.619510703734312*^9, 
   3.619510713400496*^9}, {3.619510744948284*^9, 3.619510763293185*^9}, {
   3.6195108170983973`*^9, 3.6195111249933643`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"True", ",", "True", ",", "True", ",", "True"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619159224269464*^9, 3.6193382099981613`*^9, 3.619344026217037*^9, 
   3.619344089501408*^9, {3.619344147609438*^9, 3.6193441568466377`*^9}, 
   3.619344254034203*^9, {3.6193443305568247`*^9, 3.619344374989933*^9}, 
   3.619344447591009*^9, {3.619344605057809*^9, 3.619344632438489*^9}, {
   3.619344680398192*^9, 3.619344705248294*^9}, {3.619344748027232*^9, 
   3.619344845363861*^9}, 3.619423875498185*^9, 3.6194239886956387`*^9, 
   3.6194240237659817`*^9, 3.619424109656242*^9, {3.6194241595640697`*^9, 
   3.6194242963764973`*^9}, {3.6194243331859083`*^9, 3.619424459513543*^9}, 
   3.619424681606709*^9, 3.619428583327437*^9, 3.619506598151864*^9, 
   3.619508814260186*^9, 3.619510347769953*^9, 3.6195106163846893`*^9, 
   3.619510727124015*^9, 3.619510764212512*^9, {3.6195108239432373`*^9, 
   3.61951091427036*^9}, {3.619510952528981*^9, 3.619511018236569*^9}, {
   3.619511060118928*^9, 3.619511126273753*^9}, 3.619513149945793*^9, 
   3.619519274613312*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"w", "[", 
       RowBox[{"i", ",", "j", ",", "s", ",", "t"}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"h1", "\[Rule]", "0"}], ",", 
        RowBox[{"h2", "\[Rule]", "0"}], ",", 
        RowBox[{"h3", "\[Rule]", "0"}], ",", 
        RowBox[{"h4", "\[Rule]", "0"}], ",", 
        RowBox[{"h5", "\[Rule]", "0"}], ",", 
        RowBox[{"e1", "\[Rule]", "0"}], ",", 
        RowBox[{"e2", "\[Rule]", "0"}], ",", 
        RowBox[{"d", "\[Rule]", "0"}], ",", 
        RowBox[{"a3", "\[Rule]", "a2"}], ",", 
        RowBox[{"f5", "\[Rule]", "f2"}], ",", 
        RowBox[{"f4", "\[Rule]", "f3"}], ",", 
        RowBox[{"c4", "\[Rule]", "c3"}], ",", 
        RowBox[{"c2", "\[Rule]", "c1"}], ",", 
        RowBox[{"e4", "\[Rule]", "e3"}], ",", 
        RowBox[{"b12", "\[Rule]", "b9"}], ",", 
        RowBox[{"b11", "\[Rule]", "b8"}], ",", 
        RowBox[{"b10", "\[Rule]", "b7"}], ",", 
        RowBox[{"b6", "\[Rule]", "b5"}], ",", 
        RowBox[{"b3", "\[Rule]", "b2"}], ",", 
        RowBox[{"g2", "\[Rule]", "g1"}]}], "}"}]}], ")"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"b8", "\[Rule]", "b7"}], ",", 
      RowBox[{"b4", "\[Rule]", "b1"}], ",", 
      RowBox[{"b5", "\[Rule]", "b2"}], ",", 
      RowBox[{"c3", "\[Rule]", "c1"}], ",", 
      RowBox[{"f3", "\[Rule]", "f2"}], ",", 
      RowBox[{"b9", "\[Rule]", 
       RowBox[{"-", "a1"}]}]}], "}"}]}], ")"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"b2", "\[Rule]", 
     RowBox[{"-", "a2"}]}], ",", 
    RowBox[{"h6", "\[Rule]", 
     RowBox[{"-", "e3"}]}], ",", 
    RowBox[{"b1", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "b7"}], "-", "f2"}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619344865396747*^9, 3.619344871438109*^9}, {
  3.619346338533216*^9, 3.619346368271214*^9}, {3.619424463691934*^9, 
  3.61942446899702*^9}, {3.61942467274938*^9, 3.6194246745941553`*^9}, {
  3.619511155789122*^9, 3.6195111757546577`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "s"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "j"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"j", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"i", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["i",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["j",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "3"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619344872446163*^9, {3.6193463481406612`*^9, 3.619346369115699*^9}, 
   3.61942446987114*^9, 3.619424683007712*^9, 3.619428585583086*^9, 
   3.619506598237074*^9, 3.6195088209208803`*^9, 3.619511176783217*^9, 
   3.619513150117107*^9, 3.619519274778503*^9}]
}, Open  ]],

Cell["w is now given in terms of a2, b7, c1, c5, e3, f1, f2, g1", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyWtIU3EAhvFVuOFS2VaryEtMxAZbLheMOVty7DacLDTQNsIPtg2DoIuX
tOPSLgS1lWKUEy3MgqRsyWqWM7pKFBO21ErbFuEq4lCw1bJInf3f8+Hh9+GR
VB8styzlcDgyEtTF9v3c9I6hAtsicdh3VmffTIyGK1mFqb63MGn+1TQ8bine
wnvPUI67wSIY8irb4KlLL9rhZ0kFV0RsiJ5mtagEBVDaU6yBWc2qoJJ4g+9n
VeRImgrxpf9oeLHVpwwSzdkftaw6W2LqA0N5Ai2LsMfdfbk+yFD3qFEn3Dld
Zmsg+rRMK4w/M7uho+Abq50+MgErLoxNQSN9ZQYa1uR9hbnnY1X3fzHUnl69
FYY7I6uDxBUZhWthfKs4C4Yy6XWw64uAGyYO6dXJ0DPuSIVzvd1iqOYMi0bi
DHXdJV4JBSPnrI+I49b0Gji5YXgsQlzyxOSH87TzVtJvhnKWPh+AuwYfe2Cu
94EX1ghHP/GIRp4xAtuD3Dk5URNPLMCE+bAnj/j9zvaHcOPMQgCGdtNvYNQl
y1cQq0UdrPnrW1Rwx7VaCmozYiWwXNNVCvtLJuqg6XW0EboG604uzjJUzk3Z
GWhIXmaHV58e64BDSn6K9A9DlRW1sQb6rXIjMcFPUUP5j/2VcJXi717or19u
MBEnX2azpumFjXDWdqgJVrkPpJ8gakSSTCho7qy9TRxIMx+F/wGz7n5y
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Talt", "[", 
   RowBox[{"k_", ",", "l_", ",", "m_", ",", "n_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{"1", "/", "2"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"m", ",", "n"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"l", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "x"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"m", ",", "x"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"l", ",", "n"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"d", "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "m"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"l", ",", "n"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"d", "[", 
       RowBox[{"x", ",", "y"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"k", ",", "l"}], "]"}], 
      RowBox[{"d", "[", 
       RowBox[{"m", ",", "n"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.619428615537554*^9, 3.619428667664604*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"k", "x"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"l", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "n"}]]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"k", "l"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "n"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"x", "y"}]]}], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"k", "y"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"l", "n"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "x"}]]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"k", "m"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"l", "n"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"x", "y"}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619428668954516*^9, 3.6195065989180613`*^9, 
  3.619508851289557*^9, 3.619511264784423*^9, 3.619513150171679*^9, 
  3.619519274841214*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Taltsym", "[", 
   RowBox[{"k_", ",", "l_", ",", "m_", ",", "n_", ",", "x_", ",", "y_"}], 
   "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", "8"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Talt", "[", 
       RowBox[{"k", ",", "l", ",", "m", ",", "n", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"l", ",", "k", ",", "m", ",", "n", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"k", ",", "l", ",", "n", ",", "m", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"l", ",", "k", ",", "n", ",", "m", ",", "x", ",", "y"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"m", ",", "n", ",", "k", ",", "l", ",", "y", ",", "x"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"n", ",", "m", ",", "k", ",", "l", ",", "y", ",", "x"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"m", ",", "n", ",", "l", ",", "k", ",", "y", ",", "x"}], "]"}],
       "+", 
      RowBox[{"Talt", "[", 
       RowBox[{"n", ",", "m", ",", "l", ",", "k", ",", "y", ",", "x"}], 
       "]"}]}], ")"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.6194287289281807`*^9, 3.619428740811838*^9}, {
  3.6194975014281816`*^9, 3.619497539837103*^9}, {3.6194979178290253`*^9, 
  3.619497984315345*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "y"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "x"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"x", "y"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "+", 
   RowBox[{
    FractionBox["1", "16"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"k", "l"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}], "-", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["g", 
     RowBox[{"l", "k"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "m"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"y", "x"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619428736105389*^9, 3.6194287413712187`*^9}, 
   3.61950659901649*^9, 3.619507293932802*^9, 3.6195088533604193`*^9, 
   3.619511266988407*^9, 3.619513150256522*^9, 3.619519274935656*^9}]
}, Open  ]],

Cell[TextData[{
 "The mixed terms are the following expression contracted into ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["J", "st"]}], 
    RowBox[{
     SubscriptBox["h", "mn"], "'"}]}], TraditionalForm]]],
 ".\n"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwlyVtIU3EAx/FVuOFSmKtVlBkTWSOXywVjzpYcuw2VhQabW9GDbcOeoppS
nUypCGorxW4bs7ALJFJLbLOc0VUi2WBLrbSzRbiKOBRstS6kzv6/08OXz8NX
2rCvzjafx+OtIUF9as/39W9YKro5kYbXT+udG4jJuIkzLzf0GmbNvJyEx2yV
GwVvWcp1l6mAsaCqHZ64+LwDfpQa+WJic/Ikp00tKoPyrkotLDiqZlTEm8II
p7JIergcX/6XhufbQiqGaC18r+PUt2Qm3rFUINo6B7v6vZeaGJa6Rw274bbJ
2pZmYkjHtsH0U2s/dJV94XTSB8ag8Vx4AprpK1PQsKzkM5SdTe32/2Cp+u5q
O4xfTixliIvyy5fD9CZJAYytpFdBzycRP04cqNZkw8CoKxdOd3slUMMbFA+l
WeqGT7IYiobO2B8SR+0rGuH42sFwgjjvsSUCZ2h3b9ZPlnLXPLsNt/c9CkBZ
8H4QNuYNfxAQzQJzAnYw/GkFUZvOzMKMdX+ghPj1zpYHcN3UbBTGdtCvYNJX
XKokNog7OUtXt6rh1msHKajLT1XBOq2nBvZUjTmgZSR5CPr6HMfnfrFU0a3i
U9CQvcAJrz450gkHVMIc+W+Wqq1o54z22BVmYkaYo4GKb3tNcInyzy4YaVpo
sBDHXxRyevUjsp3EC44wp8dY7+8l+k3//Qc123h/
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixed", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Talt", "[", 
             RowBox[{"m", ",", "n", ",", "c", ",", "dd", ",", "x", ",", "y"}],
              "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "x"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "y"}], "]"}], " ", 
            RowBox[{"w", "[", 
             RowBox[{"c", ",", "dd", ",", "s", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"Talt", "[", 
             RowBox[{"a", ",", "b", ",", "m", ",", "n", ",", "x", ",", "y"}], 
             "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "x"}], "]"}], 
            RowBox[{"FVD", "[", 
             RowBox[{"p", ",", "y"}], "]"}], 
            RowBox[{"w", "[", 
             RowBox[{"a", ",", "b", ",", "s", ",", "t"}], "]"}]}], "-", 
           RowBox[{
            RowBox[{"d", "[", 
             RowBox[{"s", ",", "m"}], "]"}], 
            RowBox[{"d", "[", 
             RowBox[{"t", ",", "n"}], "]"}]}]}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"h1", "\[Rule]", "0"}], ",", 
           RowBox[{"h2", "\[Rule]", "0"}], ",", 
           RowBox[{"h3", "\[Rule]", "0"}], ",", 
           RowBox[{"h4", "\[Rule]", "0"}], ",", 
           RowBox[{"h5", "\[Rule]", "0"}], ",", 
           RowBox[{"e1", "\[Rule]", "0"}], ",", 
           RowBox[{"e2", "\[Rule]", "0"}], ",", 
           RowBox[{"d", "\[Rule]", "0"}], ",", 
           RowBox[{"a3", "\[Rule]", "a2"}], ",", 
           RowBox[{"f5", "\[Rule]", "f2"}], ",", 
           RowBox[{"f4", "\[Rule]", "f3"}], ",", 
           RowBox[{"c4", "\[Rule]", "c3"}], ",", 
           RowBox[{"c2", "\[Rule]", "c1"}], ",", 
           RowBox[{"e4", "\[Rule]", "e3"}], ",", 
           RowBox[{"b12", "\[Rule]", "b9"}], ",", 
           RowBox[{"b11", "\[Rule]", "b8"}], ",", 
           RowBox[{"b10", "\[Rule]", "b7"}], ",", 
           RowBox[{"b6", "\[Rule]", "b5"}], ",", 
           RowBox[{"b3", "\[Rule]", "b2"}], ",", 
           RowBox[{"g2", "\[Rule]", "g1"}]}], "}"}]}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b8", "\[Rule]", "b7"}], ",", 
         RowBox[{"b4", "\[Rule]", "b1"}], ",", 
         RowBox[{"b5", "\[Rule]", "b2"}], ",", 
         RowBox[{"c3", "\[Rule]", "c1"}], ",", 
         RowBox[{"f3", "\[Rule]", "f2"}], ",", 
         RowBox[{"b9", "\[Rule]", 
          RowBox[{"-", "a1"}]}]}], "}"}]}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b2", "\[Rule]", 
        RowBox[{"-", "a2"}]}], ",", 
       RowBox[{"h6", "\[Rule]", 
        RowBox[{"-", "e3"}]}], ",", 
       RowBox[{"b1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "b7"}], "-", "f2"}]}]}], "}"}]}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "m"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "n"}], "]"}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.619343088326528*^9, 3.6193431592784*^9}, {
   3.619343449142192*^9, 3.619343459751338*^9}, {3.619344916020316*^9, 
   3.6193449936098337`*^9}, {3.6193450406949263`*^9, 
   3.6193450420955353`*^9}, {3.619346745876843*^9, 3.619346781902206*^9}, {
   3.6194246980892076`*^9, 3.61942470458995*^9}, {3.619424855350925*^9, 
   3.619424873015131*^9}, {3.619424919677514*^9, 3.619424921935769*^9}, {
   3.6194249602829733`*^9, 3.619424968051961*^9}, {3.619428678336111*^9, 
   3.6194286813185062`*^9}, 3.619509773333761*^9, {3.6195113287742653`*^9, 
   3.619511360710836*^9}, {3.619511395612479*^9, 3.619511402462801*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "-", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "+", 
   RowBox[{"a1", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   RowBox[{"a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "c5", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "a1", " ", "D", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "b7"}], "-", "f2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619344969765562*^9, 3.619344999223496*^9}, 
   3.619345046190477*^9, 3.619345111447053*^9, 3.619346481397852*^9, 
   3.619346785424179*^9, 3.619424787208252*^9, 3.619424885318141*^9, 
   3.619424936297092*^9, 3.619424980088998*^9, 3.619428702752151*^9, 
   3.619506600648134*^9, 3.619509782444858*^9, 3.619511408505575*^9, 
   3.6195131544917603`*^9, 3.619519279208871*^9}]
}, Open  ]],

Cell["In this contraction only the symmetric parts contribute:", "Text",
 CellChangeTimes->{{3.6019649471232033`*^9, 3.60196496710215*^9}, {
   3.601982554266801*^9, 3.601982554745842*^9}, {3.601983150345345*^9, 
   3.601983182280764*^9}, {3.602397682074889*^9, 3.602397694865179*^9}, {
   3.60239832958531*^9, 3.602398342112001*^9}, {3.602419762691637*^9, 
   3.602419764154353*^9}, {3.60242016850664*^9, 3.602420178081562*^9}, {
   3.602487001702651*^9, 3.602487006470049*^9}, {3.602504649035667*^9, 
   3.602504671817402*^9}, {3.602831766359445*^9, 3.602831854941698*^9}, {
   3.6044001159150867`*^9, 3.604400123994227*^9}, {3.604720820865553*^9, 
   3.60472083813302*^9}, {3.604722666557773*^9, 3.604722695320043*^9}, {
   3.604723091148676*^9, 3.604723095257025*^9}, {3.604723355577581*^9, 
   3.604723398392375*^9}, {3.604723476921307*^9, 3.604723505440467*^9}, {
   3.61743231154848*^9, 3.617432370363323*^9}, {3.617511615112288*^9, 
   3.617511633847177*^9}, {3.617511664664545*^9, 3.617511675847395*^9}, {
   3.617515568528027*^9, 3.617515593759242*^9}, {3.617515628400721*^9, 
   3.617515692863401*^9}, {3.6179703257812767`*^9, 3.617970336677568*^9}, {
   3.617973044335335*^9, 3.6179730568563013`*^9}, {3.6180537337868443`*^9, 
   3.618053754835816*^9}, {3.618123092765135*^9, 3.61812311007185*^9}, {
   3.618123181959022*^9, 3.618123221741473*^9}, {3.618127622127125*^9, 
   3.618127642782147*^9}, {3.618203608214302*^9, 3.618203631967313*^9}, {
   3.618207147543578*^9, 3.6182071701774807`*^9}, {3.618207367933861*^9, 
   3.6182073718539867`*^9}, {3.6182081373651047`*^9, 3.618208140564744*^9}, {
   3.618208179973534*^9, 3.6182082676134367`*^9}, {3.618208343534697*^9, 
   3.618208356788369*^9}, {3.6182086786028633`*^9, 3.618208711524579*^9}, {
   3.6191590596465673`*^9, 3.619159089364153*^9}, {3.619159128094886*^9, 
   3.619159187836013*^9}, {3.6192420803186903`*^9, 3.619242084476479*^9}, {
   3.619342691208107*^9, 3.619342784376342*^9}, {3.6193430353102016`*^9, 
   3.619343079755748*^9}, {3.619343479573813*^9, 3.619343493404797*^9}, 
   3.6194247436576567`*^9},
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixedsym", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mixed", "[", 
         RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "+", 
        RowBox[{"mixed", "[", 
         RowBox[{"t", ",", "s", ",", "m", ",", "n"}], "]"}]}], ")"}], "+", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"mixed", "[", 
         RowBox[{"s", ",", "t", ",", "n", ",", "m"}], "]"}], "+", 
        RowBox[{"mixed", "[", 
         RowBox[{"t", ",", "s", ",", "n", ",", "m"}], "]"}]}], ")"}]}], 
     ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619343495328998*^9, 3.619343505263935*^9}, {
  3.619343663360697*^9, 3.6193437075143967`*^9}, {3.619345076376606*^9, 
  3.619345114343253*^9}, {3.619346909115327*^9, 3.619346939172804*^9}, {
  3.619424751054744*^9, 3.619424758742614*^9}, {3.619424998237258*^9, 
  3.6194249984932127`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "+", 
   RowBox[{"a1", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   RowBox[{"a2", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", "c5", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   RowBox[{
    FractionBox["1", "2"], " ", "a1", " ", "D", " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "n"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"s", "t"}]]}], "-", 
   FractionBox[
    RowBox[{"a1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"a1", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"a2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{"f1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", "D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", "f2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"c1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"b7", " ", "D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", "f2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   FractionBox[
    RowBox[{"g1", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", "f2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", "b7", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"b7", " ", "D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", "f2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"f2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", "e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"e3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"],
      TraditionalForm], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619344029323474*^9, {3.619345027985772*^9, 3.619345114964498*^9}, 
   3.619346531926855*^9, 3.619346796641436*^9, 3.619346942596128*^9, 
   3.619425003973073*^9, 3.619506600815529*^9, 3.619509885837367*^9, 
   3.619511428566633*^9, 3.619513154560403*^9, 3.619519279291953*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Filter", "[", 
  RowBox[{
   RowBox[{"mixedsym", "[", 
    RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], ",", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "s"}], "]"}], 
     RowBox[{"FVD", "[", 
      RowBox[{"q", ",", "t"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619511467545761*^9, 3.619511475578136*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.619511476102591*^9, 3.6195131546199636`*^9, 
  3.619519279361154*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"mixedsym", "[", 
   RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "-", 
  RowBox[{"mixedsym", "[", 
   RowBox[{"t", ",", "s", ",", "p", ",", "q"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619345190144669*^9, 3.619345198654861*^9}, {
  3.619425045767671*^9, 3.619425050264908*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6193451940386257`*^9, 3.6193451990910597`*^9}, 
   3.61934653463984*^9, 3.6193468030883083`*^9, 3.61934694495994*^9, {
   3.6194250470347643`*^9, 3.6194250506310263`*^9}, 3.619506600862376*^9, 
   3.619509917449135*^9, 3.6195131546525517`*^9, 3.619519279405427*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Contract", "[", 
  RowBox[{
   RowBox[{"mixedsym", "[", 
    RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "-", 
   RowBox[{"mixedsym", "[", 
    RowBox[{"s", ",", "t", ",", "q", ",", "p"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.619345121783123*^9, 3.619345180325617*^9}, {
  3.619346871060742*^9, 3.619346873837055*^9}, {3.619425052649048*^9, 
  3.619425056221531*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6193451323681507`*^9, 3.619345180867734*^9}, 
   3.619346535888644*^9, 3.619346804744907*^9, 3.6193468742248096`*^9, 
   3.619346947655848*^9, 3.619425056506399*^9, 3.6195066008995657`*^9, 
   3.619509918872862*^9, 3.619513154686131*^9, 3.619519279442955*^9}]
}, Open  ]],

Cell["Now want that these mixed terms vanish. D\[NotEqual]2", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyWtIU3EAhvFVuOFSmLNlpRkL0ZHL5YQxZ1OO3YaKoZG2JX2wbSgGUZlU
J9MuBLWlw8gmWmgFSegSa5YzugoVE1yzi3a2CFcRB4PNThdSZ//3fHj4fXjk
1QfLLUsFAsEGEjRE9s/mvGcp39YQB29cMNg2E8PBSt6EeO87GDP/agqeshTm
iz6wlP0uUwADHnUrPHvlhQN+kVcIpcSG8Dlei0aSCxVdhTqYelLDqIm3xOO8
qjT58Tx8xT8aXm72qhmief0nPa+hMTr5kaXcvqZF2DXY2X6UYal71KgT7pgq
a2wgevVsM+SemQehPfc7r40+PAErWsYmoZG+Ng1LV2V9g+mXIvvu/2SpPd3F
Vhi8GkpiiIkpeWsgt0WWCgNr6XWw46tEGCQOFWtjodtvj4dz3Z0yqBUMS0c4
lrrpkq2AkpGL1kdEvzW5Br7dODwWIi55YhqH87TzTswvlnKWPO+DOwceu2G6
54EH1iSMfhYRjSJjCDoY4ZySqOOiCzBqPuTOIs70b3sIN00v+GBgF/0Ghl2Z
2SpitbSNNzujSQO39xyhoD4lUgTLdR0lsLdooh6aXoePQddA/ZnF3yyVdjvz
PCyNXWaD15+eaINDanGc4g9LlRW08vp6rUojMSqO00Llj9pKuFL1twr2V822
wNVcnwPmLH9ZayL6k3bXwfyZvXWnie3y5APwP0qRd7s=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"mixedsym", "[", 
     RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "\[Equal]", "0"}], 
   "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"c1", "\[Rule]", "0"}], ",", 
    RowBox[{"a2", "\[Rule]", "1"}], ",", 
    RowBox[{"b7", "\[Rule]", 
     RowBox[{"-", "1"}]}], ",", 
    RowBox[{"e3", "\[Rule]", "0"}], ",", 
    RowBox[{"f1", "\[Rule]", "2"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619345259741219*^9, 3.619345290355543*^9}, {
   3.619345409277294*^9, 3.619345409868456*^9}, {3.619346565849185*^9, 
   3.619346598727993*^9}, {3.6193469612741003`*^9, 3.619346996375458*^9}, {
   3.619425060127437*^9, 3.6194252503626213`*^9}, {3.619509938995936*^9, 
   3.619509987777143*^9}, {3.6195100432496967`*^9, 3.6195101096122303`*^9}, 
   3.619511498430678*^9, {3.619511528919511*^9, 3.6195115300041037`*^9}, {
   3.619511579663123*^9, 3.619511632534823*^9}, {3.619511664832369*^9, 
   3.61951166693607*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"], " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], "2"], " ", 
       SuperscriptBox["g", 
        RowBox[{"p", "q"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"a1", " ", 
              RowBox[{"(", 
               RowBox[{"D", "-", "2"}], ")"}]}]}], "+", "c5", "-", "2"}], 
           ")"}], " ", 
          SuperscriptBox["g", 
           RowBox[{"s", "t"}]], " ", 
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}]}], "+", 
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["t",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["s",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"D", " ", "f2"}], "-", "D", "-", 
            RowBox[{"2", " ", "f2"}], "+", "g1", "+", "4"}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["s",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["t",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"D", " ", "f2"}], "-", "D", "-", 
            RowBox[{"2", " ", "f2"}], "+", "g1", "+", "4"}], ")"}]}]}], 
        ")"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["p",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["q",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox[
            FormBox["p",
             TraditionalForm], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"a1", " ", 
              RowBox[{"(", 
               RowBox[{"D", "-", "2"}], ")"}]}], "+", "2"}], ")"}], " ", 
           SuperscriptBox["g", 
            RowBox[{"s", "t"}]], " ", 
           RowBox[{
            FormBox["p",
             TraditionalForm], "\[CenterDot]", 
            FormBox["q",
             TraditionalForm]}]}]}], "+", 
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"D", "-", "2"}], ")"}], " ", "f2"}], "-", "D", "+", 
            "4"}], ")"}], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["t",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["s",
             TraditionalForm],
            TraditionalForm]]}], "+", 
         RowBox[{
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"D", "-", "2"}], ")"}], " ", "f2"}], "-", "D", "+", 
            "4"}], ")"}], " ", 
          SuperscriptBox[
           FormBox["p",
            TraditionalForm], 
           FormBox[
            FormBox["s",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox["q",
            TraditionalForm], 
           FormBox[
            FormBox["t",
             TraditionalForm],
            TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "\[LongEqual]", "0"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619345269190913*^9, 3.619345300146064*^9, 3.619345410139189*^9, {
   3.619346566379876*^9, 3.619346599020526*^9}, {3.619346957480111*^9, 
   3.619346996815539*^9}, {3.6194250725483103`*^9, 3.619425251112821*^9}, 
   3.619506601174234*^9, {3.619509940738439*^9, 3.61950997603132*^9}, {
   3.6195100679944468`*^9, 3.619510110465024*^9}, 3.619511500371229*^9, 
   3.6195115337468557`*^9, {3.619511588565227*^9, 3.619511605675857*^9}, 
   3.619511639541394*^9, 3.619511684853887*^9, 3.619513155323098*^9, 
   3.619519280108231*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sys", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "a1"}], " ", 
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}]}], "+", "c5", "-", "2"}], "\[Equal]", 
      "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"D", " ", "f2"}], "-", "D", "-", 
       RowBox[{"2", " ", "f2"}], "+", "g1", "+", "4"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"D", " ", "f2"}], "-", "D", "-", 
       RowBox[{"2", " ", "f2"}], "+", "g1", "+", "4"}], "\[Equal]", "0"}], 
     ",", 
     RowBox[{
      RowBox[{
       RowBox[{"a1", " ", 
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}]}], "+", "2"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], " ", "f2"}], "-", "D", "+", "4"}], 
      "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], " ", "f2"}], "-", "D", "+", "4"}], 
      "\[Equal]", "0"}]}], "}"}]}], ";", 
  RowBox[{"sys", "//", "TableForm"}]}]], "Input",
 CellChangeTimes->{{3.619511769459227*^9, 3.619511852594228*^9}}],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a1", " ", 
           RowBox[{"(", 
            RowBox[{"D", "-", "2"}], ")"}]}]}], "+", "c5", "-", "2"}], 
        "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"D", " ", "f2"}], "-", "D", "-", 
         RowBox[{"2", " ", "f2"}], "+", "g1", "+", "4"}], "\[LongEqual]", 
        "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"D", " ", "f2"}], "-", "D", "-", 
         RowBox[{"2", " ", "f2"}], "+", "g1", "+", "4"}], "\[LongEqual]", 
        "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{"a1", " ", 
          RowBox[{"(", 
           RowBox[{"D", "-", "2"}], ")"}]}], "+", "2"}], "\[LongEqual]", 
        "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"D", "-", "2"}], ")"}], " ", "f2"}], "-", "D", "+", "4"}], 
        "\[LongEqual]", "0"}]},
      {
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"D", "-", "2"}], ")"}], " ", "f2"}], "-", "D", "+", "4"}], 
        "\[LongEqual]", "0"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619511844030089*^9, 3.6195118531901417`*^9}, 
   3.619513155354865*^9, 3.619519280194261*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"res", "=", 
  RowBox[{"Solve", "[", "sys", "]"}]}]], "Input",
 CellChangeTimes->{{3.619511890875486*^9, 3.619511893297867*^9}, {
  3.619512055409897*^9, 3.6195120561221733`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c5", "\[Rule]", "0"}], ",", 
     RowBox[{"g1", "\[Rule]", "0"}], ",", 
     RowBox[{"a1", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["2", 
        RowBox[{"D", "-", "2"}]]}]}], ",", 
     RowBox[{"f2", "\[Rule]", 
      FractionBox[
       RowBox[{"D", "-", "4"}], 
       RowBox[{"D", "-", "2"}]]}]}], "}"}], "}"}], TraditionalForm]], "Output",\

 CellChangeTimes->{3.619511893677175*^9, 3.6195120569180803`*^9, 
  3.619513155398506*^9, 3.619519280245894*^9}]
}, Open  ]],

Cell["\<\
As a result it is now possible to get rid of the mixed terms! But the metric \
propagator is now ambiguous:\
\>", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyV1IU3EAhvFVuOFSmNaymhkLsYHL5YQxtSnHvoaKoZG2JV3YNiZGUdmo
TqZ9ENSWDiObqGElJKZLrFlq9ClUTHBOS+3MClcRB6tpKyN19n/PxcPv4pGW
HC4wLuXxeHIS1E4fmEl5x1Kebf4gvHVJa91CDEwUcUZFut/CsPnX4/CMMStD
MMpStntMJvT1Kmvg+Wsv7fCztJAfTbQELnAaVaJUKGvMSoNxp1WMktgiHORU
xEtPpuPL/tHwapVbyRANGz5oOLUVobH3LOXyVC7Cxq6GuuMMS92n+h1w53h+
hYXo1rBVMPjc0AVtqd84rfTRYVhYPTAGdXTTJMxbnfQVJlyZ3v/gF0vtbc4x
wYnr/hiGuCI2fS0MbhXHQd86ej2s/yLiTxC7c9Th0OW1RcK55gYxVPN6ovuC
LHXbKV4JRX2XTY+JXpPEDEc29Qz4iUue6gfhPO1oC/vNUo7cF+1wV+cTF0zo
fdgLzVH9nwREnUDnh3aGPycnpgVDCzBkOOJKIk51bH8EN08ueKBvNz0EA87E
ZAWxJLqWM3ljpQruuHmMgprY6WxYkFafC1uzh8uh/k3gBHR2lp9b/MNS8XcS
L8K88GVWeOPZqVrYrRRGyGZZKj+zhtPTapLriCFhhBrKv5cWwVWKv8Wwo3im
Gq4JttthyvJXpXqiN2ZPGcyY2ld2llgnlRyELR9Hf7QRJU2zP6HZbRm6SzxE
60bgf7rnjWU=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"mixedsym", "[", 
     RowBox[{"s", ",", "t", ",", "p", ",", "q"}], "]"}], "\[Equal]", "0"}], 
   "]"}], "/.", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c1", "\[Rule]", "0"}], ",", 
      RowBox[{"a2", "\[Rule]", "1"}], ",", 
      RowBox[{"b7", "\[Rule]", 
       RowBox[{"-", "1"}]}], ",", 
      RowBox[{"e3", "\[Rule]", "0"}], ",", 
      RowBox[{"f1", "\[Rule]", "2"}]}], "}"}], ",", 
    RowBox[{"res", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619345259741219*^9, 3.619345290355543*^9}, {
  3.619345409277294*^9, 3.619345409868456*^9}, {3.619346565849185*^9, 
  3.619346598727993*^9}, {3.6193469612741003`*^9, 3.619346996375458*^9}, {
  3.619512035971718*^9, 3.6195120745996447`*^9}}],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.619345269190913*^9, 3.619345300146064*^9, 3.619345410139189*^9, {
   3.619346566379876*^9, 3.619346599020526*^9}, {3.619346957480111*^9, 
   3.619346996815539*^9}, {3.619512067656061*^9, 3.619512080151187*^9}, 
   3.619513160518064*^9, 3.619519285627831*^9}]
}, Open  ]],

Cell[TextData[{
 "Hence, the JJ term is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["J", "st"]}], 
    SuperscriptBox["J", "mn"]}], TraditionalForm]]],
 "times the following expression:\n\n(The propagator is the following term \
multiplied by 2i (up to the ambiguities)"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdyX0s1HEAx/Gr5m4u2lE6SRozaeTh2O2cLn7Xg8OlUHRYNnE7649SsuoS
q2Y7dyEtMWp62LLiMnUKPWc9sbmI6O5ac6e139SOfj0snL6f3x/vvf54BxYc
yihayuFwokhQMXNgNmaMpszb7Ay8rlPoNxOdtmxWL8+BUeg2/2YCni6Sb+F9
pCnDXUsCtPaKauHZSy/roCMwi+tNLHOeYy0SC+JgaItcCgNOiS0i4k3+EGtk
cOCJePzQf1p4sXJAZCEWBn2WsSrKXeOfaMpkrliELV3NDccsNHWP6m+ESRPp
5WXEARldCZnnhV3QEPeNVa89MgKzagbHoUp7ZRKm+UZ8hSHnZ/bf/0lT+1pT
1dB22S60EFf6x/tBZqtPALSu066HTVMCro3YnSpxh6Zhgyeca232gRJOj3cf
Q1M3jD6roKCvWv2IOKxeq4EfNvUM2olLnuYMwXlt4223XzTVqHzRDnd1PjHB
kN4HvVDj1f+FR1TxVHZYZ+HOhROljGsBugpLTBHE6Y7tD2HU5IIZWjO176HT
GBYdSSzwrmeN3lAhhjuuHaWgzH8mBWZIm5SwLWWkFOa8dR6Hxs7SM4u/aSr4
VlgVTHNfpodXn52sh90ivkfoH5pKT6hlNbepw1VEF99DAsO/F2fD1ZF/82BH
3mwNXMO018GY5a+Lc4jDwr0HoTzxVRXcUzqkg+0XxpJyidUbeclw2jdxJxwN
WpEO/WyesXlEhzKXdT4/Nhnq5A4l1Agf74bvfqRmwsMl+Y47RH6EcAr+B9AF
qv0=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prop", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"1", "/", 
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"p", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], 
    RowBox[{"Contract", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}]}], "]"}], 
        RowBox[{"(", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Talt", "[", 
                   RowBox[{
                   "a", ",", "b", ",", "c", ",", "dd", ",", "x", ",", "y"}], 
                   "]"}], 
                  RowBox[{"FVD", "[", 
                   RowBox[{"p", ",", "x"}], "]"}], 
                  RowBox[{"FVD", "[", 
                   RowBox[{"p", ",", "y"}], "]"}], 
                  RowBox[{"w", "[", 
                   RowBox[{"a", ",", "b", ",", "s", ",", "t"}], "]"}], 
                  RowBox[{"w", "[", 
                   RowBox[{"c", ",", "dd", ",", "m", ",", "n"}], "]"}]}], "-", 
                 RowBox[{"w", "[", 
                  RowBox[{"m", ",", "n", ",", "s", ",", "t"}], "]"}]}], ")"}],
                "/.", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"h1", "\[Rule]", "0"}], ",", 
                 RowBox[{"h2", "\[Rule]", "0"}], ",", 
                 RowBox[{"h3", "\[Rule]", "0"}], ",", 
                 RowBox[{"h4", "\[Rule]", "0"}], ",", 
                 RowBox[{"h5", "\[Rule]", "0"}], ",", 
                 RowBox[{"e1", "\[Rule]", "0"}], ",", 
                 RowBox[{"e2", "\[Rule]", "0"}], ",", 
                 RowBox[{"d", "\[Rule]", "0"}], ",", 
                 RowBox[{"a3", "\[Rule]", "a2"}], ",", 
                 RowBox[{"f5", "\[Rule]", "f2"}], ",", 
                 RowBox[{"f4", "\[Rule]", "f3"}], ",", 
                 RowBox[{"c4", "\[Rule]", "c3"}], ",", 
                 RowBox[{"c2", "\[Rule]", "c1"}], ",", 
                 RowBox[{"e4", "\[Rule]", "e3"}], ",", 
                 RowBox[{"b12", "\[Rule]", "b9"}], ",", 
                 RowBox[{"b11", "\[Rule]", "b8"}], ",", 
                 RowBox[{"b10", "\[Rule]", "b7"}], ",", 
                 RowBox[{"b6", "\[Rule]", "b5"}], ",", 
                 RowBox[{"b3", "\[Rule]", "b2"}], ",", 
                 RowBox[{"g2", "\[Rule]", "g1"}]}], "}"}]}], ")"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"b8", "\[Rule]", "b7"}], ",", 
               RowBox[{"b4", "\[Rule]", "b1"}], ",", 
               RowBox[{"b5", "\[Rule]", "b2"}], ",", 
               RowBox[{"c3", "\[Rule]", "c1"}], ",", 
               RowBox[{"f3", "\[Rule]", "f2"}], ",", 
               RowBox[{"b9", "\[Rule]", 
                RowBox[{"-", "a1"}]}]}], "}"}]}], ")"}], "/.", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"b2", "\[Rule]", 
              RowBox[{"-", "a2"}]}], ",", 
             RowBox[{"h6", "\[Rule]", 
              RowBox[{"-", "e3"}]}], ",", 
             RowBox[{"b1", "\[Rule]", 
              RowBox[{
               RowBox[{"-", "b7"}], "-", "f2"}]}]}], "}"}]}], ")"}], ")"}]}], 
       "/.", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"c1", "\[Rule]", "0"}], ",", 
           RowBox[{"a2", "\[Rule]", "1"}], ",", 
           RowBox[{"b7", "\[Rule]", 
            RowBox[{"-", "1"}]}], ",", 
           RowBox[{"e3", "\[Rule]", "0"}], ",", 
           RowBox[{"f1", "\[Rule]", "2"}]}], "}"}], ",", 
         RowBox[{"res", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], "]"}], "]"}]}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "s"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"Contract", "[", 
       RowBox[{
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "m"}], "]"}], 
        RowBox[{"FVD", "[", 
         RowBox[{"q", ",", "n"}], "]"}]}], "]"}], "\[Rule]", "0"}]}], 
    "}"}]}]}]], "Input",
 CellChangeTimes->{{3.6193470899869213`*^9, 3.619347228215808*^9}, {
  3.619347266194653*^9, 3.619347302539509*^9}, {3.619348306110195*^9, 
  3.6193483098403463`*^9}, {3.619348399484983*^9, 3.6193484007660713`*^9}, {
  3.6193485626928062`*^9, 3.619348589254005*^9}, {3.619512248123021*^9, 
  3.619512285624751*^9}, {3.619512361698971*^9, 3.619512385791407*^9}, {
  3.619513773748996*^9, 3.619513774073873*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["m",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["n",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["q",
          TraditionalForm], 
         FormBox[
          FormBox["s",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox["p",
          TraditionalForm], 
         FormBox[
          FormBox["t",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox["D", "4"]}], 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
        SuperscriptBox[
         FormBox[
          RowBox[{
           FormBox["p",
            TraditionalForm], "\[CenterDot]", 
           FormBox["q",
            TraditionalForm]}],
          TraditionalForm], "2"]}]]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "4"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "4"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "4"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"11", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"11", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"11", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"11", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "3"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", 
       SuperscriptBox["D", "2"]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], "2"]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"21", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"21", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"21", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"21", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["D", "2"]}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      RowBox[{"D", "-", "2"}]], "+", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], "2"]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]], " ", "D"}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"16", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"16", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"16", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"12", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"16", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "+", 
     FractionBox[
      RowBox[{"7", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]], " ", "D"}], 
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "t"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "s"}]]}], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "s"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "t"}]]}], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      RowBox[{"D", "-", "2"}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], "2"]], "-", 
     RowBox[{
      SuperscriptBox["g", 
       RowBox[{"m", "n"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"s", "t"}]]}], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"6", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"5", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"s", "t"}]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "t"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "t"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "t"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "t"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "s"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "s"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox["g", 
        RowBox[{"n", "s"}]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "s"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["g", 
        RowBox[{"m", "n"}]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{"2", " ", 
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}]}]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}],
        TraditionalForm], "2"]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}],
        TraditionalForm], "2"]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}],
        TraditionalForm], "2"]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"D", "-", "2"}], ")"}], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"8", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], "2"], " ", 
       SuperscriptBox[
        FormBox[
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}],
         TraditionalForm], "2"]}]], "-", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["m",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["n",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["p",
         TraditionalForm], 
        FormBox[
         FormBox["s",
          TraditionalForm],
         TraditionalForm]], " ", 
       SuperscriptBox[
        FormBox["q",
         TraditionalForm], 
        FormBox[
         FormBox["t",
          TraditionalForm],
         TraditionalForm]]}], 
      SuperscriptBox[
       FormBox[
        RowBox[{
         FormBox["p",
          TraditionalForm], "\[CenterDot]", 
         FormBox["q",
          TraditionalForm]}],
        TraditionalForm], "2"]]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619513757365714*^9, 3.6195147119020023`*^9, 
  3.6195201789847507`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prop2", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"prop", "[", 
     RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.619520457340352*^9, 3.619520460937922*^9}, {
  3.619520556949759*^9, 3.619520591036467*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"D", " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "t"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "s"}]]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"D", "-", "2"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619520461562231*^9, 3.6195205598698273`*^9, 
  3.619520591574292*^9}]
}, Open  ]],

Cell["Bring this to a nice form:", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyX0s1HEAx/Gr5m4u2jnppIsxk0Z0x4yT+F0PDpc6ig7LpnNj/VFKVh2x
arbjQlpi1PSwZYVMnULPWU9sLiL6udbcae03tTtdDwun7+f3x3uvP97+eYfT
8pdzOBwJCSrsB+cixhnKtN3igNf1iuotRJs5k9XDfXAMuiy8mYSn8+VbeR8Z
ynCXjodTfdJaePbSyzpo9c/gCokltnOs+VGCGBjcIpdB39IoWkq8yR9mDQ/0
PxmLH/xPBy9WDEppoibgcxyrosw58YmhjKbyJdjS3dxwnGaoe9RAI0ycVJWV
EAfjmAroeK7phoaYb6zVuqOjMKNmaAKqdVemYap32FcYdN5+4P5PhtrfmqKF
5ssWEU30FMf6QMc2L184tV7nB5tmBFwzsScl2hUaRwzucL612QtGc3qF/Q6G
utHptRoK+qu0j4gj2nUF8MOm3iELcdnTrGG4oGu87fKLoRqVL9rh7q4nRhjU
96APFngMfOER1Ty1BdbR3PlQoszhXIROTZExjDjbseMh3Dy9aIJT6br30NYZ
Igkn5gnrWSUbyqPgzmvHKBgntifDNFmTErYljxbDrLe2E7Czq/jM0m+GCrwV
UglTXVdUw6vPTtXDHinfLfgPQ6nia1lNbdpQNdHJd4uGod8LM+Ga8L85sCNn
rgaudbTXwYiVrwuziCOifYegPOFVJdxbPKyH7RfGE7OJVRt5SXDWO2EXHAtY
pYI+ZvfIHKJVmc26kBuZBPVyqxIWiB7vge9+pKTDI0W51jtEfphoBopFfqVd
RJneswz+B70fssM=
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prod", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"s", ",", "m"}], "]"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "s"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "m"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "s"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "m"}], "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], ")"}]}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d", "[", 
       RowBox[{"n", ",", "t"}], "]"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "n"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "n"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "t"}], "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"q", ",", "i"}], "]"}]}], "]"}], ")"}]}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.619521653022656*^9, 3.619521676221137*^9}, 
   3.619521944380652*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["m",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["s",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "t"}]]}], 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]], "+", 
   RowBox[{
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619521678078718*^9, 3.619521945081235*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prodsym", "[", 
   RowBox[{"s_", ",", "t_", ",", "m_", ",", "n_"}], "]"}], "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"prod", "[", 
       RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "+", 
      RowBox[{"prod", "[", 
       RowBox[{"t", ",", "s", ",", "m", ",", "n"}], "]"}], "+", 
      RowBox[{"prod", "[", 
       RowBox[{"s", ",", "t", ",", "n", ",", "m"}], "]"}], "+", 
      RowBox[{"prod", "[", 
       RowBox[{"t", ",", "s", ",", "n", ",", "m"}], "]"}]}], ")"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6195216917756233`*^9, 3.619521770007444*^9}, {
  3.6195218254510517`*^9, 3.619521827994298*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["m",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["t",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "s"}]]}], 
     RowBox[{"2", " ", 
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}]}]]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "t"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "s"}]]}], "+", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["g", 
     RowBox[{"m", "s"}]], " ", 
    SuperscriptBox["g", 
     RowBox[{"n", "t"}]]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    SuperscriptBox[
     FormBox[
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}],
      TraditionalForm], "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.619521770325469*^9, 3.619521828263288*^9, 
  3.619521946486661*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"prop2", "[", 
     RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "+", 
    RowBox[{
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"D", "-", "2"}], ")"}], 
        RowBox[{"Contract", "[", 
         RowBox[{
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}], 
          RowBox[{"FVD", "[", 
           RowBox[{"p", ",", "i"}], "]"}]}], "]"}]}], " ", ")"}]}], 
     RowBox[{"prodsym", "[", 
      RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}]}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.619521530705353*^9, 3.619521651465034*^9}, {
  3.6195218488015747`*^9, 3.619521873466867*^9}, {3.619521922710576*^9, 
  3.619522076773665*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"D", " ", 
      SuperscriptBox["g", 
       RowBox[{"m", "t"}]], " ", 
      SuperscriptBox["g", 
       RowBox[{"n", "s"}]]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"D", "-", "2"}], ")"}], " ", 
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], "2"]}]]}], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"5", " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{"D", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{"5", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6195216014085608`*^9, 3.619521634817401*^9, {3.6195218540997868`*^9, 
   3.619521874256905*^9}, {3.619521927676814*^9, 3.619521956348521*^9}, {
   3.619521987700432*^9, 3.6195220770000362`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"prop2", "[", 
   RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.619520606541202*^9, 3.619520613142107*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"D", "-", "2"}], ")"}], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     SuperscriptBox[
      FormBox[
       RowBox[{
        FormBox["p",
         TraditionalForm], "\[CenterDot]", 
        FormBox["q",
         TraditionalForm]}],
       TraditionalForm], "2"]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       FormBox["p",
        TraditionalForm], "\[CenterDot]", 
       FormBox["q",
        TraditionalForm]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"D", "-", "2"}], ")"}], " ", 
         SuperscriptBox["g", 
          RowBox[{"m", "t"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"n", "s"}]], " ", 
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["n",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["n",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"D", "-", "2"}], ")"}], " ", 
         SuperscriptBox["g", 
          RowBox[{"m", "s"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"n", "t"}]], " ", 
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["n",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["n",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["g", 
          RowBox[{"m", "n"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SuperscriptBox["g", 
              RowBox[{"s", "t"}]], " ", 
             RowBox[{
              FormBox["p",
               TraditionalForm], "\[CenterDot]", 
              FormBox["q",
               TraditionalForm]}]}]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["q",
        TraditionalForm], 
       FormBox[
        FormBox["m",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"D", "-", "2"}], ")"}], " ", 
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"n", "t"}]]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"n", "s"}]]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["p",
           TraditionalForm], 
          FormBox[
           FormBox["n",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"D", "-", "4"}], ")"}], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"D", "-", "4"}], ")"}], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["g", 
             RowBox[{"s", "t"}]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       FormBox["p",
        TraditionalForm], 
       FormBox[
        FormBox["m",
         TraditionalForm],
        TraditionalForm]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"D", "-", "2"}], ")"}], " ", 
         RowBox[{
          FormBox["p",
           TraditionalForm], "\[CenterDot]", 
          FormBox["q",
           TraditionalForm]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"n", "t"}]]}], "+", 
           RowBox[{
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox["g", 
             RowBox[{"n", "s"}]]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox[
          FormBox["q",
           TraditionalForm], 
          FormBox[
           FormBox["n",
            TraditionalForm],
           TraditionalForm]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"D", "-", "4"}], ")"}], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"D", "-", "4"}], ")"}], " ", 
            SuperscriptBox[
             FormBox["p",
              TraditionalForm], 
             FormBox[
              FormBox["s",
               TraditionalForm],
              TraditionalForm]], " ", 
            SuperscriptBox[
             FormBox["q",
              TraditionalForm], 
             FormBox[
              FormBox["t",
               TraditionalForm],
              TraditionalForm]]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["g", 
             RowBox[{"s", "t"}]], " ", 
            RowBox[{
             FormBox["p",
              TraditionalForm], "\[CenterDot]", 
             FormBox["q",
              TraditionalForm]}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.619520613564026*^9}]
}, Open  ]],

Cell["In D=4 the \[OpenCurlyDoubleQuote]propagator\[CloseCurlyDoubleQuote] \
looks nicest!", "Text",
 CellChangeTimes->CompressedData["
1:eJwdyX0s1HEAx/Grxs1F89D1ky7GTBqRY3ZO4nc9OO5SR9Fh2cSN9UcpWXVE
D7MdQpo6o6aHLStk6hR6zvTA5iJPnWvNnVa/qR1dD8s5fT+/P957/fH2zT6c
nLucw+EISVA6d3A+fIyh9dtNVnhDI63cQrQY01jdXAZGoYPtzSQ8nSvZyh1n
6Kp7hlg41SOsgefqX9VCs2+qozuxyHKeNTfSNQoGNknE0Ls40iAk3uINsYb6
+56Mxg/8p4aXygaEBmKO36cYVmmJfeIjQ+v0pUuwqbPx8nEDQ9+n+7QwflJR
UkQciGHKoPVFTiesivrKWqk+OgJTqwcnoFJ9dRomeYZ8gQEX5g48+MnQ+5tl
Kmi8YqIMRA9BtBe0buN7w6n1ah/YMOPqaCR2yUROUDdc5QIXmhv5UMTpdu+1
MvTNdv5q6NpboXpMHFaty4MfNnUPmojLnqUPQZtae8fhF0Nr5S9b4e6OpzoY
0POwB+a59X3mEpVcpQnWGhwXgoliq30R2nMKdCHE2bYdj+Dm6UU9nEpRv4eW
9qCwUGK2ex1r2IbSSLjz+jEaxgjmEmGyuEEOWxJHCmH6W8sJ2N5ReHbpN0P7
3w4qh0lOKyrhteen6mCXkOcc+IehFbE1rPoWVbCSaOc5i2Dw9/w0uCb0byZs
y5yvhmutrbUwfOXr/HTiMLXvEJTE9ZfDvYVDGth6cSw+g1ixkZsAZz3jdsFR
v1UK6GV0icgkmuUZrLasiASokZjlMI96sge++yFLgUcKssx3ibwQagYKKJ/i
DqJY41EC+4sUY5A6820c/gdDrb0j
  "],
 Background->RGBColor[0.94, 0.88, 0.94]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prop2", "[", 
   RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "/.", 
  RowBox[{"{", 
   RowBox[{"D", "\[Rule]", "4"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.619520479852676*^9, 3.619520545711431*^9}, {
  3.619520596277589*^9, 3.6195206035233383`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["m",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["n",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], 
      FormBox[
       FormBox["s",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox["q",
       TraditionalForm], 
      FormBox[
       FormBox["t",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"], " ", 
     RowBox[{
      FormBox["p",
       TraditionalForm], "\[CenterDot]", 
      FormBox["q",
       TraditionalForm]}]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "t"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "s"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "s"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"n", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["g", 
      RowBox[{"m", "n"}]], " ", 
     SuperscriptBox["g", 
      RowBox[{"s", "t"}]]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox["p",
       TraditionalForm], "2"]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619520483808351*^9, 3.619520545953094*^9}, 
   3.6195206042204657`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prop2", "[", 
   RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "-", 
  RowBox[{"prop2", "[", 
   RowBox[{"t", ",", "s", ",", "m", ",", "n"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6195172072011127`*^9, 3.6195172156112833`*^9}, {
  3.61952061958396*^9, 3.61952062182362*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.61951721603545*^9, 3.619520179209868*^9, 
  3.6195206221394444`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prop2", "[", 
   RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "-", 
  RowBox[{"prop2", "[", 
   RowBox[{"s", ",", "t", ",", "n", ",", "m"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.619517220850251*^9, 3.6195172248240757`*^9}, {
  3.619520623816531*^9, 3.6195206259199123`*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.6195172250482683`*^9, 3.619520179258175*^9, 
  3.619520626379052*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"Contract", "[", 
   RowBox[{
    RowBox[{"prop2", "[", 
     RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], "-", 
    RowBox[{"prop2", "[", 
     RowBox[{"m", ",", "n", ",", "s", ",", "t"}], "]"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6195172382922487`*^9, 3.619517276063883*^9}, {
  3.61952062951307*^9, 3.619520631104789*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{{3.6195172438944073`*^9, 3.619517278951199*^9}, 
   3.619520181569909*^9, 3.619520631514812*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"prop2", "[", 
       RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "s"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.619514945227644*^9, 3.619514987140093*^9}, 
   3.619520633859191*^9, {3.619520739451768*^9, 3.619520743748061*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["m",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["n",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["t",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.619514958804657*^9, 3.619514988344589*^9}, 
   3.619520182423768*^9, 3.619520636675206*^9, 3.619520744168919*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"prop2", "[", 
       RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "t"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.619520773740884*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["m",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["n",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["s",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619520775000105*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"prop2", "[", 
       RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "m"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.619520781445228*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["n",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["s",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["t",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619520781740264*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{"Expand", "[", 
     RowBox[{
      RowBox[{"prop2", "[", 
       RowBox[{"s", ",", "t", ",", "m", ",", "n"}], "]"}], 
      RowBox[{"FVD", "[", 
       RowBox[{"q", ",", "n"}], "]"}]}], "]"}], "]"}], "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}], 
       RowBox[{"FVD", "[", 
        RowBox[{"q", ",", "i"}], "]"}]}], "]"}], "\[Rule]", "0"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{3.6195207864855843`*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], 
     FormBox[
      FormBox["m",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["s",
       TraditionalForm],
      TraditionalForm]], " ", 
    SuperscriptBox[
     FormBox["q",
      TraditionalForm], 
     FormBox[
      FormBox["t",
       TraditionalForm],
      TraditionalForm]]}], 
   RowBox[{
    SuperscriptBox[
     FormBox["p",
      TraditionalForm], "2"], " ", 
    RowBox[{
     FormBox["p",
      TraditionalForm], "\[CenterDot]", 
     FormBox["q",
      TraditionalForm]}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.619520786812808*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
WindowSize->{806, 1056},
WindowMargins->{{321, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September 9, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[400, 13, 71, 1, 28, "Input"],
Cell[474, 16, 509, 12, 63, "Input"],
Cell[986, 30, 1054, 26, 350, "Text"],
Cell[CellGroupData[{
Cell[2065, 60, 216, 3, 64, "Section"],
Cell[2284, 65, 2938, 105, 219, "Text"],
Cell[CellGroupData[{
Cell[5247, 174, 166, 2, 44, "Subsection"],
Cell[5416, 178, 208, 3, 46, "Text"],
Cell[5627, 183, 394, 9, 28, "Input"],
Cell[6024, 194, 360, 5, 46, "Text"],
Cell[6387, 201, 226, 6, 28, "Input"],
Cell[6616, 209, 375, 5, 46, "Text"],
Cell[6994, 216, 253, 7, 28, "Input"],
Cell[7250, 225, 307, 8, 28, "Input"],
Cell[7560, 235, 385, 6, 46, "Text"],
Cell[7948, 243, 532, 14, 46, "Input"],
Cell[CellGroupData[{
Cell[8505, 261, 453, 13, 28, "Input"],
Cell[8961, 276, 2104, 31, 28, "Output"]
}, Open  ]],
Cell[11080, 310, 269, 4, 46, "Text"],
Cell[11352, 316, 247, 7, 28, "Input"],
Cell[11602, 325, 369, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[11996, 336, 283, 8, 28, "Input"],
Cell[12282, 346, 640, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12959, 364, 254, 7, 28, "Input"],
Cell[13216, 373, 642, 11, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13895, 389, 492, 15, 28, "Input"],
Cell[14390, 406, 675, 15, 28, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[15126, 428, 205, 2, 50, "Section"],
Cell[CellGroupData[{
Cell[15356, 434, 100, 1, 44, "Subsection"],
Cell[15459, 437, 744, 12, 65, "Text"],
Cell[16206, 451, 5141, 148, 240, "Input"],
Cell[CellGroupData[{
Cell[21372, 603, 129, 2, 30, "Input"],
Cell[21504, 607, 548, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22089, 620, 1470, 45, 88, "Input"],
Cell[23562, 667, 1847, 51, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25446, 723, 191, 4, 30, "Input"],
Cell[25640, 729, 7033, 184, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32710, 918, 133, 2, 30, "Input"],
Cell[32846, 922, 531, 8, 70, "Output"]
}, Open  ]],
Cell[33392, 933, 806, 14, 65, "Text"],
Cell[34201, 949, 118, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[34344, 955, 1329, 35, 88, "Input"],
Cell[35676, 992, 5131, 137, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40844, 1134, 405, 10, 30, "Input"],
Cell[41252, 1146, 7048, 182, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[48337, 1333, 146, 2, 30, "Input"],
Cell[48486, 1337, 520, 8, 70, "Output"]
}, Open  ]],
Cell[49021, 1348, 903, 17, 46, "Text"],
Cell[CellGroupData[{
Cell[49949, 1369, 247, 5, 30, "Input"],
Cell[50199, 1376, 601, 9, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50837, 1390, 319, 7, 30, "Input"],
Cell[51159, 1399, 551, 8, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[51759, 1413, 232, 4, 36, "Subsection"],
Cell[51994, 1419, 985, 18, 46, "Text"],
Cell[CellGroupData[{
Cell[53004, 1441, 576, 16, 50, "Input"],
Cell[53583, 1459, 1837, 48, 70, "Output"]
}, Open  ]],
Cell[55435, 1510, 994, 16, 46, "Text"],
Cell[CellGroupData[{
Cell[56454, 1530, 3532, 89, 221, "Input"],
Cell[59989, 1621, 2109, 52, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62135, 1678, 1254, 36, 88, "Input"],
Cell[63392, 1716, 1716, 47, 70, "Output"]
}, Open  ]],
Cell[65123, 1766, 960, 13, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[66120, 1784, 278, 5, 36, "Subsection"],
Cell[66401, 1791, 541, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[66967, 1810, 871, 20, 50, "Input"],
Cell[67841, 1832, 3671, 99, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71549, 1936, 201, 3, 30, "Input"],
Cell[71753, 1941, 609, 9, 70, "Output"]
}, Open  ]],
Cell[72377, 1953, 891, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[73293, 1971, 3199, 82, 183, "Input"],
Cell[76495, 2055, 2081, 56, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78613, 2116, 266, 5, 30, "Input"],
Cell[78882, 2123, 700, 11, 70, "Output"]
}, Open  ]],
Cell[79597, 2137, 1051, 21, 160, "Text"],
Cell[CellGroupData[{
Cell[80673, 2162, 2525, 66, 164, "Input"],
Cell[83201, 2230, 1712, 47, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84950, 2282, 167, 3, 30, "Input"],
Cell[85120, 2287, 520, 8, 70, "Output"]
}, Open  ]],
Cell[85655, 2298, 963, 13, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[86655, 2316, 254, 5, 36, "Subsection"],
Cell[86912, 2323, 1053, 20, 47, "Text"],
Cell[CellGroupData[{
Cell[87990, 2347, 823, 20, 28, "Input"],
Cell[88816, 2369, 6659, 188, 427, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[95512, 2562, 181, 3, 28, "Input"],
Cell[95696, 2567, 596, 9, 28, "Output"]
}, Open  ]],
Cell[96307, 2579, 891, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[97223, 2597, 5770, 128, 233, "Input"],
Cell[102996, 2727, 9081, 255, 465, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112114, 2987, 240, 4, 30, "Input"],
Cell[112357, 2993, 675, 11, 70, "Output"]
}, Open  ]],
Cell[113047, 3007, 1051, 21, 160, "Text"],
Cell[CellGroupData[{
Cell[114123, 3032, 1912, 52, 126, "Input"],
Cell[116038, 3086, 8035, 252, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124110, 3343, 141, 2, 30, "Input"],
Cell[124254, 3347, 502, 8, 70, "Output"]
}, Open  ]],
Cell[124771, 3358, 963, 13, 46, "Text"],
Cell[125737, 3373, 591, 16, 46, "Text"],
Cell[CellGroupData[{
Cell[126353, 3393, 1449, 34, 80, "Input"],
Cell[127805, 3429, 5803, 158, 165, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133645, 3592, 206, 3, 28, "Input"],
Cell[133854, 3597, 612, 9, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134503, 3611, 3456, 89, 148, "Input"],
Cell[137962, 3702, 1641, 45, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139640, 3752, 1841, 51, 97, "Input"],
Cell[141484, 3805, 1393, 44, 47, "Output"]
}, Open  ]],
Cell[142892, 3852, 505, 9, 46, "Text"],
Cell[CellGroupData[{
Cell[143422, 3865, 113, 3, 28, "Input"],
Cell[143538, 3870, 2538, 73, 63, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146113, 3948, 4849, 113, 233, "Input"],
Cell[150965, 4063, 3311, 86, 99, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[154313, 4154, 2075, 55, 97, "Input"],
Cell[156391, 4211, 2320, 73, 72, "Output"]
}, Open  ]],
Cell[158726, 4287, 505, 9, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[159268, 4301, 230, 4, 36, "Subsection"],
Cell[159501, 4307, 1009, 19, 46, "Text"],
Cell[CellGroupData[{
Cell[160535, 4330, 773, 19, 50, "Input"],
Cell[161311, 4351, 10494, 301, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171842, 4657, 159, 3, 30, "Input"],
Cell[172004, 4662, 570, 9, 70, "Output"]
}, Open  ]],
Cell[172589, 4674, 956, 15, 46, "Text"],
Cell[173548, 4691, 891, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[174464, 4709, 5121, 128, 259, "Input"],
Cell[179588, 4839, 9681, 274, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189306, 5118, 217, 4, 30, "Input"],
Cell[189526, 5124, 572, 9, 70, "Output"]
}, Open  ]],
Cell[190113, 5136, 1051, 21, 160, "Text"],
Cell[CellGroupData[{
Cell[191189, 5161, 1914, 52, 107, "Input"],
Cell[193106, 5215, 8614, 275, 70, "Output"]
}, Open  ]],
Cell[201735, 5493, 1022, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[202782, 5512, 642, 18, 50, "Input"],
Cell[203427, 5532, 7549, 261, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211013, 5798, 118, 2, 30, "Input"],
Cell[211134, 5802, 502, 8, 70, "Output"]
}, Open  ]],
Cell[211651, 5813, 590, 12, 46, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[212290, 5831, 199, 3, 50, "Section"],
Cell[212492, 5836, 679, 11, 65, "Text"],
Cell[CellGroupData[{
Cell[213196, 5851, 896, 26, 46, "Subsection"],
Cell[CellGroupData[{
Cell[214117, 5881, 629, 21, 30, "Input"],
Cell[214749, 5904, 1578, 41, 70, "Output"]
}, Open  ]],
Cell[216342, 5948, 489, 8, 46, "Text"],
Cell[CellGroupData[{
Cell[216856, 5960, 368, 13, 30, "Input"],
Cell[217227, 5975, 1334, 33, 70, "Output"]
}, Open  ]],
Cell[218576, 6011, 555, 10, 46, "Text"],
Cell[219134, 6023, 444, 7, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[219615, 6035, 879, 26, 39, "Subsection"],
Cell[220497, 6063, 343, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[220865, 6073, 933, 29, 69, "Input"],
Cell[221801, 6104, 1434, 38, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223272, 6147, 1093, 35, 69, "Input"],
Cell[224368, 6184, 2736, 58, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[227141, 6247, 520, 14, 50, "Input"],
Cell[227664, 6263, 1498, 39, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[229199, 6307, 1655, 46, 126, "Input"],
Cell[230857, 6355, 4132, 134, 70, "Output"]
}, Open  ]],
Cell[235004, 6492, 563, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[235592, 6506, 685, 19, 50, "Input"],
Cell[236280, 6527, 1692, 33, 70, "Output"]
}, Open  ]],
Cell[237987, 6563, 496, 8, 46, "Text"],
Cell[238486, 6573, 638, 11, 46, "Text"],
Cell[CellGroupData[{
Cell[239149, 6588, 1591, 41, 69, "Input"],
Cell[240743, 6631, 2336, 59, 70, "Output"]
}, Open  ]],
Cell[243094, 6693, 623, 8, 46, "Text"],
Cell[CellGroupData[{
Cell[243742, 6705, 1087, 29, 88, "Input"],
Cell[244832, 6736, 5454, 183, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[250323, 6924, 1136, 30, 88, "Input"],
Cell[251462, 6956, 4624, 174, 70, "Output"]
}, Open  ]],
Cell[256101, 7133, 444, 7, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[256582, 7145, 914, 27, 37, "Subsection"],
Cell[257499, 7174, 396, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[257920, 7185, 1145, 36, 69, "Input"],
Cell[259068, 7223, 1654, 46, 70, "Output"]
}, Open  ]],
Cell[260737, 7272, 332, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[261094, 7281, 2765, 80, 240, "Input"],
Cell[263862, 7363, 13953, 537, 70, "Output"]
}, Open  ]],
Cell[277830, 7903, 389, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[278244, 7912, 804, 22, 69, "Input"],
Cell[279051, 7936, 7925, 297, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287013, 8238, 163, 3, 30, "Input"],
Cell[287179, 8243, 2020, 30, 70, "Output"]
}, Open  ]],
Cell[289214, 8276, 431, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[289670, 8286, 648, 17, 30, "Input"],
Cell[290321, 8305, 10947, 417, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301305, 8727, 140, 2, 30, "Input"],
Cell[301448, 8731, 471, 7, 70, "Output"]
}, Open  ]],
Cell[301934, 8741, 548, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[302507, 8755, 3751, 99, 221, "Input"],
Cell[306261, 8856, 6628, 238, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312926, 9099, 440, 12, 30, "Input"],
Cell[313369, 9113, 9914, 374, 70, "Output"]
}, Open  ]],
Cell[323298, 9490, 601, 8, 46, "Text"],
Cell[CellGroupData[{
Cell[323924, 9502, 381, 9, 50, "Input"],
Cell[324308, 9513, 2006, 29, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326351, 9547, 247, 5, 30, "Input"],
Cell[326601, 9554, 506, 8, 70, "Output"]
}, Open  ]],
Cell[327122, 9565, 763, 12, 65, "Text"],
Cell[CellGroupData[{
Cell[327910, 9581, 2217, 64, 183, "Input"],
Cell[330130, 9647, 9673, 371, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[339840, 10023, 918, 25, 69, "Input"],
Cell[340761, 10050, 8219, 298, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349017, 10353, 273, 6, 30, "Input"],
Cell[349293, 10361, 468, 7, 70, "Output"]
}, Open  ]],
Cell[349776, 10371, 444, 7, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[350257, 10383, 1068, 33, 37, "Subsection"],
Cell[351328, 10418, 394, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[351747, 10429, 4235, 141, 259, "Input"],
Cell[355985, 10572, 4467, 149, 70, "Output"]
}, Open  ]],
Cell[360467, 10724, 413, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[360905, 10734, 973, 25, 88, "Input"],
Cell[361881, 10761, 8312, 282, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370230, 11048, 319, 7, 30, "Input"],
Cell[370552, 11057, 2045, 29, 70, "Output"]
}, Open  ]],
Cell[372612, 11089, 691, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[373328, 11105, 1220, 34, 50, "Input"],
Cell[374551, 11141, 13601, 490, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[388189, 11636, 125, 2, 30, "Input"],
Cell[388317, 11640, 820, 15, 70, "Output"]
}, Open  ]],
Cell[389152, 11658, 713, 12, 84, "Text"],
Cell[CellGroupData[{
Cell[389890, 11674, 3243, 92, 221, "Input"],
Cell[393136, 11768, 70869, 2642, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[464042, 14415, 2268, 64, 164, "Input"],
Cell[466313, 14481, 78447, 2917, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544797, 17403, 177, 3, 30, "Input"],
Cell[544977, 17408, 245, 4, 70, "Output"]
}, Open  ]],
Cell[545237, 17415, 629, 9, 46, "Text"],
Cell[CellGroupData[{
Cell[545891, 17428, 1156, 32, 69, "Input"],
Cell[547050, 17462, 71240, 2651, 70, "Output"]
}, Open  ]],
Cell[618305, 20116, 711, 11, 46, "Text"],
Cell[CellGroupData[{
Cell[619041, 20131, 936, 26, 69, "Input"],
Cell[619980, 20159, 70830, 2642, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[690847, 22806, 178, 3, 30, "Input"],
Cell[691028, 22811, 507, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[691572, 22824, 953, 26, 69, "Input"],
Cell[692528, 22852, 78474, 2917, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[771039, 25774, 185, 4, 30, "Input"],
Cell[771227, 25780, 500, 8, 70, "Output"]
}, Open  ]],
Cell[771742, 25791, 444, 7, 46, "Text"],
Cell[772189, 25800, 350, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[772564, 25809, 167, 3, 30, "Input"],
Cell[772734, 25814, 2028, 29, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[774799, 25848, 302, 9, 30, "Input"],
Cell[775104, 25859, 4567, 137, 70, "Output"]
}, Open  ]],
Cell[779686, 25999, 393, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[780104, 26009, 7033, 185, 468, "Input"],
Cell[787140, 26196, 2027, 31, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[789216, 26233, 245, 4, 36, "Subsection"],
Cell[789464, 26239, 884, 14, 65, "Text"],
Cell[CellGroupData[{
Cell[790373, 26257, 827, 27, 69, "Input"],
Cell[791203, 26286, 1387, 38, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[792627, 26329, 476, 15, 30, "Input"],
Cell[793106, 26346, 1066, 26, 70, "Output"]
}, Open  ]],
Cell[794187, 26375, 716, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[794928, 26389, 21957, 623, 924, "Input"],
Cell[816888, 27014, 26581, 934, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[843506, 27953, 266, 6, 30, "Input"],
Cell[843775, 27961, 1791, 26, 70, "Output"]
}, Open  ]],
Cell[845581, 27990, 852, 13, 65, "Text"],
Cell[846436, 28005, 991, 16, 65, "Text"],
Cell[CellGroupData[{
Cell[847452, 28025, 753, 20, 69, "Input"],
Cell[848208, 28047, 9889, 316, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[858134, 28368, 129, 2, 30, "Input"],
Cell[858266, 28372, 1717, 25, 70, "Output"]
}, Open  ]],
Cell[859998, 28400, 1121, 18, 103, "Text"],
Cell[CellGroupData[{
Cell[861144, 28422, 4340, 138, 259, "Input"],
Cell[865487, 28562, 4390, 148, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[869914, 28715, 626, 18, 69, "Input"],
Cell[870543, 28735, 9775, 315, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[880355, 29055, 173, 3, 30, "Input"],
Cell[880531, 29060, 1764, 25, 70, "Output"]
}, Open  ]],
Cell[882310, 29088, 862, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[883197, 29106, 263, 6, 30, "Input"],
Cell[883463, 29114, 772, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[884272, 29134, 1082, 28, 69, "Input"],
Cell[885357, 29164, 1856, 27, 70, "Output"]
}, Open  ]],
Cell[887228, 29194, 856, 12, 46, "Text"],
Cell[888087, 29208, 799, 12, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[888923, 29225, 684, 27, 38, "Subsection"],
Cell[CellGroupData[{
Cell[889632, 29256, 1937, 63, 107, "Input"],
Cell[891572, 29321, 2797, 75, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[894406, 29401, 1826, 61, 88, "Input"],
Cell[896235, 29464, 2083, 67, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[898355, 29536, 3792, 111, 240, "Input"],
Cell[902150, 29649, 28536, 1101, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[930723, 30755, 136, 2, 30, "Input"],
Cell[930862, 30759, 476, 7, 70, "Output"]
}, Open  ]],
Cell[931353, 30769, 735, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[932113, 30783, 2244, 60, 183, "Input"],
Cell[934360, 30845, 570, 10, 70, "Output"]
}, Open  ]],
Cell[934945, 30858, 767, 12, 65, "Text"],
Cell[CellGroupData[{
Cell[935737, 30874, 1453, 42, 88, "Input"],
Cell[937193, 30918, 10567, 384, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[947797, 31307, 125, 2, 30, "Input"],
Cell[947925, 31311, 1337, 20, 70, "Output"]
}, Open  ]],
Cell[949277, 31334, 604, 11, 46, "Text"],
Cell[CellGroupData[{
Cell[949906, 31349, 1905, 45, 107, "Input"],
Cell[951814, 31396, 8324, 302, 70, "Output"]
}, Open  ]],
Cell[960153, 31701, 601, 8, 46, "Text"],
Cell[CellGroupData[{
Cell[960779, 31713, 456, 11, 50, "Input"],
Cell[961238, 31726, 2038, 29, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[963325, 31761, 978, 35, 37, "Subsection"],
Cell[964306, 31798, 3056, 72, 148, "Input"],
Cell[CellGroupData[{
Cell[967387, 31874, 290, 6, 28, "Input"],
Cell[967680, 31882, 527, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[968244, 31895, 4236, 110, 199, "Input"],
Cell[972483, 32007, 13312, 374, 174, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[985832, 32386, 215, 4, 28, "Input"],
Cell[986050, 32392, 570, 9, 28, "Output"]
}, Open  ]],
Cell[986635, 32404, 549, 12, 46, "Text"],
Cell[987187, 32418, 1025, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[988237, 32437, 1479, 40, 63, "Input"],
Cell[989719, 32479, 645, 10, 28, "Output"]
}, Open  ]],
Cell[990379, 32492, 993, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[991397, 32510, 2089, 54, 114, "Input"],
Cell[993489, 32566, 631, 11, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[994157, 32582, 6053, 168, 186, "Input"],
Cell[1000213, 32752, 1033, 18, 28, "Output"]
}, Open  ]],
Cell[1001261, 32773, 475, 9, 46, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1001785, 32788, 260, 4, 50, "Section"],
Cell[CellGroupData[{
Cell[1002070, 32796, 874, 29, 37, "Subsection"],
Cell[1002947, 32827, 780, 11, 46, "Text"],
Cell[CellGroupData[{
Cell[1003752, 32842, 2031, 59, 107, "Input"],
Cell[1005786, 32903, 1869, 41, 70, "Output"],
Cell[1007658, 32946, 1845, 41, 70, "Output"],
Cell[1009506, 32989, 1819, 40, 70, "Output"],
Cell[1011328, 33031, 1795, 40, 70, "Output"],
Cell[1013126, 33073, 1773, 40, 70, "Output"],
Cell[1014902, 33115, 1747, 39, 35, "Output"],
Cell[1016652, 33156, 1725, 39, 35, "Output"],
Cell[1018380, 33197, 1703, 39, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1020120, 33241, 829, 21, 69, "Input"],
Cell[1020952, 33264, 1928, 42, 70, "Output"],
Cell[1022883, 33308, 1902, 41, 70, "Output"],
Cell[1024788, 33351, 1880, 41, 70, "Output"],
Cell[1026671, 33394, 1856, 41, 70, "Output"],
Cell[1028530, 33437, 1830, 40, 70, "Output"],
Cell[1030363, 33479, 1808, 40, 35, "Output"],
Cell[1032174, 33521, 1786, 40, 35, "Output"],
Cell[1033963, 33563, 1760, 39, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1035760, 33607, 756, 20, 69, "Input"],
Cell[1036519, 33629, 1148, 34, 70, "Output"],
Cell[1037670, 33665, 1131, 33, 70, "Output"],
Cell[1038804, 33700, 1123, 33, 70, "Output"],
Cell[1039930, 33735, 1111, 33, 70, "Output"],
Cell[1041044, 33770, 1103, 33, 70, "Output"],
Cell[1042150, 33805, 1095, 33, 35, "Output"],
Cell[1043248, 33840, 1083, 33, 35, "Output"],
Cell[1044334, 33875, 1070, 32, 35, "Output"]
}, Open  ]],
Cell[1045419, 33910, 750, 11, 46, "Text"],
Cell[CellGroupData[{
Cell[1046194, 33925, 81, 1, 30, "Input"],
Cell[1046278, 33928, 3479, 129, 70, "Output"],
Cell[1049760, 34059, 3471, 129, 70, "Output"],
Cell[1053234, 34190, 3463, 129, 70, "Output"],
Cell[1056700, 34321, 3455, 129, 70, "Output"],
Cell[1060158, 34452, 3447, 129, 70, "Output"],
Cell[1063608, 34583, 3438, 128, 58, "Output"],
Cell[1067049, 34713, 3426, 128, 58, "Output"],
Cell[1070478, 34843, 3418, 128, 58, "Output"]
}, Open  ]],
Cell[1073911, 34974, 1023, 16, 65, "Text"],
Cell[CellGroupData[{
Cell[1074959, 34994, 1715, 45, 88, "Input"],
Cell[1076677, 35041, 4363, 135, 70, "Output"],
Cell[1081043, 35178, 4339, 135, 70, "Output"],
Cell[1085385, 35315, 4311, 134, 70, "Output"],
Cell[1089699, 35451, 4289, 134, 70, "Output"],
Cell[1093991, 35587, 4267, 134, 70, "Output"],
Cell[1098261, 35723, 4241, 133, 74, "Output"],
Cell[1102505, 35858, 4219, 133, 74, "Output"],
Cell[1106727, 35993, 4195, 133, 74, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1110959, 36131, 85, 1, 30, "Input"],
Cell[1111047, 36134, 7727, 295, 70, "Output"],
Cell[1118777, 36431, 7719, 295, 70, "Output"],
Cell[1126499, 36728, 7711, 295, 70, "Output"],
Cell[1134213, 37025, 7707, 295, 70, "Output"],
Cell[1141923, 37322, 7695, 295, 70, "Output"],
Cell[1149621, 37619, 7687, 295, 209, "Output"],
Cell[1157311, 37916, 7678, 294, 209, "Output"],
Cell[1164992, 38212, 7666, 294, 209, "Output"]
}, Open  ]],
Cell[1172673, 38509, 1031, 16, 46, "Text"],
Cell[CellGroupData[{
Cell[1173729, 38529, 570, 14, 30, "Input"],
Cell[1174302, 38545, 7687, 295, 70, "Output"],
Cell[1181992, 38842, 7674, 294, 70, "Output"],
Cell[1189669, 39138, 7662, 294, 70, "Output"],
Cell[1197334, 39434, 7650, 294, 70, "Output"],
Cell[1204987, 39730, 7642, 294, 70, "Output"],
Cell[1212632, 40026, 7634, 294, 209, "Output"],
Cell[1220269, 40322, 7622, 294, 209, "Output"],
Cell[1227894, 40618, 7609, 293, 209, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1235540, 40916, 1976, 51, 88, "Input"],
Cell[1237519, 40969, 38568, 1513, 70, "Output"],
Cell[1276090, 42484, 38546, 1513, 70, "Output"],
Cell[1314639, 43999, 38524, 1513, 70, "Output"],
Cell[1353166, 45514, 38498, 1512, 70, "Output"],
Cell[1391667, 47028, 38476, 1512, 70, "Output"],
Cell[1430146, 48542, 38454, 1512, 818, "Output"],
Cell[1468603, 50056, 38428, 1511, 818, "Output"],
Cell[1507034, 51569, 38406, 1511, 818, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1545477, 53085, 155, 3, 30, "Input"],
Cell[1545635, 53090, 712, 15, 70, "Output"],
Cell[1546350, 53107, 695, 14, 70, "Output"],
Cell[1547048, 53123, 687, 14, 70, "Output"],
Cell[1547738, 53139, 679, 14, 70, "Output"],
Cell[1548420, 53155, 671, 14, 70, "Output"],
Cell[1549094, 53171, 659, 14, 31, "Output"],
Cell[1549756, 53187, 647, 14, 31, "Output"],
Cell[1550406, 53203, 634, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1551077, 53221, 1877, 52, 107, "Input"],
Cell[1552957, 53275, 37508, 1499, 70, "Output"],
Cell[1590468, 54776, 37484, 1499, 70, "Output"],
Cell[1627955, 56277, 37462, 1499, 70, "Output"],
Cell[1665420, 57778, 37437, 1498, 70, "Output"],
Cell[1702860, 59278, 37415, 1498, 70, "Output"],
Cell[1740278, 60778, 37393, 1498, 810, "Output"],
Cell[1777674, 62278, 37368, 1497, 810, "Output"],
Cell[1815045, 63777, 37346, 1497, 810, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1852428, 65279, 157, 3, 30, "Input"],
Cell[1852588, 65284, 704, 15, 70, "Output"],
Cell[1853295, 65301, 687, 14, 70, "Output"],
Cell[1853985, 65317, 679, 14, 70, "Output"],
Cell[1854667, 65333, 667, 14, 70, "Output"],
Cell[1855337, 65349, 659, 14, 70, "Output"],
Cell[1855999, 65365, 647, 14, 31, "Output"],
Cell[1856649, 65381, 634, 13, 31, "Output"],
Cell[1857286, 65396, 622, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1857945, 65414, 1963, 53, 107, "Input"],
Cell[1859911, 65469, 38586, 1515, 70, "Output"],
Cell[1898500, 66986, 38562, 1515, 70, "Output"],
Cell[1937065, 68503, 38536, 1514, 70, "Output"],
Cell[1975604, 70019, 38512, 1514, 70, "Output"],
Cell[2014119, 71535, 38490, 1514, 70, "Output"],
Cell[2052612, 73051, 38464, 1513, 820, "Output"],
Cell[2091079, 74566, 38442, 1513, 820, "Output"],
Cell[2129524, 76081, 38418, 1513, 820, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2167979, 77599, 125, 2, 30, "Input"],
Cell[2168107, 77603, 1474, 23, 70, "Output"],
Cell[2169584, 77628, 1452, 23, 70, "Output"],
Cell[2171039, 77653, 1428, 23, 70, "Output"],
Cell[2172470, 77678, 1402, 22, 70, "Output"],
Cell[2173875, 77702, 1380, 22, 70, "Output"],
Cell[2175258, 77726, 1358, 22, 31, "Output"],
Cell[2176619, 77750, 1330, 21, 31, "Output"],
Cell[2177952, 77773, 1308, 21, 31, "Output"]
}, Open  ]],
Cell[2179275, 77797, 932, 13, 46, "Text"],
Cell[CellGroupData[{
Cell[2180232, 77814, 1821, 48, 126, "Input"],
Cell[2182056, 77864, 25887, 997, 70, "Output"],
Cell[2207946, 78863, 25865, 997, 70, "Output"],
Cell[2233814, 79862, 25838, 996, 70, "Output"],
Cell[2259655, 80860, 25816, 996, 70, "Output"],
Cell[2285474, 81858, 25792, 996, 70, "Output"],
Cell[2311269, 82856, 25765, 995, 710, "Output"],
Cell[2337037, 83853, 25743, 995, 710, "Output"],
Cell[2362783, 84850, 25721, 995, 710, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2388541, 85850, 183, 3, 30, "Input"],
Cell[2388727, 85855, 1544, 24, 70, "Output"],
Cell[2390274, 85881, 1522, 24, 70, "Output"],
Cell[2391799, 85907, 1500, 24, 70, "Output"],
Cell[2393302, 85933, 1475, 23, 70, "Output"],
Cell[2394780, 85958, 1453, 23, 70, "Output"],
Cell[2396236, 85983, 1431, 23, 31, "Output"],
Cell[2397670, 86008, 1403, 22, 31, "Output"],
Cell[2399076, 86032, 1379, 22, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2400492, 86059, 597, 17, 69, "Input"],
Cell[2401092, 86078, 9343, 366, 70, "Output"]
}, Open  ]],
Cell[2410450, 86447, 931, 13, 46, "Text"],
Cell[2411384, 86462, 891, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[2412300, 86478, 3813, 97, 240, "Input"],
Cell[2416116, 86577, 1691, 27, 70, "Output"],
Cell[2417810, 86606, 1669, 27, 70, "Output"],
Cell[2419482, 86635, 1647, 27, 70, "Output"],
Cell[2421132, 86664, 1622, 26, 70, "Output"],
Cell[2422757, 86692, 1600, 26, 70, "Output"],
Cell[2424360, 86720, 1578, 26, 31, "Output"],
Cell[2425941, 86748, 1552, 25, 31, "Output"],
Cell[2427496, 86775, 1528, 25, 31, "Output"]
}, Open  ]],
Cell[2429039, 86803, 864, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[2429928, 86819, 740, 19, 50, "Input"],
Cell[2430671, 86840, 14931, 552, 70, "Output"],
Cell[2445605, 87394, 14909, 552, 70, "Output"],
Cell[2460517, 87948, 14885, 552, 70, "Output"],
Cell[2475405, 88502, 14857, 551, 70, "Output"],
Cell[2490265, 89055, 14835, 551, 70, "Output"],
Cell[2505103, 89608, 14813, 551, 369, "Output"],
Cell[2519919, 90161, 14787, 550, 369, "Output"],
Cell[2534709, 90713, 14763, 550, 369, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2549509, 91268, 155, 3, 30, "Input"],
Cell[2549667, 91273, 1565, 24, 70, "Output"],
Cell[2551235, 91299, 1544, 24, 70, "Output"],
Cell[2552782, 91325, 1518, 23, 70, "Output"],
Cell[2554303, 91350, 1496, 23, 70, "Output"],
Cell[2555802, 91375, 1474, 23, 70, "Output"],
Cell[2557279, 91400, 1448, 22, 31, "Output"],
Cell[2558730, 91424, 1426, 22, 31, "Output"],
Cell[2560159, 91448, 1402, 22, 31, "Output"]
}, Open  ]],
Cell[2561576, 91473, 1099, 17, 65, "Text"],
Cell[CellGroupData[{
Cell[2562700, 91494, 1696, 47, 126, "Input"],
Cell[2564399, 91543, 10715, 390, 70, "Output"],
Cell[2575117, 91935, 10693, 390, 70, "Output"],
Cell[2585813, 92327, 10671, 390, 70, "Output"],
Cell[2596487, 92719, 10646, 389, 70, "Output"],
Cell[2607136, 93110, 10624, 389, 70, "Output"],
Cell[2617763, 93501, 10600, 389, 249, "Output"],
Cell[2628366, 93892, 10577, 388, 249, "Output"],
Cell[2638946, 94282, 10555, 388, 249, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2649550, 94676, 382, 5, 37, "Subsection"],
Cell[2649935, 94683, 481, 9, 46, "Text"],
Cell[2650419, 94694, 501, 10, 65, "Text"],
Cell[2650923, 94706, 377, 8, 30, "Input"],
Cell[2651303, 94716, 348, 8, 30, "Input"],
Cell[2651654, 94726, 372, 9, 30, "Input"],
Cell[CellGroupData[{
Cell[2652051, 94739, 346, 7, 30, "Input"],
Cell[2652400, 94748, 878, 19, 70, "Output"]
}, Open  ]],
Cell[2653293, 94770, 321, 8, 30, "Input"],
Cell[2653617, 94780, 345, 8, 30, "Input"],
Cell[2653965, 94790, 342, 8, 30, "Input"],
Cell[2654310, 94800, 467, 10, 30, "Input"],
Cell[2654780, 94812, 345, 8, 30, "Input"],
Cell[2655128, 94822, 343, 8, 30, "Input"],
Cell[2655474, 94832, 392, 6, 46, "Text"],
Cell[2655869, 94840, 761, 26, 50, "Input"],
Cell[2656633, 94868, 460, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[2657118, 94878, 1441, 39, 88, "Input"],
Cell[2658562, 94919, 3029, 67, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2661628, 94991, 983, 17, 50, "Input"],
Cell[2662614, 95010, 9413, 213, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2672064, 95228, 200, 5, 30, "Input"],
Cell[2672267, 95235, 867, 18, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2673171, 95258, 200, 5, 30, "Input"],
Cell[2673374, 95265, 930, 21, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2674341, 95291, 198, 5, 30, "Input"],
Cell[2674542, 95298, 1844, 29, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2676423, 95332, 198, 5, 30, "Input"],
Cell[2676624, 95339, 1855, 29, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2678516, 95373, 226, 6, 30, "Input"],
Cell[2678745, 95381, 916, 20, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2679698, 95406, 198, 5, 30, "Input"],
Cell[2679899, 95413, 1859, 29, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2681795, 95447, 228, 6, 30, "Input"],
Cell[2682026, 95455, 1939, 33, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2684002, 95493, 228, 6, 30, "Input"],
Cell[2684233, 95501, 981, 22, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2685251, 95528, 230, 6, 30, "Input"],
Cell[2685484, 95536, 956, 21, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2686477, 95562, 10795, 264, 525, "Input"],
Cell[2697275, 95828, 1462, 23, 70, "Output"]
}, Open  ]],
Cell[2698752, 95854, 813, 13, 65, "Text"],
Cell[CellGroupData[{
Cell[2699590, 95871, 10823, 264, 544, "Input"],
Cell[2710416, 96137, 1492, 24, 70, "Output"]
}, Open  ]],
Cell[2711923, 96164, 823, 13, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2712783, 96182, 895, 28, 29, "Subsection"],
Cell[CellGroupData[{
Cell[2713703, 96214, 3458, 101, 164, "Input"],
Cell[2717164, 96317, 1758, 31, 70, "Output"],
Cell[2718925, 96350, 1736, 31, 70, "Output"],
Cell[2720664, 96383, 1714, 31, 70, "Output"],
Cell[2722381, 96416, 1688, 30, 70, "Output"],
Cell[2724072, 96448, 1666, 30, 70, "Output"],
Cell[2725741, 96480, 1644, 30, 52, "Output"],
Cell[2727388, 96512, 1618, 29, 52, "Output"],
Cell[2729009, 96543, 1594, 29, 52, "Output"],
Cell[2730606, 96574, 1572, 29, 52, "Output"],
Cell[2732181, 96605, 1546, 28, 52, "Output"],
Cell[2733730, 96635, 1524, 28, 52, "Output"],
Cell[2735257, 96665, 1502, 28, 52, "Output"],
Cell[2736762, 96695, 1474, 27, 52, "Output"],
Cell[2738239, 96724, 1452, 27, 52, "Output"],
Cell[2739694, 96753, 1430, 27, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2741161, 96785, 713, 19, 30, "Input"],
Cell[2741877, 96806, 1715, 31, 70, "Output"],
Cell[2743595, 96839, 1690, 30, 70, "Output"],
Cell[2745288, 96871, 1669, 30, 70, "Output"],
Cell[2746960, 96903, 1645, 30, 70, "Output"],
Cell[2748608, 96935, 1619, 29, 70, "Output"],
Cell[2750230, 96966, 1597, 29, 52, "Output"],
Cell[2751830, 96997, 1573, 29, 52, "Output"],
Cell[2753406, 97028, 1545, 28, 52, "Output"],
Cell[2754954, 97058, 1523, 28, 52, "Output"],
Cell[2756480, 97088, 1501, 28, 52, "Output"],
Cell[2757984, 97118, 1473, 27, 52, "Output"],
Cell[2759460, 97147, 1451, 27, 52, "Output"],
Cell[2760914, 97176, 1429, 27, 52, "Output"],
Cell[2762346, 97205, 1403, 26, 52, "Output"],
Cell[2763752, 97233, 1382, 26, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2765171, 97264, 718, 19, 30, "Input"],
Cell[2765892, 97285, 995, 23, 70, "Output"],
Cell[2766890, 97310, 987, 23, 70, "Output"],
Cell[2767880, 97335, 975, 23, 70, "Output"],
Cell[2768858, 97360, 963, 23, 70, "Output"],
Cell[2769824, 97385, 955, 23, 70, "Output"],
Cell[2770782, 97410, 943, 23, 52, "Output"],
Cell[2771728, 97435, 930, 22, 52, "Output"],
Cell[2772661, 97459, 922, 22, 52, "Output"],
Cell[2773586, 97483, 910, 22, 52, "Output"],
Cell[2774499, 97507, 902, 22, 52, "Output"],
Cell[2775404, 97531, 894, 22, 52, "Output"],
Cell[2776301, 97555, 882, 22, 52, "Output"],
Cell[2777186, 97579, 877, 21, 52, "Output"],
Cell[2778066, 97602, 865, 21, 52, "Output"],
Cell[2778934, 97625, 857, 21, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2779828, 97651, 852, 24, 69, "Input"],
Cell[2780683, 97677, 1694, 31, 70, "Output"],
Cell[2782380, 97710, 1672, 31, 70, "Output"],
Cell[2784055, 97743, 1648, 31, 70, "Output"],
Cell[2785706, 97776, 1622, 30, 70, "Output"],
Cell[2787331, 97808, 1600, 30, 70, "Output"],
Cell[2788934, 97840, 1578, 30, 53, "Output"],
Cell[2790515, 97872, 1552, 29, 53, "Output"],
Cell[2792070, 97903, 1530, 29, 53, "Output"],
Cell[2793603, 97934, 1506, 29, 53, "Output"],
Cell[2795112, 97965, 1480, 28, 53, "Output"],
Cell[2796595, 97995, 1456, 28, 53, "Output"],
Cell[2798054, 98025, 1434, 28, 53, "Output"],
Cell[2799491, 98055, 1406, 27, 53, "Output"],
Cell[2800900, 98084, 1384, 27, 53, "Output"],
Cell[2802287, 98113, 1363, 27, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2803687, 98145, 875, 27, 50, "Input"],
Cell[2804565, 98174, 1771, 34, 70, "Output"],
Cell[2806339, 98210, 1749, 34, 70, "Output"],
Cell[2808091, 98246, 1723, 33, 70, "Output"],
Cell[2809817, 98281, 1701, 33, 70, "Output"],
Cell[2811521, 98316, 1679, 33, 70, "Output"],
Cell[2813203, 98351, 1653, 32, 53, "Output"],
Cell[2814859, 98385, 1629, 32, 53, "Output"],
Cell[2816491, 98419, 1608, 32, 53, "Output"],
Cell[2818102, 98453, 1582, 31, 53, "Output"],
Cell[2819687, 98486, 1560, 31, 53, "Output"],
Cell[2821250, 98519, 1538, 31, 53, "Output"]
}, Open  ]],
Cell[2822803, 98553, 943, 14, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2823783, 98572, 953, 30, 29, "Subsection"],
Cell[CellGroupData[{
Cell[2824761, 98606, 81, 1, 30, "Input"],
Cell[2824845, 98609, 3495, 129, 70, "Output"],
Cell[2828343, 98740, 3483, 129, 70, "Output"],
Cell[2831829, 98871, 3475, 129, 70, "Output"],
Cell[2835307, 99002, 3467, 129, 70, "Output"],
Cell[2838777, 99133, 3459, 129, 70, "Output"],
Cell[2842239, 99264, 3447, 129, 58, "Output"],
Cell[2845689, 99395, 3434, 128, 58, "Output"],
Cell[2849126, 99525, 3426, 128, 58, "Output"],
Cell[2852555, 99655, 3414, 128, 58, "Output"],
Cell[2855972, 99785, 3406, 128, 58, "Output"],
Cell[2859381, 99915, 3398, 128, 58, "Output"],
Cell[2862782, 100045, 3390, 128, 58, "Output"],
Cell[2866175, 100175, 3382, 128, 58, "Output"],
Cell[2869560, 100305, 3369, 127, 58, "Output"],
Cell[2872932, 100434, 3361, 127, 58, "Output"]
}, Open  ]],
Cell[2876308, 100564, 1045, 16, 65, "Text"],
Cell[CellGroupData[{
Cell[2877378, 100584, 1770, 46, 88, "Input"],
Cell[2879151, 100632, 4375, 135, 70, "Output"],
Cell[2883529, 100769, 4351, 135, 70, "Output"],
Cell[2887883, 100906, 4329, 135, 70, "Output"],
Cell[2892215, 101043, 4303, 134, 70, "Output"],
Cell[2896521, 101179, 4282, 134, 70, "Output"],
Cell[2900806, 101315, 4258, 134, 74, "Output"],
Cell[2905067, 101451, 4232, 133, 74, "Output"],
Cell[2909302, 101586, 4210, 133, 74, "Output"],
Cell[2913515, 101721, 4188, 133, 74, "Output"],
Cell[2917706, 101856, 4162, 132, 74, "Output"],
Cell[2921871, 101990, 4138, 132, 74, "Output"],
Cell[2926012, 102124, 4117, 132, 74, "Output"],
Cell[2930132, 102258, 4091, 131, 74, "Output"],
Cell[2934226, 102391, 4069, 131, 74, "Output"],
Cell[2938298, 102524, 4048, 131, 74, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2942383, 102660, 2527, 76, 145, "Input"],
Cell[2944913, 102738, 2802, 82, 70, "Output"],
Cell[2947718, 102822, 2777, 81, 70, "Output"],
Cell[2950498, 102905, 2755, 81, 70, "Output"],
Cell[2953256, 102988, 2733, 81, 70, "Output"],
Cell[2955992, 103071, 2707, 80, 70, "Output"],
Cell[2958702, 103153, 2687, 80, 35, "Output"],
Cell[2961392, 103235, 2665, 80, 35, "Output"],
Cell[2964060, 103317, 2639, 79, 35, "Output"],
Cell[2966702, 103398, 2617, 79, 35, "Output"],
Cell[2969322, 103479, 2595, 79, 35, "Output"],
Cell[2971920, 103560, 2570, 78, 35, "Output"],
Cell[2974493, 103640, 2548, 78, 35, "Output"],
Cell[2977044, 103720, 2524, 78, 35, "Output"],
Cell[2979571, 103800, 2498, 77, 35, "Output"],
Cell[2982072, 103879, 2476, 77, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2984585, 103961, 665, 18, 30, "Input"],
Cell[2985253, 103981, 2137, 75, 70, "Output"],
Cell[2987393, 104058, 2125, 75, 70, "Output"],
Cell[2989521, 104135, 2113, 75, 70, "Output"],
Cell[2991637, 104212, 2100, 74, 70, "Output"],
Cell[2993740, 104288, 2092, 74, 70, "Output"],
Cell[2995835, 104364, 2084, 74, 35, "Output"],
Cell[2997922, 104440, 2072, 74, 35, "Output"],
Cell[2999997, 104516, 2060, 74, 35, "Output"],
Cell[3002060, 104592, 2052, 74, 35, "Output"],
Cell[3004115, 104668, 2044, 74, 35, "Output"],
Cell[3006162, 104744, 2031, 73, 35, "Output"],
Cell[3008196, 104819, 2023, 73, 35, "Output"],
Cell[3010222, 104894, 2015, 73, 35, "Output"],
Cell[3012240, 104969, 2463, 77, 35, "Output"],
Cell[3014706, 105048, 2441, 77, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3017184, 105130, 663, 18, 30, "Input"],
Cell[3017850, 105150, 2129, 75, 70, "Output"],
Cell[3019982, 105227, 2121, 75, 70, "Output"],
Cell[3022106, 105304, 2109, 75, 70, "Output"],
Cell[3024218, 105381, 2096, 74, 70, "Output"],
Cell[3026317, 105457, 2092, 74, 70, "Output"],
Cell[3028412, 105533, 2080, 74, 35, "Output"],
Cell[3030495, 105609, 2068, 74, 35, "Output"],
Cell[3032566, 105685, 2056, 74, 35, "Output"],
Cell[3034625, 105761, 2048, 74, 35, "Output"],
Cell[3036676, 105837, 2039, 73, 35, "Output"],
Cell[3038718, 105912, 2031, 73, 35, "Output"],
Cell[3040752, 105987, 2019, 73, 35, "Output"],
Cell[3042774, 106062, 2011, 73, 35, "Output"],
Cell[3044788, 106137, 2468, 77, 35, "Output"],
Cell[3047259, 106216, 2446, 77, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3049742, 106298, 282, 6, 30, "Input"],
Cell[3050027, 106306, 3973, 122, 70, "Output"],
Cell[3054003, 106430, 3947, 121, 70, "Output"],
Cell[3057953, 106553, 3925, 121, 70, "Output"],
Cell[3061881, 106676, 3901, 121, 70, "Output"],
Cell[3065785, 106799, 3876, 120, 70, "Output"],
Cell[3069664, 106921, 3854, 120, 36, "Output"],
Cell[3073521, 107043, 3832, 120, 36, "Output"],
Cell[3077356, 107165, 3804, 119, 36, "Output"],
Cell[3081163, 107286, 3780, 119, 36, "Output"],
Cell[3084946, 107407, 3758, 119, 36, "Output"],
Cell[3088707, 107528, 3732, 118, 36, "Output"],
Cell[3092442, 107648, 3711, 118, 36, "Output"],
Cell[3096156, 107768, 3689, 118, 36, "Output"],
Cell[3099848, 107888, 3664, 117, 36, "Output"],
Cell[3103515, 108007, 3642, 117, 36, "Output"]
}, Open  ]],
Cell[3107172, 108127, 1031, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[3108228, 108145, 335, 9, 30, "Input"],
Cell[3108566, 108156, 4121, 119, 70, "Output"],
Cell[3112690, 108277, 4097, 119, 70, "Output"],
Cell[3116790, 108398, 4073, 119, 70, "Output"],
Cell[3120866, 108519, 4047, 118, 70, "Output"],
Cell[3124916, 108639, 4023, 118, 70, "Output"],
Cell[3128942, 108759, 4001, 118, 52, "Output"],
Cell[3132946, 108879, 3975, 117, 52, "Output"],
Cell[3136924, 108998, 3951, 117, 52, "Output"],
Cell[3140878, 109117, 3929, 117, 52, "Output"],
Cell[3144810, 109236, 3901, 116, 52, "Output"],
Cell[3148714, 109354, 3879, 116, 52, "Output"],
Cell[3152596, 109472, 3857, 116, 52, "Output"],
Cell[3156456, 109590, 3831, 115, 52, "Output"],
Cell[3160290, 109707, 3809, 115, 52, "Output"],
Cell[3164102, 109824, 3788, 115, 52, "Output"]
}, Open  ]],
Cell[3167905, 109942, 1070, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[3169000, 109960, 1463, 40, 107, "Input"],
Cell[3170466, 110002, 2439, 60, 70, "Output"],
Cell[3172908, 110064, 2417, 60, 70, "Output"],
Cell[3175328, 110126, 2395, 60, 70, "Output"],
Cell[3177726, 110188, 2369, 59, 70, "Output"],
Cell[3180098, 110249, 2347, 59, 70, "Output"],
Cell[3182448, 110310, 2323, 59, 31, "Output"],
Cell[3184774, 110371, 2297, 58, 31, "Output"],
Cell[3187074, 110431, 2275, 58, 31, "Output"],
Cell[3189352, 110491, 2253, 58, 31, "Output"],
Cell[3191608, 110551, 2227, 57, 31, "Output"],
Cell[3193838, 110610, 2203, 57, 31, "Output"],
Cell[3196044, 110669, 2181, 57, 31, "Output"],
Cell[3198228, 110728, 2155, 56, 31, "Output"],
Cell[3200386, 110786, 2133, 56, 31, "Output"],
Cell[3202522, 110844, 2111, 56, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3204670, 110905, 472, 8, 30, "Input"],
Cell[3205145, 110915, 1545, 24, 70, "Output"],
Cell[3206693, 110941, 1523, 24, 70, "Output"],
Cell[3208219, 110967, 1495, 23, 70, "Output"],
Cell[3209717, 110992, 1473, 23, 70, "Output"],
Cell[3211193, 111017, 1451, 23, 70, "Output"],
Cell[3212647, 111042, 1425, 22, 31, "Output"],
Cell[3214075, 111066, 1404, 22, 31, "Output"],
Cell[3215482, 111090, 1382, 22, 31, "Output"],
Cell[3216867, 111114, 1356, 21, 31, "Output"],
Cell[3218226, 111137, 1332, 21, 31, "Output"],
Cell[3219561, 111160, 1310, 21, 31, "Output"],
Cell[3220874, 111183, 1284, 20, 31, "Output"],
Cell[3222161, 111205, 1262, 20, 31, "Output"],
Cell[3223426, 111227, 1238, 20, 31, "Output"],
Cell[3224667, 111249, 1210, 19, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3225914, 111273, 337, 6, 30, "Input"],
Cell[3226254, 111281, 669, 14, 70, "Output"],
Cell[3226926, 111297, 665, 14, 70, "Output"],
Cell[3227594, 111313, 657, 14, 70, "Output"],
Cell[3228254, 111329, 645, 14, 70, "Output"],
Cell[3228902, 111345, 636, 13, 70, "Output"],
Cell[3229541, 111360, 624, 13, 31, "Output"],
Cell[3230168, 111375, 612, 13, 31, "Output"],
Cell[3230783, 111390, 604, 13, 31, "Output"],
Cell[3231390, 111405, 592, 13, 31, "Output"],
Cell[3231985, 111420, 584, 13, 31, "Output"],
Cell[3232572, 111435, 575, 12, 31, "Output"],
Cell[3233150, 111449, 563, 12, 31, "Output"],
Cell[3233716, 111463, 555, 12, 31, "Output"],
Cell[3234274, 111477, 547, 12, 31, "Output"],
Cell[3234824, 111491, 1004, 16, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3235865, 111512, 153, 3, 30, "Input"],
Cell[3236021, 111517, 660, 14, 70, "Output"],
Cell[3236684, 111533, 652, 14, 70, "Output"],
Cell[3237339, 111549, 640, 14, 70, "Output"],
Cell[3237982, 111565, 627, 13, 70, "Output"],
Cell[3238612, 111580, 619, 13, 70, "Output"],
Cell[3239234, 111595, 607, 13, 31, "Output"],
Cell[3239844, 111610, 595, 13, 31, "Output"],
Cell[3240442, 111625, 583, 13, 31, "Output"],
Cell[3241028, 111640, 574, 12, 31, "Output"],
Cell[3241605, 111654, 566, 12, 31, "Output"],
Cell[3242174, 111668, 558, 12, 31, "Output"],
Cell[3242735, 111682, 546, 12, 31, "Output"],
Cell[3243284, 111696, 987, 16, 31, "Output"],
Cell[3244274, 111714, 965, 16, 31, "Output"],
Cell[3245242, 111732, 940, 15, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3246219, 111752, 157, 3, 30, "Input"],
Cell[3246379, 111757, 659, 14, 70, "Output"],
Cell[3247041, 111773, 651, 14, 70, "Output"],
Cell[3247695, 111789, 643, 14, 70, "Output"],
Cell[3248341, 111805, 630, 13, 70, "Output"],
Cell[3248974, 111820, 618, 13, 70, "Output"],
Cell[3249595, 111835, 610, 13, 31, "Output"],
Cell[3250208, 111850, 598, 13, 31, "Output"],
Cell[3250809, 111865, 586, 13, 31, "Output"],
Cell[3251398, 111880, 578, 13, 31, "Output"],
Cell[3251979, 111895, 569, 12, 31, "Output"],
Cell[3252551, 111909, 557, 12, 31, "Output"],
Cell[3253111, 111923, 549, 12, 31, "Output"],
Cell[3253663, 111937, 990, 16, 31, "Output"],
Cell[3254656, 111955, 969, 16, 31, "Output"],
Cell[3255628, 111973, 944, 15, 31, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3256633, 111995, 632, 23, 50, "Section"],
Cell[3257268, 112020, 501, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[3257794, 112031, 1237, 33, 69, "Input"],
Cell[3259034, 112066, 8950, 308, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3268021, 112379, 140, 2, 30, "Input"],
Cell[3268164, 112383, 816, 15, 70, "Output"]
}, Open  ]],
Cell[3268995, 112401, 525, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[3269545, 112412, 2125, 56, 107, "Input"],
Cell[3271673, 112470, 4126, 105, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3275836, 112580, 1515, 43, 88, "Input"],
Cell[3277354, 112625, 1989, 67, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3279380, 112697, 1463, 43, 88, "Input"],
Cell[3280846, 112742, 1932, 66, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3282815, 112813, 1843, 54, 88, "Input"],
Cell[3284661, 112869, 605, 10, 70, "Output"]
}, Open  ]],
Cell[3285281, 112882, 493, 8, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3285811, 112895, 811, 29, 50, "Section"],
Cell[CellGroupData[{
Cell[3286647, 112928, 109, 1, 37, "Subsection"],
Cell[3286759, 112931, 861, 14, 46, "Text"],
Cell[CellGroupData[{
Cell[3287645, 112949, 3120, 78, 202, "Input"],
Cell[3290768, 113029, 9829, 274, 172, "Output"]
}, Open  ]],
Cell[3300612, 113306, 437, 8, 46, "Text"],
Cell[CellGroupData[{
Cell[3301074, 113318, 233, 4, 30, "Input"],
Cell[3301310, 113324, 911, 17, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3302258, 113346, 695, 19, 50, "Input"],
Cell[3302956, 113367, 2017, 31, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3305010, 113403, 597, 16, 69, "Input"],
Cell[3305610, 113421, 3925, 97, 70, "Output"]
}, Open  ]],
Cell[3309550, 113521, 435, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[3310010, 113531, 7024, 185, 468, "Input"],
Cell[3317037, 113718, 1886, 29, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3318972, 113753, 145, 2, 37, "Subsection"],
Cell[3319120, 113757, 920, 15, 65, "Text"],
Cell[CellGroupData[{
Cell[3320065, 113776, 1309, 38, 69, "Input"],
Cell[3321377, 113816, 2950, 61, 70, "Output"]
}, Open  ]],
Cell[3324342, 113880, 435, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[3324802, 113890, 7129, 185, 468, "Input"],
Cell[3331934, 114077, 1948, 30, 31, "Output"]
}, Open  ]],
Cell[3333897, 114110, 512, 7, 46, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3334446, 114122, 149, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[3334620, 114128, 1096, 19, 30, "Input"],
Cell[3335719, 114149, 9815, 274, 208, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3345571, 114428, 125, 2, 30, "Input"],
Cell[3345699, 114432, 956, 18, 31, "Output"]
}, Open  ]],
Cell[3346670, 114453, 464, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[3347159, 114463, 525, 15, 50, "Input"],
Cell[3347687, 114480, 661, 15, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3348385, 114500, 142, 3, 30, "Input"],
Cell[3348530, 114505, 777, 15, 31, "Output"]
}, Open  ]],
Cell[3349322, 114523, 444, 7, 46, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3349803, 114535, 394, 5, 37, "Subsection"],
Cell[3350200, 114542, 521, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[3350746, 114553, 2025, 48, 88, "Input"],
Cell[3352774, 114603, 11475, 325, 200, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3364286, 114933, 176, 3, 30, "Input"],
Cell[3364465, 114938, 943, 17, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3365445, 114960, 324, 9, 30, "Input"],
Cell[3365772, 114971, 703, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3366512, 114989, 2427, 66, 107, "Input"],
Cell[3368942, 115057, 11685, 432, 193, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3380664, 115494, 277, 7, 30, "Input"],
Cell[3380944, 115503, 446, 7, 31, "Output"]
}, Open  ]],
Cell[3381405, 115513, 776, 21, 65, "Text"],
Cell[3382184, 115536, 241, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[3382450, 115544, 712, 19, 30, "Input"],
Cell[3383165, 115565, 12419, 486, 249, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3395621, 116056, 229, 5, 30, "Input"],
Cell[3395853, 116063, 264, 4, 31, "Output"]
}, Open  ]],
Cell[3396132, 116070, 564, 13, 46, "Text"],
Cell[3396699, 116085, 366, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[3397090, 116096, 2055, 49, 88, "Input"],
Cell[3399148, 116147, 10712, 300, 202, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3409897, 116452, 176, 3, 30, "Input"],
Cell[3410076, 116457, 943, 17, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3411056, 116479, 2455, 67, 107, "Input"],
Cell[3413514, 116548, 11699, 432, 193, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3425250, 116985, 303, 7, 30, "Input"],
Cell[3425556, 116994, 11572, 430, 193, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3437165, 117429, 226, 6, 30, "Input"],
Cell[3437394, 117437, 433, 7, 31, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3437888, 117451, 842, 33, 50, "Section"],
Cell[CellGroupData[{
Cell[3438755, 117488, 1022, 25, 126, "Input"],
Cell[3439780, 117515, 2918, 100, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3442735, 117620, 1233, 35, 50, "Input"],
Cell[3443971, 117657, 2438, 90, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3446446, 117752, 387, 10, 30, "Input"],
Cell[3446836, 117764, 812, 19, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3447685, 117788, 158, 2, 37, "Subsection"],
Cell[3447846, 117792, 732, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[3448603, 117808, 734, 19, 50, "Input"],
Cell[3449340, 117829, 1855, 36, 101, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3451232, 117870, 230, 5, 30, "Input"],
Cell[3451465, 117877, 1256, 30, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3452758, 117912, 476, 11, 30, "Input"],
Cell[3453237, 117925, 1136, 27, 49, "Output"]
}, Open  ]],
Cell[3454388, 117955, 877, 16, 46, "Text"],
Cell[3455268, 117973, 1827, 48, 145, "Input"],
Cell[CellGroupData[{
Cell[3457120, 118025, 200, 4, 30, "Input"],
Cell[3457323, 118031, 1488, 27, 52, "Output"]
}, Open  ]],
Cell[3458826, 118061, 2261, 64, 107, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3461124, 118130, 133, 2, 37, "Subsection"],
Cell[3461260, 118134, 1247, 36, 87, "Text"],
Cell[3462510, 118172, 90, 1, 30, "Text"],
Cell[3462603, 118175, 902, 14, 65, "Text"],
Cell[CellGroupData[{
Cell[3463530, 118193, 1487, 36, 126, "Input"],
Cell[3465020, 118231, 10308, 280, 184, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3475365, 118516, 212, 4, 30, "Input"],
Cell[3475580, 118522, 537, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3476154, 118536, 336, 6, 30, "Input"],
Cell[3476493, 118544, 452, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3476982, 118556, 1490, 41, 107, "Input"],
Cell[3478475, 118599, 13771, 392, 214, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3492283, 118996, 134, 2, 30, "Input"],
Cell[3492420, 119000, 500, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3492957, 119013, 475, 9, 30, "Input"],
Cell[3493435, 119024, 8902, 253, 172, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3502374, 119282, 139, 2, 30, "Input"],
Cell[3502516, 119286, 548, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3503101, 119299, 391, 9, 30, "Input"],
Cell[3503495, 119310, 549, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3504081, 119323, 161, 3, 30, "Input"],
Cell[3504245, 119328, 1089, 32, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3505371, 119365, 278, 6, 30, "Input"],
Cell[3505652, 119373, 1104, 32, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3506793, 119410, 360, 9, 30, "Input"],
Cell[3507156, 119421, 1112, 32, 53, "Output"]
}, Open  ]],
Cell[3508283, 119456, 802, 11, 46, "Text"],
Cell[CellGroupData[{
Cell[3509110, 119471, 1904, 47, 221, "Input"],
Cell[3511017, 119520, 10602, 302, 212, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3521656, 119827, 136, 2, 30, "Input"],
Cell[3521795, 119831, 453, 7, 31, "Output"]
}, Open  ]],
Cell[3522263, 119841, 840, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[3523128, 119857, 1378, 33, 107, "Input"],
Cell[3524509, 119892, 562, 11, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3525120, 119909, 106, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[3525251, 119914, 1147, 28, 88, "Input"],
Cell[3526401, 119944, 4886, 134, 124, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3531324, 120083, 162, 3, 30, "Input"],
Cell[3531489, 120088, 549, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3532075, 120101, 807, 23, 88, "Input"],
Cell[3532885, 120126, 11771, 338, 212, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3544693, 120469, 134, 2, 30, "Input"],
Cell[3544830, 120473, 476, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3545343, 120485, 351, 7, 30, "Input"],
Cell[3545697, 120494, 4703, 128, 114, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3550437, 120627, 139, 2, 30, "Input"],
Cell[3550579, 120631, 432, 7, 31, "Output"]
}, Open  ]],
Cell[3551026, 120641, 849, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[3551900, 120657, 1461, 33, 145, "Input"],
Cell[3553364, 120692, 4720, 129, 114, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3558121, 120826, 161, 3, 30, "Input"],
Cell[3558285, 120831, 506, 8, 31, "Output"]
}, Open  ]],
Cell[3558806, 120842, 840, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[3559671, 120858, 1407, 34, 107, "Input"],
Cell[3561081, 120894, 603, 11, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3561733, 120911, 192, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[3561950, 120917, 1269, 29, 107, "Input"],
Cell[3563222, 120948, 15674, 587, 410, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3578933, 121540, 193, 4, 30, "Input"],
Cell[3579129, 121546, 487, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3579653, 121558, 874, 24, 69, "Input"],
Cell[3580530, 121584, 15545, 584, 410, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3596112, 122173, 163, 3, 30, "Input"],
Cell[3596278, 122178, 446, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3596761, 122190, 385, 8, 50, "Input"],
Cell[3597149, 122200, 11550, 440, 369, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3608736, 122645, 172, 3, 30, "Input"],
Cell[3608911, 122650, 432, 7, 31, "Output"]
}, Open  ]],
Cell[3609358, 122660, 942, 13, 46, "Text"],
Cell[CellGroupData[{
Cell[3610325, 122677, 1564, 34, 145, "Input"],
Cell[3611892, 122713, 111716, 4328, 3609, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3723645, 127046, 187, 3, 30, "Input"],
Cell[3723835, 127051, 499, 8, 31, "Output"]
}, Open  ]],
Cell[3724349, 127062, 840, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[3725214, 127078, 1561, 36, 202, "Input"],
Cell[3726778, 127116, 605, 11, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3727432, 127133, 245, 3, 37, "Subsection"],
Cell[CellGroupData[{
Cell[3727702, 127140, 2365, 59, 107, "Input"],
Cell[3730070, 127201, 2769, 90, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3732876, 127296, 222, 4, 30, "Input"],
Cell[3733101, 127302, 528, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3733666, 127315, 1517, 41, 88, "Input"],
Cell[3735186, 127358, 8644, 319, 185, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3743867, 127682, 189, 3, 30, "Input"],
Cell[3744059, 127687, 472, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3744568, 127699, 441, 8, 50, "Input"],
Cell[3745012, 127709, 5397, 200, 169, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3750446, 127914, 222, 3, 30, "Input"],
Cell[3750671, 127919, 450, 7, 31, "Output"]
}, Open  ]],
Cell[3751136, 127929, 849, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[3752010, 127945, 2265, 50, 297, "Input"],
Cell[3754278, 127997, 74687, 2889, 2409, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3829002, 130891, 243, 4, 30, "Input"],
Cell[3829248, 130897, 528, 8, 31, "Output"]
}, Open  ]],
Cell[3829791, 130908, 840, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[3830656, 130924, 1729, 36, 202, "Input"],
Cell[3832388, 130962, 638, 12, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3833075, 130980, 299, 4, 37, "Subsection"],
Cell[CellGroupData[{
Cell[3833399, 130988, 2027, 44, 126, "Input"],
Cell[3835429, 131034, 45608, 1731, 947, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3881074, 132770, 239, 4, 30, "Input"],
Cell[3881316, 132776, 581, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3881934, 132790, 1019, 26, 69, "Input"],
Cell[3882956, 132818, 89183, 3392, 1930, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3972176, 136215, 206, 3, 30, "Input"],
Cell[3972385, 136220, 500, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3972922, 136233, 480, 9, 50, "Input"],
Cell[3973405, 136244, 21705, 805, 717, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3995147, 137054, 243, 4, 30, "Input"],
Cell[3995393, 137060, 469, 7, 31, "Output"]
}, Open  ]],
Cell[3995877, 137070, 972, 16, 46, "Text"],
Cell[CellGroupData[{
Cell[3996874, 137090, 6231, 146, 563, "Input"],
Cell[4003108, 137238, 11642, 329, 212, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4014787, 137572, 260, 4, 30, "Input"],
Cell[4015050, 137578, 567, 9, 31, "Output"]
}, Open  ]],
Cell[4015632, 137590, 840, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[4016497, 137606, 1678, 37, 202, "Input"],
Cell[4018178, 137645, 679, 12, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4018906, 137663, 104, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[4019035, 137668, 341, 7, 50, "Input"],
Cell[4019379, 137677, 10609, 303, 172, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4030025, 137985, 129, 2, 30, "Input"],
Cell[4030157, 137989, 435, 7, 31, "Output"]
}, Open  ]],
Cell[4030607, 137999, 943, 13, 46, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4031587, 138017, 233, 3, 37, "Subsection"],
Cell[4031823, 138022, 899, 12, 46, "Text"],
Cell[4032725, 138036, 540, 11, 30, "Input"],
Cell[4033268, 138049, 508, 11, 30, "Input"],
Cell[4033779, 138062, 470, 10, 30, "Input"],
Cell[4034252, 138074, 447, 9, 30, "Input"],
Cell[4034702, 138085, 276, 7, 30, "Input"],
Cell[4034981, 138094, 902, 31, 50, "Input"],
Cell[CellGroupData[{
Cell[4035908, 138129, 954, 26, 69, "Input"],
Cell[4036865, 138157, 2354, 63, 137, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4039256, 138225, 1059, 18, 30, "Input"],
Cell[4040318, 138245, 2270, 54, 115, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4042625, 138304, 172, 4, 30, "Input"],
Cell[4042800, 138310, 728, 17, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4043565, 138332, 313, 8, 30, "Input"],
Cell[4043881, 138342, 526, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4044444, 138356, 148, 4, 30, "Input"],
Cell[4044595, 138362, 727, 17, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4045359, 138384, 264, 7, 30, "Input"],
Cell[4045626, 138393, 445, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4046108, 138405, 148, 4, 30, "Input"],
Cell[4046259, 138411, 617, 13, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4046913, 138429, 231, 6, 30, "Input"],
Cell[4047147, 138437, 476, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4047660, 138449, 229, 5, 30, "Input"],
Cell[4047892, 138456, 484, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4048413, 138470, 1653, 49, 88, "Input"],
Cell[4050069, 138521, 1114, 26, 52, "Output"]
}, Open  ]],
Cell[4051198, 138550, 710, 18, 49, "Text"],
Cell[CellGroupData[{
Cell[4051933, 138572, 1972, 53, 145, "Input"],
Cell[4053908, 138627, 14201, 419, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4068146, 139051, 185, 3, 30, "Input"],
Cell[4068334, 139056, 533, 9, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4068904, 139070, 1679, 44, 126, "Input"],
Cell[4070586, 139116, 12454, 363, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4083077, 139484, 140, 2, 30, "Input"],
Cell[4083220, 139488, 537, 8, 70, "Output"]
}, Open  ]],
Cell[4083772, 139499, 431, 9, 30, "Input"],
Cell[4084206, 139510, 410, 9, 30, "Input"],
Cell[4084619, 139521, 409, 9, 30, "Input"],
Cell[4085031, 139532, 453, 9, 30, "Input"],
Cell[4085487, 139543, 234, 6, 30, "Input"],
Cell[4085724, 139551, 530, 10, 30, "Input"],
Cell[4086257, 139563, 409, 9, 30, "Input"],
Cell[4086669, 139574, 410, 9, 30, "Input"],
Cell[4087082, 139585, 455, 9, 30, "Input"],
Cell[4087540, 139596, 238, 6, 30, "Input"],
Cell[CellGroupData[{
Cell[4087803, 139606, 1593, 43, 126, "Input"],
Cell[4089399, 139651, 3144, 92, 70, "Output"]
}, Open  ]],
Cell[4092558, 139746, 1235, 22, 69, "Input"],
Cell[CellGroupData[{
Cell[4093818, 139772, 211, 5, 30, "Input"],
Cell[4094032, 139779, 11615, 376, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4105684, 140160, 4635, 116, 240, "Input"],
Cell[4110322, 140278, 20874, 702, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4131233, 140985, 3737, 100, 183, "Input"],
Cell[4134973, 141087, 11145, 326, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4146155, 141418, 517, 10, 30, "Input"],
Cell[4146675, 141430, 2565, 71, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4149277, 141506, 133, 2, 30, "Input"],
Cell[4149413, 141510, 1115, 39, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4150565, 141554, 938, 26, 69, "Input"],
Cell[4151506, 141582, 534, 8, 70, "Output"]
}, Open  ]],
Cell[4152055, 141593, 564, 12, 46, "Text"],
Cell[4152622, 141607, 241, 4, 46, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4152912, 141617, 229, 3, 50, "Section"],
Cell[4153144, 141622, 354, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[4153523, 141632, 103, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[4153651, 141637, 1111, 36, 69, "Input"],
Cell[4154765, 141675, 1794, 52, 70, "Output"]
}, Open  ]],
Cell[4156574, 141730, 333, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[4156932, 141739, 2347, 68, 126, "Input"],
Cell[4159282, 141809, 1174, 38, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4160493, 141852, 1443, 44, 88, "Input"],
Cell[4161939, 141898, 341, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4162317, 141908, 418, 11, 30, "Input"],
Cell[4162738, 141921, 12617, 423, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4175392, 142349, 179, 3, 30, "Input"],
Cell[4175574, 142354, 763, 14, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4176374, 142373, 2924, 83, 183, "Input"],
Cell[4179301, 142458, 9156, 332, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4188494, 142795, 159, 3, 30, "Input"],
Cell[4188656, 142800, 776, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4189469, 142820, 1757, 50, 107, "Input"],
Cell[4191229, 142872, 8200, 293, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4199466, 143170, 172, 3, 30, "Input"],
Cell[4199641, 143175, 2061, 33, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4201739, 143213, 131, 2, 30, "Input"],
Cell[4201873, 143217, 1696, 25, 70, "Output"]
}, Open  ]],
Cell[4203584, 143245, 303, 4, 46, "Text"],
Cell[CellGroupData[{
Cell[4203912, 143253, 203, 4, 30, "Input"],
Cell[4204118, 143259, 2571, 62, 70, "Output"]
}, Open  ]],
Cell[4206704, 143324, 666, 13, 103, "Text"],
Cell[CellGroupData[{
Cell[4207395, 143341, 7255, 205, 392, "Input"],
Cell[4214653, 143548, 507, 8, 70, "Output"]
}, Open  ]],
Cell[4215175, 143559, 336, 5, 46, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4215548, 143569, 129, 2, 37, "Subsection"],
Cell[CellGroupData[{
Cell[4215702, 143575, 6582, 197, 259, "Input"],
Cell[4222287, 143774, 13150, 487, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4235474, 144266, 1255, 33, 88, "Input"],
Cell[4236732, 144301, 14052, 496, 70, "Output"]
}, Open  ]],
Cell[4250799, 144800, 455, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[4251279, 144810, 6069, 161, 278, "Input"],
Cell[4257351, 144973, 3169, 80, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4260557, 145058, 5923, 159, 278, "Input"],
Cell[4266483, 145219, 2113, 69, 70, "Output"]
}, Open  ]],
Cell[4268611, 145291, 483, 7, 46, "Text"],
Cell[CellGroupData[{
Cell[4269119, 145302, 499, 11, 30, "Input"],
Cell[4269621, 145315, 10351, 275, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4280009, 145595, 127, 2, 30, "Input"],
Cell[4280139, 145599, 1820, 26, 70, "Output"]
}, Open  ]],
Cell[4281974, 145628, 733, 12, 65, "Text"],
Cell[CellGroupData[{
Cell[4282732, 145644, 410, 14, 30, "Input"],
Cell[4283145, 145660, 10173, 273, 70, "Output"]
}, Open  ]],
Cell[4293333, 145936, 413, 11, 30, "Input"],
Cell[CellGroupData[{
Cell[4293771, 145951, 434, 14, 30, "Input"],
Cell[4294208, 145967, 11224, 302, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4305469, 146274, 128, 2, 30, "Input"],
Cell[4305600, 146278, 733, 14, 70, "Output"]
}, Open  ]],
Cell[4306348, 146295, 630, 9, 46, "Text"],
Cell[CellGroupData[{
Cell[4307003, 146308, 252, 6, 30, "Input"],
Cell[4307258, 146316, 13659, 378, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4320954, 146699, 380, 7, 30, "Input"],
Cell[4321337, 146708, 12063, 330, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4333437, 147043, 183, 3, 30, "Input"],
Cell[4333623, 147048, 1188, 18, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4334848, 147071, 9887, 270, 487, "Input"],
Cell[4344738, 147343, 1407, 21, 70, "Output"]
}, Open  ]],
Cell[4346160, 147367, 1020, 18, 103, "Text"],
Cell[4347183, 147387, 728, 11, 46, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4347960, 147404, 91, 1, 50, "Section"],
Cell[4348054, 147407, 4101, 121, 480, "Text"],
Cell[4352158, 147530, 1157, 40, 46, "Text"],
Cell[CellGroupData[{
Cell[4353340, 147574, 129, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[4353494, 147579, 4229, 109, 183, "Input"],
Cell[4357726, 147690, 11347, 317, 176, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4369110, 148012, 161, 3, 30, "Input"],
Cell[4369274, 148017, 861, 13, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4370172, 148035, 443, 9, 30, "Input"],
Cell[4370618, 148046, 7970100, 168236, 234, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12340755, 316287, 3154, 91, 145, "Input"],
Cell[12343912, 316380, 326510, 8980, 2004, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12670459, 325365, 1377, 41, 50, "Input"],
Cell[12671839, 325408, 18592, 475, 121, "Output"]
}, Open  ]],
Cell[12690446, 325886, 636, 17, 49, "Text"]
}, Open  ]],
Cell[12691097, 325906, 249, 3, 37, "Subsection"],
Cell[CellGroupData[{
Cell[12691371, 325913, 157, 2, 29, "Subsection"],
Cell[CellGroupData[{
Cell[12691553, 325919, 6867, 178, 259, "Input"],
Cell[12698423, 326099, 13523, 396, 176, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12711983, 326500, 183, 3, 30, "Input"],
Cell[12712169, 326505, 910, 14, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12713116, 326524, 998, 28, 69, "Input"],
Cell[12714117, 326554, 10806, 307, 176, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12724960, 326866, 136, 2, 30, "Input"],
Cell[12725099, 326870, 317, 5, 31, "Output"]
}, Open  ]],
Cell[12725431, 326878, 698, 15, 103, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12726166, 326898, 282, 3, 37, "Subsection"],
Cell[12726451, 326903, 899, 12, 46, "Text"],
Cell[12727353, 326917, 540, 11, 30, "Input"],
Cell[12727896, 326930, 508, 11, 30, "Input"],
Cell[12728407, 326943, 470, 10, 30, "Input"],
Cell[12728880, 326955, 447, 9, 30, "Input"],
Cell[12729330, 326966, 276, 7, 30, "Input"],
Cell[12729609, 326975, 902, 31, 50, "Input"],
Cell[CellGroupData[{
Cell[12730536, 327010, 954, 26, 69, "Input"],
Cell[12731493, 327038, 2398, 64, 137, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12733928, 327107, 1080, 18, 30, "Input"],
Cell[12735011, 327127, 16413, 465, 1259, "Output"]
}, Open  ]],
Cell[12751439, 327595, 186, 4, 30, "Input"],
Cell[CellGroupData[{
Cell[12751650, 327603, 204, 5, 30, "Input"],
Cell[12751857, 327610, 1391, 34, 90, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12753285, 327649, 342, 8, 30, "Input"],
Cell[12753630, 327659, 595, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12754262, 327674, 178, 4, 30, "Input"],
Cell[12754443, 327680, 1026, 25, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12755506, 327710, 296, 8, 30, "Input"],
Cell[12755805, 327720, 517, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12756359, 327733, 176, 4, 30, "Input"],
Cell[12756538, 327739, 1417, 37, 90, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12757992, 327781, 263, 7, 30, "Input"],
Cell[12758258, 327790, 543, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12758838, 327803, 260, 6, 30, "Input"],
Cell[12759101, 327811, 555, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12759693, 327826, 1683, 49, 88, "Input"],
Cell[12761379, 327877, 2019, 54, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12763435, 327936, 163, 3, 30, "Input"],
Cell[12763601, 327941, 9234, 258, 174, "Output"]
}, Open  ]],
Cell[12772850, 328202, 785, 18, 68, "Text"],
Cell[12773638, 328222, 287, 7, 30, "Input"],
Cell[CellGroupData[{
Cell[12773950, 328233, 486, 13, 30, "Input"],
Cell[12774439, 328248, 994, 24, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12775470, 328277, 3690, 102, 202, "Input"],
Cell[12779163, 328381, 9362, 254, 198, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12788562, 328640, 115, 2, 30, "Input"],
Cell[12788680, 328644, 390, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12789107, 328655, 1496, 38, 107, "Input"],
Cell[12790606, 328695, 7615, 212, 144, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12798258, 328912, 143, 2, 30, "Input"],
Cell[12798404, 328916, 356, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12798797, 328927, 164, 3, 30, "Input"],
Cell[12798964, 328932, 358, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12799359, 328943, 1687, 40, 107, "Input"],
Cell[12801049, 328985, 5205, 143, 136, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12806291, 329133, 169, 3, 30, "Input"],
Cell[12806463, 329138, 412, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12806912, 329149, 162, 3, 30, "Input"],
Cell[12807077, 329154, 412, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12807526, 329165, 1299, 35, 107, "Input"],
Cell[12808828, 329202, 6760, 181, 178, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12815625, 329388, 191, 3, 30, "Input"],
Cell[12815819, 329393, 386, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12816242, 329404, 217, 5, 30, "Input"],
Cell[12816462, 329411, 384, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12816883, 329422, 1353, 36, 107, "Input"],
Cell[12818239, 329460, 7451, 204, 178, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12825727, 329669, 212, 3, 30, "Input"],
Cell[12825942, 329674, 429, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12826408, 329686, 261, 5, 30, "Input"],
Cell[12826672, 329693, 438, 7, 31, "Output"]
}, Open  ]],
Cell[12827125, 329703, 548, 10, 46, "Text"],
Cell[12827676, 329715, 431, 9, 30, "Input"],
Cell[12828110, 329726, 479, 10, 30, "Input"],
Cell[12828592, 329738, 234, 6, 30, "Input"],
Cell[12828829, 329746, 410, 9, 30, "Input"],
Cell[12829242, 329757, 455, 9, 30, "Input"],
Cell[12829700, 329768, 238, 6, 30, "Input"],
Cell[CellGroupData[{
Cell[12829963, 329778, 1191, 31, 107, "Input"],
Cell[12831157, 329811, 6427, 184, 133, "Output"]
}, Open  ]],
Cell[12837599, 329998, 1257, 22, 50, "Input"],
Cell[12838859, 330022, 142, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[12839026, 330029, 351, 8, 30, "Input"],
Cell[12839380, 330039, 5587, 156, 563, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12845004, 330200, 3795, 93, 202, "Input"],
Cell[12848802, 330295, 12590, 424, 822, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12861429, 330724, 2059, 51, 126, "Input"],
Cell[12863491, 330777, 3773, 97, 193, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12867301, 330879, 2424, 68, 183, "Input"],
Cell[12869728, 330949, 2312, 84, 89, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12872077, 331038, 450, 10, 50, "Input"],
Cell[12872530, 331050, 13934, 374, 1567, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12886501, 331429, 199, 3, 30, "Input"],
Cell[12886703, 331434, 465, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12887205, 331447, 495, 9, 30, "Input"],
Cell[12887703, 331458, 3288, 66, 394, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12891028, 331529, 132, 2, 30, "Input"],
Cell[12891163, 331533, 904, 24, 53, "Output"]
}, Open  ]],
Cell[12892082, 331560, 1493, 26, 49, "Text"],
Cell[12893578, 331588, 241, 4, 46, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12893856, 331597, 521, 12, 55, "Subsection"],
Cell[12894380, 331611, 899, 12, 46, "Text"],
Cell[12895282, 331625, 540, 11, 30, "Input"],
Cell[12895825, 331638, 508, 11, 30, "Input"],
Cell[12896336, 331651, 470, 10, 30, "Input"],
Cell[12896809, 331663, 447, 9, 30, "Input"],
Cell[12897259, 331674, 276, 7, 30, "Input"],
Cell[12897538, 331683, 902, 31, 50, "Input"],
Cell[CellGroupData[{
Cell[12898465, 331718, 954, 26, 69, "Input"],
Cell[12899422, 331746, 2472, 65, 137, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12901931, 331816, 1106, 19, 30, "Input"],
Cell[12903040, 331837, 2470, 56, 115, "Output"]
}, Open  ]],
Cell[12905525, 331896, 186, 4, 30, "Input"],
Cell[CellGroupData[{
Cell[12905736, 331904, 204, 5, 30, "Input"],
Cell[12905943, 331911, 932, 21, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12906912, 331937, 342, 8, 30, "Input"],
Cell[12907257, 331947, 671, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12907965, 331963, 178, 4, 30, "Input"],
Cell[12908146, 331969, 841, 19, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12909024, 331993, 296, 8, 30, "Input"],
Cell[12909323, 332003, 564, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12909924, 332017, 176, 4, 30, "Input"],
Cell[12910103, 332023, 738, 15, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12910878, 332043, 263, 7, 30, "Input"],
Cell[12911144, 332052, 594, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12911775, 332066, 260, 6, 30, "Input"],
Cell[12912038, 332074, 600, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12912675, 332090, 1683, 49, 88, "Input"],
Cell[12914361, 332141, 1257, 28, 52, "Output"]
}, Open  ]],
Cell[12915633, 332172, 785, 18, 68, "Text"],
Cell[12916421, 332192, 287, 7, 30, "Input"],
Cell[CellGroupData[{
Cell[12916733, 332203, 486, 13, 30, "Input"],
Cell[12917222, 332218, 671, 16, 57, "Output"]
}, Open  ]],
Cell[12917908, 332237, 613, 13, 46, "Text"],
Cell[CellGroupData[{
Cell[12918546, 332254, 3690, 102, 202, "Input"],
Cell[12922239, 332358, 10144, 294, 236, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12932420, 332657, 115, 2, 30, "Input"],
Cell[12932538, 332661, 410, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12932985, 332672, 1496, 38, 107, "Input"],
Cell[12934484, 332712, 9014, 260, 154, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12943535, 332977, 143, 2, 30, "Input"],
Cell[12943681, 332981, 386, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12944104, 332992, 164, 3, 30, "Input"],
Cell[12944271, 332997, 378, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12944686, 333008, 1687, 40, 107, "Input"],
Cell[12946376, 333050, 8674, 242, 202, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12955087, 333297, 169, 3, 30, "Input"],
Cell[12955259, 333302, 437, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12955733, 333314, 162, 3, 30, "Input"],
Cell[12955898, 333319, 436, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12956371, 333331, 1299, 35, 107, "Input"],
Cell[12957673, 333368, 12437, 367, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12970147, 333740, 191, 3, 30, "Input"],
Cell[12970341, 333745, 403, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12970781, 333756, 217, 5, 30, "Input"],
Cell[12971001, 333763, 408, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12971446, 333774, 1353, 36, 107, "Input"],
Cell[12972802, 333812, 10902, 316, 250, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12983741, 334133, 212, 3, 30, "Input"],
Cell[12983956, 334138, 455, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12984448, 334150, 261, 5, 30, "Input"],
Cell[12984712, 334157, 461, 7, 31, "Output"]
}, Open  ]],
Cell[12985188, 334167, 548, 10, 46, "Text"],
Cell[12985739, 334179, 431, 9, 30, "Input"],
Cell[12986173, 334190, 479, 10, 30, "Input"],
Cell[12986655, 334202, 234, 6, 30, "Input"],
Cell[12986892, 334210, 410, 9, 30, "Input"],
Cell[12987305, 334221, 455, 9, 30, "Input"],
Cell[12987763, 334232, 238, 6, 30, "Input"],
Cell[CellGroupData[{
Cell[12988026, 334242, 1191, 31, 107, "Input"],
Cell[12989220, 334275, 2889, 82, 255, "Output"]
}, Open  ]],
Cell[12992124, 334360, 1257, 22, 50, "Input"],
Cell[12993384, 334384, 142, 3, 30, "Input"],
Cell[CellGroupData[{
Cell[12993551, 334391, 351, 8, 30, "Input"],
Cell[12993905, 334401, 5419, 152, 563, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12999361, 334558, 3795, 93, 202, "Input"],
Cell[13003159, 334653, 15452, 519, 893, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13018648, 335177, 2059, 51, 126, "Input"],
Cell[13020710, 335230, 5912, 166, 226, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13026659, 335401, 2424, 68, 183, "Input"],
Cell[13029086, 335471, 2442, 87, 91, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13031565, 335563, 450, 10, 50, "Input"],
Cell[13032018, 335575, 29585, 1017, 2352, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13061640, 336597, 199, 3, 30, "Input"],
Cell[13061842, 336602, 487, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13062366, 336615, 495, 9, 30, "Input"],
Cell[13062864, 336626, 9780, 236, 684, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13072681, 336867, 132, 2, 30, "Input"],
Cell[13072816, 336871, 4926, 125, 250, "Output"]
}, Open  ]],
Cell[13077757, 336999, 1325, 22, 46, "Text"],
Cell[13079085, 337023, 312, 5, 46, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[13079446, 337034, 247, 4, 50, "Section"],
Cell[13079696, 337040, 1750, 36, 84, "Text"],
Cell[13081449, 337078, 1448, 38, 63, "Input"],
Cell[CellGroupData[{
Cell[13082922, 337120, 283, 6, 28, "Input"],
Cell[13083208, 337128, 191, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13083436, 337136, 338, 7, 28, "Input"],
Cell[13083777, 337145, 12528, 488, 161, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13096342, 337638, 306, 6, 28, "Input"],
Cell[13096651, 337646, 12349, 485, 161, "Output"]
}, Open  ]],
Cell[13109015, 338134, 1485, 26, 48, "Text"],
Cell[13110503, 338162, 1574, 40, 63, "Input"],
Cell[CellGroupData[{
Cell[13112102, 338206, 277, 6, 28, "Input"],
Cell[13112382, 338214, 216, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13112635, 338223, 233, 5, 28, "Input"],
Cell[13112871, 338230, 9281, 365, 123, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13122189, 338600, 209, 5, 28, "Input"],
Cell[13122401, 338607, 9247, 364, 123, "Output"]
}, Open  ]],
Cell[13131663, 338974, 1408, 19, 46, "Text"],
Cell[13133074, 338995, 3874, 101, 165, "Input"],
Cell[CellGroupData[{
Cell[13136973, 339100, 134, 2, 28, "Input"],
Cell[13137110, 339104, 275, 4, 28, "Output"]
}, Open  ]],
Cell[13137400, 339111, 3874, 101, 165, "Input"],
Cell[CellGroupData[{
Cell[13141299, 339216, 136, 2, 28, "Input"],
Cell[13141438, 339220, 193, 3, 28, "Output"]
}, Open  ]],
Cell[13141646, 339226, 3532, 96, 165, "Input"],
Cell[CellGroupData[{
Cell[13145203, 339326, 110, 2, 28, "Input"],
Cell[13145316, 339330, 196, 3, 28, "Output"]
}, Open  ]],
Cell[13145527, 339336, 3506, 96, 165, "Input"],
Cell[CellGroupData[{
Cell[13149058, 339436, 134, 2, 28, "Input"],
Cell[13149195, 339440, 191, 3, 28, "Output"]
}, Open  ]],
Cell[13149401, 339446, 3577, 97, 165, "Input"],
Cell[CellGroupData[{
Cell[13153003, 339547, 160, 3, 28, "Input"],
Cell[13153166, 339552, 221, 4, 28, "Output"]
}, Open  ]],
Cell[13153402, 339559, 3579, 97, 165, "Input"],
Cell[CellGroupData[{
Cell[13157006, 339660, 185, 3, 28, "Input"],
Cell[13157194, 339665, 271, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13157502, 339674, 251, 5, 28, "Input"],
Cell[13157756, 339681, 10775, 314, 166, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13168568, 340000, 134, 2, 28, "Input"],
Cell[13168705, 340004, 243, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13168985, 340013, 156, 3, 28, "Input"],
Cell[13169144, 340018, 197, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13169378, 340026, 1658, 49, 80, "Input"],
Cell[13171039, 340077, 10749, 314, 166, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13181825, 340396, 140, 2, 28, "Input"],
Cell[13181968, 340400, 223, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13182228, 340409, 158, 3, 28, "Input"],
Cell[13182389, 340414, 1527, 58, 57, "Output"]
}, Open  ]],
Cell[13183931, 340475, 1479, 24, 84, "Text"],
Cell[CellGroupData[{
Cell[13185435, 340503, 142, 2, 44, "Subsection"],
Cell[13185580, 340507, 160, 5, 28, "Input"],
Cell[13185743, 340514, 446, 9, 28, "Input"],
Cell[13186192, 340525, 423, 10, 28, "Input"],
Cell[13186618, 340537, 571, 11, 28, "Input"],
Cell[13187192, 340550, 443, 10, 28, "Input"],
Cell[13187638, 340562, 390, 9, 28, "Input"],
Cell[13188031, 340573, 616, 12, 28, "Input"],
Cell[13188650, 340587, 392, 6, 46, "Text"],
Cell[13189045, 340595, 1091, 37, 46, "Input"],
Cell[13190139, 340634, 475, 6, 46, "Text"],
Cell[CellGroupData[{
Cell[13190639, 340644, 1592, 43, 80, "Input"],
Cell[13192234, 340689, 3301, 87, 192, "Output"]
}, Open  ]],
Cell[13195550, 340779, 1269, 22, 28, "Input"],
Cell[13196822, 340803, 186, 4, 28, "Input"],
Cell[CellGroupData[{
Cell[13197033, 340811, 378, 9, 28, "Input"],
Cell[13197414, 340822, 1526, 44, 130, "Output"]
}, Open  ]],
Cell[13198955, 340869, 848, 12, 46, "Text"],
Cell[13199806, 340883, 501, 11, 28, "Input"],
Cell[13200310, 340896, 543, 11, 28, "Input"],
Cell[13200856, 340909, 301, 8, 28, "Input"],
Cell[13201160, 340919, 303, 8, 28, "Input"],
Cell[13201466, 340929, 476, 10, 28, "Input"],
Cell[13201945, 340941, 523, 11, 28, "Input"],
Cell[13202471, 340954, 305, 8, 28, "Input"],
Cell[13202779, 340964, 305, 8, 28, "Input"],
Cell[CellGroupData[{
Cell[13203109, 340976, 1471, 38, 114, "Input"],
Cell[13204583, 341016, 3164, 84, 182, "Output"]
}, Open  ]],
Cell[13207762, 341103, 1431, 25, 46, "Input"],
Cell[13209196, 341130, 193, 4, 28, "Input"],
Cell[CellGroupData[{
Cell[13209414, 341138, 247, 5, 28, "Input"],
Cell[13209664, 341145, 10993, 356, 1328, "Output"]
}, Open  ]],
Cell[13220672, 341504, 869, 12, 46, "Text"],
Cell[13221544, 341518, 206, 5, 30, "Input"],
Cell[CellGroupData[{
Cell[13221775, 341527, 491, 11, 30, "Input"],
Cell[13222269, 341540, 1248, 20, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13223554, 341565, 439, 10, 30, "Input"],
Cell[13223996, 341577, 1036, 17, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13225069, 341599, 413, 10, 30, "Input"],
Cell[13225485, 341611, 538, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13226060, 341627, 464, 10, 30, "Input"],
Cell[13226527, 341639, 1025, 16, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13227589, 341660, 417, 10, 30, "Input"],
Cell[13228009, 341672, 962, 19, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13229008, 341696, 390, 10, 30, "Input"],
Cell[13229401, 341708, 795, 12, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13230233, 341725, 342, 9, 30, "Input"],
Cell[13230578, 341736, 848, 16, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13231463, 341757, 343, 9, 30, "Input"],
Cell[13231809, 341768, 852, 16, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13232698, 341789, 341, 9, 30, "Input"],
Cell[13233042, 341800, 797, 12, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13233876, 341817, 341, 9, 30, "Input"],
Cell[13234220, 341828, 867, 17, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13235124, 341850, 389, 9, 30, "Input"],
Cell[13235516, 341861, 1059, 20, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13236612, 341886, 391, 9, 30, "Input"],
Cell[13237006, 341897, 946, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13237989, 341917, 389, 9, 30, "Input"],
Cell[13238381, 341928, 1037, 19, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13239455, 341952, 389, 9, 30, "Input"],
Cell[13239847, 341963, 1048, 19, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13240932, 341987, 388, 9, 30, "Input"],
Cell[13241323, 341998, 937, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13242297, 342018, 391, 9, 30, "Input"],
Cell[13242691, 342029, 1062, 20, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13243790, 342054, 384, 9, 30, "Input"],
Cell[13244177, 342065, 994, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13245208, 342085, 389, 9, 30, "Input"],
Cell[13245600, 342096, 943, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13246580, 342116, 389, 9, 28, "Input"],
Cell[13246972, 342127, 975, 16, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13247984, 342148, 390, 9, 28, "Input"],
Cell[13248377, 342159, 962, 16, 28, "Output"]
}, Open  ]],
Cell[13249354, 342178, 641, 9, 46, "Text"],
Cell[CellGroupData[{
Cell[13250020, 342191, 1064, 27, 80, "Input"],
Cell[13251087, 342220, 997, 30, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13252121, 342255, 2008, 60, 97, "Input"],
Cell[13254132, 342317, 882, 30, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13255051, 342352, 4041, 104, 182, "Input"],
Cell[13259095, 342458, 29315, 1036, 1788, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13288447, 343499, 10893, 286, 573, "Input"],
Cell[13299343, 343787, 12773, 406, 872, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13312153, 344198, 2933, 82, 182, "Input"],
Cell[13315089, 344282, 2813, 107, 85, "Output"]
}, Open  ]],
Cell[13317917, 344392, 697, 14, 28, "Input"],
Cell[CellGroupData[{
Cell[13318639, 344410, 164, 3, 28, "Input"],
Cell[13318806, 344415, 486, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13319329, 344428, 242, 4, 28, "Input"],
Cell[13319574, 344434, 2197, 62, 201, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13321808, 344501, 213, 4, 28, "Input"],
Cell[13322024, 344507, 606, 15, 35, "Output"]
}, Open  ]],
Cell[13322645, 344525, 680, 10, 46, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[13323374, 344541, 144, 2, 50, "Section"],
Cell[CellGroupData[{
Cell[13323543, 344547, 173, 2, 44, "Subsection"],
Cell[13323719, 344551, 1095, 17, 65, "Text"],
Cell[CellGroupData[{
Cell[13324839, 344572, 14487, 409, 487, "Input"],
Cell[13339329, 344983, 4172, 132, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13343538, 345120, 1830, 51, 107, "Input"],
Cell[13345371, 345173, 3472, 122, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13348880, 345300, 1752, 50, 107, "Input"],
Cell[13350635, 345352, 3398, 121, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13354070, 345478, 438, 12, 30, "Input"],
Cell[13354511, 345492, 9840, 357, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13364388, 345854, 2000, 50, 69, "Input"],
Cell[13366391, 345906, 776, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13367204, 345922, 1354, 41, 69, "Input"],
Cell[13368561, 345965, 242, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13368840, 345974, 1382, 42, 69, "Input"],
Cell[13370225, 346018, 245, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13370507, 346028, 1382, 42, 69, "Input"],
Cell[13371892, 346072, 379, 6, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13372308, 346083, 1089, 33, 50, "Input"],
Cell[13373400, 346118, 2958, 110, 70, "Output"]
}, Open  ]],
Cell[13376373, 346231, 489, 9, 46, "Text"],
Cell[CellGroupData[{
Cell[13376887, 346244, 4500, 124, 240, "Input"],
Cell[13381390, 346370, 2461, 88, 70, "Output"]
}, Open  ]],
Cell[13383866, 346461, 490, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[13384381, 346475, 2049, 62, 107, "Input"],
Cell[13386433, 346539, 1252, 44, 70, "Output"]
}, Open  ]],
Cell[13387700, 346586, 520, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[13388245, 346600, 1727, 52, 88, "Input"],
Cell[13389975, 346654, 1497, 63, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13391509, 346722, 301, 8, 30, "Input"],
Cell[13391813, 346732, 244, 4, 70, "Output"]
}, Open  ]],
Cell[13392072, 346739, 528, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[13392625, 346753, 1568, 47, 107, "Input"],
Cell[13394196, 346802, 1442, 55, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[13395687, 346863, 118, 1, 36, "Subsection"],
Cell[13395808, 346866, 982, 14, 46, "Text"],
Cell[13396793, 346882, 521, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[13397339, 346896, 4110, 113, 233, "Input"],
Cell[13401452, 347011, 178, 3, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13401667, 347019, 1947, 54, 114, "Input"],
Cell[13403617, 347075, 13559, 400, 173, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13417213, 347480, 149, 2, 28, "Input"],
Cell[13417365, 347484, 191, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13417593, 347492, 5968, 162, 267, "Input"],
Cell[13423564, 347656, 12527, 368, 133, "Output"]
}, Open  ]],
Cell[13436106, 348027, 553, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[13436684, 348043, 9103, 218, 403, "Input"],
Cell[13445790, 348263, 8707, 232, 146, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13454534, 348500, 177, 3, 28, "Input"],
Cell[13454714, 348505, 409, 7, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13455160, 348517, 326, 8, 28, "Input"],
Cell[13455489, 348527, 153, 3, 28, "Output"]
}, Open  ]],
Cell[13455657, 348533, 641, 13, 65, "Text"],
Cell[CellGroupData[{
Cell[13456323, 348550, 6706, 193, 301, "Input"],
Cell[13463032, 348745, 10975, 317, 155, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13474044, 349067, 170, 3, 28, "Input"],
Cell[13474217, 349072, 287, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13474541, 349082, 2375, 68, 165, "Input"],
Cell[13476919, 349152, 10754, 311, 163, "Output"]
}, Open  ]],
Cell[13487688, 349466, 617, 16, 50, "Text"],
Cell[CellGroupData[{
Cell[13488330, 349486, 18084, 474, 675, "Input"],
Cell[13506417, 349962, 31680, 1316, 344, "Output"]
}, Open  ]],
Cell[13538112, 351281, 542, 10, 46, "Text"],
Cell[CellGroupData[{
Cell[13538679, 351295, 2219, 64, 131, "Input"],
Cell[13540901, 351361, 32627, 925, 240, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13573565, 352291, 2605, 74, 80, "Input"],
Cell[13576173, 352367, 98609, 3720, 957, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13674819, 356092, 3485, 85, 131, "Input"],
Cell[13678307, 356179, 9404, 279, 149, "Output"]
}, Open  ]],
Cell[13687726, 356461, 691, 17, 50, "Text"],
Cell[13688420, 356480, 1021, 27, 88, "Text"],
Cell[CellGroupData[{
Cell[13689466, 356511, 768, 20, 28, "Input"],
Cell[13690237, 356533, 575, 11, 24, "Message"],
Cell[13690815, 356546, 575, 11, 24, "Message"],
Cell[13691393, 356559, 387, 6, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13691817, 356570, 2215, 58, 97, "Input"],
Cell[13694035, 356630, 20590, 594, 270, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13714662, 357229, 2020, 56, 97, "Input"],
Cell[13716685, 357287, 25828, 1085, 287, "Output"]
}, Open  ]],
Cell[13742528, 358375, 1130, 29, 107, "Text"],
Cell[CellGroupData[{
Cell[13743683, 358408, 2704, 78, 114, "Input"],
Cell[13746390, 358488, 21335, 914, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13767762, 359407, 1106, 31, 63, "Input"],
Cell[13768871, 359440, 1203, 43, 51, "Output"]
}, Open  ]],
Cell[13770089, 359486, 705, 15, 46, "Text"],
Cell[13770797, 359503, 838, 22, 48, "Text"],
Cell[CellGroupData[{
Cell[13771660, 359529, 392, 12, 28, "Input"],
Cell[13772055, 359543, 26476, 1119, 293, "Output"]
}, Open  ]],
Cell[13798546, 360665, 985, 26, 49, "Text"],
Cell[CellGroupData[{
Cell[13799556, 360695, 3062, 85, 97, "Input"],
Cell[13802621, 360782, 78668, 2959, 806, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13881326, 363746, 3671, 88, 131, "Input"],
Cell[13885000, 363836, 1625, 43, 52, "Output"]
}, Open  ]],
Cell[13886640, 363882, 691, 17, 50, "Text"],
Cell[13887334, 363901, 1021, 27, 88, "Text"],
Cell[CellGroupData[{
Cell[13888380, 363932, 1963, 50, 80, "Input"],
Cell[13890346, 363984, 17259, 544, 217, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13907642, 364533, 1728, 47, 80, "Input"],
Cell[13909373, 364582, 21306, 893, 240, "Output"]
}, Open  ]],
Cell[13930694, 365478, 694, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[13931413, 365497, 2992, 86, 114, "Input"],
Cell[13934408, 365585, 15485, 658, 188, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13949930, 366248, 1072, 25, 63, "Input"],
Cell[13951005, 366275, 420, 7, 28, "Output"]
}, Open  ]],
Cell[13951440, 366285, 918, 23, 67, "Text"],
Cell[CellGroupData[{
Cell[13952383, 366312, 1030, 26, 63, "Input"],
Cell[13953416, 366340, 8256, 349, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13961709, 366694, 588, 18, 28, "Input"],
Cell[13962300, 366714, 912, 36, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13963249, 366755, 586, 18, 28, "Input"],
Cell[13963838, 366775, 911, 36, 54, "Output"]
}, Open  ]],
Cell[13964764, 366814, 656, 12, 46, "Text"],
Cell[CellGroupData[{
Cell[13965445, 366830, 2509, 72, 165, "Input"],
Cell[13967957, 366904, 5151, 207, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13973145, 367116, 561, 17, 28, "Input"],
Cell[13973709, 367135, 908, 36, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13974654, 367176, 488, 16, 28, "Input"],
Cell[13975145, 367194, 857, 35, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13976039, 367234, 488, 16, 28, "Input"],
Cell[13976530, 367252, 860, 35, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13977427, 367292, 488, 16, 28, "Input"],
Cell[13977918, 367310, 860, 35, 53, "Output"]
}, Open  ]],
Cell[13978793, 367348, 1040, 24, 67, "Text"],
Cell[CellGroupData[{
Cell[13979858, 367376, 2094, 62, 114, "Input"],
Cell[13981955, 367440, 2159, 88, 53, "Output"]
}, Open  ]],
Cell[13984129, 367531, 892, 21, 50, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13985058, 367557, 163, 3, 44, "Subsection"],
Cell[CellGroupData[{
Cell[13985246, 367564, 3956, 105, 221, "Input"],
Cell[13989205, 367671, 8019123, 169232, 258, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22008365, 536908, 2853, 87, 126, "Input"],
Cell[22011221, 536997, 332761, 9162, 2084, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22344019, 546164, 1326, 40, 69, "Input"],
Cell[22345348, 546206, 28777, 751, 210, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22374162, 546962, 3969, 105, 221, "Input"],
Cell[22378134, 547069, 7914, 203, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22386085, 547277, 2926, 88, 126, "Input"],
Cell[22389014, 547367, 4093, 119, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22393144, 547491, 1350, 40, 69, "Input"],
Cell[22394497, 547533, 2173, 65, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22396707, 547603, 3960, 105, 221, "Input"],
Cell[22400670, 547710, 371135, 9874, 2426, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22771842, 557589, 2916, 88, 145, "Input"],
Cell[22774761, 557679, 24303, 690, 173, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22799101, 558374, 2477, 78, 126, "Input"],
Cell[22801581, 558454, 333143, 9179, 2044, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23134761, 567638, 1270, 39, 69, "Input"],
Cell[23136034, 567679, 10902, 296, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23146973, 567980, 152, 2, 30, "Input"],
Cell[23147128, 567984, 17965, 466, 121, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[23165142, 568456, 190, 2, 36, "Subsection"],
Cell[23165335, 568460, 880, 17, 65, "Text"],
Cell[CellGroupData[{
Cell[23166240, 568481, 17521, 469, 658, "Input"],
Cell[23183764, 568952, 30372, 1303, 295, "Output"]
}, Closed]],
Cell[23214151, 570258, 1004, 22, 64, "Text"],
Cell[CellGroupData[{
Cell[23215180, 570284, 3299, 91, 148, "Input"],
Cell[23218482, 570377, 175, 4, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23218694, 570386, 2082, 60, 114, "Input"],
Cell[23220779, 570448, 25392, 1084, 287, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23246208, 571537, 912, 21, 80, "Input"],
Cell[23247123, 571560, 12223, 364, 131, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23259383, 571929, 148, 2, 28, "Input"],
Cell[23259534, 571933, 123, 2, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23259694, 571940, 6570, 168, 233, "Input"],
Cell[23266267, 572110, 8775, 242, 166, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23275079, 572357, 150, 2, 28, "Input"],
Cell[23275232, 572361, 507, 8, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23275776, 572374, 2006, 55, 131, "Input"],
Cell[23277785, 572431, 10478, 299, 133, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23288300, 572735, 2202, 58, 131, "Input"],
Cell[23290505, 572795, 12974, 361, 166, "Output"]
}, Open  ]],
Cell[23303494, 573159, 1088, 16, 65, "Text"],
Cell[CellGroupData[{
Cell[23304607, 573179, 377, 7, 46, "Input"],
Cell[23304987, 573188, 10613, 305, 164, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23315637, 573498, 168, 3, 28, "Input"],
Cell[23315808, 573503, 175, 3, 28, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[23316032, 573512, 291, 4, 36, "Subsection"],
Cell[23316326, 573518, 935, 13, 46, "Text"],
Cell[23317264, 573533, 624, 11, 30, "Input"],
Cell[23317891, 573546, 547, 11, 30, "Input"],
Cell[23318441, 573559, 480, 10, 30, "Input"],
Cell[23318924, 573571, 463, 10, 30, "Input"],
Cell[23319390, 573583, 789, 27, 30, "Input"],
Cell[CellGroupData[{
Cell[23320204, 573614, 882, 23, 69, "Input"],
Cell[23321089, 573639, 1905, 51, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23323031, 573695, 1098, 18, 30, "Input"],
Cell[23324132, 573715, 1579, 31, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23325748, 573751, 172, 4, 30, "Input"],
Cell[23325923, 573757, 586, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23326546, 573774, 313, 8, 30, "Input"],
Cell[23326862, 573784, 552, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23327451, 573798, 148, 4, 30, "Input"],
Cell[23327602, 573804, 602, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23328241, 573821, 264, 7, 30, "Input"],
Cell[23328508, 573830, 447, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23328992, 573842, 769, 21, 50, "Input"],
Cell[23329764, 573865, 747, 15, 31, "Output"]
}, Open  ]],
Cell[23330526, 573883, 710, 18, 49, "Text"],
Cell[23331239, 573903, 310, 8, 30, "Input"],
Cell[CellGroupData[{
Cell[23331574, 573915, 1650, 40, 107, "Input"],
Cell[23333227, 573957, 79052, 2468, 3758, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23412316, 576430, 947, 26, 50, "Input"],
Cell[23413266, 576458, 1874, 55, 162, "Output"]
}, Open  ]],
Cell[23415155, 576516, 1046, 17, 46, "Text"],
Cell[CellGroupData[{
Cell[23416226, 576537, 2280, 65, 145, "Input"],
Cell[23418509, 576604, 207598, 6800, 13138, "Output"]
}, Open  ]],
Cell[23626122, 583407, 1035, 14, 46, "Text"],
Cell[23627160, 583423, 438, 9, 30, "Input"],
Cell[23627601, 583434, 417, 9, 30, "Input"],
Cell[23628021, 583445, 415, 9, 30, "Input"],
Cell[23628439, 583456, 466, 10, 30, "Input"],
Cell[23628908, 583468, 541, 11, 30, "Input"],
Cell[23629452, 583481, 418, 9, 30, "Input"],
Cell[23629873, 583492, 417, 9, 30, "Input"],
Cell[23630293, 583503, 468, 10, 30, "Input"],
Cell[CellGroupData[{
Cell[23630786, 583517, 1391, 37, 126, "Input"],
Cell[23632180, 583556, 1786, 47, 169, "Output"]
}, Open  ]],
Cell[23633981, 583606, 1260, 23, 50, "Input"],
Cell[CellGroupData[{
Cell[23635266, 583633, 211, 5, 30, "Input"],
Cell[23635480, 583640, 6724, 217, 921, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23642241, 583862, 290, 7, 30, "Input"],
Cell[23642534, 583871, 432, 9, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23643003, 583885, 490, 10, 50, "Input"],
Cell[23643496, 583897, 755, 14, 192, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23644288, 583916, 237, 6, 30, "Input"],
Cell[23644528, 583924, 309, 7, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23644874, 583936, 1325, 34, 126, "Input"],
Cell[23646202, 583972, 11239, 408, 868, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23657478, 584385, 350, 10, 30, "Input"],
Cell[23657831, 584397, 351, 10, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23658219, 584412, 1518, 39, 126, "Input"],
Cell[23659740, 584453, 4954, 133, 127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23664731, 584591, 469, 13, 30, "Input"],
Cell[23665203, 584606, 752, 22, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23665992, 584633, 1501, 40, 145, "Input"],
Cell[23667496, 584675, 6553, 217, 289, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23674086, 584897, 350, 10, 30, "Input"],
Cell[23674439, 584909, 352, 10, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23674828, 584924, 1523, 29, 69, "Input"],
Cell[23676354, 584955, 6857, 173, 166, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23683248, 585133, 358, 6, 30, "Input"],
Cell[23683609, 585141, 3958, 112, 241, "Output"]
}, Open  ]],
Cell[23687582, 585256, 1335, 23, 46, "Text"],
Cell[CellGroupData[{
Cell[23688942, 585283, 348, 9, 30, "Input"],
Cell[23689293, 585294, 504, 11, 49, "Output"]
}, Open  ]],
Cell[23689812, 585308, 521, 14, 30, "Input"],
Cell[CellGroupData[{
Cell[23690358, 585326, 731, 17, 69, "Input"],
Cell[23691092, 585345, 11389, 298, 607, "Output"]
}, Open  ]],
Cell[23702496, 585646, 1128, 16, 46, "Text"],
Cell[23703627, 585664, 241, 4, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[23703905, 585673, 369, 7, 36, "Subsection"],
Cell[CellGroupData[{
Cell[23704299, 585684, 122, 1, 28, "Subsubsection"],
Cell[23704424, 585687, 935, 13, 46, "Text"],
Cell[23705362, 585702, 624, 11, 30, "Input"],
Cell[23705989, 585715, 547, 11, 30, "Input"],
Cell[23706539, 585728, 480, 10, 30, "Input"],
Cell[23707022, 585740, 463, 10, 30, "Input"],
Cell[23707488, 585752, 789, 27, 30, "Input"],
Cell[CellGroupData[{
Cell[23708302, 585783, 882, 23, 69, "Input"],
Cell[23709187, 585808, 2071, 53, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23711295, 585866, 1098, 18, 30, "Input"],
Cell[23712396, 585886, 1744, 33, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23714177, 585924, 172, 4, 30, "Input"],
Cell[23714352, 585930, 747, 14, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23715136, 585949, 313, 8, 30, "Input"],
Cell[23715452, 585959, 717, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23716206, 585975, 148, 4, 30, "Input"],
Cell[23716357, 585981, 767, 14, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23717161, 586000, 264, 7, 30, "Input"],
Cell[23717428, 586009, 607, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23718072, 586023, 769, 21, 50, "Input"],
Cell[23718844, 586046, 912, 18, 31, "Output"]
}, Open  ]],
Cell[23719771, 586067, 710, 18, 49, "Text"],
Cell[23720484, 586087, 310, 8, 30, "Input"],
Cell[CellGroupData[{
Cell[23720819, 586099, 1886, 42, 107, "Input"],
Cell[23722708, 586143, 32578, 1015, 1444, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23755323, 587163, 996, 27, 50, "Input"],
Cell[23756322, 587192, 1899, 52, 115, "Output"]
}, Open  ]],
Cell[23758236, 587247, 1046, 17, 46, "Text"],
Cell[CellGroupData[{
Cell[23759307, 587268, 2280, 65, 145, "Input"],
Cell[23761590, 587335, 83432, 2740, 5193, "Output"]
}, Open  ]],
Cell[23845037, 590078, 1035, 14, 46, "Text"],
Cell[23846075, 590094, 438, 9, 30, "Input"],
Cell[23846516, 590105, 417, 9, 30, "Input"],
Cell[23846936, 590116, 415, 9, 30, "Input"],
Cell[23847354, 590127, 466, 10, 30, "Input"],
Cell[23847823, 590139, 541, 11, 30, "Input"],
Cell[23848367, 590152, 418, 9, 30, "Input"],
Cell[23848788, 590163, 417, 9, 30, "Input"],
Cell[23849208, 590174, 468, 10, 30, "Input"],
Cell[CellGroupData[{
Cell[23849701, 590188, 1391, 37, 126, "Input"],
Cell[23851095, 590227, 1954, 49, 156, "Output"]
}, Open  ]],
Cell[23853064, 590279, 1260, 23, 50, "Input"],
Cell[CellGroupData[{
Cell[23854349, 590306, 211, 5, 30, "Input"],
Cell[23854563, 590313, 6889, 220, 908, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23861489, 590538, 290, 7, 30, "Input"],
Cell[23861782, 590547, 596, 12, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23862415, 590564, 490, 10, 50, "Input"],
Cell[23862908, 590576, 919, 16, 192, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23863864, 590597, 237, 6, 30, "Input"],
Cell[23864104, 590605, 505, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23864646, 590621, 1325, 34, 126, "Input"],
Cell[23865974, 590657, 11384, 410, 855, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23877395, 591072, 350, 10, 30, "Input"],
Cell[23877748, 591084, 495, 12, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23878280, 591101, 1518, 39, 126, "Input"],
Cell[23879801, 591142, 5125, 136, 114, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23884963, 591283, 469, 13, 30, "Input"],
Cell[23885435, 591298, 870, 23, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23886342, 591326, 1501, 40, 145, "Input"],
Cell[23887846, 591368, 6695, 219, 289, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23894578, 591592, 350, 10, 30, "Input"],
Cell[23894931, 591604, 494, 12, 49, "Output"]
}, Open  ]],
Cell[23895440, 591619, 1241, 21, 46, "Text"],
Cell[CellGroupData[{
Cell[23896706, 591644, 910, 25, 88, "Input"],
Cell[23897619, 591671, 1712, 57, 92, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23899368, 591733, 349, 10, 30, "Input"],
Cell[23899720, 591745, 268, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23900025, 591754, 1056, 29, 88, "Input"],
Cell[23901084, 591785, 32294, 1052, 1461, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23933415, 592842, 560, 16, 30, "Input"],
Cell[23933978, 592860, 2020, 76, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23936035, 592941, 728, 17, 69, "Input"],
Cell[23936766, 592960, 14468, 385, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23951271, 593350, 505, 13, 50, "Input"],
Cell[23951779, 593365, 696, 12, 52, "Output"]
}, Open  ]],
Cell[23952490, 593380, 1233, 19, 46, "Text"],
Cell[CellGroupData[{
Cell[23953748, 593403, 1690, 32, 69, "Input"],
Cell[23955441, 593437, 156882, 4298, 9324, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24112360, 597740, 146, 2, 30, "Input"],
Cell[24112509, 597744, 215, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24112761, 597753, 385, 6, 30, "Input"],
Cell[24113149, 597761, 4239, 117, 218, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24117425, 597883, 448, 12, 30, "Input"],
Cell[24117876, 597897, 8031, 216, 402, "Output"]
}, Open  ]],
Cell[24125922, 598116, 1402, 23, 46, "Text"],
Cell[CellGroupData[{
Cell[24127349, 598143, 578, 14, 30, "Input"],
Cell[24127930, 598159, 599, 9, 31, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24128578, 598174, 174, 2, 28, "Subsubsection"],
Cell[24128755, 598178, 935, 13, 46, "Text"],
Cell[24129693, 598193, 624, 11, 30, "Input"],
Cell[24130320, 598206, 547, 11, 30, "Input"],
Cell[24130870, 598219, 480, 10, 30, "Input"],
Cell[24131353, 598231, 463, 10, 30, "Input"],
Cell[24131819, 598243, 789, 27, 30, "Input"],
Cell[CellGroupData[{
Cell[24132633, 598274, 882, 23, 69, "Input"],
Cell[24133518, 598299, 2120, 54, 104, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24135675, 598358, 1122, 18, 30, "Input"],
Cell[24136800, 598378, 4023, 104, 190, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24140860, 598487, 172, 4, 30, "Input"],
Cell[24141035, 598493, 1154, 28, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24142226, 598526, 313, 8, 30, "Input"],
Cell[24142542, 598536, 767, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24143346, 598553, 148, 4, 30, "Input"],
Cell[24143497, 598559, 1225, 31, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24144759, 598595, 264, 7, 30, "Input"],
Cell[24145026, 598604, 656, 10, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24145719, 598619, 769, 21, 50, "Input"],
Cell[24146491, 598642, 1219, 28, 49, "Output"]
}, Open  ]],
Cell[24147725, 598673, 710, 18, 49, "Text"],
Cell[24148438, 598693, 310, 8, 30, "Input"],
Cell[CellGroupData[{
Cell[24148773, 598705, 1886, 42, 107, "Input"],
Cell[24150662, 598749, 32620, 1015, 1444, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24183319, 599769, 996, 27, 50, "Input"],
Cell[24184318, 599798, 2216, 62, 149, "Output"]
}, Open  ]],
Cell[24186549, 599863, 1046, 17, 46, "Text"],
Cell[CellGroupData[{
Cell[24187620, 599884, 2280, 65, 145, "Input"],
Cell[24189903, 599951, 108616, 3494, 5649, "Output"]
}, Open  ]],
Cell[24298534, 603448, 1035, 14, 46, "Text"],
Cell[24299572, 603464, 438, 9, 30, "Input"],
Cell[24300013, 603475, 417, 9, 30, "Input"],
Cell[24300433, 603486, 415, 9, 30, "Input"],
Cell[24300851, 603497, 466, 10, 30, "Input"],
Cell[24301320, 603509, 541, 11, 30, "Input"],
Cell[24301864, 603522, 418, 9, 30, "Input"],
Cell[24302285, 603533, 417, 9, 30, "Input"],
Cell[24302705, 603544, 468, 10, 30, "Input"],
Cell[CellGroupData[{
Cell[24303198, 603558, 1391, 37, 126, "Input"],
Cell[24304592, 603597, 4610, 131, 222, "Output"]
}, Open  ]],
Cell[24309217, 603731, 1260, 23, 50, "Input"],
Cell[CellGroupData[{
Cell[24310502, 603758, 211, 5, 30, "Input"],
Cell[24310716, 603765, 7529, 237, 970, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24318282, 604007, 290, 7, 30, "Input"],
Cell[24318575, 604016, 621, 12, 112, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24319233, 604033, 490, 10, 50, "Input"],
Cell[24319726, 604045, 947, 17, 192, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24320710, 604067, 237, 6, 30, "Input"],
Cell[24320950, 604075, 527, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24321514, 604091, 1325, 34, 126, "Input"],
Cell[24322842, 604127, 18323, 614, 1127, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24341202, 604746, 350, 10, 30, "Input"],
Cell[24341555, 604758, 903, 25, 58, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24342495, 604788, 1518, 39, 126, "Input"],
Cell[24344016, 604829, 5168, 136, 114, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24349221, 604970, 469, 13, 30, "Input"],
Cell[24349693, 604985, 844, 22, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24350574, 605012, 1501, 40, 145, "Input"],
Cell[24352078, 605054, 16590, 537, 1224, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24368705, 605596, 350, 10, 30, "Input"],
Cell[24369058, 605608, 497, 11, 49, "Output"]
}, Open  ]],
Cell[24369570, 605622, 1241, 21, 46, "Text"],
Cell[CellGroupData[{
Cell[24370836, 605647, 910, 25, 88, "Input"],
Cell[24371749, 605674, 2046, 67, 108, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24373832, 605746, 349, 10, 30, "Input"],
Cell[24374184, 605758, 439, 10, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24374660, 605773, 1056, 29, 88, "Input"],
Cell[24375719, 605804, 32446, 1051, 1461, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24408202, 606860, 560, 16, 30, "Input"],
Cell[24408765, 606878, 2066, 77, 36, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24410868, 606960, 728, 17, 69, "Input"],
Cell[24411599, 606979, 13459, 363, 256, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24425095, 607347, 505, 13, 50, "Input"],
Cell[24425603, 607362, 696, 12, 52, "Output"]
}, Open  ]],
Cell[24426314, 607377, 1233, 19, 46, "Text"],
Cell[CellGroupData[{
Cell[24427572, 607400, 1690, 32, 69, "Input"],
Cell[24429265, 607434, 157595, 4298, 8843, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24586897, 611737, 146, 2, 30, "Input"],
Cell[24587046, 611741, 215, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24587298, 611750, 385, 6, 30, "Input"],
Cell[24587686, 611758, 4204, 117, 241, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24591927, 611880, 448, 12, 30, "Input"],
Cell[24592378, 611894, 8078, 217, 402, "Output"]
}, Open  ]],
Cell[24600471, 612114, 1402, 23, 46, "Text"],
Cell[CellGroupData[{
Cell[24601898, 612141, 629, 15, 30, "Input"],
Cell[24602530, 612158, 5209, 139, 126, "Output"]
}, Open  ]],
Cell[24607754, 612300, 1128, 16, 46, "Text"],
Cell[24608885, 612318, 241, 4, 46, "Text"],
Cell[24609129, 612324, 1128, 16, 46, "Text"],
Cell[24610260, 612342, 241, 4, 46, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[24610550, 612352, 131, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[24610706, 612357, 17569, 470, 772, "Input"],
Cell[24628278, 612829, 30401, 1304, 448, "Output"]
}, Open  ]],
Cell[24658694, 614136, 1526, 40, 132, "Text"],
Cell[CellGroupData[{
Cell[24660245, 614180, 4893, 124, 240, "Input"],
Cell[24665141, 614306, 593, 11, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24665771, 614322, 2736, 74, 145, "Input"],
Cell[24668510, 614398, 12056, 511, 203, "Output"]
}, Open  ]],
Cell[24680581, 614912, 838, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[24681444, 614931, 744, 24, 50, "Input"],
Cell[24682191, 614957, 677, 21, 49, "Output"]
}, Open  ]],
Cell[24682883, 614981, 1047, 25, 65, "Text"],
Cell[CellGroupData[{
Cell[24683955, 615010, 4620, 118, 221, "Input"],
Cell[24688578, 615130, 9607, 404, 202, "Output"]
}, Open  ]],
Cell[24698200, 615537, 844, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[24699069, 615556, 941, 24, 88, "Input"],
Cell[24700013, 615582, 7381, 303, 154, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24707431, 615890, 275, 6, 30, "Input"],
Cell[24707709, 615898, 246, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24707992, 615907, 363, 8, 30, "Input"],
Cell[24708358, 615917, 266, 4, 31, "Output"]
}, Open  ]],
Cell[24708639, 615924, 839, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[24709503, 615943, 611, 16, 30, "Input"],
Cell[24710117, 615961, 296, 5, 31, "Output"]
}, Open  ]],
Cell[24710428, 615969, 1158, 26, 84, "Text"],
Cell[CellGroupData[{
Cell[24711611, 615999, 5447, 132, 278, "Input"],
Cell[24717061, 616133, 9579, 373, 155, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24726677, 616511, 682, 20, 30, "Input"],
Cell[24727362, 616533, 246, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24727645, 616542, 561, 18, 30, "Input"],
Cell[24728209, 616562, 2410, 102, 56, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24730656, 616669, 353, 8, 30, "Input"],
Cell[24731012, 616679, 200, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24731249, 616688, 351, 8, 30, "Input"],
Cell[24731603, 616698, 195, 4, 31, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[24731847, 616708, 239, 3, 36, "Subsection"],
Cell[CellGroupData[{
Cell[24732111, 616715, 17569, 470, 791, "Input"],
Cell[24749683, 617187, 30493, 1305, 497, "Output"]
}, Open  ]],
Cell[24780191, 618495, 1543, 41, 132, "Text"],
Cell[CellGroupData[{
Cell[24781759, 618540, 4091, 101, 221, "Input"],
Cell[24785853, 618643, 889, 15, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24786779, 618663, 1985, 49, 107, "Input"],
Cell[24788767, 618714, 10975, 466, 203, "Output"]
}, Open  ]],
Cell[24799757, 619183, 863, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[24800645, 619202, 1219, 39, 69, "Input"],
Cell[24801867, 619243, 1133, 37, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24803037, 619285, 1392, 36, 88, "Input"],
Cell[24804432, 619323, 6378, 229, 289, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24810847, 619557, 364, 10, 30, "Input"],
Cell[24811214, 619569, 3347, 139, 89, "Output"]
}, Open  ]],
Cell[24814576, 619711, 1059, 25, 65, "Text"],
Cell[CellGroupData[{
Cell[24815660, 619740, 4059, 102, 221, "Input"],
Cell[24819722, 619844, 10335, 425, 203, "Output"]
}, Open  ]],
Cell[24830072, 620272, 2125, 29, 46, "Text"],
Cell[CellGroupData[{
Cell[24832222, 620305, 1040, 26, 88, "Input"],
Cell[24833265, 620333, 10436, 431, 252, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24843738, 620769, 322, 7, 30, "Input"],
Cell[24844063, 620778, 344, 5, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24844444, 620788, 410, 9, 30, "Input"],
Cell[24844857, 620799, 337, 5, 31, "Output"]
}, Open  ]],
Cell[24845209, 620807, 869, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[24846103, 620826, 886, 20, 50, "Input"],
Cell[24846992, 620848, 894, 25, 49, "Output"]
}, Open  ]],
Cell[24847901, 620876, 902, 18, 46, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[24848840, 620899, 352, 9, 38, "Subsection"],
Cell[24849195, 620910, 1112, 26, 48, "Text"],
Cell[CellGroupData[{
Cell[24850332, 620940, 18337, 480, 658, "Input"],
Cell[24868672, 621422, 26245, 1120, 248, "Output"]
}, Open  ]],
Cell[24894932, 622545, 1543, 41, 127, "Text"],
Cell[CellGroupData[{
Cell[24896500, 622590, 4858, 114, 165, "Input"],
Cell[24901361, 622706, 1132, 19, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24902530, 622730, 2031, 51, 97, "Input"],
Cell[24904564, 622783, 20929, 888, 243, "Output"]
}, Open  ]],
Cell[24925508, 623674, 885, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[24926418, 623693, 1219, 39, 63, "Input"],
Cell[24927640, 623734, 1156, 38, 48, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24928833, 623777, 1392, 36, 80, "Input"],
Cell[24930228, 623815, 6400, 229, 199, "Output"]
}, Open  ]],
Cell[24936643, 624047, 1059, 25, 67, "Text"],
Cell[CellGroupData[{
Cell[24937727, 624076, 4491, 111, 182, "Input"],
Cell[24942221, 624189, 24084, 1009, 321, "Output"]
}, Open  ]],
Cell[24966320, 625201, 2125, 29, 46, "Text"],
Cell[CellGroupData[{
Cell[24968470, 625234, 1040, 26, 63, "Input"],
Cell[24969513, 625262, 27693, 1163, 366, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24997243, 626430, 405, 11, 28, "Input"],
Cell[24997651, 626443, 147, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24997835, 626451, 322, 7, 28, "Input"],
Cell[24998160, 626460, 344, 5, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24998541, 626470, 410, 9, 28, "Input"],
Cell[24998954, 626481, 338, 5, 28, "Output"]
}, Open  ]],
Cell[24999307, 626489, 869, 15, 46, "Text"],
Cell[CellGroupData[{
Cell[25000201, 626508, 1000, 22, 28, "Input"],
Cell[25001204, 626532, 5420, 178, 100, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25006661, 626715, 1241, 40, 63, "Input"],
Cell[25007905, 626757, 1855, 60, 114, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25009797, 626822, 202, 4, 28, "Input"],
Cell[25010002, 626828, 553, 17, 47, "Output"]
}, Open  ]],
Cell[25010570, 626848, 960, 19, 46, "Text"],
Cell[CellGroupData[{
Cell[25011555, 626871, 857, 22, 46, "Input"],
Cell[25012415, 626895, 342, 6, 28, "Output"]
}, Open  ]],
Cell[25012772, 626904, 1199, 27, 85, "Text"],
Cell[CellGroupData[{
Cell[25013996, 626935, 5237, 130, 250, "Input"],
Cell[25019236, 627067, 82353, 3194, 698, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25101626, 630266, 396, 10, 28, "Input"],
Cell[25102025, 630278, 23897, 997, 278, "Output"]
}, Open  ]],
Cell[25125937, 631278, 936, 17, 46, "Text"],
Cell[CellGroupData[{
Cell[25126898, 631299, 1796, 56, 80, "Input"],
Cell[25128697, 631357, 5833, 253, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25134567, 631615, 734, 19, 46, "Input"],
Cell[25135304, 631636, 10247, 441, 96, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25145588, 632082, 817, 23, 63, "Input"],
Cell[25146408, 632107, 26309, 1087, 278, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25172754, 633199, 203, 4, 28, "Input"],
Cell[25172960, 633205, 10139, 349, 118, "Output"]
}, Open  ]],
Cell[25183114, 633557, 1006, 18, 46, "Text"],
Cell[CellGroupData[{
Cell[25184145, 633579, 296, 7, 28, "Input"],
Cell[25184444, 633588, 8490, 358, 98, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25192971, 633951, 318, 7, 28, "Input"],
Cell[25193292, 633960, 146, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25193475, 633968, 320, 7, 28, "Input"],
Cell[25193798, 633977, 147, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25193982, 633985, 399, 10, 28, "Input"],
Cell[25194384, 633997, 172, 3, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25194593, 634005, 707, 20, 46, "Input"],
Cell[25195303, 634027, 873, 35, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25196213, 634067, 611, 19, 46, "Input"],
Cell[25196827, 634088, 779, 34, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25197643, 634127, 611, 19, 46, "Input"],
Cell[25198257, 634148, 779, 34, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25199073, 634187, 613, 19, 46, "Input"],
Cell[25199689, 634208, 779, 34, 53, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)

